@@ -6,7 +6,6 @@
  */
 
 use Drupal\Core\Database\Database;
-use Drupal\Core\File\FileSystemInterface;
 use Drupal\Core\Link;
 use Drupal\Core\Url;
 use Drupal\Core\Utility\UpdateException;
@@ -180,14 +179,22 @@ function hook_module_preinstall($module) {
  *
  * @param $modules
  *   An array of the modules that were installed.
+ * @param bool $is_syncing
+ *   TRUE if the module is being installed as part of a configuration import. In
+ *   these cases, your hook implementation needs to carefully consider what
+ *   changes, if any, it should make. For example, it should not make any
+ *   changes to configuration objects or entities.
  *
  * @see \Drupal\Core\Extension\ModuleInstaller::install()
  * @see hook_install()
  */
-function hook_modules_installed($modules) {
+function hook_modules_installed($modules, $is_syncing) {
   if (in_array('lousy_module', $modules)) {
     \Drupal::state()->set('mymodule.lousy_module_compatibility', TRUE);
   }
+  if (!$is_syncing) {
+    \Drupal::service('mymodule.service')->doSomething($modules);
+  }
 }
 
 /**
@@ -220,15 +227,21 @@ function hook_modules_installed($modules) {
  * Please be sure that anything added or modified in this function that can
  * be removed during uninstall should be removed with hook_uninstall().
  *
+ * @param bool $is_syncing
+ *   TRUE if the module is being installed as part of a configuration import. In
+ *   these cases, your hook implementation needs to carefully consider what
+ *   changes, if any, it should make. For example, it should not make any
+ *   changes to configuration objects or entities.
+ *
+ * @see \Drupal\Core\Config\ConfigInstallerInterface::isSyncing
  * @see hook_schema()
  * @see \Drupal\Core\Extension\ModuleInstaller::install()
  * @see hook_uninstall()
  * @see hook_modules_installed()
  */
-function hook_install() {
-  // Create the styles directory and ensure it's writable.
-  $directory = \Drupal::config('system.file')->get('default_scheme') . '://styles';
-  \Drupal::service('file_system')->prepareDirectory($directory, FileSystemInterface::CREATE_DIRECTORY | FileSystemInterface::MODIFY_PERMISSIONS);
+function hook_install($is_syncing) {
+  // Set general module variables.
+  \Drupal::state()->set('mymodule.foo', 'bar');
 }
 
 /**
@@ -253,14 +266,22 @@ function hook_module_preuninstall($module) {
  *
  * @param $modules
  *   An array of the modules that were uninstalled.
+ * @param bool $is_syncing
+ *   TRUE if the module is being uninstalled as part of a configuration import.
+ *   In these cases, your hook implementation needs to carefully consider what
+ *   changes, if any, it should make. For example, it should not make any
+ *   changes to configuration objects or entities.
  *
  * @see hook_uninstall()
  */
-function hook_modules_uninstalled($modules) {
+function hook_modules_uninstalled($modules, $is_syncing) {
   if (in_array('lousy_module', $modules)) {
     \Drupal::state()->delete('mymodule.lousy_module_compatibility');
   }
   mymodule_cache_rebuild();
+  if (!$is_syncing) {
+    \Drupal::service('mymodule.service')->doSomething($modules);
+  }
 }
 
 /**
@@ -278,13 +299,19 @@ function hook_modules_uninstalled($modules) {
  * tables are removed, allowing your module to query its own tables during
  * this routine.
  *
+ * @param bool $is_syncing
+ *   TRUE if the module is being uninstalled as part of a configuration import.
+ *   In these cases, your hook implementation needs to carefully consider what
+ *   changes, if any, it should make. For example, it should not make any
+ *   changes to configuration objects or entities.
+ *
  * @see hook_install()
  * @see hook_schema()
  * @see hook_modules_uninstalled()
  */
-function hook_uninstall() {
-  // Remove the styles directory and generated images.
-  \Drupal::service('file_system')->deleteRecursive(\Drupal::config('system.file')->get('default_scheme') . '://styles');
+function hook_uninstall($is_syncing) {
+  // Delete remaining general module variables.
+  \Drupal::state()->delete('mymodule.foo');
 }
 
 /**
@@ -394,51 +421,51 @@ function hook_install_tasks(&$install_state) {
   // Here, we define a variable to allow tasks to indicate that a particular,
   // processor-intensive batch process needs to be triggered later on in the
   // installation.
-  $myprofile_needs_batch_processing = \Drupal::state()->get('myprofile.needs_batch_processing', FALSE);
+  $my_profile_needs_batch_processing = \Drupal::state()->get('my_profile.needs_batch_processing', FALSE);
   $tasks = [
     // This is an example of a task that defines a form which the user who is
     // installing the site will be asked to fill out. To implement this task,
-    // your profile would define a function named myprofile_data_import_form()
+    // your profile would define a function named my_profile_data_import_form()
     // as a normal form API callback function, with associated validation and
     // submit handlers. In the submit handler, in addition to saving whatever
     // other data you have collected from the user, you might also call
-    // \Drupal::state()->set('myprofile.needs_batch_processing', TRUE) if the
+    // \Drupal::state()->set('my_profile.needs_batch_processing', TRUE) if the
     // user has entered data which requires that batch processing will need to
     // occur later on.
-    'myprofile_data_import_form' => [
+    'my_profile_data_import_form' => [
       'display_name' => t('Data import options'),
       'type' => 'form',
     ],
     // Similarly, to implement this task, your profile would define a function
-    // named myprofile_settings_form() with associated validation and submit
+    // named my_profile_settings_form() with associated validation and submit
     // handlers. This form might be used to collect and save additional
     // information from the user that your profile needs. There are no extra
     // steps required for your profile to act as an "installation wizard"; you
     // can simply define as many tasks of type 'form' as you wish to execute,
     // and the forms will be presented to the user, one after another.
-    'myprofile_settings_form' => [
+    'my_profile_settings_form' => [
       'display_name' => t('Additional options'),
       'type' => 'form',
     ],
     // This is an example of a task that performs batch operations. To
     // implement this task, your profile would define a function named
-    // myprofile_batch_processing() which returns a batch API array definition
+    // my_profile_batch_processing() which returns a batch API array definition
     // that the installer will use to execute your batch operations. Due to the
-    // 'myprofile.needs_batch_processing' variable used here, this task will be
+    // 'my_profile.needs_batch_processing' variable used here, this task will be
     // hidden and skipped unless your profile set it to TRUE in one of the
     // previous tasks.
-    'myprofile_batch_processing' => [
+    'my_profile_batch_processing' => [
       'display_name' => t('Import additional data'),
-      'display' => $myprofile_needs_batch_processing,
+      'display' => $my_profile_needs_batch_processing,
       'type' => 'batch',
-      'run' => $myprofile_needs_batch_processing ? INSTALL_TASK_RUN_IF_NOT_COMPLETED : INSTALL_TASK_SKIP,
+      'run' => $my_profile_needs_batch_processing ? INSTALL_TASK_RUN_IF_NOT_COMPLETED : INSTALL_TASK_SKIP,
     ],
     // This is an example of a task that will not be displayed in the list that
     // the user sees. To implement this task, your profile would define a
-    // function named myprofile_final_site_setup(), in which additional,
+    // function named my_profile_final_site_setup(), in which additional,
     // automated site setup operations would be performed. Since this is the
     // last task defined by your profile, you should also use this function to
-    // call \Drupal::state()->delete('myprofile.needs_batch_processing') and
+    // call \Drupal::state()->delete('my_profile.needs_batch_processing') and
     // clean up the state that was used above. If you want the user to pass
     // to the final Drupal installation tasks uninterrupted, return no output
     // from this function. Otherwise, return themed output that the user will
@@ -446,7 +473,7 @@ function hook_install_tasks(&$install_state) {
     // tasks are complete, with a link to reload the current page and therefore
     // pass on to the final Drupal installation tasks when the user is ready to
     // do so).
-    'myprofile_final_site_setup' => [],
+    'my_profile_final_site_setup' => [],
   ];
   return $tasks;
 }
@@ -472,7 +499,7 @@ function hook_install_tasks(&$install_state) {
 function hook_install_tasks_alter(&$tasks, $install_state) {
   // Replace the entire site configuration form provided by Drupal core
   // with a custom callback function defined by this installation profile.
-  $tasks['install_configure_form']['function'] = 'myprofile_install_configure_form';
+  $tasks['install_configure_form']['function'] = 'my_profile_install_configure_form';
 }
 
 /**
@@ -547,9 +574,6 @@ function hook_install_tasks_alter(&$tasks, $install_state) {
  *   \Drupal::entityDefinitionUpdateManager()::getFieldStorageDefinition(). When
  *   adding a new definition always replicate it in the update function body as
  *   you would do with a schema definition.
- * - Never call \Drupal::entityDefinitionUpdateManager()::applyUpdates() in an
- *   update function, as it will apply updates for any module not only yours,
- *   which will lead to unpredictable results.
  * - Be careful about API functions and especially CRUD operations that you use
  *   in your update function. If they invoke hooks or use services, they may
  *   not behave as expected, and it may actually not be appropriate to use the
@@ -608,8 +632,6 @@ function hook_install_tasks_alter(&$tasks, $install_state) {
  * @see hook_update_last_removed()
  * @see update_get_update_list()
  * @see \Drupal\Core\Entity\EntityDefinitionUpdateManagerInterface
- * @see node_update_8001
- * @see system_update_8004
  * @see https://www.drupal.org/node/2535316
  */
 function hook_update_N(&$sandbox) {
@@ -625,7 +647,7 @@ function hook_update_N(&$sandbox) {
     'not null' => FALSE,
   ];
   $schema = Database::getConnection()->schema();
-  $schema->addField('mytable1', 'newcol', $spec);
+  $schema->addField('my_table', 'newcol', $spec);
 
   // Example of what to do if there is an error during your update.
   if ($some_error_condition_met) {
@@ -638,26 +660,26 @@ function hook_update_N(&$sandbox) {
     // This must be the first run. Initialize the sandbox.
     $sandbox['progress'] = 0;
     $sandbox['current_pk'] = 0;
-    $sandbox['max'] = Database::getConnection()->query('SELECT COUNT(myprimarykey) FROM {mytable1}')->fetchField();
+    $sandbox['max'] = Database::getConnection()->query('SELECT COUNT([my_primary_key]) FROM {my_table}')->fetchField();
   }
 
   // Update in chunks of 20.
-  $records = Database::getConnection()->select('mytable1', 'm')
-    ->fields('m', ['myprimarykey', 'otherfield'])
-    ->condition('myprimarykey', $sandbox['current_pk'], '>')
+  $records = Database::getConnection()->select('my_table', 'm')
+    ->fields('m', ['my_primary_key', 'other_field'])
+    ->condition('my_primary_key', $sandbox['current_pk'], '>')
     ->range(0, 20)
-    ->orderBy('myprimarykey', 'ASC')
+    ->orderBy('my_primary_key', 'ASC')
     ->execute();
   foreach ($records as $record) {
     // Here, you would make an update something related to this record. In this
     // example, some text is added to the other field.
-    Database::getConnection()->update('mytable1')
-      ->fields(['otherfield' => $record->otherfield . '-suffix'])
-      ->condition('myprimarykey', $record->myprimarykey)
+    Database::getConnection()->update('my_table')
+      ->fields(['other_field' => $record->other_field . '-suffix'])
+      ->condition('my_primary_key', $record->my_primary_key)
       ->execute();
 
     $sandbox['progress']++;
-    $sandbox['current_pk'] = $record->myprimarykey;
+    $sandbox['current_pk'] = $record->my_primary_key;
   }
 
   $sandbox['#finished'] = empty($sandbox['max']) ? 1 : ($sandbox['progress'] / $sandbox['max']);
@@ -724,25 +746,10 @@ function hook_post_update_NAME(&$sandbox) {
 
   $result = t('Node %nid saved', ['%nid' => $node->id()]);
 
-  // Example of disabling blocks with missing condition contexts. Note: The
-  // block itself is in a state which is valid at that point.
-  // @see block_update_8001()
-  // @see block_post_update_disable_blocks_with_missing_contexts()
-  $block_update_8001 = \Drupal::keyValue('update_backup')->get('block_update_8001', []);
-
-  $block_ids = array_keys($block_update_8001);
-  $block_storage = \Drupal::entityTypeManager()->getStorage('block');
-  $blocks = $block_storage->loadMultiple($block_ids);
-  /** @var $blocks \Drupal\block\BlockInterface[] */
-  foreach ($blocks as $block) {
-    // This block has had conditions removed due to an inability to resolve
-    // contexts in block_update_8001() so disable it.
-
-    // Disable currently enabled blocks.
-    if ($block_update_8001[$block->id()]['status']) {
-      $block->setStatus(FALSE);
-      $block->save();
-    }
+  // Example of updating some config.
+  if (\Drupal::moduleHandler()->moduleExists('taxonomy')) {
+    // Update the dependencies of all Vocabulary configuration entities.
+    \Drupal::classResolver(\Drupal\Core\Config\Entity\ConfigEntityUpdater::class)->update($sandbox, 'taxonomy_vocabulary');
   }
 
   return $result;
@@ -980,8 +987,8 @@ function hook_requirements($phase) {
     'title' => t('PHP'),
     'value' => ($phase == 'runtime') ? Link::fromTextAndUrl(phpversion(), Url::fromRoute('system.php'))->toString() : phpversion(),
   ];
-  if (version_compare(phpversion(), DRUPAL_MINIMUM_PHP) < 0) {
-    $requirements['php']['description'] = t('Your PHP installation is too old. Drupal requires at least PHP %version.', ['%version' => DRUPAL_MINIMUM_PHP]);
+  if (version_compare(phpversion(), \Drupal::MINIMUM_PHP) < 0) {
+    $requirements['php']['description'] = t('Your PHP installation is too old. Drupal requires at least PHP %version.', ['%version' => \Drupal::MINIMUM_PHP]);
     $requirements['php']['severity'] = REQUIREMENT_ERROR;
   }
 
