@@ -9,8 +9,8 @@ use Drupal\Core\Cache\CacheBackendInterface;
 use Drupal\Core\Cache\CacheTagsInvalidatorInterface;
 use Drupal\Core\Database\Connection;
 use Drupal\Core\Database\Database;
+use Drupal\Core\Database\DatabaseException;
 use Drupal\Core\Database\Query\SelectInterface;
-use Drupal\Core\Database\SchemaObjectExistsException;
 
 /**
  * Provides a menu tree storage using the database.
@@ -1002,8 +1002,8 @@ class MenuTreeStorage implements MenuTreeStorageInterface {
     $route_names = [];
     foreach (array_keys($tree) as $id) {
       $definitions[$id] = $this->definitions[$id];
-      if (!empty($definition['route_name'])) {
-        $route_names[$definition['route_name']] = $definition['route_name'];
+      if (!empty($definitions[$id]['route_name'])) {
+        $route_names[$definitions[$id]['route_name']] = $definitions[$id]['route_name'];
       }
       if ($tree[$id]['subtree']) {
         $route_names += $this->doCollectRoutesAndDefinitions($tree[$id]['subtree'], $definitions);
@@ -1168,7 +1168,7 @@ class MenuTreeStorage implements MenuTreeStorageInterface {
         return TRUE;
       }
     }
-    catch (SchemaObjectExistsException $e) {
+    catch (DatabaseException $e) {
       // If another process has already created the config table, attempting to
       // recreate it will throw an exception. In this case just catch the
       // exception and do nothing.
@@ -1247,7 +1247,7 @@ class MenuTreeStorage implements MenuTreeStorageInterface {
           'default' => '',
         ],
         'route_name' => [
-          'description' => 'The machine name of a defined Symfony Route this menu item represents.',
+          'description' => 'The machine name of a defined Symfony Route this menu link represents.',
           'type' => 'varchar_ascii',
           'length' => 255,
         ],
@@ -1304,7 +1304,7 @@ class MenuTreeStorage implements MenuTreeStorageInterface {
           'default' => 'system',
         ],
         'enabled' => [
-          'description' => 'A flag for whether the link should be rendered in menus. (0 = a disabled menu item that may be shown on admin screens, 1 = a normal, visible link)',
+          'description' => 'A flag for whether the link should be rendered in menus. (0 = a disabled menu link that may be shown on admin screens, 1 = a normal, visible link)',
           'type' => 'int',
           'not null' => TRUE,
           'default' => 1,
@@ -1459,6 +1459,7 @@ class MenuTreeStorage implements MenuTreeStorageInterface {
    *
    * @param array $definitions
    *   The new menu link definitions.
+   *
    * @return array
    *   A list of menu link IDs that no longer exist.
    */
