@@ -57,12 +57,15 @@ trait AssertMailTrait {
    *   this default.
    *
    * @return bool
-   *   TRUE on pass, FALSE on fail.
+   *   TRUE on pass.
    */
   protected function assertMail($name, $value = '', $message = '', $group = 'Email') {
     $captured_emails = $this->container->get('state')->get('system.test_mail_collector') ?: [];
     $email = end($captured_emails);
-    return $this->assertTrue($email && isset($email[$name]) && $email[$name] == $value, $message, $group);
+    $this->assertIsArray($email, $message);
+    $this->assertArrayHasKey($name, $email, $message);
+    $this->assertEquals($value, $email[$name], $message);
+    return TRUE;
   }
 
   /**
@@ -84,9 +87,6 @@ trait AssertMailTrait {
    *   in test output. Use 'Debug' to indicate this is debugging output. Do not
    *   translate this string. Defaults to 'Other'; most tests do not override
    *   this default.
-   *
-   * @return bool
-   *   TRUE on pass, FALSE on fail.
    */
   protected function assertMailString($field_name, $string, $email_depth, $message = '', $group = 'Other') {
     $mails = $this->getMails();
@@ -107,7 +107,7 @@ trait AssertMailTrait {
     if (!$message) {
       $message = new FormattableMarkup('Expected text found in @field of email message: "@expected".', ['@field' => $field_name, '@expected' => $string]);
     }
-    return $this->assertTrue($string_found, $message, $group);
+    $this->assertTrue($string_found, $message, $group);
   }
 
   /**
@@ -127,9 +127,6 @@ trait AssertMailTrait {
    *   in test output. Use 'Debug' to indicate this is debugging output. Do not
    *   translate this string. Defaults to 'Other'; most tests do not override
    *   this default.
-   *
-   * @return bool
-   *   TRUE on pass, FALSE on fail.
    */
   protected function assertMailPattern($field_name, $regex, $message = '', $group = 'Other') {
     $mails = $this->getMails();
@@ -138,7 +135,7 @@ trait AssertMailTrait {
     if (!$message) {
       $message = new FormattableMarkup('Expected text found in @field of email message: "@expected".', ['@field' => $field_name, '@expected' => $regex]);
     }
-    return $this->assertTrue($regex_found, $message, $group);
+    $this->assertTrue((bool) $regex_found, $message, $group);
   }
 
   /**
