@@ -15,12 +15,12 @@ class MigrateAggregatorItemTest extends MigrateDrupal6TestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['aggregator'];
+  protected static $modules = ['aggregator'];
 
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $this->installEntitySchema('aggregator_feed');
     $this->installEntitySchema('aggregator_item');
@@ -33,15 +33,15 @@ class MigrateAggregatorItemTest extends MigrateDrupal6TestBase {
   public function testAggregatorItem() {
     /** @var \Drupal\aggregator\Entity\Item $item */
     $item = Item::load(1);
-    $this->assertIdentical('1', $item->id());
-    $this->assertIdentical('5', $item->getFeedId());
-    $this->assertIdentical('This (three) weeks in Drupal Core - January 10th 2014', $item->label());
-    $this->assertIdentical('larowlan', $item->getAuthor());
-    $this->assertIdentical("<h2 id='new'>What's new with Drupal 8?</h2>", $item->getDescription());
-    $this->assertIdentical('https://groups.drupal.org/node/395218', $item->getLink());
-    $this->assertIdentical('1389297196', $item->getPostedTime());
-    $this->assertIdentical('en', $item->language()->getId());
-    $this->assertIdentical('395218 at https://groups.drupal.org', $item->getGuid());
+    $this->assertSame('1', $item->id());
+    $this->assertSame('5', $item->getFeedId());
+    $this->assertSame('This (three) weeks in Drupal Core - January 10th 2014', $item->label());
+    $this->assertSame('larowlan', $item->getAuthor());
+    $this->assertSame("<h2 id='new'>What's new with Drupal 8?</h2>", $item->getDescription());
+    $this->assertSame('https://groups.drupal.org/node/395218', $item->getLink());
+    $this->assertSame('1389297196', $item->getPostedTime());
+    $this->assertSame('en', $item->language()->getId());
+    $this->assertSame('395218 at https://groups.drupal.org', $item->getGuid());
 
   }
 
