@@ -85,21 +85,21 @@ class BlockCacheTest extends BrowserTestBase {
     \Drupal::state()->set('block_test.content', $current_content);
     $this->drupalLogin($this->normalUser);
     $this->drupalGet('');
-    $this->assertText($current_content);
+    $this->assertSession()->pageTextContains($current_content);
 
     // Change the content, but the cached copy should still be served.
     $old_content = $current_content;
     $current_content = $this->randomMachineName();
     \Drupal::state()->set('block_test.content', $current_content);
     $this->drupalGet('');
-    $this->assertText($old_content);
+    $this->assertSession()->pageTextContains($old_content);
 
     // Clear the cache and verify that the stale data is no longer there.
     Cache::invalidateTags(['block_view']);
     $this->drupalGet('');
     $this->assertNoText($old_content);
     // Fresh block content is displayed after clearing the cache.
-    $this->assertText($current_content);
+    $this->assertSession()->pageTextContains($current_content);
 
     // Test whether the cached data is served for the correct users.
     $old_content = $current_content;
@@ -113,7 +113,7 @@ class BlockCacheTest extends BrowserTestBase {
     // User with the same roles sees per-role cached content.
     $this->drupalLogin($this->normalUserAlt);
     $this->drupalGet('');
-    $this->assertText($old_content);
+    $this->assertSession()->pageTextContains($old_content);
 
     // Admin user does not see content cached per-role for normal user.
     $this->drupalLogin($this->adminUser);
@@ -123,7 +123,7 @@ class BlockCacheTest extends BrowserTestBase {
     // Block is served from the per-role cache.
     $this->drupalLogin($this->normalUser);
     $this->drupalGet('');
-    $this->assertText($old_content);
+    $this->assertSession()->pageTextContains($old_content);
   }
 
   /**
@@ -138,7 +138,7 @@ class BlockCacheTest extends BrowserTestBase {
     \Drupal::state()->set('block_test.content', $current_content);
 
     $this->drupalGet('');
-    $this->assertText($current_content);
+    $this->assertSession()->pageTextContains($current_content);
 
     $old_content = $current_content;
     $current_content = $this->randomMachineName();
@@ -146,12 +146,12 @@ class BlockCacheTest extends BrowserTestBase {
 
     // Block content served from cache.
     $this->drupalGet('user');
-    $this->assertText($old_content);
+    $this->assertSession()->pageTextContains($old_content);
 
     // Block content not served from cache.
     $this->drupalLogout();
     $this->drupalGet('user');
-    $this->assertText($current_content);
+    $this->assertSession()->pageTextContains($current_content);
   }
 
   /**
@@ -165,14 +165,14 @@ class BlockCacheTest extends BrowserTestBase {
 
     // If max_age = 0 has no effect, the next request would be cached.
     $this->drupalGet('');
-    $this->assertText($current_content);
+    $this->assertSession()->pageTextContains($current_content);
 
     // A cached copy should not be served.
     $current_content = $this->randomMachineName();
     \Drupal::state()->set('block_test.content', $current_content);
     $this->drupalGet('');
     // Maximum age of zero prevents blocks from being cached.
-    $this->assertText($current_content);
+    $this->assertSession()->pageTextContains($current_content);
   }
 
   /**
@@ -186,7 +186,7 @@ class BlockCacheTest extends BrowserTestBase {
     $this->drupalLogin($this->normalUser);
 
     $this->drupalGet('');
-    $this->assertText($current_content);
+    $this->assertSession()->pageTextContains($current_content);
 
     $old_content = $current_content;
     $current_content = $this->randomMachineName();
@@ -194,17 +194,17 @@ class BlockCacheTest extends BrowserTestBase {
 
     // Block is served from per-user cache.
     $this->drupalGet('');
-    $this->assertText($old_content);
+    $this->assertSession()->pageTextContains($old_content);
 
     // Per-user block cache is not served for other users.
     $this->drupalLogin($this->normalUserAlt);
     $this->drupalGet('');
-    $this->assertText($current_content);
+    $this->assertSession()->pageTextContains($current_content);
 
     // Per-user block cache is persistent.
     $this->drupalLogin($this->normalUser);
     $this->drupalGet('');
-    $this->assertText($old_content);
+    $this->assertSession()->pageTextContains($old_content);
   }
 
   /**
@@ -217,7 +217,7 @@ class BlockCacheTest extends BrowserTestBase {
     \Drupal::state()->set('block_test.content', $current_content);
 
     $this->drupalGet('test-page');
-    $this->assertText($current_content);
+    $this->assertSession()->pageTextContains($current_content);
 
     $old_content = $current_content;
     $current_content = $this->randomMachineName();
@@ -231,7 +231,7 @@ class BlockCacheTest extends BrowserTestBase {
     $this->drupalGet('test-page');
     $this->assertSession()->statusCodeEquals(200);
     // Verify that the block content is cached for the test page.
-    $this->assertText($old_content);
+    $this->assertSession()->pageTextContains($old_content);
   }
 
 }
