@@ -43,25 +43,25 @@ class BlockFormInBlockTest extends BrowserTestBase {
     // Go to "test-page" and test if the block is enabled.
     $this->drupalGet('test-page');
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertText('Your .com email address.');
+    $this->assertSession()->pageTextContains('Your .com email address.');
 
     // Make sure that we're currently still on /test-page after submitting the
     // form.
     $this->submitForm($form_values, 'Submit');
     $this->assertSession()->addressEquals('test-page');
-    $this->assertText('Your email address is test@example.com');
+    $this->assertSession()->pageTextContains('Your email address is test@example.com');
 
     // Go to a different page and see if the block is enabled there as well.
     $this->drupalGet('test-render-title');
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertText('Your .com email address.');
+    $this->assertSession()->pageTextContains('Your .com email address.');
 
     // Make sure that submitting the form didn't redirect us to the first page
     // we submitted the form from after submitting the form from
     // /test-render-title.
     $this->submitForm($form_values, 'Submit');
     $this->assertSession()->addressEquals('test-render-title');
-    $this->assertText('Your email address is test@example.com');
+    $this->assertSession()->pageTextContains('Your email address is test@example.com');
   }
 
   /**
@@ -71,7 +71,7 @@ class BlockFormInBlockTest extends BrowserTestBase {
     $this->drupalGet('test-multiple-forms');
 
     $placeholder = 'form_action_' . Crypt::hashBase64('Drupal\Core\Form\FormBuilder::prepareForm');
-    $this->assertText('Form action: ' . $placeholder);
+    $this->assertSession()->pageTextContains('Form action: ' . $placeholder);
   }
 
 }
