@@ -93,8 +93,7 @@ class BlockUiTest extends BrowserTestBase {
     $this->drupalPlaceBlock('help_block', ['region' => 'help']);
     $this->drupalGet('admin/structure/block');
     $this->clickLink(t('Demonstrate block regions (@theme)', ['@theme' => 'Classy']));
-    $elements = $this->xpath('//div[contains(@class, "region-highlighted")]/div[contains(@class, "block-region") and contains(text(), :title)]', [':title' => 'Highlighted']);
-    $this->assertTrue(!empty($elements), 'Block demo regions are shown.');
+    $this->assertSession()->elementExists('xpath', '//div[contains(@class, "region-highlighted")]/div[contains(@class, "block-region") and contains(text(), "Highlighted")]');
 
     // Ensure that other themes can use the block demo page.
     \Drupal::service('theme_installer')->install(['test_theme']);
@@ -131,7 +130,8 @@ class BlockUiTest extends BrowserTestBase {
       // Change the test block's weight.
       $edit['blocks[' . $values['settings']['id'] . '][weight]'] = $values['test_weight'];
     }
-    $this->drupalPostForm('admin/structure/block', $edit, 'Save blocks');
+    $this->drupalGet('admin/structure/block');
+    $this->submitForm($edit, 'Save blocks');
     foreach ($this->blockValues as $values) {
       // Check if the region and weight settings changes have persisted.
       $this->assertTrue($this->assertSession()->optionExists('edit-blocks-' . $values['settings']['id'] . '-region', 'header')->isSelected());
@@ -201,16 +201,10 @@ class BlockUiTest extends BrowserTestBase {
    * Tests the behavior of unsatisfied context-aware blocks.
    */
   public function testContextAwareUnsatisfiedBlocks() {
-    $arguments = [
-      ':category' => 'Block test',
-      ':href' => 'admin/structure/block/add/test_context_aware_unsatisfied/classy',
-      ':text' => 'Test context-aware unsatisfied block',
-    ];
-
     $this->drupalGet('admin/structure/block');
     $this->clickLink('Place block');
-    $elements = $this->xpath('//tr[.//td/div[text()=:text] and .//td[text()=:category] and .//td//a[contains(@href, :href)]]', $arguments);
-    $this->assertTrue(empty($elements), 'The context-aware test block does not appear.');
+    // Verify that the context-aware test block does not appear.
+    $this->assertSession()->elementNotExists('xpath', '//tr[.//td/div[text()="Test context-aware unsatisfied block"] and .//td[text()="Block test"] and .//td//a[contains(@href, "admin/structure/block/add/test_context_aware_unsatisfied/classy")]]');
 
     $definition = \Drupal::service('plugin.manager.block')->getDefinition('test_context_aware_unsatisfied');
     $this->assertTrue(!empty($definition), 'The context-aware test block does not exist.');
@@ -243,11 +237,12 @@ class BlockUiTest extends BrowserTestBase {
       'region' => 'content',
       'settings[context_mapping][user]' => '@block_test.multiple_static_context:userB',
     ];
-    $this->drupalPostForm($block_url, $edit, 'Save block');
+    $this->drupalGet($block_url);
+    $this->submitForm($edit, 'Save block');
 
     $this->drupalGet('');
-    $this->assertText('Test context-aware block');
-    $this->assertText('User context found.');
+    $this->assertSession()->pageTextContains('Test context-aware block');
+    $this->assertSession()->pageTextContains('User context found.');
     $this->assertRaw($expected_text);
 
     // Test context mapping form element is not visible if there are no valid
@@ -264,7 +259,7 @@ class BlockUiTest extends BrowserTestBase {
     ];
     $this->submitForm($edit, 'Save block');
     $this->drupalGet('');
-    $this->assertText('No context mapping selected.');
+    $this->assertSession()->pageTextContains('No context mapping selected.');
     $this->assertNoText('User context found.');
 
     // Tests that conditions with missing context are not displayed.
@@ -283,14 +278,16 @@ class BlockUiTest extends BrowserTestBase {
     $this->drupalGet($url);
     $this->assertSession()->fieldValueEquals('id', 'displaymessage');
     $edit = ['region' => 'content'];
-    $this->drupalPostForm($url, $edit, 'Save block');
-    $this->assertText('The block configuration has been saved.');
+    $this->drupalGet($url);
+    $this->submitForm($edit, 'Save block');
+    $this->assertSession()->pageTextContains('The block configuration has been saved.');
 
     // Now, check to make sure the form starts by autoincrementing correctly.
     $this->drupalGet($url);
     $this->assertSession()->fieldValueEquals('id', 'displaymessage_2');
-    $this->drupalPostForm($url, $edit, 'Save block');
-    $this->assertText('The block configuration has been saved.');
+    $this->drupalGet($url);
+    $this->submitForm($edit, 'Save block');
+    $this->assertSession()->pageTextContains('The block configuration has been saved.');
 
     // And verify that it continues working beyond just the first two.
     $this->drupalGet($url);
@@ -326,7 +323,8 @@ class BlockUiTest extends BrowserTestBase {
     $block['region'] = 'content';
 
     // After adding a block, it will indicate which block was just added.
-    $this->drupalPostForm('admin/structure/block/add/system_powered_by_block', $block, 'Save block');
+    $this->drupalGet('admin/structure/block/add/system_powered_by_block');
+    $this->submitForm($block, 'Save block');
     $this->assertSession()->addressEquals('admin/structure/block/list/classy?block-placement=' . Html::getClass($block['id']));
 
     // Resaving the block page will remove the block placement indicator.
@@ -356,7 +354,11 @@ class BlockUiTest extends BrowserTestBase {
    * Tests if validation errors are passed plugin form to the parent form.
    */
   public function testBlockValidateErrors() {
-    $this->drupalPostForm('admin/structure/block/add/test_settings_validation/classy', ['region' => 'content', 'settings[digits]' => 'abc'], 'Save block');
+    $this->drupalGet('admin/structure/block/add/test_settings_validation/classy');
+    $this->submitForm([
+      'region' => 'content',
+      'settings[digits]' => 'abc',
+    ], 'Save block');
 
     $arguments = [':message' => 'Only digits are allowed'];
     $pattern = '//div[contains(@class,"messages messages--error")]/div[contains(text()[2],:message)]';
