@@ -56,7 +56,8 @@ class BlockContentCreationTest extends BlockContentTestBase {
     $edit = [];
     $edit['info[0][value]'] = 'Test Block';
     $edit['body[0][value]'] = $this->randomMachineName(16);
-    $this->drupalPostForm('block/add/basic', $edit, 'Save');
+    $this->drupalGet('block/add/basic');
+    $this->submitForm($edit, 'Save');
 
     // Check that the Basic block has been created.
     $this->assertRaw(new FormattableMarkup('@block %name has been created.', [
@@ -76,7 +77,8 @@ class BlockContentCreationTest extends BlockContentTestBase {
 
     // Check that attempting to create another block with the same value for
     // 'info' returns an error.
-    $this->drupalPostForm('block/add/basic', $edit, 'Save');
+    $this->drupalGet('block/add/basic');
+    $this->submitForm($edit, 'Save');
 
     // Check that the Basic block has been created.
     $this->assertRaw(new FormattableMarkup('A custom block with block description %value already exists.', [
@@ -105,7 +107,8 @@ class BlockContentCreationTest extends BlockContentTestBase {
     $edit = [];
     $edit['info[0][value]'] = 'Test Block';
     $edit['body[0][value]'] = $this->randomMachineName(16);
-    $this->drupalPostForm('block/add/basic', $edit, 'Save');
+    $this->drupalGet('block/add/basic');
+    $this->submitForm($edit, 'Save');
 
     // Check that the Basic block has been created.
     $this->assertRaw(new FormattableMarkup('@block %name has been created.', [
@@ -160,7 +163,8 @@ class BlockContentCreationTest extends BlockContentTestBase {
 
     // Check that attempting to create another block with the same value for
     // 'info' returns an error.
-    $this->drupalPostForm('block/add/basic', $edit, 'Save');
+    $this->drupalGet('block/add/basic');
+    $this->submitForm($edit, 'Save');
 
     // Check that the Basic block has been created.
     $this->assertRaw(new FormattableMarkup('A custom block with block description %value already exists.', [
@@ -180,7 +184,8 @@ class BlockContentCreationTest extends BlockContentTestBase {
     $edit['info[0][value]'] = $this->randomMachineName(8);
     $edit['body[0][value]'] = $this->randomMachineName(16);
     // Don't pass the custom block type in the url so the default is forced.
-    $this->drupalPostForm('block/add', $edit, 'Save');
+    $this->drupalGet('block/add');
+    $this->submitForm($edit, 'Save');
 
     // Check that the block has been created and that it is a basic block.
     $this->assertRaw(new FormattableMarkup('@block %name has been created.', [
@@ -229,7 +234,8 @@ class BlockContentCreationTest extends BlockContentTestBase {
     $edit['info[0][value]'] = $this->randomMachineName(8);
     $body = $this->randomMachineName(16);
     $edit['body[0][value]'] = $body;
-    $this->drupalPostForm('block/add/basic', $edit, 'Save');
+    $this->drupalGet('block/add/basic');
+    $this->submitForm($edit, 'Save');
 
     // Place the block.
     $instance = [
@@ -239,7 +245,8 @@ class BlockContentCreationTest extends BlockContentTestBase {
     ];
     $block = BlockContent::load(1);
     $url = 'admin/structure/block/add/block_content:' . $block->uuid() . '/' . $this->config('system.theme')->get('default');
-    $this->drupalPostForm($url, $instance, 'Save block');
+    $this->drupalGet($url);
+    $this->submitForm($instance, 'Save block');
 
     $block = BlockContent::load(1);
 
@@ -248,11 +255,11 @@ class BlockContentCreationTest extends BlockContentTestBase {
 
     // Navigate to home page.
     $this->drupalGet('');
-    $this->assertText($body);
+    $this->assertSession()->pageTextContains($body);
 
     // Delete the block.
     $this->drupalGet('block/1/delete');
-    $this->assertText('This will also remove 1 placed block instance.');
+    $this->assertSession()->pageTextContains('This will also remove 1 placed block instance.');
 
     $this->submitForm([], 'Delete');
     $this->assertRaw(t('The custom block %name has been deleted.', ['%name' => $edit['info[0][value]']]));
@@ -262,7 +269,8 @@ class BlockContentCreationTest extends BlockContentTestBase {
     $edit2['info[0][value]'] = $this->randomMachineName(8);
     $body2 = $this->randomMachineName(16);
     $edit2['body[0][value]'] = $body2;
-    $this->drupalPostForm('block/add/basic', $edit2, 'Save');
+    $this->drupalGet('block/add/basic');
+    $this->submitForm($edit2, 'Save');
 
     $this->assertNoRaw('Error message');
 
@@ -272,7 +280,8 @@ class BlockContentCreationTest extends BlockContentTestBase {
     $edit3['info[0][value]'] = $this->randomMachineName(8);
     $body = $this->randomMachineName(16);
     $edit3['body[0][value]'] = $body;
-    $this->drupalPostForm('block/add/basic', $edit3, 'Save');
+    $this->drupalGet('block/add/basic');
+    $this->submitForm($edit3, 'Save');
 
     // Show the delete confirm form.
     $this->drupalGet('block/3/delete');
@@ -293,11 +302,12 @@ class BlockContentCreationTest extends BlockContentTestBase {
     ];
     $block = BlockContent::load(1);
     $url = 'admin/structure/block/add/block_content:' . $block->uuid() . '/' . $this->config('system.theme')->get('default');
-    $this->drupalPostForm($url, $instance, 'Save block');
+    $this->drupalGet($url);
+    $this->submitForm($instance, 'Save block');
 
     $dependencies = \Drupal::service('config.manager')->findConfigEntityDependentsAsEntities('content', [$block->getConfigDependencyName()]);
     $block_placement = reset($dependencies);
-    $this->assertEqual($block_placement_id, $block_placement->id(), "The block placement config entity has a dependency on the block content entity.");
+    $this->assertEquals($block_placement_id, $block_placement->id(), "The block placement config entity has a dependency on the block content entity.");
   }
 
 }
