@@ -19,7 +19,7 @@ class BlockContentEntityReferenceSelectionTest extends KernelTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = [
+  protected static $modules = [
     'block',
     'block_content',
     'block_content_test',
@@ -65,7 +65,7 @@ class BlockContentEntityReferenceSelectionTest extends KernelTestBase {
   /**
    * {@inheritdoc}
    */
-  public function setUp() {
+  public function setUp(): void {
     parent::setUp();
     $this->installSchema('system', ['sequences']);
     $this->installEntitySchema('user');
@@ -121,14 +121,20 @@ class BlockContentEntityReferenceSelectionTest extends KernelTestBase {
    */
   public function testQueriesNotAltered() {
     // Ensure that queries without all the tags are not altered.
-    $query = $this->entityTypeManager->getStorage('block_content')->getQuery();
+    $query = $this->entityTypeManager->getStorage('block_content')
+      ->getQuery()
+      ->accessCheck(FALSE);
     $this->assertCount(2, $query->execute());
 
-    $query = $this->entityTypeManager->getStorage('block_content')->getQuery();
+    $query = $this->entityTypeManager->getStorage('block_content')
+      ->getQuery()
+      ->accessCheck(FALSE);
     $query->addTag('block_content_access');
     $this->assertCount(2, $query->execute());
 
-    $query = $this->entityTypeManager->getStorage('block_content')->getQuery();
+    $query = $this->entityTypeManager->getStorage('block_content')
+      ->getQuery()
+      ->accessCheck(FALSE);
     $query->addTag('entity_query_block_content');
     $this->assertCount(2, $query->execute());
   }
