@@ -17,7 +17,7 @@ class ColorSafePreviewTest extends BrowserTestBase {
    *
    * @var string[]
    */
-  public static $modules = ['color', 'color_test'];
+  protected static $modules = ['color', 'color_test'];
 
   /**
    * {@inheritdoc}
@@ -34,7 +34,7 @@ class ColorSafePreviewTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     // Create user.
@@ -49,11 +49,11 @@ class ColorSafePreviewTest extends BrowserTestBase {
     \Drupal::service('theme_installer')->install(['color_test_theme']);
     $this->drupalLogin($this->bigUser);
 
-    // Markup is being printed from a HTML file located in:
+    // Markup is being printed from an HTML file located in:
     // core/modules/color/tests/modules/color_test/themes/color_test_theme/color/preview.html
     $url = Url::fromRoute('system.theme_settings_theme', ['theme' => 'color_test_theme']);
     $this->drupalGet($url);
-    $this->assertText('TEST COLOR PREVIEW');
+    $this->assertSession()->pageTextContains('TEST COLOR PREVIEW');
 
     $this->assertNoRaw('<script>alert("security filter test");</script>');
     $this->assertRaw('<h2>TEST COLOR PREVIEW</h2>');
