@@ -66,8 +66,8 @@ class CommentNodeAccessTest extends CommentTestBase {
 
     // Check comment display.
     $this->drupalGet('node/' . $this->node->id());
-    $this->assertText($comment_subject);
-    $this->assertText($comment_text);
+    $this->assertSession()->pageTextContains($comment_subject);
+    $this->assertSession()->pageTextContains($comment_text);
 
     // Reply to comment, creating second comment.
     $this->drupalGet('comment/reply/node/' . $this->node->id() . '/comment/' . $comment->id());
@@ -78,10 +78,10 @@ class CommentNodeAccessTest extends CommentTestBase {
 
     // Go to the node page and verify comment and reply are visible.
     $this->drupalGet('node/' . $this->node->id());
-    $this->assertText($comment_text);
-    $this->assertText($comment_subject);
-    $this->assertText($reply_text);
-    $this->assertText($reply_subject);
+    $this->assertSession()->pageTextContains($comment_text);
+    $this->assertSession()->pageTextContains($comment_subject);
+    $this->assertSession()->pageTextContains($reply_text);
+    $this->assertSession()->pageTextContains($reply_subject);
   }
 
 }
