@@ -70,9 +70,10 @@ class ConfigDependencyWebTest extends BrowserTestBase {
     $this->assertNoText('Configuration deletions');
     $this->drupalGet($entity1->toUrl('delete-form'));
     $this->assertNoText('Configuration updates');
-    $this->assertText('Configuration deletions');
-    $this->assertText($entity2->id());
-    $this->drupalPostForm($entity1->toUrl('delete-form'), [], 'Delete');
+    $this->assertSession()->pageTextContains('Configuration deletions');
+    $this->assertSession()->pageTextContains($entity2->id());
+    $this->drupalGet($entity1->toUrl('delete-form'));
+    $this->submitForm([], 'Delete');
     $storage->resetCache();
     $this->assertEmpty($storage->loadMultiple([$entity1->id(), $entity2->id()]), 'Test entities deleted');
 
@@ -117,12 +118,13 @@ class ConfigDependencyWebTest extends BrowserTestBase {
     $entity3->save();
 
     $this->drupalGet($entity1->toUrl('delete-form'));
-    $this->assertText('Configuration updates');
+    $this->assertSession()->pageTextContains('Configuration updates');
     $this->assertNoText('Configuration deletions');
     $this->assertNoText($entity2->id());
-    $this->assertText($entity2->label());
+    $this->assertSession()->pageTextContains($entity2->label());
     $this->assertNoText($entity3->id());
-    $this->drupalPostForm($entity1->toUrl('delete-form'), [], 'Delete');
+    $this->drupalGet($entity1->toUrl('delete-form'));
+    $this->submitForm([], 'Delete');
     $storage->resetCache();
     $this->assertNull($storage->load('entity1'), 'Test entity 1 deleted');
     $entity2 = $storage->load('entity2');
