@@ -52,7 +52,8 @@ class ConfigExportUITest extends BrowserTestBase {
 
     // Submit the export form and verify response. This will create a file in
     // temporary directory with the default name config.tar.gz.
-    $this->drupalPostForm('admin/config/development/configuration/full/export', [], 'Export');
+    $this->drupalGet('admin/config/development/configuration/full/export');
+    $this->submitForm([], 'Export');
     $this->assertSession()->statusCodeEquals(200);
 
     // Test if header contains file name with hostname and timestamp.
