@@ -129,7 +129,8 @@ class ConfigTranslationListUiTest extends BrowserTestBase {
       'label' => $label,
     ];
     // Create the menu by posting the form.
-    $this->drupalPostForm('admin/structure/menu/add', $edit, 'Save');
+    $this->drupalGet('admin/structure/menu/add');
+    $this->submitForm($edit, 'Save');
 
     // Get the Menu listing.
     $this->drupalGet('admin/structure/menu');
@@ -371,7 +372,8 @@ class ConfigTranslationListUiTest extends BrowserTestBase {
     $edit['id'] = strtolower($edit['label']);
     $edit['fallback_image_style'] = 'thumbnail';
 
-    $this->drupalPostForm('admin/config/media/responsive-image-style/add', $edit, 'Save');
+    $this->drupalGet('admin/config/media/responsive-image-style/add');
+    $this->submitForm($edit, 'Save');
     $this->assertRaw(t('Responsive image style %label saved.', ['%label' => $edit['label']]));
 
     // Get the responsive image style listing.
