@@ -43,6 +43,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
     'node',
     'views',
     'views_ui',
+    'menu_ui',
   ];
 
   /**
@@ -55,7 +56,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
    *
    * @var array
    */
-  protected $langcodes = ['fr', 'ta'];
+  protected $langcodes = ['fr', 'ta', 'tyv'];
 
   /**
    * Administrator user for tests.
@@ -169,7 +170,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       'translation[config_names][system.site][slogan]' => $fr_site_slogan,
     ];
 
-    $this->drupalPostForm("$translation_base_url/fr/add", $edit, 'Save translation');
+    $this->drupalGet("{$translation_base_url}/fr/add");
+    $this->submitForm($edit, 'Save translation');
     $this->assertRaw(t('Successfully saved @language translation.', ['@language' => 'French']));
 
     // Check for edit, delete links (and no 'add' link) for French language.
@@ -192,8 +194,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
 
     // Visit French site to ensure base language string present as source.
     $this->drupalGet("fr/$translation_base_url/fr/edit");
-    $this->assertText($site_name);
-    $this->assertText($site_slogan);
+    $this->assertSession()->pageTextContains($site_name);
+    $this->assertSession()->pageTextContains($site_slogan);
 
     // Translate 'Site name' label in French.
     $search = [
@@ -201,29 +203,31 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       'langcode' => 'fr',
       'translation' => 'untranslated',
     ];
-    $this->drupalPostForm('admin/config/regional/translate', $search, 'Filter');
+    $this->drupalGet('admin/config/regional/translate');
+    $this->submitForm($search, 'Filter');
 
     $textarea = $this->assertSession()->elementExists('xpath', '//textarea');
     $lid = $textarea->getAttribute('name');
     $edit = [
       $lid => $fr_site_name_label,
     ];
-    $this->drupalPostForm('admin/config/regional/translate', $edit, 'Save translations');
+    $this->drupalGet('admin/config/regional/translate');
+    $this->submitForm($edit, 'Save translations');
 
     // Ensure that the label is in French (and not in English).
     $this->drupalGet("fr/$translation_base_url/fr/edit");
-    $this->assertText($fr_site_name_label);
+    $this->assertSession()->pageTextContains($fr_site_name_label);
     $this->assertNoText($site_name_label);
 
     // Ensure that the label is also in French (and not in English)
     // when editing another language with the interface in French.
     $this->drupalGet("fr/$translation_base_url/ta/edit");
-    $this->assertText($fr_site_name_label);
+    $this->assertSession()->pageTextContains($fr_site_name_label);
     $this->assertNoText($site_name_label);
 
     // Ensure that the label is not translated when the interface is in English.
     $this->drupalGet("$translation_base_url/fr/edit");
-    $this->assertText($site_name_label);
+    $this->assertSession()->pageTextContains($site_name_label);
     $this->assertNoText($fr_site_name_label);
   }
 
@@ -246,7 +250,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       'translation[config_names][system.site][slogan]' => 'FR ' . $site_slogan,
     ];
     // First time, no overrides, so just Add link.
-    $this->drupalPostForm("$translation_base_url/fr/add", $edit, 'Save translation');
+    $this->drupalGet("{$translation_base_url}/fr/add");
+    $this->submitForm($edit, 'Save translation');
 
     // Read overridden file from active config.
     $override = \Drupal::languageManager()->getLanguageConfigOverride('fr', 'system.site');
@@ -256,7 +261,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       'name' => 'FR ' . $site_name,
       'slogan' => 'FR ' . $site_slogan,
     ];
-    $this->assertEqual($expected, $override->get());
+    $this->assertEquals($expected, $override->get());
 
     // Case 2: Update new value for site slogan and default value for site name.
     $this->drupalGet("$translation_base_url/fr/edit");
@@ -274,7 +279,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
 
     // Expect only slogan in language specific file.
     $expected = 'FR ' . $site_slogan;
-    $this->assertEqual($expected, $override->get('slogan'));
+    $this->assertEquals($expected, $override->get('slogan'));
 
     // Case 3: Keep default value for site name and slogan.
     $this->drupalGet("$translation_base_url/fr/edit");
@@ -322,7 +327,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       'recipients' => 'sales@example.com,support@example.com',
       'reply' => 'Thank you for your mail',
     ];
-    $this->drupalPostForm('admin/structure/contact/manage/feedback', $edit, 'Save');
+    $this->drupalGet('admin/structure/contact/manage/feedback');
+    $this->submitForm($edit, 'Save');
 
     // Ensure translation link is present.
     $translation_base_url = 'admin/structure/contact/manage/feedback/translate';
@@ -334,7 +340,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
 
     // Visit the form to confirm the changes.
     $this->drupalGet('contact/feedback');
-    $this->assertText($label);
+    $this->assertSession()->pageTextContains($label);
 
     foreach ($this->langcodes as $langcode) {
       $this->drupalGet($translation_base_url);
@@ -346,7 +352,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
 
       // Make sure original text is present on this page.
       $this->drupalGet($translation_page_url);
-      $this->assertText($label);
+      $this->assertSession()->pageTextContains($label);
 
       // Update translatable fields.
       $edit = [
@@ -355,7 +361,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       ];
 
       // Save language specific version of form.
-      $this->drupalPostForm($translation_page_url, $edit, 'Save translation');
+      $this->drupalGet($translation_page_url);
+      $this->submitForm($edit, 'Save translation');
 
       // Expect translated values in language specific file.
       $override = \Drupal::languageManager()->getLanguageConfigOverride($langcode, 'contact.form.feedback');
@@ -363,7 +370,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
         'label' => 'Website feedback - ' . $langcode,
         'reply' => 'Thank you for your mail - ' . $langcode,
       ];
-      $this->assertEqual($expected, $override->get());
+      $this->assertEquals($expected, $override->get());
 
       // Check for edit, delete links (and no 'add' link) for $langcode.
       $this->assertSession()->linkByHrefNotExists("$translation_base_url/$langcode/add");
@@ -372,7 +379,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
 
       // Visit language specific version of form to check label.
       $this->drupalGet($langcode . '/contact/feedback');
-      $this->assertText('Website feedback - ' . $langcode);
+      $this->assertSession()->pageTextContains('Website feedback - ' . $langcode);
 
       // Submit feedback.
       $edit = [
@@ -390,7 +397,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       foreach ($langcode_prefixes as $langcode_prefix) {
         $this->drupalGet(ltrim("$langcode_prefix/$translation_base_url/$langcode/edit", '/'));
         $this->assertSession()->fieldValueEquals('translation[config_names][contact.form.feedback][label]', 'Website feedback - ' . $langcode);
-        $this->assertText($label);
+        $this->assertSession()->pageTextContains($label);
       }
     }
 
@@ -401,7 +408,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
     foreach ($captured_emails as $email) {
       if ($email['id'] == 'contact_page_autoreply') {
         // Trim because we get an added newline for the body.
-        $this->assertEqual('Thank you for your mail - ' . $email['langcode'], trim($email['body']));
+        $this->assertEquals('Thank you for your mail - ' . $email['langcode'], trim($email['body']));
       }
     }
 
@@ -457,7 +464,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       'id' => 'custom_medium',
       'date_format_pattern' => 'Y. m. d. H:i',
     ];
-    $this->drupalPostForm('admin/config/regional/date-time/formats/add', $edit, 'Add format');
+    $this->drupalGet('admin/config/regional/date-time/formats/add');
+    $this->submitForm($edit, 'Add format');
 
     // Test translating a default shipped format and our custom format.
     $formats = [
@@ -475,7 +483,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
 
       // Make sure original text is present on this page.
       $this->drupalGet($translation_page_url);
-      $this->assertText($label);
+      $this->assertSession()->pageTextContains($label);
 
       // Make sure that the date library is added.
       $this->assertRaw('core/modules/system/js/system.date.js');
@@ -487,7 +495,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       ];
 
       // Save language specific version of form.
-      $this->drupalPostForm($translation_page_url, $edit, 'Save translation');
+      $this->drupalGet($translation_page_url);
+      $this->submitForm($edit, 'Save translation');
 
       // Get translation and check we've got the right value.
       $override = \Drupal::languageManager()->getLanguageConfigOverride('fr', 'core.date_format.' . $id);
@@ -495,12 +504,12 @@ class ConfigTranslationUiTest extends BrowserTestBase {
         'label' => $id . ' - FR',
         'pattern' => 'D',
       ];
-      $this->assertEqual($expected, $override->get());
+      $this->assertEquals($expected, $override->get());
 
       // Formatting the date 8 / 27 / 1985 @ 13:37 EST with pattern D should
       // display "Tue".
       $formatted_date = $this->container->get('date.formatter')->format(494015820, $id, NULL, 'America/New_York', 'fr');
-      $this->assertEqual('Tue', $formatted_date, 'Got the right formatted date using the date format translation pattern.');
+      $this->assertEquals('Tue', $formatted_date, 'Got the right formatted date using the date format translation pattern.');
     }
   }
 
@@ -528,7 +537,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       'translation[config_names][user.mail][status_blocked][body]' => 'Testing account blocked body.',
     ];
 
-    $this->drupalPostForm('admin/config/people/accounts/translate/fr/add', $edit, 'Save translation');
+    $this->drupalGet('admin/config/people/accounts/translate/fr/add');
+    $this->submitForm($edit, 'Save translation');
 
     // Make sure the changes are saved and loaded back properly.
     $this->drupalGet('admin/config/people/accounts/translate/fr/edit');
@@ -537,8 +547,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       $this->assertSession()->fieldValueEquals($key, $value);
     }
     // Check that labels for email settings appear.
-    $this->assertText('Account cancellation confirmation');
-    $this->assertText('Password recovery');
+    $this->assertSession()->pageTextContains('Account cancellation confirmation');
+    $this->assertSession()->pageTextContains('Password recovery');
   }
 
   /**
@@ -616,7 +626,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       'translation[config_names][views.view.frontpage][display][default][display_title]' => $display_settings_master . " FR",
       'translation[config_names][views.view.frontpage][display][default][display_options][title]' => $display_options_master . " FR",
     ];
-    $this->drupalPostForm("$translation_base_url/fr/add", $edit, 'Save translation');
+    $this->drupalGet("{$translation_base_url}/fr/add");
+    $this->submitForm($edit, 'Save translation');
     $this->assertRaw(t('Successfully saved @language translation.', ['@language' => 'French']));
 
     // Check for edit, delete links (and no 'add' link) for French language.
@@ -649,7 +660,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       // Import a .po file to add a new language with a given number of plural forms
       $name = \Drupal::service('file_system')->tempnam('temporary://', $langcode . '_') . '.po';
       file_put_contents($name, $this->getPoFile($data['plurals']));
-      $this->drupalPostForm('admin/config/regional/translate/import', [
+      $this->drupalGet('admin/config/regional/translate/import');
+      $this->submitForm([
         'langcode' => $langcode,
         'files[file]' => $name,
       ], 'Import');
@@ -685,7 +697,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
     // This will also automatically add the 'sl' language.
     $name = \Drupal::service('file_system')->tempnam('temporary://', "sl_") . '.po';
     file_put_contents($name, $this->getPoFile(4));
-    $this->drupalPostForm('admin/config/regional/translate/import', [
+    $this->drupalGet('admin/config/regional/translate/import');
+    $this->submitForm([
       'langcode' => 'sl',
       'files[file]' => $name,
     ], 'Import');
@@ -712,7 +725,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       'translation[config_names][views.view.files][display][default][display_options][fields][count][format_plural_string][2]' => $field_value_plural . ' 2 SL',
       'translation[config_names][views.view.files][display][default][display_options][fields][count][format_plural_string][3]' => $field_value_plural . ' 3 SL',
     ];
-    $this->drupalPostForm($translation_url, $edit, 'Save translation');
+    $this->drupalGet($translation_url);
+    $this->submitForm($edit, 'Save translation');
 
     // Make sure the values have changed.
     $this->drupalGet($translation_url);
@@ -756,9 +770,9 @@ class ConfigTranslationUiTest extends BrowserTestBase {
     $this->drupalGet("/entity_test/structure/$bundle/fields/entity_test.$bundle.$field_name/translate");
     $this->clickLink('Add');
 
-    $this->assertText('Translatable field setting');
+    $this->assertSession()->pageTextContains('Translatable field setting');
     $this->assertSession()->assertEscaped($translatable_field_setting);
-    $this->assertText('Translatable storage setting');
+    $this->assertSession()->pageTextContains('Translatable storage setting');
     $this->assertSession()->assertEscaped($translatable_storage_setting);
   }
 
@@ -795,7 +809,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
 
     // Checks the text of details summary element that surrounds the translation
     // options.
-    $this->assertText(Html::escape(strip_tags($on_label)) . ' Boolean settings');
+    $this->assertSession()->responseContains(Html::escape(strip_tags($on_label)) . ' Boolean settings');
 
     // Checks that the correct on and off labels appear on the form.
     $this->assertSession()->assertEscaped($on_label);
@@ -823,7 +837,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       'label' => $name,
       'direction' => Language::DIRECTION_LTR,
     ];
-    $this->drupalPostForm('admin/config/regional/language/add', $edit, 'Add custom language');
+    $this->drupalGet('admin/config/regional/language/add');
+    $this->submitForm($edit, 'Add custom language');
 
     // Make sure there is no translation stored in locale storage before edit.
     $translation = $this->getTranslation('user.settings', 'anonymous', 'fr');
@@ -833,22 +848,24 @@ class ConfigTranslationUiTest extends BrowserTestBase {
     $edit = [
       'translation[config_names][user.settings][anonymous]' => 'Anonyme',
     ];
-    $this->drupalPostForm('admin/config/people/accounts/translate/fr/add', $edit, 'Save translation');
+    $this->drupalGet('admin/config/people/accounts/translate/fr/add');
+    $this->submitForm($edit, 'Save translation');
 
     // Make sure translation stored in locale storage after saved language
     // specific configuration translation.
     $translation = $this->getTranslation('user.settings', 'anonymous', 'fr');
-    $this->assertEqual('Anonyme', $translation->getString());
+    $this->assertEquals('Anonyme', $translation->getString());
 
     // revert custom translations to base translation.
     $edit = [
       'translation[config_names][user.settings][anonymous]' => 'Anonymous',
     ];
-    $this->drupalPostForm('admin/config/people/accounts/translate/fr/edit', $edit, 'Save translation');
+    $this->drupalGet('admin/config/people/accounts/translate/fr/edit');
+    $this->submitForm($edit, 'Save translation');
 
     // Make sure there is no translation stored in locale storage after revert.
     $translation = $this->getTranslation('user.settings', 'anonymous', 'fr');
-    $this->assertEqual('Anonymous', $translation->getString());
+    $this->assertEquals('Anonymous', $translation->getString());
   }
 
   /**
@@ -858,18 +875,21 @@ class ConfigTranslationUiTest extends BrowserTestBase {
     $this->drupalLogin($this->adminUser);
 
     // Delete French language
-    $this->drupalPostForm('admin/config/regional/language/delete/fr', [], 'Delete');
+    $this->drupalGet('admin/config/regional/language/delete/fr');
+    $this->submitForm([], 'Delete');
     $this->assertRaw(t('The %language (%langcode) language has been removed.', ['%language' => 'French', '%langcode' => 'fr']));
 
     // Change default language to Tamil.
     $edit = [
       'site_default_language' => 'ta',
     ];
-    $this->drupalPostForm('admin/config/regional/language', $edit, 'Save configuration');
+    $this->drupalGet('admin/config/regional/language');
+    $this->submitForm($edit, 'Save configuration');
     $this->assertRaw(t('Configuration saved.'));
 
     // Delete English language
-    $this->drupalPostForm('admin/config/regional/language/delete/en', [], 'Delete');
+    $this->drupalGet('admin/config/regional/language/delete/en');
+    $this->submitForm([], 'Delete');
     $this->assertRaw(t('The %language (%langcode) language has been removed.', ['%language' => 'English', '%langcode' => 'en']));
 
     // Visit account setting translation page, this should not
@@ -889,12 +909,12 @@ class ConfigTranslationUiTest extends BrowserTestBase {
 
     // Check out if the translation page has the altered in settings.
     $this->drupalGet('admin/config/system/site-information/translate/fr/add');
-    $this->assertText('Feed channel');
-    $this->assertText('Feed description');
+    $this->assertSession()->pageTextContains('Feed channel');
+    $this->assertSession()->pageTextContains('Feed description');
 
     // Check if the translation page does not have the altered out settings.
     $this->drupalGet('admin/config/people/accounts/translate/fr/add');
-    $this->assertText('Name');
+    $this->assertSession()->pageTextContains('Name');
     $this->assertNoText('Account cancellation confirmation');
     $this->assertNoText('Password recovery');
   }
@@ -915,7 +935,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
     $actual = $config_factory
       ->getEditable('config_translation_test.content')
       ->get('animals');
-    $this->assertEqual($expected, $actual);
+    $this->assertEquals($expected, $actual);
 
     $edit = [
       'translation[config_names][config_translation_test.content][content][value]' => '<p><strong>Hello World</strong> - FR</p>',
@@ -923,7 +943,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       'translation[config_names][config_translation_test.content][animals][1]' => 'llama - FR',
       'translation[config_names][config_translation_test.content][animals][2]' => 'elephant - FR',
     ];
-    $this->drupalPostForm('admin/config/media/file-system/translate/fr/add', $edit, 'Save translation');
+    $this->drupalGet('admin/config/media/file-system/translate/fr/add');
+    $this->submitForm($edit, 'Save translation');
 
     $this->container->get('language.config_factory_override')
       ->setLanguage(new Language(['id' => 'fr']));
@@ -936,7 +957,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
     $actual = $config_factory
       ->get('config_translation_test.content')
       ->get('animals');
-    $this->assertEqual($expected, $actual);
+    $this->assertEquals($expected, $actual);
   }
 
   /**
@@ -954,7 +975,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
     $actual = $config_factory
       ->get('config_translation_test.content')
       ->getOriginal('content', FALSE);
-    $this->assertEqual($expected, $actual);
+    $this->assertEquals($expected, $actual);
 
     $translation_base_url = 'admin/config/media/file-system/translate';
     $this->drupalGet($translation_base_url);
@@ -975,7 +996,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
     ];
 
     // Save language specific version of form.
-    $this->drupalPostForm($translation_page_url, $edit, 'Save translation');
+    $this->drupalGet($translation_page_url);
+    $this->submitForm($edit, 'Save translation');
 
     // Get translation and check we've got the right value.
     $expected = [
@@ -987,7 +1009,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
     $actual = $config_factory
       ->get('config_translation_test.content')
       ->get('content');
-    $this->assertEqual($expected, $actual);
+    $this->assertEquals($expected, $actual);
 
     // Change the text format of the source configuration and verify that the
     // text format of the translation does not change because that could lead to
@@ -1001,7 +1023,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       ->get('config_translation_test.content')
       ->get('content');
     // The translation should not have changed, so re-use $expected.
-    $this->assertEqual($expected, $actual);
+    $this->assertEquals($expected, $actual);
 
     // Because the text is now in a text format that the translator does not
     // have access to, the translator should not be able to translate it.
@@ -1015,14 +1037,15 @@ class ConfigTranslationUiTest extends BrowserTestBase {
     $actual = $config_factory
       ->get('config_translation_test.content')
       ->get('content');
-    $this->assertEqual($expected, $actual);
+    $this->assertEquals($expected, $actual);
 
     // The administrator must explicitly change the text format.
     $this->drupalLogin($this->adminUser);
     $edit = [
       'translation[config_names][config_translation_test.content][content][format]' => 'full_html',
     ];
-    $this->drupalPostForm($translation_page_url, $edit, 'Save translation');
+    $this->drupalGet($translation_page_url);
+    $this->submitForm($edit, 'Save translation');
     $expected = [
       'value' => '<p><strong>Hello World</strong> - FR</p>',
       'format' => 'full_html',
@@ -1030,7 +1053,7 @@ class ConfigTranslationUiTest extends BrowserTestBase {
     $actual = $config_factory
       ->get('config_translation_test.content')
       ->get('content');
-    $this->assertEqual($expected, $actual);
+    $this->assertEquals($expected, $actual);
   }
 
   /**
@@ -1065,13 +1088,31 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       'translation[config_names][field.field.node.article.translatable_field][label]' => 'FR label',
     ];
     $this->submitForm($form_values, 'Save translation');
-    $this->assertText('Successfully saved French translation.');
+    $this->assertSession()->pageTextContains('Successfully saved French translation.');
 
     // Check that the translations are saved.
     $this->clickLink('Add');
     $this->assertRaw('FR label');
   }
 
+  /**
+   * Test translation save confirmation message.
+   */
+  public function testMenuTranslationWithoutChange() {
+    $this->drupalLogin($this->adminUser);
+    $this->drupalGet('admin/structure/menu/manage/main/translate/tyv/add');
+    $this->submitForm([], 'Save translation');
+    $this->assertSession()->pageTextContains('Tuvan translation was not added. To add a translation, you must modify the configuration.');
+
+    $this->drupalGet('admin/structure/menu/manage/main/translate/tyv/add');
+    $edit = [
+      'translation[config_names][system.menu.main][label]' => 'Main navigation Translation',
+      'translation[config_names][system.menu.main][description]' => 'Site section links Translation',
+    ];
+    $this->submitForm($edit, 'Save translation');
+    $this->assertSession()->pageTextContains('Successfully saved Tuvan translation.');
+  }
+
   /**
    * Gets translation from locale storage.
    *
@@ -1117,7 +1158,8 @@ class ConfigTranslationUiTest extends BrowserTestBase {
       'site_name' => $site_name,
       'site_slogan' => $site_slogan,
     ];
-    $this->drupalPostForm('admin/config/system/site-information', $edit, 'Save configuration');
+    $this->drupalGet('admin/config/system/site-information');
+    $this->submitForm($edit, 'Save configuration');
     $this->assertRaw(t('The configuration options have been saved.'));
   }
 
