@@ -24,6 +24,7 @@ class MigrateSystemSiteTranslationTest extends MigrateDrupal7TestBase {
    */
   protected function setUp(): void {
     parent::setUp();
+    $this->executeMigration('system_site');
     $this->executeMigration('d7_system_site_translation');
   }
 
@@ -35,17 +36,17 @@ class MigrateSystemSiteTranslationTest extends MigrateDrupal7TestBase {
     $config_translation = $language_manager->getLanguageConfigOverride('fr', 'system.site');
     $this->assertSame('The Site Name', $config_translation->get('name'));
     $this->assertSame('fr - The Slogan', $config_translation->get('slogan'));
-    $this->assertSame('node', $config_translation->get('page.403'));
-    $this->assertSame('node', $config_translation->get('page.404'));
-    $this->assertSame('node', $config_translation->get('page.front'));
+    $this->assertSame(NULL, $config_translation->get('page.403'));
+    $this->assertSame(NULL, $config_translation->get('page.404'));
+    $this->assertSame(NULL, $config_translation->get('page.front'));
     $this->assertSame(NULL, $config_translation->get('admin_compact_mode'));
 
     $config_translation = $language_manager->getLanguageConfigOverride('is', 'system.site');
     $this->assertSame('is - The Site Name', $config_translation->get('name'));
     $this->assertSame('is - The Slogan', $config_translation->get('slogan'));
-    $this->assertSame('node/1', $config_translation->get('page.403'));
-    $this->assertSame('node/6', $config_translation->get('page.404'));
-    $this->assertSame('node/4', $config_translation->get('page.front'));
+    $this->assertSame(NULL, $config_translation->get('page.403'));
+    $this->assertSame(NULL, $config_translation->get('page.404'));
+    $this->assertSame(NULL, $config_translation->get('page.front'));
     $this->assertNULL($config_translation->get('admin_compact_mode'));
   }
 
