@@ -129,8 +129,18 @@ class EntityTypeInfo implements ContainerInjectionInterface {
    */
   public function entityTypeAlter(array &$entity_types) {
     foreach ($entity_types as $entity_type_id => $entity_type) {
-      // The ContentModerationState entity type should never be moderated.
-      if ($entity_type->isRevisionable() && !$entity_type->isInternal()) {
+      // Internal entity types should never be moderated, and the 'path_alias'
+      // entity type needs to be excluded for now.
+      // @todo Enable moderation for path aliases after they become publishable
+      //   in https://www.drupal.org/project/drupal/issues/3007669.
+      // Workspace entities can not be moderated because they use string IDs.
+      // @see \Drupal\content_moderation\Entity\ContentModerationState::baseFieldDefinitions()
+      // where the target entity ID is defined as an integer.
+      $entity_type_to_exclude = [
+        'path_alias',
+        'workspace',
+      ];
+      if ($entity_type->isRevisionable() && !$entity_type->isInternal() && !in_array($entity_type_id, $entity_type_to_exclude)) {
         $entity_types[$entity_type_id] = $this->addModerationToEntityType($entity_type);
       }
     }
@@ -318,37 +328,36 @@ class EntityTypeInfo implements ContainerInjectionInterface {
   public function formAlter(array &$form, FormStateInterface $form_state, $form_id) {
     $form_object = $form_state->getFormObject();
     if ($form_object instanceof BundleEntityFormBase) {
-      $config_entity_type = $form_object->getEntity()->getEntityType();
-      $bundle_of = $config_entity_type->getBundleOf();
+      $config_entity = $form_object->getEntity();
+      $bundle_of = $config_entity->getEntityType()->getBundleOf();
       if ($bundle_of
           && ($bundle_of_entity_type = $this->entityTypeManager->getDefinition($bundle_of))
-          && $this->moderationInfo->canModerateEntitiesOfEntityType($bundle_of_entity_type)) {
-        $this->entityTypeManager->getHandler($config_entity_type->getBundleOf(), 'moderation')->enforceRevisionsBundleFormAlter($form, $form_state, $form_id);
+          && $this->moderationInfo->shouldModerateEntitiesOfBundle($bundle_of_entity_type, $config_entity->id())) {
+        $this->entityTypeManager->getHandler($bundle_of, 'moderation')->enforceRevisionsBundleFormAlter($form, $form_state, $form_id);
       }
     }
     elseif ($this->isModeratedEntityEditForm($form_object)) {
       /** @var \Drupal\Core\Entity\ContentEntityFormInterface $form_object */
       /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
       $entity = $form_object->getEntity();
-      if ($this->moderationInfo->isModeratedEntity($entity)) {
-        $this->entityTypeManager
-          ->getHandler($entity->getEntityTypeId(), 'moderation')
-          ->enforceRevisionsEntityFormAlter($form, $form_state, $form_id);
 
-        // Submit handler to redirect to the latest version, if available.
-        $form['actions']['submit']['#submit'][] = [EntityTypeInfo::class, 'bundleFormRedirect'];
+      $this->entityTypeManager
+        ->getHandler($entity->getEntityTypeId(), 'moderation')
+        ->enforceRevisionsEntityFormAlter($form, $form_state, $form_id);
 
-        // Move the 'moderation_state' field widget to the footer region, if
-        // available.
-        if (isset($form['footer']) && in_array($form_object->getOperation(), ['edit', 'default'], TRUE)) {
-          $form['moderation_state']['#group'] = 'footer';
-        }
+      // Submit handler to redirect to the latest version, if available.
+      $form['actions']['submit']['#submit'][] = [EntityTypeInfo::class, 'bundleFormRedirect'];
 
-        // If the publishing status exists in the meta region, replace it with
-        // the current state instead.
-        if (isset($form['meta']['published'])) {
-          $form['meta']['published']['#markup'] = $this->moderationInfo->getWorkflowForEntity($entity)->getTypePlugin()->getState($entity->moderation_state->value)->label();
-        }
+      // Move the 'moderation_state' field widget to the footer region, if
+      // available.
+      if (isset($form['footer']) && in_array($form_object->getOperation(), ['edit', 'default'], TRUE)) {
+        $form['moderation_state']['#group'] = 'footer';
+      }
+
+      // If the publishing status exists in the meta region, replace it with
+      // the current state instead.
+      if (isset($form['meta']['published'])) {
+        $form['meta']['published']['#markup'] = $this->moderationInfo->getWorkflowForEntity($entity)->getTypePlugin()->getState($entity->moderation_state->value)->label();
       }
     }
   }
@@ -380,7 +389,7 @@ class EntityTypeInfo implements ContainerInjectionInterface {
    *   The current state of the form.
    */
   public static function bundleFormRedirect(array &$form, FormStateInterface $form_state) {
-    /* @var \Drupal\Core\Entity\ContentEntityInterface $entity */
+    /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
     $entity = $form_state->getFormObject()->getEntity();
 
     $moderation_info = \Drupal::getContainer()->get('content_moderation.moderation_information');
