@@ -16,7 +16,7 @@ class ContentModerationWorkflowTypeTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = [
+  protected static $modules = [
     'content_moderation',
     'node',
     'entity_test',
@@ -30,7 +30,7 @@ class ContentModerationWorkflowTypeTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $admin = $this->drupalCreateUser([
       'administer workflows',
@@ -48,7 +48,8 @@ class ContentModerationWorkflowTypeTest extends BrowserTestBase {
 
     $entity_bundle_info = \Drupal::service('entity_type.bundle.info');
 
-    $this->drupalPostForm('admin/config/workflow/workflows/add', [
+    $this->drupalGet('admin/config/workflow/workflows/add');
+    $this->submitForm([
       'label' => 'Test',
       'id' => 'test',
       'workflow_type' => 'content_moderation',
