@@ -68,7 +68,8 @@ class ContentTranslationLanguageChangeTest extends NodeTestBase {
       'settings[node][article][translatable]' => TRUE,
       'settings[node][article][settings][language][language_alterable]' => TRUE,
     ];
-    $this->drupalPostForm('admin/config/regional/content-language', $edit, t('Save configuration'));
+    $this->drupalGet('admin/config/regional/content-language');
+    $this->submitForm($edit, 'Save configuration');
 
     // Add an image field.
     $this->drupalGet('admin/structure/types/manage/article/fields/add-field');
@@ -77,9 +78,9 @@ class ContentTranslationLanguageChangeTest extends NodeTestBase {
       'field_name' => 'image_field',
       'label' => 'image_field',
     ];
-    $this->drupalPostForm(NULL, $edit, t('Save and continue'));
-    $this->drupalPostForm(NULL, [], t('Save field settings'));
-    $this->drupalPostForm(NULL, [], t('Save settings'));
+    $this->submitForm($edit, 'Save and continue');
+    $this->submitForm([], 'Save field settings');
+    $this->submitForm([], 'Save settings');
   }
 
   /**
@@ -91,12 +92,12 @@ class ContentTranslationLanguageChangeTest extends NodeTestBase {
     $edit = [
       'title[0][value]' => 'english_title',
     ];
-    $this->drupalPostForm(NULL, $edit, t('Save'));
+    $this->submitForm($edit, 'Save');
 
     // Create a translation in French.
     $this->clickLink('Translate');
     $this->clickLink('Add');
-    $this->drupalPostForm(NULL, [], t('Save (this translation)'));
+    $this->submitForm([], 'Save (this translation)');
     $this->clickLink('Translate');
 
     // Edit English translation.
@@ -107,8 +108,8 @@ class ContentTranslationLanguageChangeTest extends NodeTestBase {
       'langcode[0][value]' => 'de',
       'files[field_image_field_0]' => $images->uri,
     ];
-    $this->drupalPostForm(NULL, $edit, t('Upload'));
-    $this->drupalPostForm(NULL, ['field_image_field[0][alt]' => 'alternative_text'], t('Save (this translation)'));
+    $this->submitForm($edit, 'Upload');
+    $this->submitForm(['field_image_field[0][alt]' => 'alternative_text'], 'Save (this translation)');
 
     // Check that the translation languages are correct.
     $node = $this->getNodeByTitle('english_title');
@@ -127,13 +128,13 @@ class ContentTranslationLanguageChangeTest extends NodeTestBase {
       'title[0][value]' => 'english_title',
       'test_field_only_en_fr' => 'node created',
     ];
-    $this->drupalPostForm(NULL, $edit, t('Save'));
-    $this->assertEqual('node created', \Drupal::state()->get('test_field_only_en_fr'));
+    $this->submitForm($edit, 'Save');
+    $this->assertEquals('node created', \Drupal::state()->get('test_field_only_en_fr'));
 
     // Create a translation in French.
     $this->clickLink('Translate');
     $this->clickLink('Add');
-    $this->drupalPostForm(NULL, [], t('Save (this translation)'));
+    $this->submitForm([], 'Save (this translation)');
     $this->clickLink('Translate');
 
     // Edit English translation.
@@ -147,7 +148,7 @@ class ContentTranslationLanguageChangeTest extends NodeTestBase {
       'langcode[0][value]' => 'de',
       'files[field_image_field_0]' => $images->uri,
     ];
-    $this->drupalPostForm(NULL, $edit, t('Upload'));
+    $this->submitForm($edit, 'Upload');
     // Test the expected title after triggering an ajax call with a new
     // language selected.
     $this->assertRaw('<title>Edit Article english_title | Drupal</title>');
@@ -155,7 +156,7 @@ class ContentTranslationLanguageChangeTest extends NodeTestBase {
       'langcode[0][value]' => 'en',
       'field_image_field[0][alt]' => 'alternative_text',
     ];
-    $this->drupalPostForm(NULL, $edit, t('Save (this translation)'));
+    $this->submitForm($edit, 'Save (this translation)');
 
     // Check that the translation languages are correct.
     $node = $this->getNodeByTitle('english_title');
