@@ -52,7 +52,7 @@ class DateFilterTest extends ViewTestBase {
    */
   protected function setUp($import_test_views = TRUE): void {
     parent::setUp($import_test_views);
-    ViewTestData::createTestViews(get_class($this), ['datetime_test']);
+    ViewTestData::createTestViews(static::class, ['datetime_test']);
 
     // Add a date field to page nodes.
     $node_type = NodeType::create([
@@ -86,40 +86,43 @@ class DateFilterTest extends ViewTestBase {
 
     $this->drupalGet('test_exposed_filter_datetime');
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertOption('edit-field-date-value-op', '=');
-    $this->assertNoOption('edit-field-date-value-op', '>');
-    $this->assertNoOption('edit-field-date-value-op', '>=');
+    $this->assertSession()->optionExists('edit-field-date-value-op', '=');
+    $this->assertSession()->optionNotExists('edit-field-date-value-op', '>');
+    $this->assertSession()->optionNotExists('edit-field-date-value-op', '>=');
 
     // Because there are not operators that use the min and max fields, those
     // fields should not be in the exposed form.
-    $this->assertFieldById('edit-field-date-value-value');
-    $this->assertNoFieldById('edit-field-date-value-min');
-    $this->assertNoFieldById('edit-field-date-value-max');
+    $this->assertSession()->fieldExists('edit-field-date-value-value');
+    $this->assertSession()->fieldNotExists('edit-field-date-value-min');
+    $this->assertSession()->fieldNotExists('edit-field-date-value-max');
 
     $edit = [];
     $edit['options[operator]'] = '>';
     $edit['options[expose][operator_list][]'] = ['>', '>=', 'between'];
-    $this->drupalPostForm('admin/structure/views/nojs/handler/test_exposed_filter_datetime/default/filter/field_date_value', $edit, t('Apply'));
-    $this->drupalPostForm('admin/structure/views/view/test_exposed_filter_datetime/edit/default', [], t('Save'));
+    $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_filter_datetime/default/filter/field_date_value');
+    $this->submitForm($edit, 'Apply');
+    $this->drupalGet('admin/structure/views/view/test_exposed_filter_datetime/edit/default');
+    $this->submitForm([], 'Save');
 
     $this->drupalGet('test_exposed_filter_datetime');
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertNoOption('edit-field-date-value-op', '<');
-    $this->assertNoOption('edit-field-date-value-op', '<=');
-    $this->assertNoOption('edit-field-date-value-op', '=');
-    $this->assertOption('edit-field-date-value-op', '>');
-    $this->assertOption('edit-field-date-value-op', '>=');
+    $this->assertSession()->optionNotExists('edit-field-date-value-op', '<');
+    $this->assertSession()->optionNotExists('edit-field-date-value-op', '<=');
+    $this->assertSession()->optionNotExists('edit-field-date-value-op', '=');
+    $this->assertSession()->optionExists('edit-field-date-value-op', '>');
+    $this->assertSession()->optionExists('edit-field-date-value-op', '>=');
 
-    $this->assertFieldById('edit-field-date-value-value');
-    $this->assertFieldById('edit-field-date-value-min');
-    $this->assertFieldById('edit-field-date-value-max');
+    $this->assertSession()->fieldExists('edit-field-date-value-value');
+    $this->assertSession()->fieldExists('edit-field-date-value-min');
+    $this->assertSession()->fieldExists('edit-field-date-value-max');
 
     // Set the default to an excluded operator.
     $edit = [];
     $edit['options[operator]'] = '=';
     $edit['options[expose][operator_list][]'] = ['<', '>'];
-    $this->drupalPostForm('admin/structure/views/nojs/handler/test_exposed_filter_datetime/default/filter/field_date_value', $edit, t('Apply'));
-    $this->assertText('You selected the "Is equal to" operator as the default value but is not included in the list of limited operators.');
+    $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_filter_datetime/default/filter/field_date_value');
+    $this->submitForm($edit, 'Apply');
+    $this->assertSession()->pageTextContains('You selected the "Is equal to" operator as the default value but is not included in the list of limited operators.');
   }
 
 }
