@@ -42,7 +42,7 @@ class ViewsIntegrationTest extends ViewsKernelTestBase {
     $this->installEntitySchema('user');
     $this->installSchema('dblog', ['watchdog']);
 
-    ViewTestData::createTestViews(get_class($this), ['dblog_test_views']);
+    ViewTestData::createTestViews(static::class, ['dblog_test_views']);
   }
 
   /**
@@ -63,15 +63,17 @@ class ViewsIntegrationTest extends ViewsKernelTestBase {
       if (!isset($entry['variables'])) {
         continue;
       }
-      $this->assertEqual($view->style_plugin->getField($index, 'message'), new FormattableMarkup($entry['message'], $entry['variables']));
+      $message_vars = $entry['variables'];
+      unset($message_vars['link']);
+      $this->assertEquals(new FormattableMarkup($entry['message'], $message_vars), $view->style_plugin->getField($index, 'message'));
       $link_field = $view->style_plugin->getField($index, 'link');
       // The 3rd entry contains some unsafe markup that needs to get filtered.
       if ($index == 2) {
         // Make sure that unsafe link differs from the rendered link, so we know
         // that some filtering actually happened.
-        $this->assertNotEqual($link_field, $entry['variables']['link']);
+        $this->assertNotEquals($entry['variables']['link'], $link_field);
       }
-      $this->assertEqual($link_field, Xss::filterAdmin($entry['variables']['link']));
+      $this->assertEquals(Xss::filterAdmin($entry['variables']['link']), $link_field);
     }
 
     // Disable replacing variables and check that the tokens aren't replaced.
@@ -82,7 +84,7 @@ class ViewsIntegrationTest extends ViewsKernelTestBase {
     $view->initStyle();
     $view->field['message']->options['replace_variables'] = FALSE;
     foreach ($entries as $index => $entry) {
-      $this->assertEqual($view->style_plugin->getField($index, 'message'), $entry['message']);
+      $this->assertEquals($entry['message'], $view->style_plugin->getField($index, 'message'));
     }
   }
 
