@@ -92,10 +92,10 @@ class FieldCrudTest extends FieldKernelTestBase {
     $this->assertSame('', $config['description'], 'Description defaults to empty string.');
 
     // Check that default settings are set.
-    $this->assertEqual($config['settings'], $field_type_manager->getDefaultFieldSettings($this->fieldStorageDefinition['type']), 'Default field settings have been written.');
+    $this->assertEquals($config['settings'], $field_type_manager->getDefaultFieldSettings($this->fieldStorageDefinition['type']), 'Default field settings have been written.');
 
     // Check that the denormalized 'field_type' was properly written.
-    $this->assertEqual($config['field_type'], $this->fieldStorageDefinition['type']);
+    $this->assertEquals($config['field_type'], $this->fieldStorageDefinition['type']);
 
     // Guarantee that the field/bundle combination is unique.
     try {
@@ -260,9 +260,9 @@ class FieldCrudTest extends FieldKernelTestBase {
     $field->save();
 
     $field_new = FieldConfig::load('entity_test.' . $this->fieldDefinition['bundle'] . '.' . $this->fieldDefinition['field_name']);
-    $this->assertEqual($field->isRequired(), $field_new->isRequired(), '"required" change is saved');
-    $this->assertEqual($field->getLabel(), $field_new->getLabel(), '"label" change is saved');
-    $this->assertEqual($field->getDescription(), $field_new->getDescription(), '"description" change is saved');
+    $this->assertEquals($field->isRequired(), $field_new->isRequired(), '"required" change is saved');
+    $this->assertEquals($field->getLabel(), $field_new->getLabel(), '"label" change is saved');
+    $this->assertEquals($field->getDescription(), $field_new->getDescription(), '"description" change is saved');
 
     // TODO: test failures.
   }
