@@ -66,26 +66,26 @@ class EntityDisplayTest extends KernelTestBase {
     $expected['component_2'] = ['weight' => -3, 'settings' => [], 'third_party_settings' => []];
     $display->setComponent('component_1');
     $display->setComponent('component_2');
-    $this->assertEqual($expected['component_1'], $display->getComponent('component_1'));
-    $this->assertEqual($expected['component_2'], $display->getComponent('component_2'));
+    $this->assertEquals($expected['component_1'], $display->getComponent('component_1'));
+    $this->assertEquals($expected['component_2'], $display->getComponent('component_2'));
 
     // Check that arbitrary options are correctly stored.
     $expected['component_3'] = ['weight' => 10, 'third_party_settings' => ['field_test' => ['foo' => 'bar']], 'settings' => []];
     $display->setComponent('component_3', $expected['component_3']);
-    $this->assertEqual($expected['component_3'], $display->getComponent('component_3'));
+    $this->assertEquals($expected['component_3'], $display->getComponent('component_3'));
 
     // Check that the display can be properly saved and read back.
     $display->save();
     $display = EntityViewDisplay::load($display->id());
     foreach (['component_1', 'component_2', 'component_3'] as $name) {
       $expected[$name]['region'] = 'content';
-      $this->assertEqual($expected[$name], $display->getComponent($name));
+      $this->assertEquals($expected[$name], $display->getComponent($name));
     }
 
     // Ensure that third party settings were added to the config entity.
     // These are added by entity_test_entity_presave() implemented in
     // entity_test module.
-    $this->assertEqual('bar', $display->getThirdPartySetting('entity_test', 'foo'), 'Third party settings were added to the entity view display.');
+    $this->assertEquals('bar', $display->getThirdPartySetting('entity_test', 'foo'), 'Third party settings were added to the entity view display.');
 
     // Check that getComponents() returns options for all components.
     $expected['name'] = [
@@ -98,7 +98,7 @@ class EntityDisplayTest extends KernelTestBase {
       'third_party_settings' => [],
       'region' => 'content',
     ];
-    $this->assertEqual($expected, $display->getComponents());
+    $this->assertEquals($expected, $display->getComponents());
 
     // Check that a component can be removed.
     $display->removeComponent('component_3');
@@ -116,11 +116,11 @@ class EntityDisplayTest extends KernelTestBase {
     $new_display->save();
     $new_display = EntityViewDisplay::load($new_display->id());
     $dependencies = $new_display->calculateDependencies()->getDependencies();
-    $this->assertEqual(['config' => ['core.entity_view_mode.entity_test.other_view_mode'], 'module' => ['entity_test']], $dependencies);
-    $this->assertEqual($display->getTargetEntityTypeId(), $new_display->getTargetEntityTypeId());
-    $this->assertEqual($display->getTargetBundle(), $new_display->getTargetBundle());
-    $this->assertEqual('other_view_mode', $new_display->getMode());
-    $this->assertEqual($display->getComponents(), $new_display->getComponents());
+    $this->assertEquals(['config' => ['core.entity_view_mode.entity_test.other_view_mode'], 'module' => ['entity_test']], $dependencies);
+    $this->assertEquals($display->getTargetEntityTypeId(), $new_display->getTargetEntityTypeId());
+    $this->assertEquals($display->getTargetBundle(), $new_display->getTargetBundle());
+    $this->assertEquals('other_view_mode', $new_display->getMode());
+    $this->assertEquals($display->getComponents(), $new_display->getComponents());
   }
 
   /**
@@ -160,8 +160,8 @@ class EntityDisplayTest extends KernelTestBase {
     // Check that getViewDisplay() returns the correct object.
     $display = $display_repository->getViewDisplay('entity_test', 'entity_test');
     $this->assertFalse($display->isNew());
-    $this->assertEqual('entity_test.entity_test.default', $display->id());
-    $this->assertEqual(['weight' => 10, 'settings' => [], 'third_party_settings' => [], 'region' => 'content'], $display->getComponent('component_1'));
+    $this->assertEquals('entity_test.entity_test.default', $display->id());
+    $this->assertEquals(['weight' => 10, 'settings' => [], 'third_party_settings' => [], 'region' => 'content'], $display->getComponent('component_1'));
   }
 
   /**
@@ -177,14 +177,14 @@ class EntityDisplayTest extends KernelTestBase {
 
     // Check that the default visibility taken into account for extra fields
     // unknown in the display.
-    $this->assertEqual(['weight' => 5, 'region' => 'content', 'settings' => [], 'third_party_settings' => []], $display->getComponent('display_extra_field'));
+    $this->assertEquals(['weight' => 5, 'region' => 'content', 'settings' => [], 'third_party_settings' => []], $display->getComponent('display_extra_field'));
     $this->assertNull($display->getComponent('display_extra_field_hidden'));
 
     // Check that setting explicit options overrides the defaults.
     $display->removeComponent('display_extra_field');
     $display->setComponent('display_extra_field_hidden', ['weight' => 10]);
     $this->assertNull($display->getComponent('display_extra_field'));
-    $this->assertEqual(['weight' => 10, 'settings' => [], 'third_party_settings' => []], $display->getComponent('display_extra_field_hidden'));
+    $this->assertEquals(['weight' => 10, 'settings' => [], 'third_party_settings' => []], $display->getComponent('display_extra_field_hidden'));
   }
 
   /**
@@ -206,14 +206,14 @@ class EntityDisplayTest extends KernelTestBase {
 
     // Check that the default visibility taken into account for extra fields
     // unknown in the display that were included in the initial config.
-    $this->assertEqual(['weight' => 5, 'region' => 'content'], $display->getComponent('display_extra_field'));
+    $this->assertEquals(['weight' => 5, 'region' => 'content'], $display->getComponent('display_extra_field'));
     $this->assertNull($display->getComponent('display_extra_field_hidden'));
 
     // Check that setting explicit options overrides the defaults.
     $display->removeComponent('display_extra_field');
     $display->setComponent('display_extra_field_hidden', ['weight' => 10]);
     $this->assertNull($display->getComponent('display_extra_field'));
-    $this->assertEqual(['weight' => 10, 'settings' => [], 'third_party_settings' => []], $display->getComponent('display_extra_field_hidden'));
+    $this->assertEquals(['weight' => 10, 'settings' => [], 'third_party_settings' => []], $display->getComponent('display_extra_field_hidden'));
   }
 
   /**
@@ -252,32 +252,32 @@ class EntityDisplayTest extends KernelTestBase {
       'settings' => $formatter_settings,
       'third_party_settings' => [],
     ];
-    $this->assertEqual($expected, $display->getComponent($field_name));
+    $this->assertEquals($expected, $display->getComponent($field_name));
 
     // Check that the getFormatter() method returns the correct formatter plugin.
     $formatter = $display->getRenderer($field_name);
-    $this->assertEqual($default_formatter, $formatter->getPluginId());
-    $this->assertEqual($formatter_settings, $formatter->getSettings());
+    $this->assertEquals($default_formatter, $formatter->getPluginId());
+    $this->assertEquals($formatter_settings, $formatter->getSettings());
 
     // Check that the formatter is statically persisted, by assigning an
     // arbitrary property and reading it back.
     $random_value = $this->randomString();
     $formatter->randomValue = $random_value;
     $formatter = $display->getRenderer($field_name);
-    $this->assertEqual($random_value, $formatter->randomValue);
+    $this->assertEquals($random_value, $formatter->randomValue);
 
     // Check that changing the definition creates a new formatter.
     $display->setComponent($field_name, [
       'type' => 'field_test_multiple',
     ]);
     $formatter = $display->getRenderer($field_name);
-    $this->assertEqual('field_test_multiple', $formatter->getPluginId());
+    $this->assertEquals('field_test_multiple', $formatter->getPluginId());
     $this->assertFalse(isset($formatter->randomValue));
 
     // Check that the display has dependencies on the field and the module that
     // provides the formatter.
     $dependencies = $display->calculateDependencies()->getDependencies();
-    $this->assertEqual(['config' => ['field.field.entity_test.entity_test.test_field'], 'module' => ['entity_test', 'field_test']], $dependencies);
+    $this->assertEquals(['config' => ['field.field.entity_test.entity_test.test_field'], 'module' => ['entity_test', 'field_test']], $dependencies);
   }
 
   /**
@@ -312,7 +312,7 @@ class EntityDisplayTest extends KernelTestBase {
       ],
     ];
     foreach ($expected as $field_name => $options) {
-      $this->assertEqual($options, $display->getComponent($field_name));
+      $this->assertEquals($options, $display->getComponent($field_name));
     }
 
     // Check that saving the display only writes data for fields whose display
@@ -322,14 +322,14 @@ class EntityDisplayTest extends KernelTestBase {
     $data = $config->get();
     $this->assertFalse(isset($data['content']['test_no_display']));
     $this->assertFalse(isset($data['hidden']['test_no_display']));
-    $this->assertEqual($expected['test_display_configurable'], $data['content']['test_display_configurable']);
+    $this->assertEquals($expected['test_display_configurable'], $data['content']['test_display_configurable']);
     $this->assertFalse(isset($data['content']['test_display_non_configurable']));
     $this->assertFalse(isset($data['hidden']['test_display_non_configurable']));
 
     // Check that defaults are correctly filled when loading the display.
     $display = EntityViewDisplay::load($display->id());
     foreach ($expected as $field_name => $options) {
-      $this->assertEqual($options, $display->getComponent($field_name));
+      $this->assertEquals($options, $display->getComponent($field_name));
     }
 
     // Check that data manually written for fields whose display is not
@@ -339,7 +339,7 @@ class EntityDisplayTest extends KernelTestBase {
     $config->setData($data)->save();
     $display = EntityViewDisplay::load($display->id());
     foreach ($expected as $field_name => $options) {
-      $this->assertEqual($options, $display->getComponent($field_name));
+      $this->assertEquals($options, $display->getComponent($field_name));
     }
   }
 
@@ -445,13 +445,13 @@ class EntityDisplayTest extends KernelTestBase {
 
     // Check the component exists and is of the correct type.
     $display = $display_repository->getViewDisplay('entity_test', 'entity_test');
-    $this->assertEqual('field_plugins_test_text_formatter', $display->getComponent($field_name)['type']);
+    $this->assertEquals('field_plugins_test_text_formatter', $display->getComponent($field_name)['type']);
 
     // Removing the field_plugins_test module should change the component to use
     // the default formatter for test fields.
     \Drupal::service('config.manager')->uninstall('module', 'field_plugins_test');
     $display = $display_repository->getViewDisplay('entity_test', 'entity_test');
-    $this->assertEqual('text_default', $display->getComponent($field_name)['type']);
+    $this->assertEquals('text_default', $display->getComponent($field_name)['type']);
 
     // Removing the text module should remove the field from the view display.
     \Drupal::service('config.manager')->uninstall('module', 'text');
@@ -509,17 +509,17 @@ class EntityDisplayTest extends KernelTestBase {
 
     // Test getViewModeOptionsByBundle().
     $view_modes = \Drupal::service('entity_display.repository')->getViewModeOptionsByBundle('node', 'article');
-    $this->assertEqual(['default' => 'Default'], $view_modes);
+    $this->assertEquals(['default' => 'Default'], $view_modes);
     $display_teaser->setStatus(TRUE)->save();
     $view_modes = \Drupal::service('entity_display.repository')->getViewModeOptionsByBundle('node', 'article');
-    $this->assertEqual(['default' => 'Default', 'teaser' => 'Teaser'], $view_modes);
+    $this->assertEquals(['default' => 'Default', 'teaser' => 'Teaser'], $view_modes);
 
     // Test getFormModeOptionsByBundle().
     $form_modes = \Drupal::service('entity_display.repository')->getFormModeOptionsByBundle('user', 'user');
-    $this->assertEqual(['default' => 'Default'], $form_modes);
+    $this->assertEquals(['default' => 'Default'], $form_modes);
     $form_display_teaser->setStatus(TRUE)->save();
     $form_modes = \Drupal::service('entity_display.repository')->getFormModeOptionsByBundle('user', 'user');
-    $this->assertEqual(['default' => 'Default', 'register' => 'Register'], $form_modes);
+    $this->assertEquals(['default' => 'Default', 'register' => 'Register'], $form_modes);
   }
 
   /**
