@@ -88,7 +88,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
       'file_test_replace' => FileSystemInterface::EXISTS_REPLACE,
       'files[file_test_upload][]' => $file_system->realpath($this->image->getFileUri()),
     ];
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('You WIN!'));
 
@@ -111,7 +112,7 @@ class SaveUploadFormTest extends FileManagedTestBase {
     $file1 = File::load($max_fid_after);
     $this->assertInstanceOf(File::class, $file1);
     // MIME type of the uploaded image may be either image/jpeg or image/png.
-    $this->assertEqual('image', substr($file1->getMimeType(), 0, 5), 'A MIME type was set.');
+    $this->assertEquals('image', substr($file1->getMimeType(), 0, 5), 'A MIME type was set.');
 
     // Reset the hook counters to get rid of the 'load' we just called.
     file_test_reset();
@@ -121,7 +122,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
     /** @var \Drupal\Core\File\FileSystemInterface $file_system */
     $file_system = \Drupal::service('file_system');
     $edit = ['files[file_test_upload][]' => $file_system->realpath($image2->uri)];
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('You WIN!'));
     $max_fid_after = (int) \Drupal::entityQueryAggregate('file')
@@ -135,7 +137,7 @@ class SaveUploadFormTest extends FileManagedTestBase {
     $file2 = File::load($max_fid_after);
     $this->assertInstanceOf(File::class, $file2);
     // MIME type of the uploaded image may be either image/jpeg or image/png.
-    $this->assertEqual('image', substr($file2->getMimeType(), 0, 5), 'A MIME type was set.');
+    $this->assertEquals('image', substr($file2->getMimeType(), 0, 5), 'A MIME type was set.');
 
     // Load both files using File::loadMultiple().
     $files = File::loadMultiple([$file1->id(), $file2->id()]);
@@ -150,7 +152,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
       'files[file_test_upload][]' => $image3_realpath,
       'file_subdir' => $dir,
     ];
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('You WIN!'));
     $this->assertFileExists('temporary://' . $dir . '/' . trim(\Drupal::service('file_system')->basename($image3_realpath)));
@@ -173,7 +176,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
       'extensions' => $extensions,
     ];
 
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertSession()->responseContains('Only files with the following extensions are allowed: <em class="placeholder">' . $extensions . '</em>');
     $this->assertRaw(t('Epic upload FAIL!'));
@@ -192,7 +196,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
       'extensions' => $extensions,
     ];
 
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertNoRaw(t('Only files with the following extensions are allowed:'));
     $this->assertRaw(t('You WIN!'));
@@ -209,7 +214,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
       'files[file_test_upload][]' => $file_system->realpath($this->image->getFileUri()),
       'allow_all_extensions' => 'empty_array',
     ];
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertNoRaw(t('Only files with the following extensions are allowed:'));
     $this->assertRaw(t('You WIN!'));
@@ -234,7 +240,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
       'extensions' => 'php',
     ];
 
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertSession()->responseContains('For security reasons, your upload has been renamed to <em class="placeholder">' . $this->phpfile->filename . '_.txt' . '</em>');
     $this->assertRaw(t('File MIME type is text/plain.'));
@@ -249,7 +256,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
     // Reset the hook counters.
     file_test_reset();
 
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertNoRaw(t('For security reasons, your upload has been renamed'));
     $this->assertRaw(t('File name is @filename', ['@filename' => $this->phpfile->filename]));
@@ -286,7 +294,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
     $munged_filename = substr($munged_filename, 0, strrpos($munged_filename, '.'));
     $munged_filename .= '_.' . $this->imageExtension;
 
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('For security reasons, your upload has been renamed'));
     $this->assertRaw(t('File name is @filename', ['@filename' => $munged_filename]));
@@ -309,7 +318,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
     $munged_filename = substr($munged_filename, 0, strrpos($munged_filename, '.'));
     $munged_filename .= '_.' . $this->imageExtension;
 
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('For security reasons, your upload has been renamed'));
     $this->assertRaw(t('File name is @filename', ['@filename' => $munged_filename]));
@@ -328,7 +338,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
       'allow_all_extensions' => 'empty_array',
     ];
 
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertNoRaw(t('For security reasons, your upload has been renamed'));
     $this->assertRaw(t('File name is @filename', ['@filename' => $this->image->getFilename()]));
@@ -347,7 +358,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
       'allow_all_extensions' => 'empty_string',
     ];
 
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertNoRaw(t('For security reasons, your upload has been renamed'));
     $this->assertRaw(t('Epic upload FAIL!'));
@@ -366,7 +378,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
       'file_test_replace' => FileSystemInterface::EXISTS_RENAME,
       'files[file_test_upload][]' => $file_system->realpath($this->image->getFileUri()),
     ];
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('You WIN!'));
 
@@ -384,7 +397,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
       'file_test_replace' => FileSystemInterface::EXISTS_REPLACE,
       'files[file_test_upload][]' => $file_system->realpath($this->image->getFileUri()),
     ];
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('You WIN!'));
 
@@ -402,7 +416,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
       'file_test_replace' => FileSystemInterface::EXISTS_ERROR,
       'files[file_test_upload][]' => $file_system->realpath($this->image->getFileUri()),
     ];
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('Epic upload FAIL!'));
 
@@ -414,7 +429,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
    * Tests for no failures when not uploading a file.
    */
   public function testNoUpload() {
-    $this->drupalPostForm('file-test/save_upload_from_form_test', [], 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm([], 'Submit');
     $this->assertNoRaw(t('Epic upload FAIL!'));
   }
 
@@ -435,7 +451,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
     ];
 
     \Drupal::state()->set('file_test.disable_error_collection', TRUE);
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('File upload error. Could not move uploaded file.'));
     $this->assertRaw(t('Epic upload FAIL!'));
@@ -461,13 +478,14 @@ class SaveUploadFormTest extends FileManagedTestBase {
       'files[file_test_upload][]' => $file_system->realpath($this->image->getFileUri()),
       'error_message' => $error,
     ];
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('You WIN!'));
 
     // Ensure the expected error message is present and the counts before and
     // after calling _file_save_upload_from_form() are correct.
-    $this->assertText($error);
+    $this->assertSession()->pageTextContains($error);
     $this->assertRaw('Number of error messages before _file_save_upload_from_form(): 1');
     $this->assertRaw('Number of error messages after _file_save_upload_from_form(): 1');
 
@@ -477,13 +495,14 @@ class SaveUploadFormTest extends FileManagedTestBase {
       'error_message' => $error,
       'extensions' => 'foo',
     ];
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('Epic upload FAIL!'));
 
     // Ensure the expected error message is present and the counts before and
     // after calling _file_save_upload_from_form() are correct.
-    $this->assertText($error);
+    $this->assertSession()->pageTextContains($error);
     $this->assertRaw('Number of error messages before _file_save_upload_from_form(): 1');
     $this->assertRaw('Number of error messages after _file_save_upload_from_form(): 1');
 
@@ -491,7 +510,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
     $edit = [
       'files[file_test_upload][]' => $file_system->realpath($this->image->getFileUri()),
     ];
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('You WIN!'));
 
@@ -512,7 +532,7 @@ class SaveUploadFormTest extends FileManagedTestBase {
     /** @var \Drupal\Core\File\FileSystemInterface $file_system */
     $file_system = \Drupal::service('file_system');
 
-    // Can't use drupalPostForm() for set nonexistent fields.
+    // Can't use submitForm() for set nonexistent fields.
     $this->drupalGet('file-test/save_upload_from_form_test');
     $client = $this->getSession()->getDriver()->getClient();
     $submit_xpath = $this->assertSession()->buttonExists('Submit')->getXpath();
@@ -544,7 +564,8 @@ class SaveUploadFormTest extends FileManagedTestBase {
       'files[file_test_upload][]' => $file_system->realpath($this->image->getFileUri()),
       'extensions' => 'foo',
     ];
-    $this->drupalPostForm('file-test/save_upload_from_form_test', $edit, 'Submit');
+    $this->drupalGet('file-test/save_upload_from_form_test');
+    $this->submitForm($edit, 'Submit');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('Epic upload FAIL!'));
     $this->assertCount(1, $this->cssSelect('input[name="files[file_test_upload][]"].error'), 'File upload field has error.');
