@@ -26,13 +26,13 @@ class CopyTest extends FileManagedUnitTestBase {
 
     // Check the return status and that the contents changed.
     $this->assertNotFalse($result, 'File copied successfully.');
-    $this->assertEqual($contents, file_get_contents($result->getFileUri()), 'Contents of file were copied correctly.');
+    $this->assertEquals($contents, file_get_contents($result->getFileUri()), 'Contents of file were copied correctly.');
 
     // Check that the correct hooks were called.
     $this->assertFileHooksCalled(['copy', 'insert']);
 
     $this->assertDifferentFile($source, $result);
-    $this->assertEqual($result->getFileUri(), $desired_uri, 'The copied file entity has the desired filepath.');
+    $this->assertEquals($result->getFileUri(), $desired_uri, 'The copied file entity has the desired filepath.');
     $this->assertFileExists($source->getFileUri());
     $this->assertFileExists($result->getFileUri());
 
@@ -57,8 +57,8 @@ class CopyTest extends FileManagedUnitTestBase {
 
     // Check the return status and that the contents changed.
     $this->assertNotFalse($result, 'File copied successfully.');
-    $this->assertEqual($contents, file_get_contents($result->getFileUri()), 'Contents of file were copied correctly.');
-    $this->assertNotEqual($result->getFileUri(), $source->getFileUri(), 'Returned file path has changed from the original.');
+    $this->assertEquals($contents, file_get_contents($result->getFileUri()), 'Contents of file were copied correctly.');
+    $this->assertNotEquals($source->getFileUri(), $result->getFileUri(), 'Returned file path has changed from the original.');
 
     // Check that the correct hooks were called.
     $this->assertFileHooksCalled(['copy', 'insert']);
@@ -97,7 +97,7 @@ class CopyTest extends FileManagedUnitTestBase {
 
     // Check the return status and that the contents changed.
     $this->assertNotFalse($result, 'File copied successfully.');
-    $this->assertEqual($contents, file_get_contents($result->getFileUri()), 'Contents of file were overwritten.');
+    $this->assertEquals($contents, file_get_contents($result->getFileUri()), 'Contents of file were overwritten.');
     $this->assertDifferentFile($source, $result);
 
     // Check that the correct hooks were called.
@@ -134,7 +134,7 @@ class CopyTest extends FileManagedUnitTestBase {
 
     // Check the return status and that the contents were not changed.
     $this->assertFalse($result, 'File copy failed.');
-    $this->assertEqual($contents, file_get_contents($target->getFileUri()), 'Contents of file were not altered.');
+    $this->assertEquals($contents, file_get_contents($target->getFileUri()), 'Contents of file were not altered.');
 
     // Check that the correct hooks were called.
     $this->assertFileHooksCalled([]);
