@@ -28,13 +28,13 @@ class MoveTest extends FileManagedUnitTestBase {
     // Check the return status and that the contents changed.
     $this->assertNotFalse($result, 'File moved successfully.');
     $this->assertFileNotExists($source->getFileUri());
-    $this->assertEqual($contents, file_get_contents($result->getFileUri()), 'Contents of file correctly written.');
+    $this->assertEquals($contents, file_get_contents($result->getFileUri()), 'Contents of file correctly written.');
 
     // Check that the correct hooks were called.
     $this->assertFileHooksCalled(['move', 'load', 'update']);
 
     // Make sure we got the same file back.
-    $this->assertEqual($source->id(), $result->id(), new FormattableMarkup("Source file id's' %fid is unchanged after move.", ['%fid' => $source->id()]));
+    $this->assertEquals($source->id(), $result->id(), new FormattableMarkup("Source file id's' %fid is unchanged after move.", ['%fid' => $source->id()]));
 
     // Reload the file from the database and check that the changes were
     // actually saved.
@@ -60,7 +60,7 @@ class MoveTest extends FileManagedUnitTestBase {
     // Check the return status and that the contents changed.
     $this->assertNotFalse($result, 'File moved successfully.');
     $this->assertFileNotExists($source->getFileUri());
-    $this->assertEqual($contents, file_get_contents($result->getFileUri()), 'Contents of file correctly written.');
+    $this->assertEquals($contents, file_get_contents($result->getFileUri()), 'Contents of file correctly written.');
 
     // Check that the correct hooks were called.
     $this->assertFileHooksCalled(['move', 'load', 'update']);
@@ -74,8 +74,8 @@ class MoveTest extends FileManagedUnitTestBase {
 
     // Compare the source and results.
     $loaded_source = File::load($source->id());
-    $this->assertEqual($loaded_source->id(), $result->id(), "Returned file's id matches the source.");
-    $this->assertNotEqual($loaded_source->getFileUri(), $source->getFileUri(), 'Returned file path has changed from the original.');
+    $this->assertEquals($result->id(), $loaded_source->id(), "Returned file's id matches the source.");
+    $this->assertNotEquals($source->getFileUri(), $loaded_source->getFileUri(), 'Returned file path has changed from the original.');
   }
 
   /**
@@ -93,7 +93,7 @@ class MoveTest extends FileManagedUnitTestBase {
     $result = file_move(clone $source, $target->getFileUri(), FileSystemInterface::EXISTS_REPLACE);
 
     // Look at the results.
-    $this->assertEqual($contents, file_get_contents($result->getFileUri()), 'Contents of file were overwritten.');
+    $this->assertEquals($contents, file_get_contents($result->getFileUri()), 'Contents of file were overwritten.');
     $this->assertFileNotExists($source->getFileUri());
     $this->assertNotEmpty($result, 'File moved successfully.');
 
@@ -122,7 +122,7 @@ class MoveTest extends FileManagedUnitTestBase {
     // about the function changing our reference copy.
     $result = file_move(clone $source, $source->getFileUri(), FileSystemInterface::EXISTS_REPLACE);
     $this->assertFalse($result, 'File move failed.');
-    $this->assertEqual($contents, file_get_contents($source->getFileUri()), 'Contents of file were not altered.');
+    $this->assertEquals($contents, file_get_contents($source->getFileUri()), 'Contents of file were not altered.');
 
     // Check that no hooks were called while failing.
     $this->assertFileHooksCalled([]);
@@ -148,7 +148,7 @@ class MoveTest extends FileManagedUnitTestBase {
     // Check the return status and that the contents did not change.
     $this->assertFalse($result, 'File move failed.');
     $this->assertFileExists($source->getFileUri());
-    $this->assertEqual($contents, file_get_contents($target->getFileUri()), 'Contents of file were not altered.');
+    $this->assertEquals($contents, file_get_contents($target->getFileUri()), 'Contents of file were not altered.');
 
     // Check that no hooks were called while failing.
     $this->assertFileHooksCalled([]);
