@@ -389,7 +389,7 @@ class FilterKernelTest extends KernelTestBase {
     $limit = max(ini_get('pcre.backtrack_limit'), ini_get('pcre.recursion_limit'));
     $source = $this->randomMachineName($limit);
     $result = _filter_autop($source);
-    $success = $this->assertEqual($result, '<p>' . $source . "</p>\n", 'Line break filter can process very long strings.');
+    $success = $this->assertEquals($result, '<p>' . $source . "</p>\n", 'Line break filter can process very long strings.');
     if (!$success) {
       $this->verbose("\n" . $source . "\n<hr />\n" . $result);
     }
@@ -940,112 +940,112 @@ www.example.com with a newline in comments -->
   public function testHtmlCorrectorFilter() {
     // Tag closing.
     $f = Html::normalize('<p>text');
-    $this->assertEqual($f, '<p>text</p>', 'HTML corrector -- tag closing at the end of input.');
+    $this->assertEquals($f, '<p>text</p>', 'HTML corrector -- tag closing at the end of input.');
 
     $f = Html::normalize('<p>text<p><p>text');
-    $this->assertEqual($f, '<p>text</p><p></p><p>text</p>', 'HTML corrector -- tag closing.');
+    $this->assertEquals($f, '<p>text</p><p></p><p>text</p>', 'HTML corrector -- tag closing.');
 
     $f = Html::normalize("<ul><li>e1<li>e2");
-    $this->assertEqual($f, "<ul><li>e1</li><li>e2</li></ul>", 'HTML corrector -- unclosed list tags.');
+    $this->assertEquals($f, "<ul><li>e1</li><li>e2</li></ul>", 'HTML corrector -- unclosed list tags.');
 
     $f = Html::normalize('<div id="d">content');
-    $this->assertEqual($f, '<div id="d">content</div>', 'HTML corrector -- unclosed tag with attribute.');
+    $this->assertEquals($f, '<div id="d">content</div>', 'HTML corrector -- unclosed tag with attribute.');
 
     // XHTML slash for empty elements.
     $f = Html::normalize('<hr><br>');
-    $this->assertEqual($f, '<hr /><br />', 'HTML corrector -- XHTML closing slash.');
+    $this->assertEquals($f, '<hr /><br />', 'HTML corrector -- XHTML closing slash.');
 
     $f = Html::normalize('<P>test</P>');
-    $this->assertEqual($f, '<p>test</p>', 'HTML corrector -- Convert uppercased tags to proper lowercased ones.');
+    $this->assertEquals($f, '<p>test</p>', 'HTML corrector -- Convert uppercased tags to proper lowercased ones.');
 
     $f = Html::normalize('<P>test</p>');
-    $this->assertEqual($f, '<p>test</p>', 'HTML corrector -- Convert uppercased tags to proper lowercased ones.');
+    $this->assertEquals($f, '<p>test</p>', 'HTML corrector -- Convert uppercased tags to proper lowercased ones.');
 
     $f = Html::normalize('test<hr />');
-    $this->assertEqual($f, 'test<hr />', 'HTML corrector -- Let proper XHTML pass through.');
+    $this->assertEquals($f, 'test<hr />', 'HTML corrector -- Let proper XHTML pass through.');
 
     $f = Html::normalize('test<hr/>');
-    $this->assertEqual($f, 'test<hr />', 'HTML corrector -- Let proper XHTML pass through, but ensure there is a single space before the closing slash.');
+    $this->assertEquals($f, 'test<hr />', 'HTML corrector -- Let proper XHTML pass through, but ensure there is a single space before the closing slash.');
 
     $f = Html::normalize('test<hr    />');
-    $this->assertEqual($f, 'test<hr />', 'HTML corrector -- Let proper XHTML pass through, but ensure there are not too many spaces before the closing slash.');
+    $this->assertEquals($f, 'test<hr />', 'HTML corrector -- Let proper XHTML pass through, but ensure there are not too many spaces before the closing slash.');
 
     $f = Html::normalize('<span class="test" />');
-    $this->assertEqual($f, '<span class="test"></span>', 'HTML corrector -- Convert XHTML that is properly formed but that would not be compatible with typical HTML user agents.');
+    $this->assertEquals($f, '<span class="test"></span>', 'HTML corrector -- Convert XHTML that is properly formed but that would not be compatible with typical HTML user agents.');
 
     $f = Html::normalize('test1<br class="test">test2');
-    $this->assertEqual($f, 'test1<br class="test" />test2', 'HTML corrector -- Automatically close single tags.');
+    $this->assertEquals($f, 'test1<br class="test" />test2', 'HTML corrector -- Automatically close single tags.');
 
     $f = Html::normalize('line1<hr>line2');
-    $this->assertEqual($f, 'line1<hr />line2', 'HTML corrector -- Automatically close single tags.');
+    $this->assertEquals($f, 'line1<hr />line2', 'HTML corrector -- Automatically close single tags.');
 
     $f = Html::normalize('line1<HR>line2');
-    $this->assertEqual($f, 'line1<hr />line2', 'HTML corrector -- Automatically close single tags.');
+    $this->assertEquals($f, 'line1<hr />line2', 'HTML corrector -- Automatically close single tags.');
 
     $f = Html::normalize('<img src="http://example.com/test.jpg">test</img>');
-    $this->assertEqual($f, '<img src="http://example.com/test.jpg" />test', 'HTML corrector -- Automatically close single tags.');
+    $this->assertEquals($f, '<img src="http://example.com/test.jpg" />test', 'HTML corrector -- Automatically close single tags.');
 
     $f = Html::normalize('<br></br>');
-    $this->assertEqual($f, '<br />', "HTML corrector -- Transform empty tags to a single closed tag if the tag's content model is EMPTY.");
+    $this->assertEquals($f, '<br />', "HTML corrector -- Transform empty tags to a single closed tag if the tag's content model is EMPTY.");
 
     $f = Html::normalize('<div></div>');
-    $this->assertEqual($f, '<div></div>', "HTML corrector -- Do not transform empty tags to a single closed tag if the tag's content model is not EMPTY.");
+    $this->assertEquals($f, '<div></div>', "HTML corrector -- Do not transform empty tags to a single closed tag if the tag's content model is not EMPTY.");
 
     $f = Html::normalize('<p>line1<br/><hr/>line2</p>');
-    $this->assertEqual($f, '<p>line1<br /></p><hr />line2', 'HTML corrector -- Move non-inline elements outside of inline containers.');
+    $this->assertEquals($f, '<p>line1<br /></p><hr />line2', 'HTML corrector -- Move non-inline elements outside of inline containers.');
 
     $f = Html::normalize('<p>line1<div>line2</div></p>');
-    $this->assertEqual($f, '<p>line1</p><div>line2</div>', 'HTML corrector -- Move non-inline elements outside of inline containers.');
+    $this->assertEquals($f, '<p>line1</p><div>line2</div>', 'HTML corrector -- Move non-inline elements outside of inline containers.');
 
     $f = Html::normalize('<p>test<p>test</p>\n');
-    $this->assertEqual($f, '<p>test</p><p>test</p>\n', 'HTML corrector -- Auto-close improperly nested tags.');
+    $this->assertEquals($f, '<p>test</p><p>test</p>\n', 'HTML corrector -- Auto-close improperly nested tags.');
 
     $f = Html::normalize('<p>Line1<br><STRONG>bold stuff</b>');
-    $this->assertEqual($f, '<p>Line1<br /><strong>bold stuff</strong></p>', 'HTML corrector -- Properly close unclosed tags, and remove useless closing tags.');
+    $this->assertEquals($f, '<p>Line1<br /><strong>bold stuff</strong></p>', 'HTML corrector -- Properly close unclosed tags, and remove useless closing tags.');
 
     $f = Html::normalize('test <!-- this is a comment -->');
-    $this->assertEqual($f, 'test <!-- this is a comment -->', 'HTML corrector -- Do not touch HTML comments.');
+    $this->assertEquals($f, 'test <!-- this is a comment -->', 'HTML corrector -- Do not touch HTML comments.');
 
     $f = Html::normalize('test <!--this is a comment-->');
-    $this->assertEqual($f, 'test <!--this is a comment-->', 'HTML corrector -- Do not touch HTML comments.');
+    $this->assertEquals($f, 'test <!--this is a comment-->', 'HTML corrector -- Do not touch HTML comments.');
 
     $f = Html::normalize('test <!-- comment <p>another
     <strong>multiple</strong> line
     comment</p> -->');
-    $this->assertEqual($f, 'test <!-- comment <p>another
+    $this->assertEquals($f, 'test <!-- comment <p>another
     <strong>multiple</strong> line
     comment</p> -->', 'HTML corrector -- Do not touch HTML comments.');
 
     $f = Html::normalize('test <!-- comment <p>another comment</p> -->');
-    $this->assertEqual($f, 'test <!-- comment <p>another comment</p> -->', 'HTML corrector -- Do not touch HTML comments.');
+    $this->assertEquals($f, 'test <!-- comment <p>another comment</p> -->', 'HTML corrector -- Do not touch HTML comments.');
 
     $f = Html::normalize('test <!--break-->');
-    $this->assertEqual($f, 'test <!--break-->', 'HTML corrector -- Do not touch HTML comments.');
+    $this->assertEquals($f, 'test <!--break-->', 'HTML corrector -- Do not touch HTML comments.');
 
     $f = Html::normalize('<p>test\n</p>\n');
-    $this->assertEqual($f, '<p>test\n</p>\n', 'HTML corrector -- New-lines are accepted and kept as-is.');
+    $this->assertEquals($f, '<p>test\n</p>\n', 'HTML corrector -- New-lines are accepted and kept as-is.');
 
     // cSpell:disable
     $f = Html::normalize('<p>دروبال');
-    $this->assertEqual($f, '<p>دروبال</p>', 'HTML corrector -- Encoding is correctly kept.');
+    $this->assertEquals($f, '<p>دروبال</p>', 'HTML corrector -- Encoding is correctly kept.');
     // cSpell:enable
 
     $f = Html::normalize('<script>alert("test")</script>');
-    $this->assertEqual($f, '<script>
+    $this->assertEquals($f, '<script>
 <!--//--><![CDATA[// ><!--
 alert("test")
 //--><!]]>
 </script>', 'HTML corrector -- CDATA added to script element');
 
     $f = Html::normalize('<p><script>alert("test")</script></p>');
-    $this->assertEqual($f, '<p><script>
+    $this->assertEquals($f, '<p><script>
 <!--//--><![CDATA[// ><!--
 alert("test")
 //--><!]]>
 </script></p>', 'HTML corrector -- CDATA added to a nested script element');
 
     $f = Html::normalize('<p><style> /* Styling */ body {color:red}</style></p>');
-    $this->assertEqual($f, '<p><style>
+    $this->assertEquals($f, '<p><style>
 <!--/*--><![CDATA[/* ><!--*/
  /* Styling */ body {color:red}
 /*--><!]]>*/
@@ -1057,7 +1057,7 @@ alert("test")
 body {color:red}
 /*]]>*/
 </style></p>');
-    $this->assertEqual($filtered_data, '<p><style>
+    $this->assertEquals($filtered_data, '<p><style>
 <!--/*--><![CDATA[/* ><!--*/
 
 /*<![CDATA[*/
@@ -1076,7 +1076,7 @@ body {color:red}
   body {color:red}
   /*--><!]]>*/
 </style></p>');
-    $this->assertEqual($filtered_data, '<p><style>
+    $this->assertEquals($filtered_data, '<p><style>
 <!--/*--><![CDATA[/* ><!--*/
 
   <!--/*--><![CDATA[/* ><!--*/
@@ -1094,7 +1094,7 @@ body {color:red}
   alert("test");
 //--><!]]>
 </script></p>');
-    $this->assertEqual($filtered_data, '<p><script>
+    $this->assertEquals($filtered_data, '<p><script>
 <!--//--><![CDATA[// ><!--
 
 <!--//--><![CDATA[// ><!--
@@ -1111,7 +1111,7 @@ body {color:red}
   alert("test");
 // ]]>
 </script></p>');
-    $this->assertEqual($filtered_data, '<p><script>
+    $this->assertEquals($filtered_data, '<p><script>
 <!--//--><![CDATA[// ><!--
 
 // <![CDATA[
