@@ -171,7 +171,7 @@ class ForumTest extends BrowserTestBase {
     $this->drupalLogin($this->webUser);
     // Verify that this user is shown a message that they may not post content.
     $this->drupalGet('forum/' . $this->forum['tid']);
-    $this->assertText('You are not allowed to post new content in the forum');
+    $this->assertSession()->pageTextContains('You are not allowed to post new content in the forum');
 
     // Log in, and do basic tests for a user with permission to edit any forum
     // content.
@@ -229,7 +229,8 @@ class ForumTest extends BrowserTestBase {
       'create forum content',
       'post comments',
     ]));
-    $this->drupalPostForm('admin/structure/types/manage/forum', ['options[promote]' => 'promote'], 'Save content type');
+    $this->drupalGet('admin/structure/types/manage/forum');
+    $this->submitForm(['options[promote]' => 'promote'], 'Save content type');
     $this->createForumTopic($this->forum, FALSE);
     $this->createForumTopic($this->forum, FALSE);
     $this->drupalGet('node');
@@ -238,13 +239,15 @@ class ForumTest extends BrowserTestBase {
     $node = $this->createForumTopic($this->forum, FALSE);
     $edit = [];
     $edit['comment_body[0][value]'] = $this->randomMachineName();
-    $this->drupalPostForm('node/' . $node->id(), $edit, 'Save');
+    $this->drupalGet('node/' . $node->id());
+    $this->submitForm($edit, 'Save');
     $this->assertSession()->statusCodeEquals(200);
 
     // Test editing a forum topic that has a comment.
     $this->drupalLogin($this->editAnyTopicsUser);
     $this->drupalGet('forum/' . $this->forum['tid']);
-    $this->drupalPostForm('node/' . $node->id() . '/edit', [], 'Save');
+    $this->drupalGet('node/' . $node->id() . '/edit');
+    $this->submitForm([], 'Save');
     $this->assertSession()->statusCodeEquals(200);
 
     // Test the root forum page title change.
@@ -285,7 +288,8 @@ class ForumTest extends BrowserTestBase {
     $edit['title[0][value]'] = $this->randomMachineName(10);
     $edit['body[0][value]'] = $this->randomMachineName(120);
     $this->drupalLogin($this->adminUser);
-    $this->drupalPostForm('node/add/forum', $edit, 'Save');
+    $this->drupalGet('node/add/forum');
+    $this->submitForm($edit, 'Save');
 
     $nid_count = $this->container->get('entity_type.manager')
       ->getStorage('node')
@@ -293,7 +297,7 @@ class ForumTest extends BrowserTestBase {
       ->accessCheck(FALSE)
       ->count()
       ->execute();
-    $this->assertEqual(0, $nid_count, 'A forum node was not created when missing a forum vocabulary.');
+    $this->assertEquals(0, $nid_count, 'A forum node was not created when missing a forum vocabulary.');
 
     // Reset the defaults for future tests.
     \Drupal::service('module_installer')->install(['forum']);
@@ -311,7 +315,8 @@ class ForumTest extends BrowserTestBase {
 
     // Add forum to the Tools menu.
     $edit = [];
-    $this->drupalPostForm('admin/structure/menu/manage/tools', $edit, 'Save');
+    $this->drupalGet('admin/structure/menu/manage/tools');
+    $this->submitForm($edit, 'Save');
     $this->assertSession()->statusCodeEquals(200);
 
     // Edit forum taxonomy.
@@ -322,7 +327,7 @@ class ForumTest extends BrowserTestBase {
     // Verify "edit container" link exists and functions correctly.
     $this->drupalGet('admin/structure/forum');
     // Verify help text is shown.
-    $this->assertText('Forums contain forum topics. Use containers to group related forums');
+    $this->assertSession()->pageTextContains('Forums contain forum topics. Use containers to group related forums');
     // Verify action links are there.
     $this->assertSession()->linkExists('Add forum');
     $this->assertSession()->linkExists('Add container');
@@ -339,7 +344,8 @@ class ForumTest extends BrowserTestBase {
     // Create second forum in container, destined to be deleted below.
     $delete_forum = $this->createForum('forum', $this->forumContainer['tid']);
     // Save forum overview.
-    $this->drupalPostForm('admin/structure/forum/', [], 'Save');
+    $this->drupalGet('admin/structure/forum/');
+    $this->submitForm([], 'Save');
     $this->assertRaw(t('The configuration options have been saved.'));
     // Delete this second forum.
     $this->deleteForum($delete_forum['tid']);
@@ -394,7 +400,8 @@ class ForumTest extends BrowserTestBase {
     ];
 
     // Edit the vocabulary.
-    $this->drupalPostForm('admin/structure/taxonomy/manage/' . $original_vocabulary->id(), $edit, 'Save');
+    $this->drupalGet('admin/structure/taxonomy/manage/' . $original_vocabulary->id());
+    $this->submitForm($edit, 'Save');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('Updated vocabulary %name.', ['%name' => $edit['name']]));
 
@@ -402,8 +409,8 @@ class ForumTest extends BrowserTestBase {
     $current_vocabulary = Vocabulary::load($vid);
 
     // Make sure we actually edited the vocabulary properly.
-    $this->assertEqual($edit['name'], $current_vocabulary->label(), 'The name was updated');
-    $this->assertEqual($edit['description'], $current_vocabulary->getDescription(), 'The description was updated');
+    $this->assertEquals($edit['name'], $current_vocabulary->label(), 'The name was updated');
+    $this->assertEquals($edit['description'], $current_vocabulary->getDescription(), 'The description was updated');
 
     // Restore the original vocabulary's name and description.
     $current_vocabulary->set('name', $original_vocabulary->label());
@@ -411,7 +418,7 @@ class ForumTest extends BrowserTestBase {
     $current_vocabulary->save();
     // Reload vocabulary to make sure changes are saved.
     $current_vocabulary = Vocabulary::load($vid);
-    $this->assertEqual($original_vocabulary->label(), $current_vocabulary->label(), 'The original vocabulary settings were restored');
+    $this->assertEquals($original_vocabulary->label(), $current_vocabulary->label(), 'The original vocabulary settings were restored');
   }
 
   /**
@@ -438,10 +445,11 @@ class ForumTest extends BrowserTestBase {
     ];
 
     // Create forum.
-    $this->drupalPostForm('admin/structure/forum/add/' . $type, $edit, 'Save');
+    $this->drupalGet('admin/structure/forum/add/' . $type);
+    $this->submitForm($edit, 'Save');
     $this->assertSession()->statusCodeEquals(200);
     $type = ($type == 'container') ? 'forum container' : 'forum';
-    $this->assertText('Created new ' . $type . ' ' . $name . '.');
+    $this->assertSession()->pageTextContains('Created new ' . $type . ' ' . $name . '.');
 
     // Verify that the creation message contains a link to a term.
     $this->assertSession()->elementExists('xpath', '//div[@data-drupal-messages]//a[contains(@href, "term/")]');
@@ -464,7 +472,7 @@ class ForumTest extends BrowserTestBase {
     $this->assertTrue($parent == $parent_tid, 'The ' . $type . ' is linked to its container');
 
     $forum = $taxonomy_term_storage->load($tid);
-    $this->assertEqual(($type == 'forum container'), (bool) $forum->forum_container->value);
+    $this->assertEquals(($type == 'forum container'), (bool) $forum->forum_container->value);
     return [
       'tid' => $tid,
       'name' => $term->getName(),
@@ -482,7 +490,7 @@ class ForumTest extends BrowserTestBase {
     // Delete the forum.
     $this->drupalGet('admin/structure/forum/edit/forum/' . $tid);
     $this->clickLink(t('Delete'));
-    $this->assertText('Are you sure you want to delete the forum');
+    $this->assertSession()->pageTextContains('Are you sure you want to delete the forum');
     $this->assertNoText('Add forum');
     $this->assertNoText('Add forum container');
     $this->submitForm([], 'Delete');
@@ -530,7 +538,8 @@ class ForumTest extends BrowserTestBase {
     $edit = [];
     $edit['subject[0][value]'] = $this->randomMachineName();
     $edit['comment_body[0][value]'] = $this->randomMachineName();
-    $this->drupalPostForm('node/' . $node->id(), $edit, 'Save');
+    $this->drupalGet('node/' . $node->id());
+    $this->submitForm($edit, 'Save');
     $this->assertSession()->statusCodeEquals(200);
 
     // Test replying to a comment.
@@ -571,7 +580,8 @@ class ForumTest extends BrowserTestBase {
     $tid = $forum['tid'];
 
     // Create the forum topic, preselecting the forum ID via a URL parameter.
-    $this->drupalPostForm('node/add/forum', $edit, 'Save', ['query' => ['forum_id' => $tid]]);
+    $this->drupalGet('node/add/forum', ['query' => ['forum_id' => $tid]]);
+    $this->submitForm($edit, 'Save');
 
     $type = t('Forum topic');
     if ($container) {
@@ -580,7 +590,7 @@ class ForumTest extends BrowserTestBase {
       return;
     }
     else {
-      $this->assertText($type . ' ' . $title . ' has been created.');
+      $this->assertSession()->pageTextContains($type . ' ' . $title . ' has been created.');
       $this->assertNoRaw(t('The item %title is a forum container, not a forum.', ['%title' => $forum['name']]));
 
       // Verify that the creation message contains a link to a node.
@@ -590,7 +600,7 @@ class ForumTest extends BrowserTestBase {
     // Retrieve node object, ensure that the topic was created and in the proper forum.
     $node = $this->drupalGetNodeByTitle($title);
     $this->assertTrue($node != NULL, new FormattableMarkup('Node @title was loaded', ['@title' => $title]));
-    $this->assertEqual($tid, $node->taxonomy_forums->target_id, 'Saved forum topic was in the expected forum');
+    $this->assertEquals($tid, $node->taxonomy_forums->target_id, 'Saved forum topic was in the expected forum');
 
     // View forum topic.
     $this->drupalGet('node/' . $node->id());
@@ -618,7 +628,7 @@ class ForumTest extends BrowserTestBase {
     $this->assertSession()->statusCodeEquals($response2);
     if ($response2 == 200) {
       $this->assertSession()->titleEquals('Forum | Drupal');
-      $this->assertText('Forum');
+      $this->assertSession()->pageTextContains('Forum');
     }
 
     // View forum container page.
@@ -659,8 +669,9 @@ class ForumTest extends BrowserTestBase {
       // Assume the topic is initially associated with $forum.
       $edit['taxonomy_forums'] = $this->rootForum['tid'];
       $edit['shadow'] = TRUE;
-      $this->drupalPostForm('node/' . $node->id() . '/edit', $edit, 'Save');
-      $this->assertText('Forum topic ' . $edit['title[0][value]'] . ' has been updated.');
+      $this->drupalGet('node/' . $node->id() . '/edit');
+      $this->submitForm($edit, 'Save');
+      $this->assertSession()->pageTextContains('Forum topic ' . $edit['title[0][value]'] . ' has been updated.');
 
       // Verify topic was moved to a different forum.
       $forum_tid = $this->container
@@ -674,7 +685,8 @@ class ForumTest extends BrowserTestBase {
       $this->assertTrue($forum_tid == $this->rootForum['tid'], 'The forum topic is linked to a different forum');
 
       // Delete forum node.
-      $this->drupalPostForm('node/' . $node->id() . '/delete', [], 'Delete');
+      $this->drupalGet('node/' . $node->id() . '/delete');
+      $this->submitForm([], 'Delete');
       $this->assertSession()->statusCodeEquals($response);
       $this->assertRaw(t('Forum topic %title has been deleted.', ['%title' => $edit['title[0][value]']]));
     }
