@@ -19,12 +19,20 @@ class HalLinkManagerTest extends KernelTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['hal', 'hal_test', 'serialization', 'system', 'node', 'user', 'field'];
+  protected static $modules = [
+    'hal',
+    'hal_test',
+    'serialization',
+    'system',
+    'node',
+    'user',
+    'field',
+  ];
 
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->installEntitySchema('node');
@@ -42,8 +50,6 @@ class HalLinkManagerTest extends KernelTestBase {
       'bundle' => 'page',
       'field_name' => 'field_ref',
     ])->save();
-
-    \Drupal::service('router.builder')->rebuild();
   }
 
   /**
@@ -60,7 +66,7 @@ class HalLinkManagerTest extends KernelTestBase {
       $hal_settings->set('link_domain', $link_domain)->save(TRUE);
     }
 
-    /* @var \Drupal\rest\LinkManager\TypeLinkManagerInterface $type_manager */
+    /** @var \Drupal\hal\LinkManager\TypeLinkManagerInterface $type_manager */
     $type_manager = \Drupal::service('hal.link_manager.type');
 
     $link = $type_manager->getTypeUri($entity_type, $bundle, $context);
@@ -70,10 +76,10 @@ class HalLinkManagerTest extends KernelTestBase {
 
   public function providerTestGetTypeUri() {
     $serialization_context_collecting_cacheability = [
-      CacheableNormalizerInterface::SERIALIZATION_CONTEXT_CACHEABILITY => new CacheableMetadata()
+      CacheableNormalizerInterface::SERIALIZATION_CONTEXT_CACHEABILITY => new CacheableMetadata(),
     ];
     $expected_serialization_context_cacheability_url_site = [
-      CacheableNormalizerInterface::SERIALIZATION_CONTEXT_CACHEABILITY => (new CacheableMetadata())->setCacheContexts(['url.site'])
+      CacheableNormalizerInterface::SERIALIZATION_CONTEXT_CACHEABILITY => (new CacheableMetadata())->setCacheContexts(['url.site']),
     ];
 
     $base_test_case = [
@@ -106,18 +112,6 @@ class HalLinkManagerTest extends KernelTestBase {
         // No cacheability metadata bubbled.
         'expected context' => ['hal_test' => TRUE] + $serialization_context_collecting_cacheability,
       ],
-      // Test hook_rest_type_uri_alter() — for backwards compatibility.
-      'site URL, with optional context, to test hook_rest_type_uri_alter()' => $base_test_case + [
-        'context' => ['rest_test' => TRUE],
-        'expected return' => 'rest_test_type',
-        'expected context' => ['rest_test' => TRUE],
-      ],
-      'site URL, with optional context, to test hook_rest_type_uri_alter(), and collecting cacheability metadata' => $base_test_case + [
-        'context' => ['rest_test' => TRUE] + $serialization_context_collecting_cacheability,
-        'expected return' => 'rest_test_type',
-          // No cacheability metadata bubbled.
-        'expected context' => ['rest_test' => TRUE] + $serialization_context_collecting_cacheability,
-      ],
       'configured URL' => [
         'link_domain' => 'http://llamas-rock.com/for-real/',
         'entity_type' => 'node',
@@ -153,7 +147,7 @@ class HalLinkManagerTest extends KernelTestBase {
       $hal_settings->set('link_domain', $link_domain)->save(TRUE);
     }
 
-    /* @var \Drupal\rest\LinkManager\RelationLinkManagerInterface $relation_manager */
+    /** @var \Drupal\hal\LinkManager\RelationLinkManagerInterface $relation_manager */
     $relation_manager = \Drupal::service('hal.link_manager.relation');
 
     $link = $relation_manager->getRelationUri($entity_type, $bundle, $field_name, $context);
@@ -163,10 +157,10 @@ class HalLinkManagerTest extends KernelTestBase {
 
   public function providerTestGetRelationUri() {
     $serialization_context_collecting_cacheability = [
-      CacheableNormalizerInterface::SERIALIZATION_CONTEXT_CACHEABILITY => new CacheableMetadata()
+      CacheableNormalizerInterface::SERIALIZATION_CONTEXT_CACHEABILITY => new CacheableMetadata(),
     ];
     $expected_serialization_context_cacheability_url_site = [
-      CacheableNormalizerInterface::SERIALIZATION_CONTEXT_CACHEABILITY => (new CacheableMetadata())->setCacheContexts(['url.site'])
+      CacheableNormalizerInterface::SERIALIZATION_CONTEXT_CACHEABILITY => (new CacheableMetadata())->setCacheContexts(['url.site']),
     ];
 
     $field_name = $this->randomMachineName();
@@ -201,18 +195,6 @@ class HalLinkManagerTest extends KernelTestBase {
         // No cacheability metadata bubbled.
         'expected context' => ['hal_test' => TRUE] + $serialization_context_collecting_cacheability,
       ],
-      // Test hook_rest_relation_uri_alter() — for backwards compatibility.
-      'site URL, with optional context, to test hook_rest_relation_uri_alter()' => $base_test_case + [
-        'context' => ['rest_test' => TRUE],
-        'expected return' => 'rest_test_relation',
-        'expected context' => ['rest_test' => TRUE],
-      ],
-      'site URL, with optional context, to test hook_rest_relation_uri_alter(), and collecting cacheability metadata' => $base_test_case + [
-        'context' => ['rest_test' => TRUE] + $serialization_context_collecting_cacheability,
-        'expected return' => 'rest_test_relation',
-        // No cacheability metadata bubbled.
-        'expected context' => ['rest_test' => TRUE] + $serialization_context_collecting_cacheability,
-      ],
       'configured URL' => [
         'link_domain' => 'http://llamas-rock.com/for-real/',
         'entity_type' => 'node',
@@ -240,16 +222,15 @@ class HalLinkManagerTest extends KernelTestBase {
    * @covers ::getRelationInternalIds
    */
   public function testGetRelationInternalIds() {
-    /* @var \Drupal\rest\LinkManager\RelationLinkManagerInterface $relation_manager */
+    /** @var \Drupal\hal\LinkManager\RelationLinkManagerInterface $relation_manager */
     $relation_manager = \Drupal::service('hal.link_manager.relation');
     $link = $relation_manager->getRelationUri('node', 'page', 'field_ref');
     $internal_ids = $relation_manager->getRelationInternalIds($link);
 
     $this->assertEquals([
       'entity_type_id' => 'node',
-      'entity_type' => \Drupal::entityTypeManager()->getDefinition('node'),
       'bundle' => 'page',
-      'field_name' => 'field_ref'
+      'field_name' => 'field_ref',
     ], $internal_ids);
   }
 
@@ -258,18 +239,18 @@ class HalLinkManagerTest extends KernelTestBase {
    */
   public function testHalLinkManagersSetLinkDomain() {
     $serialization_context = [
-      CacheableNormalizerInterface::SERIALIZATION_CONTEXT_CACHEABILITY => new CacheableMetadata()
+      CacheableNormalizerInterface::SERIALIZATION_CONTEXT_CACHEABILITY => new CacheableMetadata(),
     ];
 
-    /* @var \Drupal\rest\LinkManager\LinkManager $link_manager */
+    /** @var \Drupal\hal\LinkManager\LinkManager $link_manager */
     $link_manager = \Drupal::service('hal.link_manager');
     $link_manager->setLinkDomain('http://example.com/');
     $link = $link_manager->getTypeUri('node', 'page', $serialization_context);
-    $this->assertEqual($link, 'http://example.com/rest/type/node/page');
-    $this->assertEqual(new CacheableMetadata(), $serialization_context[CacheableNormalizerInterface::SERIALIZATION_CONTEXT_CACHEABILITY]);
+    $this->assertEquals('http://example.com/rest/type/node/page', $link);
+    $this->assertEquals($serialization_context[CacheableNormalizerInterface::SERIALIZATION_CONTEXT_CACHEABILITY], new CacheableMetadata());
     $link = $link_manager->getRelationUri('node', 'page', 'field_ref', $serialization_context);
-    $this->assertEqual($link, 'http://example.com/rest/relation/node/page/field_ref');
-    $this->assertEqual(new CacheableMetadata(), $serialization_context[CacheableNormalizerInterface::SERIALIZATION_CONTEXT_CACHEABILITY]);
+    $this->assertEquals('http://example.com/rest/relation/node/page/field_ref', $link);
+    $this->assertEquals($serialization_context[CacheableNormalizerInterface::SERIALIZATION_CONTEXT_CACHEABILITY], new CacheableMetadata());
   }
 
 }
