@@ -47,10 +47,12 @@ class HelpTopicSearchTest extends HelpTopicTranslatedTestBase {
     ]));
 
     // Add English language and set to default.
-    $this->drupalPostForm('admin/config/regional/language/add', [
+    $this->drupalGet('admin/config/regional/language/add');
+    $this->submitForm([
       'predefined_langcode' => 'en',
     ], 'Add language');
-    $this->drupalPostForm('admin/config/regional/language', [
+    $this->drupalGet('admin/config/regional/language');
+    $this->submitForm([
       'site_default_language' => 'en',
     ], 'Save configuration');
     // When default language is changed, the container is rebuilt in the child
@@ -59,7 +61,8 @@ class HelpTopicSearchTest extends HelpTopicTranslatedTestBase {
     $this->rebuildContainer();
 
     // Before running cron, verify that a search returns no results.
-    $this->drupalPostForm('search/help', ['keys' => 'notawordenglish'], 'Search');
+    $this->drupalGet('search/help');
+    $this->submitForm(['keys' => 'notawordenglish'], 'Search');
     $this->assertSearchResultsCount(0);
 
     // Run cron until the topics are fully indexed, with a limit of 100 runs
@@ -89,57 +92,57 @@ class HelpTopicSearchTest extends HelpTopicTranslatedTestBase {
     // English text, we find the topic. Note that these "words" are provided
     // by the topics that come from
     // \Drupal\help_topics_test\Plugin\HelpSection\TestHelpSection.
-    $this->drupalPostForm('search/help', ['keys' => 'notawordenglish'], 'Search');
+    $this->drupalGet('search/help');
+    $this->submitForm(['keys' => 'notawordenglish'], 'Search');
     $this->assertSearchResultsCount(1);
     $session->linkExists('Foo in English title wcsrefsdf');
 
     // Same for German.
-    $this->drupalPostForm('search/help', ['keys' => 'notawordgerman'], 'Search', [
-      'language' => $german,
-    ]);
+    $this->drupalGet('search/help', ['language' => $german]);
+    $this->submitForm(['keys' => 'notawordgerman'], 'Search');
     $this->assertSearchResultsCount(1);
     $session->linkExists('Foomm Foreign heading');
 
     // Verify when we search in English for a word that only exists in German,
     // we get no results.
-    $this->drupalPostForm('search/help', ['keys' => 'notawordgerman'], 'Search');
+    $this->drupalGet('search/help');
+    $this->submitForm(['keys' => 'notawordgerman'], 'Search');
     $this->assertSearchResultsCount(0);
     $session->pageTextContains('no results');
 
     // Same for German.
-    $this->drupalPostForm('search/help', ['keys' => 'notawordenglish'], 'Search', [
-      'language' => $german,
-    ]);
+    $this->drupalGet('search/help', ['language' => $german]);
+    $this->submitForm(['keys' => 'notawordenglish'], 'Search');
     $this->assertSearchResultsCount(0);
     $session->pageTextContains('no results');
 
     // Verify when we search in English for a word that exists in one topic
     // in English and a different topic in German, we only get the one English
     // topic.
-    $this->drupalPostForm('search/help', ['keys' => 'sqruct'], 'Search');
+    $this->drupalGet('search/help');
+    $this->submitForm(['keys' => 'sqruct'], 'Search');
     $this->assertSearchResultsCount(1);
     $session->linkExists('Foo in English title wcsrefsdf');
 
     // Same for German.
-    $this->drupalPostForm('search/help', ['keys' => 'asdrsad'], 'Search', [
-      'language' => $german,
-    ]);
+    $this->drupalGet('search/help', ['language' => $german]);
+    $this->submitForm(['keys' => 'asdrsad'], 'Search');
     $this->assertSearchResultsCount(1);
     $session->linkExists('Foomm Foreign heading');
 
     // All of the above tests used the TestHelpSection plugin. Also verify
     // that we can search for translated regular help topics, in both English
     // and German.
-    $this->drupalPostForm('search/help', ['keys' => 'nonworditem'], 'Search');
+    $this->drupalGet('search/help');
+    $this->submitForm(['keys' => 'nonworditem'], 'Search');
     $this->assertSearchResultsCount(1);
     $session->linkExists('ABC Help Test module');
     // Click the link and verify we ended up on the topic page.
     $this->clickLink('ABC Help Test module');
     $session->pageTextContains('This is a test');
 
-    $this->drupalPostForm('search/help', ['keys' => 'nonwordgerman'], 'Search', [
-      'language' => $german,
-    ]);
+    $this->drupalGet('search/help', ['language' => $german]);
+    $this->submitForm(['keys' => 'nonwordgerman'], 'Search');
     $this->assertSearchResultsCount(1);
     $session->linkExists('ABC-Hilfetestmodul');
     $this->clickLink('ABC-Hilfetestmodul');
@@ -148,26 +151,25 @@ class HelpTopicSearchTest extends HelpTopicTranslatedTestBase {
     // Verify that we can search from the admin/help page.
     $this->drupalGet('admin/help');
     $session->pageTextContains('Search help');
-    $this->drupalPostForm(NULL, ['keys' => 'nonworditem'], 'Search');
+    $this->submitForm(['keys' => 'nonworditem'], 'Search');
     $this->assertSearchResultsCount(1);
     $session->linkExists('ABC Help Test module');
 
     // Same for German.
-    $this->drupalPostForm('admin/help', ['keys' => 'nonwordgerman'], 'Search', [
-      'language' => $german,
-    ]);
+    $this->drupalGet('admin/help', ['language' => $german]);
+    $this->submitForm(['keys' => 'nonwordgerman'], 'Search');
     $this->assertSearchResultsCount(1);
     $session->linkExists('ABC-Hilfetestmodul');
 
     // Verify we can search for title text (other searches used text
     // that was part of the body).
-    $this->drupalPostForm('search/help', ['keys' => 'wcsrefsdf'], 'Search');
+    $this->drupalGet('search/help');
+    $this->submitForm(['keys' => 'wcsrefsdf'], 'Search');
     $this->assertSearchResultsCount(1);
     $session->linkExists('Foo in English title wcsrefsdf');
 
-    $this->drupalPostForm('admin/help', ['keys' => 'sdeeeee'], 'Search', [
-      'language' => $german,
-    ]);
+    $this->drupalGet('admin/help', ['language' => $german]);
+    $this->submitForm(['keys' => 'sdeeeee'], 'Search');
     $this->assertSearchResultsCount(1);
     $session->linkExists('Barmm Foreign sdeeeee');
 
@@ -176,27 +178,23 @@ class HelpTopicSearchTest extends HelpTopicTranslatedTestBase {
     // topic is rendered each time.
     \Drupal::state()->set('help_topics_test:translated_title', 'Updated translated title');
     $this->cronRun();
-    $this->drupalPostForm('admin/help', ['keys' => 'sdeeeee'], 'Search', [
-      'language' => $german,
-    ]);
+    $this->drupalGet('admin/help', ['language' => $german]);
+    $this->submitForm(['keys' => 'sdeeeee'], 'Search');
     $this->assertSearchResultsCount(1);
     $session->linkExists('Updated translated title');
     // Searching for the updated test shouldn't produce a match.
-    $this->drupalPostForm('admin/help', ['keys' => 'translated title'], 'Search', [
-      'language' => $german,
-    ]);
+    $this->drupalGet('admin/help', ['language' => $german]);
+    $this->submitForm(['keys' => 'translated title'], 'Search');
     $this->assertSearchResultsCount(0);
 
     // Clear the caches and re-run cron - this should re-index the help.
     $this->rebuildAll();
     $this->cronRun();
-    $this->drupalPostForm('admin/help', ['keys' => 'sdeeeee'], 'Search', [
-      'language' => $german,
-    ]);
+    $this->drupalGet('admin/help', ['language' => $german]);
+    $this->submitForm(['keys' => 'sdeeeee'], 'Search');
     $this->assertSearchResultsCount(0);
-    $this->drupalPostForm('admin/help', ['keys' => 'translated title'], 'Search', [
-      'language' => $german,
-    ]);
+    $this->drupalGet('admin/help', ['language' => $german]);
+    $this->submitForm(['keys' => 'translated title'], 'Search');
     $this->assertSearchResultsCount(1);
     $session->linkExists('Updated translated title');
 
@@ -222,18 +220,21 @@ class HelpTopicSearchTest extends HelpTopicTranslatedTestBase {
     $this->drupalGet('admin/help');
     $session->pageTextContains('Search help');
 
-    $this->drupalPostForm('search/help', ['keys' => 'nonworditem'], 'Search');
+    $this->drupalGet('search/help');
+    $this->submitForm(['keys' => 'nonworditem'], 'Search');
     $this->assertSearchResultsCount(1);
     $session->linkExists('ABC Help Test module');
 
-    $this->drupalPostForm('search/help', ['keys' => 'notawordenglish'], 'Search');
+    $this->drupalGet('search/help');
+    $this->submitForm(['keys' => 'notawordenglish'], 'Search');
     $this->assertSearchResultsCount(0);
     $session->pageTextContains('no results');
 
     // Uninstall the test module and verify its topics are immediately not
     // searchable.
     \Drupal::service('module_installer')->uninstall(['help_topics_test']);
-    $this->drupalPostForm('search/help', ['keys' => 'nonworditem'], 'Search');
+    $this->drupalGet('search/help');
+    $this->submitForm(['keys' => 'nonworditem'], 'Search');
     $this->assertSearchResultsCount(0);
   }
 
@@ -247,9 +248,10 @@ class HelpTopicSearchTest extends HelpTopicTranslatedTestBase {
     $this->drupalLogin($this->rootUser);
     $edit = [];
     $edit['uninstall[help_topics]'] = TRUE;
-    $this->drupalPostForm('admin/modules/uninstall', $edit, t('Uninstall'));
-    $this->drupalPostForm(NULL, NULL, t('Uninstall'));
-    $this->assertText(t('The selected modules have been uninstalled.'), 'Modules status has been updated.');
+    $this->drupalGet('admin/modules/uninstall');
+    $this->submitForm($edit, 'Uninstall');
+    $this->submitForm([], 'Uninstall');
+    $this->assertSession()->pageTextContains('The selected modules have been uninstalled.');
     $this->drupalGet('admin/help');
     $this->assertSession()->statusCodeEquals(200);
   }
