@@ -67,7 +67,8 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
       'name' => $style_name,
       'label' => $style_label,
     ];
-    $this->drupalPostForm('admin/config/media/image-styles/add', $edit, 'Create new style');
+    $this->drupalGet('admin/config/media/image-styles/add');
+    $this->submitForm($edit, 'Create new style');
     $this->assertRaw(t('Style %name was created.', ['%name' => $style_label]));
     $options = image_style_options();
     $this->assertArrayHasKey($style_name, $options);
@@ -118,7 +119,8 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
       'name' => $style_name,
       'label' => $style_label,
     ];
-    $this->drupalPostForm($admin_path . '/add', $edit, 'Create new style');
+    $this->drupalGet($admin_path . '/add');
+    $this->submitForm($edit, 'Create new style');
     $this->assertRaw(t('Style %name was created.', ['%name' => $style_label]));
 
     // Ensure that the expected entity operations are there.
@@ -136,7 +138,8 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
         $edit_data['data[' . $field . ']'] = $value;
       }
       // Add the effect.
-      $this->drupalPostForm($style_path, ['new' => $effect], 'Add');
+      $this->drupalGet($style_path);
+      $this->submitForm(['new' => $effect], 'Add');
       if (!empty($edit)) {
         $this->submitForm($edit_data, 'Add effect');
       }
@@ -148,7 +151,7 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
     // Ensure that third party settings were added to the config entity.
     // These are added by a hook_image_style_presave() implemented in
     // image_module_test module.
-    $this->assertEqual('bar', $style->getThirdPartySetting('image_module_test', 'foo'), 'Third party settings were added to the image style.');
+    $this->assertEquals('bar', $style->getThirdPartySetting('image_module_test', 'foo'), 'Third party settings were added to the image style.');
 
     // Ensure that the image style URI matches our expected path.
     $style_uri_path = $style->toUrl()->toString();
@@ -162,7 +165,7 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
       $uuids[$effect->getPluginId()] = $uuid;
       $effect_configuration = $effect->getConfiguration();
       foreach ($effect_edits[$effect->getPluginId()] as $field => $value) {
-        $this->assertEqual($effect_configuration['data'][$field], $value, new FormattableMarkup('The %field field in the %effect effect has the correct value of %value.', ['%field' => $field, '%effect' => $effect->getPluginId(), '%value' => $value]));
+        $this->assertEquals($effect_configuration['data'][$field], $value, new FormattableMarkup('The %field field in the %effect effect has the correct value of %value.', ['%field' => $field, '%effect' => $effect->getPluginId(), '%value' => $value]));
       }
     }
 
@@ -207,9 +210,10 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
 
     // Create an image to make sure it gets flushed after saving.
     $image_path = $this->createSampleImage($style);
-    $this->assertEqual(1, $this->getImageCount($style), new FormattableMarkup('Image style %style image %file successfully generated.', ['%style' => $style->label(), '%file' => $image_path]));
+    $this->assertEquals(1, $this->getImageCount($style), new FormattableMarkup('Image style %style image %file successfully generated.', ['%style' => $style->label(), '%file' => $image_path]));
 
-    $this->drupalPostForm($style_path, $edit, 'Save');
+    $this->drupalGet($style_path);
+    $this->submitForm($edit, 'Save');
 
     // Note that after changing the style name, the style path is changed.
     $style_path = 'admin/config/media/image-styles/manage/' . $style_name;
@@ -225,7 +229,7 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
     // Check that the image was flushed after updating the style.
     // This is especially important when renaming the style. Make sure that
     // the old image directory has been deleted.
-    $this->assertEqual(0, $this->getImageCount($style), new FormattableMarkup('Image style %style was flushed after renaming the style and updating the order of effects.', ['%style' => $style->label()]));
+    $this->assertEquals(0, $this->getImageCount($style), new FormattableMarkup('Image style %style was flushed after renaming the style and updating the order of effects.', ['%style' => $style->label()]));
 
     // Load the style by the new name with the new weights.
     $style = ImageStyle::load($style_name);
@@ -246,10 +250,11 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
 
     // Create an image to make sure it gets flushed after deleting an effect.
     $image_path = $this->createSampleImage($style);
-    $this->assertEqual(1, $this->getImageCount($style), new FormattableMarkup('Image style %style image %file successfully generated.', ['%style' => $style->label(), '%file' => $image_path]));
+    $this->assertEquals(1, $this->getImageCount($style), new FormattableMarkup('Image style %style image %file successfully generated.', ['%style' => $style->label(), '%file' => $image_path]));
 
     // Delete the 'image_crop' effect from the style.
-    $this->drupalPostForm($style_path . '/effects/' . $uuids['image_crop'] . '/delete', [], 'Delete');
+    $this->drupalGet($style_path . '/effects/' . $uuids['image_crop'] . '/delete');
+    $this->submitForm([], 'Delete');
     // Confirm that the form submission was successful.
     $this->assertSession()->statusCodeEquals(200);
     $image_crop_effect = $style->getEffect($uuids['image_crop']);
@@ -273,7 +278,8 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
       'data[random]' => 0,
       'data[bgcolor]' => '',
     ];
-    $this->drupalPostForm($style_path, ['new' => 'image_rotate'], 'Add');
+    $this->drupalGet($style_path);
+    $this->submitForm(['new' => 'image_rotate'], 'Add');
     $this->submitForm($edit, 'Add effect');
     $entity_type_manager = $this->container->get('entity_type.manager');
     $style = $entity_type_manager->getStorage('image_style')->loadUnchanged($style_name);
@@ -282,7 +288,8 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
     // Style deletion form.
 
     // Delete the style.
-    $this->drupalPostForm($style_path . '/delete', [], 'Delete');
+    $this->drupalGet($style_path . '/delete');
+    $this->submitForm([], 'Delete');
 
     // Confirm the style directory has been removed.
     $directory = 'public://styles/' . $style_name;
@@ -347,8 +354,9 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
       'name' => $new_style_name,
       'label' => $new_style_label,
     ];
-    $this->drupalPostForm($style_path . $style_name, $edit, 'Save');
-    $this->assertText('Changes to the style have been saved.');
+    $this->drupalGet($style_path . $style_name);
+    $this->submitForm($edit, 'Save');
+    $this->assertSession()->pageTextContains('Changes to the style have been saved.');
     $this->drupalGet('node/' . $nid);
 
     // Reload the image style using the new name.
@@ -359,7 +367,8 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
     $edit = [
       'replacement' => 'thumbnail',
     ];
-    $this->drupalPostForm($style_path . $new_style_name . '/delete', $edit, 'Delete');
+    $this->drupalGet($style_path . $new_style_name . '/delete');
+    $this->submitForm($edit, 'Delete');
     $message = t('The image style %name has been deleted.', ['%name' => $new_style_label]);
     $this->assertRaw($message);
 
@@ -378,12 +387,12 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
     $this->submitForm(['label' => 'Test style effect edit', 'name' => $style_name], 'Create new style');
     $this->submitForm(['new' => 'image_scale_and_crop'], 'Add');
     $this->submitForm(['data[width]' => '300', 'data[height]' => '200'], 'Add effect');
-    $this->assertText('Scale and crop 300×200');
+    $this->assertSession()->pageTextContains('Scale and crop 300×200');
 
     // There should normally be only one edit link on this page initially.
     $this->clickLink(t('Edit'));
     $this->submitForm(['data[width]' => '360', 'data[height]' => '240'], 'Update effect');
-    $this->assertText('Scale and crop 360×240');
+    $this->assertSession()->pageTextContains('Scale and crop 360×240');
 
     // Check that the previous effect is replaced.
     $this->assertNoText('Scale and crop 300×200');
@@ -412,8 +421,8 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
     }
     $this->submitForm(['new' => 'image_scale'], 'Add');
     $this->submitForm(['data[width]' => '12', 'data[height]' => '19'], 'Add effect');
-    $this->assertText('Scale 24×19');
-    $this->assertText('Scale 12×19');
+    $this->assertSession()->pageTextContains('Scale 24×19');
+    $this->assertSession()->pageTextContains('Scale 12×19');
 
     // Try to edit a nonexistent effect.
     $uuid = $this->container->get('uuid');
@@ -437,7 +446,7 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
     $image_uri = $files[0]->uri;
     $derivative_uri = $style->buildUri($image_uri);
     $this->assertTrue($style->createDerivative($image_uri, $derivative_uri));
-    $this->assertEqual(1, $this->getImageCount($style));
+    $this->assertEquals(1, $this->getImageCount($style));
 
     // Go to image styles list page and check if the flush operation link
     // exists.
@@ -446,10 +455,11 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
     $this->assertSession()->linkByHrefExists($flush_path);
 
     // Flush the image style derivatives using the user interface.
-    $this->drupalPostForm($flush_path, [], 'Flush');
+    $this->drupalGet($flush_path);
+    $this->submitForm([], 'Flush');
 
     // The derivative image file should have been deleted.
-    $this->assertEqual(0, $this->getImageCount($style));
+    $this->assertEquals(0, $this->getImageCount($style));
   }
 
   /**
@@ -499,7 +509,7 @@ class ImageAdminStylesTest extends ImageFieldTestBase {
     $this->configImporter()->import();
 
     $this->assertNull(ImageStyle::load($style_name), 'Style deleted after config import.');
-    $this->assertEqual(0, $this->getImageCount($style), 'Image style was flushed after being deleted by config import.');
+    $this->assertEquals(0, $this->getImageCount($style), 'Image style was flushed after being deleted by config import.');
   }
 
   /**
