@@ -41,7 +41,8 @@ class ImageFieldValidateTest extends ImageFieldTestBase {
     $this->assertFileExists($expected_path . '/' . $image_files[0]->filename);
 
     // Remove the image.
-    $this->drupalPostForm('node/' . $node . '/edit', [], 'Remove');
+    $this->drupalGet('node/' . $node . '/edit');
+    $this->submitForm([], 'Remove');
     $this->submitForm([], 'Save');
 
     // Get invalid image test files from simpletest.
@@ -60,7 +61,8 @@ class ImageFieldValidateTest extends ImageFieldTestBase {
     $edit = [
       'files[' . $field_name . '_0]' => $file_system->realpath($zero_size_image->uri),
     ];
-    $this->drupalPostForm('node/' . $node . '/edit', $edit, 'Upload');
+    $this->drupalGet('node/' . $node . '/edit');
+    $this->submitForm($edit, 'Upload');
     $this->assertFileNotExists($expected_path . '/' . $zero_size_image->filename);
 
     // Try uploading an invalid image.
@@ -68,7 +70,8 @@ class ImageFieldValidateTest extends ImageFieldTestBase {
     $edit = [
       'files[' . $field_name . '_0]' => $file_system->realpath($invalid_image->uri),
     ];
-    $this->drupalPostForm('node/' . $node . '/edit', $edit, 'Upload');
+    $this->drupalGet('node/' . $node . '/edit');
+    $this->submitForm($edit, 'Upload');
     $this->assertFileNotExists($expected_path . '/' . $invalid_image->filename);
 
     // Upload a valid image again.
@@ -76,7 +79,8 @@ class ImageFieldValidateTest extends ImageFieldTestBase {
     $edit = [
       'files[' . $field_name . '_0]' => $file_system->realpath($valid_image->uri),
     ];
-    $this->drupalPostForm('node/' . $node . '/edit', $edit, 'Upload');
+    $this->drupalGet('node/' . $node . '/edit');
+    $this->submitForm($edit, 'Upload');
     $this->assertFileExists($expected_path . '/' . $valid_image->filename);
   }
 
@@ -148,15 +152,15 @@ class ImageFieldValidateTest extends ImageFieldTestBase {
       '%height' => $image_that_is_too_small_file->getHeight(),
       ]));
     $this->uploadNodeImage($image_that_is_too_big, $field_names[0], 'article');
-    $this->assertText('The image was resized to fit within the maximum allowed dimensions of 100x100 pixels.');
+    $this->assertSession()->pageTextContains('The image was resized to fit within the maximum allowed dimensions of 100x100 pixels.');
     $this->uploadNodeImage($image_that_is_too_small, $field_names[1], 'article');
     $this->assertRaw(t('The specified file %name could not be uploaded.', ['%name' => $image_that_is_too_small->filename]));
     $this->uploadNodeImage($image_that_is_too_big, $field_names[1], 'article');
-    $this->assertText('The image was resized to fit within the maximum allowed width of 100 pixels.');
+    $this->assertSession()->pageTextContains('The image was resized to fit within the maximum allowed width of 100 pixels.');
     $this->uploadNodeImage($image_that_is_too_small, $field_names[2], 'article');
     $this->assertRaw(t('The specified file %name could not be uploaded.', ['%name' => $image_that_is_too_small->filename]));
     $this->uploadNodeImage($image_that_is_too_big, $field_names[2], 'article');
-    $this->assertText('The image was resized to fit within the maximum allowed height of 100 pixels.');
+    $this->assertSession()->pageTextContains('The image was resized to fit within the maximum allowed height of 100 pixels.');
   }
 
   /**
@@ -186,8 +190,8 @@ class ImageFieldValidateTest extends ImageFieldTestBase {
 
     $this->assertTrue(isset($elements[0]), 'Required marker is shown for the required title text.');
 
-    $this->assertText('Alternative text field is required.');
-    $this->assertText('Title field is required.');
+    $this->assertSession()->pageTextContains('Alternative text field is required.');
+    $this->assertSession()->pageTextContains('Title field is required.');
 
     $instance->setSetting('alt_field_required', 0);
     $instance->setSetting('title_field_required', 0);
@@ -196,7 +200,8 @@ class ImageFieldValidateTest extends ImageFieldTestBase {
     $edit = [
       'title[0][value]' => $this->randomMachineName(),
     ];
-    $this->drupalPostForm('node/add/article', $edit, 'Save');
+    $this->drupalGet('node/add/article');
+    $this->submitForm($edit, 'Save');
 
     $this->assertNoText('Alternative text field is required.');
     $this->assertNoText('Title field is required.');
@@ -209,7 +214,8 @@ class ImageFieldValidateTest extends ImageFieldTestBase {
     $edit = [
       'title[0][value]' => $this->randomMachineName(),
     ];
-    $this->drupalPostForm('node/add/article', $edit, 'Save');
+    $this->drupalGet('node/add/article');
+    $this->submitForm($edit, 'Save');
 
     $this->assertNoText('Alternative text field is required.');
     $this->assertNoText('Title field is required.');
