@@ -32,7 +32,7 @@ class LanguageConfigurationTest extends BrowserTestBase {
   public function testLanguageConfiguration() {
     // Ensure the after installing the language module the weight of the English
     // language is still 0.
-    $this->assertEqual(0, ConfigurableLanguage::load('en')->getWeight(), 'The English language has a weight of 0.');
+    $this->assertEquals(0, ConfigurableLanguage::load('en')->getWeight(), 'The English language has a weight of 0.');
 
     // User to add and remove language.
     $admin_user = $this->drupalCreateUser([
@@ -55,11 +55,11 @@ class LanguageConfigurationTest extends BrowserTestBase {
       'predefined_langcode' => 'fr',
     ];
     $this->submitForm($edit, 'Add language');
-    $this->assertText('French');
+    $this->assertSession()->pageTextContains('French');
     $this->assertSession()->addressEquals(Url::fromRoute('entity.configurable_language.collection'));
     // Langcode for Languages is always 'en'.
     $language = $this->config('language.entity.fr')->get();
-    $this->assertEqual('en', $language['langcode']);
+    $this->assertEquals('en', $language['langcode']);
 
     // Check if the Default English language has no path prefix.
     $this->drupalGet('admin/config/regional/language/detection/url');
@@ -111,48 +111,50 @@ class LanguageConfigurationTest extends BrowserTestBase {
       'prefix[en]' => '',
     ];
     $this->submitForm($edit, 'Save configuration');
-    $this->assertText('The prefix may only be left blank for the selected detection fallback language.');
+    $this->assertSession()->pageTextContains('The prefix may only be left blank for the selected detection fallback language.');
 
     //  Check that prefix cannot be changed to contain a slash.
     $edit = [
       'prefix[en]' => 'foo/bar',
     ];
     $this->submitForm($edit, 'Save configuration');
-    $this->assertText('The prefix may not contain a slash.');
+    $this->assertSession()->pageTextContains('The prefix may not contain a slash.');
 
     // Remove English language and add a new Language to check if langcode of
     // Language entity is 'en'.
-    $this->drupalPostForm('admin/config/regional/language/delete/en', [], 'Delete');
+    $this->drupalGet('admin/config/regional/language/delete/en');
+    $this->submitForm([], 'Delete');
     $this->rebuildContainer();
     $this->assertRaw(t('The %language (%langcode) language has been removed.', ['%language' => 'English', '%langcode' => 'en']));
 
     // Ensure that French language has a weight of 1 after being created through
     // the UI.
     $french = ConfigurableLanguage::load('fr');
-    $this->assertEqual(1, $french->getWeight(), 'The French language has a weight of 1.');
+    $this->assertEquals(1, $french->getWeight(), 'The French language has a weight of 1.');
     // Ensure that French language can now have a weight of 0.
     $french->setWeight(0)->save();
-    $this->assertEqual(0, $french->getWeight(), 'The French language has a weight of 0.');
+    $this->assertEquals(0, $french->getWeight(), 'The French language has a weight of 0.');
     // Ensure that new languages created through the API get a weight of 0.
     $afrikaans = ConfigurableLanguage::createFromLangcode('af');
     $afrikaans->save();
-    $this->assertEqual(0, $afrikaans->getWeight(), 'The Afrikaans language has a weight of 0.');
+    $this->assertEquals(0, $afrikaans->getWeight(), 'The Afrikaans language has a weight of 0.');
     // Ensure that a new language can be created with any weight.
     $arabic = ConfigurableLanguage::createFromLangcode('ar');
     $arabic->setWeight(4)->save();
-    $this->assertEqual(4, $arabic->getWeight(), 'The Arabic language has a weight of 0.');
+    $this->assertEquals(4, $arabic->getWeight(), 'The Arabic language has a weight of 0.');
 
     $edit = [
       'predefined_langcode' => 'de',
     ];
-    $this->drupalPostForm('admin/config/regional/language/add', $edit, 'Add language');
+    $this->drupalGet('admin/config/regional/language/add');
+    $this->submitForm($edit, 'Add language');
     $language = $this->config('language.entity.de')->get();
-    $this->assertEqual('fr', $language['langcode']);
+    $this->assertEquals('fr', $language['langcode']);
 
     // Ensure that German language has a weight of 5 after being created through
     // the UI.
     $french = ConfigurableLanguage::load('de');
-    $this->assertEqual(5, $french->getWeight(), 'The German language has a weight of 5.');
+    $this->assertEquals(5, $french->getWeight(), 'The German language has a weight of 5.');
   }
 
   /**
@@ -171,18 +173,21 @@ class LanguageConfigurationTest extends BrowserTestBase {
     $edit = [
       'predefined_langcode' => 'fr',
     ];
-    $this->drupalPostForm('admin/config/regional/language/add', $edit, 'Add language');
+    $this->drupalGet('admin/config/regional/language/add');
+    $this->submitForm($edit, 'Add language');
     $this->checkConfigurableLanguageWeight('after adding new language');
 
     // Re-ordering languages.
     $edit = [
       'languages[en][weight]' => $this->getHighestConfigurableLanguageWeight() + 1,
     ];
-    $this->drupalPostForm('admin/config/regional/language', $edit, 'Save configuration');
+    $this->drupalGet('admin/config/regional/language');
+    $this->submitForm($edit, 'Save configuration');
     $this->checkConfigurableLanguageWeight('after re-ordering');
 
     // Remove predefined language.
-    $this->drupalPostForm('admin/config/regional/language/delete/fr', [], 'Delete');
+    $this->drupalGet('admin/config/regional/language/delete/fr');
+    $this->submitForm([], 'Delete');
     $this->checkConfigurableLanguageWeight('after deleting a language');
   }
 
@@ -215,7 +220,7 @@ class LanguageConfigurationTest extends BrowserTestBase {
     $storage = $this->container->get('entity_type.manager')
       ->getStorage('configurable_language');
     $storage->resetCache();
-    /* @var $languages \Drupal\Core\Language\LanguageInterface[] */
+    /** @var \Drupal\Core\Language\LanguageInterface[] $languages */
     $languages = $storage->loadMultiple();
     foreach ($languages as $language) {
       if (!$language->isLocked()) {
