@@ -45,7 +45,7 @@ class LinkViewsTokensTest extends ViewTestBase {
    */
   protected function setUp($import_test_views = TRUE): void {
     parent::setUp($import_test_views);
-    ViewTestData::createTestViews(get_class($this), ['link_test_views']);
+    ViewTestData::createTestViews(static::class, ['link_test_views']);
 
     // Create Basic page node type.
     $this->drupalCreateContentType([
