@@ -64,7 +64,8 @@ class LocaleConfigTranslationImportTest extends BrowserTestBase {
     $edit = [
       'authenticated[translate interface]' => 'translate interface',
     ];
-    $this->drupalPostForm('admin/people/permissions', $edit, 'Save permissions');
+    $this->drupalGet('admin/people/permissions');
+    $this->submitForm($edit, 'Save permissions');
 
     // Check and update the translation status. This will import the Afrikaans
     // translations of locale_test_translate module.
@@ -76,12 +77,13 @@ class LocaleConfigTranslationImportTest extends BrowserTestBase {
     $status['drupal']['af']->type = 'current';
     \Drupal::state()->set('locale.translation_status', $status);
 
-    $this->drupalPostForm('admin/reports/translations', [], 'Update translations');
+    $this->drupalGet('admin/reports/translations');
+    $this->submitForm([], 'Update translations');
 
     // Check if configuration translations have been imported.
     $override = \Drupal::languageManager()->getLanguageConfigOverride('af', 'system.maintenance');
     // cSpell:disable-next-line
-    $this->assertEqual('Ons is tans besig met onderhoud op @site. Wees asseblief geduldig, ons sal binnekort weer terug wees.', $override->get('message'));
+    $this->assertEquals('Ons is tans besig met onderhoud op @site. Wees asseblief geduldig, ons sal binnekort weer terug wees.', $override->get('message'));
   }
 
   /**
@@ -115,19 +117,24 @@ class LocaleConfigTranslationImportTest extends BrowserTestBase {
       ->save();
 
     // Add predefined language.
-    $this->drupalPostForm('admin/config/regional/language/add', ['predefined_langcode' => 'af'], 'Add language');
+    $this->drupalGet('admin/config/regional/language/add');
+    $this->submitForm(['predefined_langcode' => 'af'], 'Add language');
 
     // Add the system branding block to the page.
     $this->drupalPlaceBlock('system_branding_block', ['region' => 'header', 'id' => 'site-branding']);
-    $this->drupalPostForm('admin/config/system/site-information', ['site_slogan' => 'Test site slogan'], 'Save configuration');
-    $this->drupalPostForm('admin/config/system/site-information/translate/af/edit', ['translation[config_names][system.site][slogan]' => 'Test site slogan in Afrikaans'], 'Save translation');
+    $this->drupalGet('admin/config/system/site-information');
+    $this->submitForm(['site_slogan' => 'Test site slogan'], 'Save configuration');
+    $this->drupalGet('admin/config/system/site-information/translate/af/edit');
+    $this->submitForm([
+      'translation[config_names][system.site][slogan]' => 'Test site slogan in Afrikaans',
+    ], 'Save translation');
 
     // Get the front page and ensure that the translated configuration appears.
     $this->drupalGet('af');
-    $this->assertText('Test site slogan in Afrikaans');
+    $this->assertSession()->pageTextContains('Test site slogan in Afrikaans');
 
     $override = \Drupal::languageManager()->getLanguageConfigOverride('af', 'locale_test_translate.settings');
-    $this->assertEqual('Locale can translate Afrikaans', $override->get('translatable_default_with_translation'));
+    $this->assertEquals('Locale can translate Afrikaans', $override->get('translatable_default_with_translation'));
 
     // Update test configuration.
     $override
@@ -137,13 +144,14 @@ class LocaleConfigTranslationImportTest extends BrowserTestBase {
       ->save();
 
     // Install any module.
-    $this->drupalPostForm('admin/modules', ['modules[dblog][enable]' => 'dblog'], 'Install');
-    $this->assertText('Module Database Logging has been enabled.');
+    $this->drupalGet('admin/modules');
+    $this->submitForm(['modules[dblog][enable]' => 'dblog'], 'Install');
+    $this->assertSession()->pageTextContains('Module Database Logging has been enabled.');
 
     // Get the front page and ensure that the translated configuration still
     // appears.
     $this->drupalGet('af');
-    $this->assertText('Test site slogan in Afrikaans');
+    $this->assertSession()->pageTextContains('Test site slogan in Afrikaans');
 
     $this->rebuildContainer();
     $override = \Drupal::languageManager()->getLanguageConfigOverride('af', 'locale_test_translate.settings');
@@ -152,7 +160,7 @@ class LocaleConfigTranslationImportTest extends BrowserTestBase {
       'translatable_default_with_translation' => 'This translation is preserved',
       'translatable_default_with_no_translation' => 'This translation is preserved',
     ];
-    $this->assertEqual($expected, $override->get());
+    $this->assertEquals($expected, $override->get());
   }
 
   /**
@@ -181,10 +189,11 @@ class LocaleConfigTranslationImportTest extends BrowserTestBase {
       ->save();
 
     // Add predefined language.
-    $this->drupalPostForm('admin/config/regional/language/add', ['predefined_langcode' => 'af'], 'Add language');
+    $this->drupalGet('admin/config/regional/language/add');
+    $this->submitForm(['predefined_langcode' => 'af'], 'Add language');
 
     $override = \Drupal::languageManager()->getLanguageConfigOverride('af', 'locale_test_translate.settings');
-    $this->assertEqual(['translatable_default_with_translation' => 'Locale can translate Afrikaans'], $override->get());
+    $this->assertEquals(['translatable_default_with_translation' => 'Locale can translate Afrikaans'], $override->get());
 
     // Remove the string from translation to simulate a Locale removal. Note
     // that is no current way of doing this in the UI.
@@ -193,10 +202,10 @@ class LocaleConfigTranslationImportTest extends BrowserTestBase {
     \Drupal::service('locale.storage')->delete($string);
     // Force a rebuild of config translations.
     $count = Locale::config()->updateConfigTranslations(['locale_test_translate.settings'], ['af']);
-    $this->assertEqual(1, $count, 'Correct count of updated translations');
+    $this->assertEquals(1, $count, 'Correct count of updated translations');
 
     $override = \Drupal::languageManager()->getLanguageConfigOverride('af', 'locale_test_translate.settings');
-    $this->assertEqual([], $override->get());
+    $this->assertEquals([], $override->get());
     $this->assertTrue($override->isNew(), 'The configuration override was deleted when the Locale string was deleted.');
   }
 
@@ -226,7 +235,8 @@ class LocaleConfigTranslationImportTest extends BrowserTestBase {
       ->save();
 
     // Add predefined language.
-    $this->drupalPostForm('admin/config/regional/language/add', ['predefined_langcode' => 'af'], 'Add language');
+    $this->drupalGet('admin/config/regional/language/add');
+    $this->submitForm(['predefined_langcode' => 'af'], 'Add language');
 
     $override = \Drupal::languageManager()->getLanguageConfigOverride('af', 'locale_test_translate.settings');
     // Update test configuration.
@@ -239,7 +249,7 @@ class LocaleConfigTranslationImportTest extends BrowserTestBase {
       'translatable_no_default' => 'This translation is preserved',
       'translatable_default_with_no_translation' => 'This translation is preserved',
     ];
-    $this->assertEqual($expected, $override->get());
+    $this->assertEquals($expected, $override->get());
 
     // Set the translated string to empty.
     $search = [
@@ -247,20 +257,22 @@ class LocaleConfigTranslationImportTest extends BrowserTestBase {
       'langcode' => 'af',
       'translation' => 'all',
     ];
-    $this->drupalPostForm('admin/config/regional/translate', $search, 'Filter');
+    $this->drupalGet('admin/config/regional/translate');
+    $this->submitForm($search, 'Filter');
     $textarea = $this->assertSession()->elementExists('xpath', '//textarea');
     $lid = $textarea->getAttribute('name');
     $edit = [
       $lid => '',
     ];
-    $this->drupalPostForm('admin/config/regional/translate', $edit, 'Save translations');
+    $this->drupalGet('admin/config/regional/translate');
+    $this->submitForm($edit, 'Save translations');
 
     $override = \Drupal::languageManager()->getLanguageConfigOverride('af', 'locale_test_translate.settings');
     $expected = [
       'translatable_no_default' => 'This translation is preserved',
       'translatable_default_with_no_translation' => 'This translation is preserved',
     ];
-    $this->assertEqual($expected, $override->get());
+    $this->assertEquals($expected, $override->get());
   }
 
 }
