@@ -65,10 +65,12 @@ class LocaleConfigTranslationTest extends BrowserTestBase {
       'label' => $name,
       'direction' => LanguageInterface::DIRECTION_LTR,
     ];
-    $this->drupalPostForm('admin/config/regional/language/add', $edit, 'Add custom language');
+    $this->drupalGet('admin/config/regional/language/add');
+    $this->submitForm($edit, 'Add custom language');
     // Set path prefix.
     $edit = ["prefix[$this->langcode]" => $this->langcode];
-    $this->drupalPostForm('admin/config/regional/language/detection/url', $edit, 'Save configuration');
+    $this->drupalGet('admin/config/regional/language/detection/url');
+    $this->submitForm($edit, 'Save configuration');
   }
 
   /**
@@ -87,18 +89,20 @@ class LocaleConfigTranslationTest extends BrowserTestBase {
       'langcode' => $this->langcode,
       'translation' => 'all',
     ];
-    $this->drupalPostForm('admin/config/regional/translate', $search, 'Filter');
+    $this->drupalGet('admin/config/regional/translate');
+    $this->submitForm($search, 'Filter');
     $textarea = $this->assertSession()->elementExists('xpath', '//textarea');
     $lid = $textarea->getAttribute('name');
     $edit = [
       $lid => $message,
     ];
-    $this->drupalPostForm('admin/config/regional/translate', $edit, 'Save translations');
+    $this->drupalGet('admin/config/regional/translate');
+    $this->submitForm($edit, 'Save translations');
 
     // Get translation and check we've only got the message.
     $translation = \Drupal::languageManager()->getLanguageConfigOverride($this->langcode, 'system.maintenance')->get();
     $this->assertCount(1, $translation, 'Got the right number of properties after translation.');
-    $this->assertEqual($message, $translation['message']);
+    $this->assertEquals($message, $translation['message']);
 
     // Check default medium date format exists and create a translation for it.
     $string = $this->storage->findString(['source' => 'D, m/d/Y - H:i', 'context' => 'PHP date format', 'type' => 'configuration']);
@@ -110,28 +114,31 @@ class LocaleConfigTranslationTest extends BrowserTestBase {
       'langcode' => $this->langcode,
       'translation' => 'all',
     ];
-    $this->drupalPostForm('admin/config/regional/translate', $search, 'Filter');
+    $this->drupalGet('admin/config/regional/translate');
+    $this->submitForm($search, 'Filter');
     $textarea = $this->assertSession()->elementExists('xpath', '//textarea');
     $lid = $textarea->getAttribute('name');
     $edit = [
       $lid => 'D',
     ];
-    $this->drupalPostForm('admin/config/regional/translate', $edit, 'Save translations');
+    $this->drupalGet('admin/config/regional/translate');
+    $this->submitForm($edit, 'Save translations');
 
     $translation = \Drupal::languageManager()->getLanguageConfigOverride($this->langcode, 'core.date_format.medium')->get();
-    $this->assertEqual('D', $translation['pattern'], 'Got the right date format pattern after translation.');
+    $this->assertEquals('D', $translation['pattern'], 'Got the right date format pattern after translation.');
 
     // Formatting the date 8 / 27 / 1985 @ 13:37 EST with pattern D should
     // display "Tue".
     $formatted_date = $this->container->get('date.formatter')->format(494015820, $type = 'medium', NULL, 'America/New_York', $this->langcode);
-    $this->assertEqual('Tue', $formatted_date, 'Got the right formatted date using the date format translation pattern.');
+    $this->assertEquals('Tue', $formatted_date, 'Got the right formatted date using the date format translation pattern.');
 
     // Assert strings from image module config are not available.
     $string = $this->storage->findString(['source' => 'Medium (220×220)', 'context' => '', 'type' => 'configuration']);
     $this->assertNull($string, 'Configuration strings have been created upon installation.');
 
     // Enable the image module.
-    $this->drupalPostForm('admin/modules', ['modules[image][enable]' => "1"], 'Install');
+    $this->drupalGet('admin/modules');
+    $this->submitForm(['modules[image][enable]' => "1"], 'Install');
     $this->rebuildContainer();
 
     $string = $this->storage->findString(['source' => 'Medium (220×220)', 'context' => '', 'type' => 'configuration']);
@@ -145,7 +152,7 @@ class LocaleConfigTranslationTest extends BrowserTestBase {
     $translations = $this->storage->getTranslations(['language' => $this->langcode, 'type' => 'configuration', 'name' => 'image.style.medium']);
     $this->assertCount(1, $translations);
     $translation = reset($translations);
-    $this->assertEqual($string->source, $translation->source);
+    $this->assertEquals($string->source, $translation->source);
     $this->assertEmpty($translation->translation);
 
     // Translate using the UI so configuration is refreshed.
@@ -155,13 +162,15 @@ class LocaleConfigTranslationTest extends BrowserTestBase {
       'langcode' => $this->langcode,
       'translation' => 'all',
     ];
-    $this->drupalPostForm('admin/config/regional/translate', $search, 'Filter');
+    $this->drupalGet('admin/config/regional/translate');
+    $this->submitForm($search, 'Filter');
     $textarea = $this->assertSession()->elementExists('xpath', '//textarea');
     $lid = $textarea->getAttribute('name');
     $edit = [
       $lid => $image_style_label,
     ];
-    $this->drupalPostForm('admin/config/regional/translate', $edit, 'Save translations');
+    $this->drupalGet('admin/config/regional/translate');
+    $this->submitForm($edit, 'Save translations');
 
     // Check the right single translation has been created.
     $translations = $this->storage->getTranslations(['language' => $this->langcode, 'type' => 'configuration', 'name' => 'image.style.medium']);
@@ -172,10 +181,11 @@ class LocaleConfigTranslationTest extends BrowserTestBase {
 
     // Try more complex configuration data.
     $translation = \Drupal::languageManager()->getLanguageConfigOverride($this->langcode, 'image.style.medium')->get();
-    $this->assertEqual($image_style_label, $translation['label'], 'Got the right translation for image style name after translation');
+    $this->assertEquals($image_style_label, $translation['label'], 'Got the right translation for image style name after translation');
 
     // Uninstall the module.
-    $this->drupalPostForm('admin/modules/uninstall', ['uninstall[image]' => "image"], 'Uninstall');
+    $this->drupalGet('admin/modules/uninstall');
+    $this->submitForm(['uninstall[image]' => "image"], 'Uninstall');
     $this->submitForm([], 'Uninstall');
 
     // Ensure that the translated configuration has been removed.
@@ -189,19 +199,21 @@ class LocaleConfigTranslationTest extends BrowserTestBase {
       'langcode' => $this->langcode,
       'translation' => 'all',
     ];
-    $this->drupalPostForm('admin/config/regional/translate', $search, 'Filter');
+    $this->drupalGet('admin/config/regional/translate');
+    $this->submitForm($search, 'Filter');
     $textarea = $this->assertSession()->elementExists('xpath', '//textarea');
     $lid = $textarea->getAttribute('name');
     $edit = [
       $lid => $category_label,
     ];
-    $this->drupalPostForm('admin/config/regional/translate', $edit, 'Save translations');
+    $this->drupalGet('admin/config/regional/translate');
+    $this->submitForm($edit, 'Save translations');
 
     // Check if this category displayed in this language will use the
     // translation. This test ensures the entity loaded from the request
     // upcasting will already work.
     $this->drupalGet($this->langcode . '/contact/feedback');
-    $this->assertText($category_label);
+    $this->assertSession()->pageTextContains($category_label);
 
     // Check if the UI does not show the translated String.
     $this->drupalGet('admin/structure/contact/manage/feedback');
@@ -214,12 +226,14 @@ class LocaleConfigTranslationTest extends BrowserTestBase {
   public function testOptionalConfiguration() {
     $this->assertNodeConfig(FALSE, FALSE);
     // Enable the node module.
-    $this->drupalPostForm('admin/modules', ['modules[node][enable]' => "1"], 'Install');
+    $this->drupalGet('admin/modules');
+    $this->submitForm(['modules[node][enable]' => "1"], 'Install');
     $this->submitForm([], 'Continue');
     $this->rebuildContainer();
     $this->assertNodeConfig(TRUE, FALSE);
     // Enable the views module (which node provides some optional config for).
-    $this->drupalPostForm('admin/modules', ['modules[views][enable]' => "1"], 'Install');
+    $this->drupalGet('admin/modules');
+    $this->submitForm(['modules[views][enable]' => "1"], 'Install');
     $this->rebuildContainer();
     $this->assertNodeConfig(TRUE, TRUE);
   }
