@@ -89,7 +89,8 @@ abstract class LocaleUpdateBase extends BrowserTestBase {
    */
   protected function addLanguage($langcode) {
     $edit = ['predefined_langcode' => $langcode];
-    $this->drupalPostForm('admin/config/regional/language/add', $edit, t('Add language'));
+    $this->drupalGet('admin/config/regional/language/add');
+    $this->submitForm($edit, 'Add language');
     $this->container->get('language_manager')->reset();
     $this->assertNotEmpty(\Drupal::languageManager()->getLanguage($langcode), new FormattableMarkup('Language %langcode added.', ['%langcode' => $langcode]));
   }
@@ -293,7 +294,7 @@ EOF;
    * @param string $source
    *   Translation source string.
    * @param string $translation
-   *   Translation to check. Use empty string to check for a not existing
+   *   Translation to check. Use empty string to check for a non-existent
    *   translation.
    * @param string $langcode
    *   Language code of the language to translate to.
@@ -301,9 +302,15 @@ EOF;
    *   (optional) A message to display with the assertion.
    */
   protected function assertTranslation($source, $translation, $langcode, $message = '') {
-    $db_translation = Database::getConnection()->query('SELECT translation FROM {locales_target} lt INNER JOIN {locales_source} ls ON ls.lid = lt.lid WHERE ls.source = :source AND lt.language = :langcode', [':source' => $source, ':langcode' => $langcode])->fetchField();
+    $query = Database::getConnection()->select('locales_target', 'lt');
+    $query->innerJoin('locales_source', 'ls', 'ls.lid = lt.lid');
+    $db_translation = $query->fields('lt', ['translation'])
+      ->condition('ls.source', $source)
+      ->condition('lt.language', $langcode)
+      ->execute()
+      ->fetchField();
     $db_translation = $db_translation == FALSE ? '' : $db_translation;
-    $this->assertEqual($translation, $db_translation, $message ? $message : new FormattableMarkup('Correct translation of %source (%language)', ['%source' => $source, '%language' => $langcode]));
+    $this->assertEquals($translation, $db_translation, $message ? $message : new FormattableMarkup('Correct translation of %source (%language)', ['%source' => $source, '%language' => $langcode]));
   }
 
 }
