@@ -39,31 +39,27 @@ class MenuLinkContentDeleteFormTest extends BrowserTestBase {
    */
   public function testMenuLinkContentDeleteForm() {
     // Add new menu item.
-    $this->drupalPostForm(
-      'admin/structure/menu/manage/admin/add',
-      [
-        'title[0][value]' => t('Front page'),
-        'link[0][uri]' => '<front>',
-      ],
-      t('Save')
-    );
-    $this->assertText(t('The menu link has been saved.'));
+    $this->drupalGet('admin/structure/menu/manage/admin/add');
+    $this->submitForm([
+      'title[0][value]' => t('Front page'),
+      'link[0][uri]' => '<front>',
+    ], 'Save');
+    $this->assertSession()->pageTextContains('The menu link has been saved.');
 
     $menu_link = MenuLinkContent::load(1);
     $this->drupalGet($menu_link->toUrl('delete-form'));
     $this->assertRaw(t('Are you sure you want to delete the custom menu link %name?', ['%name' => $menu_link->label()]));
-    $this->assertLink(t('Cancel'));
+    $this->assertSession()->linkExists('Cancel');
     // Make sure cancel link points to link edit
-    $this->assertLinkByHref($menu_link->toUrl('edit-form')->toString());
+    $this->assertSession()->linkByHrefExists($menu_link->toUrl('edit-form')->toString());
 
     \Drupal::service('module_installer')->install(['menu_ui']);
-    \Drupal::service('router.builder')->rebuild();
 
     // Make sure cancel URL points to menu_ui route now.
     $this->drupalGet($menu_link->toUrl('delete-form'));
     $menu = Menu::load($menu_link->getMenuName());
-    $this->assertLinkByHref($menu->toUrl('edit-form')->toString());
-    $this->drupalPostForm(NULL, [], t('Delete'));
+    $this->assertSession()->linkByHrefExists($menu->toUrl('edit-form')->toString());
+    $this->submitForm([], 'Delete');
     $this->assertRaw(t('The menu link %title has been deleted.', ['%title' => $menu_link->label()]));
   }
 
