@@ -73,7 +73,7 @@ class MenuLinkContentTranslationUITest extends ContentTranslationUITestBase {
    */
   public function testTranslationLinkOnMenuEditForm() {
     $this->drupalGet('admin/structure/menu/manage/tools');
-    $this->assertSession()->linkNotExists(t('Translate'));
+    $this->assertSession()->linkNotExists('Translate');
 
     $menu_link_content = MenuLinkContent::create([
       'menu_name' => 'tools',
@@ -82,7 +82,7 @@ class MenuLinkContentTranslationUITest extends ContentTranslationUITestBase {
     ]);
     $menu_link_content->save();
     $this->drupalGet('admin/structure/menu/manage/tools');
-    $this->assertSession()->linkExists(t('Translate'));
+    $this->assertSession()->linkExists('Translate');
   }
 
   /**
@@ -96,11 +96,14 @@ class MenuLinkContentTranslationUITest extends ContentTranslationUITestBase {
     $this->container->get('theme_installer')->install(['seven']);
     $edit = [];
     $edit['admin_theme'] = 'seven';
-    $this->drupalPostForm('admin/appearance', $edit, t('Save configuration'));
+    $this->drupalGet('admin/appearance');
+    $this->submitForm($edit, 'Save configuration');
+    // Check that edit uses the admin theme.
     $this->drupalGet('admin/structure/menu/item/' . $entityId . '/edit');
-    $this->assertRaw('core/themes/seven/css/base/elements.css', 'Edit uses admin theme.');
+    $this->assertRaw('core/themes/seven/css/base/elements.css');
+    // Check that translation uses admin theme as well.
     $this->drupalGet('admin/structure/menu/item/' . $entityId . '/edit/translations');
-    $this->assertRaw('core/themes/seven/css/base/elements.css', 'Translation uses admin theme as well.');
+    $this->assertRaw('core/themes/seven/css/base/elements.css');
   }
 
   /**
