@@ -54,14 +54,16 @@ class MenuLinkReorderTest extends BrowserTestBase {
     $edit = [
       'links[menu_plugin_id:test_page_test.front_page][weight]' => -10,
     ];
-    $this->drupalPostForm('admin/structure/menu/manage/main', $edit, t('Save'));
+    $this->drupalGet('admin/structure/menu/manage/main');
+    $this->submitForm($edit, 'Save');
 
     // The link is still there.
     $this->drupalGet('test-page');
     $this->assertSession()->linkExists('Home');
 
     // Clear all caches.
-    $this->drupalPostForm('admin/config/development/performance', [], t('Clear all caches'));
+    $this->drupalGet('admin/config/development/performance');
+    $this->submitForm([], 'Clear all caches');
 
     // Clearing all caches should not affect the state of the menu link.
     $this->drupalGet('test-page');
