@@ -10,6 +10,8 @@ use Drupal\taxonomy\Entity\Vocabulary;
 use Drupal\Tests\migrate_drupal\Traits\FieldDiscoveryTestTrait;
 use Drupal\field_discovery_test\FieldDiscoveryTestClass;
 
+// cspell:ignore imagelink
+
 /**
  * Test FieldDiscovery Service against Drupal 7.
  *
@@ -78,6 +80,7 @@ class FieldDiscoveryTest extends MigrateDrupal7TestBase {
       'et' => 'comment_node_et',
       'forum' => 'comment_forum',
       'test_content_type' => 'comment_node_test_content_type',
+      'a_thirty_two_character_type_name' => 'a_thirty_two_character_type_name',
     ];
     foreach ($node_types as $node_type => $comment_type) {
       NodeType::create([
@@ -95,6 +98,7 @@ class FieldDiscoveryTest extends MigrateDrupal7TestBase {
     Vocabulary::create(['vid' => 'test_vocabulary'])->save();
     $this->executeMigrations([
       'd7_field',
+      'd7_comment_type',
       'd7_taxonomy_vocabulary',
       'd7_field_instance',
     ]);
@@ -200,11 +204,23 @@ class FieldDiscoveryTest extends MigrateDrupal7TestBase {
               'map' => [
                 'taxonomy_term_reference' => [
                   'taxonomy_term_reference_link' => 'entity_reference_label',
+                  'taxonomy_term_reference_plain' => 'entity_reference_label',
+                  'taxonomy_term_reference_rss_category' => 'entity_reference_label',
                   'i18n_taxonomy_term_reference_link' => 'entity_reference_label',
                   'entityreference_entity_view' => 'entity_reference_entity_view',
                 ],
                 'link_field' => [
                   'link_default' => 'link',
+                  'link_title_plain' => 'link',
+                  'link_host' => 'link',
+                  'link_url' => 'link',
+                  'link_plain' => 'link',
+                  'link_absolute' => 'link',
+                  'link_domain' => 'link',
+                  'link_no_protocol' => 'link',
+                  'link_short' => 'link',
+                  'link_label' => 'link',
+                  'link_separate' => 'link_separate',
                 ],
                 'entityreference' => [
                   'entityreference_label' => 'entity_reference_label',
@@ -279,8 +295,8 @@ class FieldDiscoveryTest extends MigrateDrupal7TestBase {
     $this->assertArrayHasKey('test_vocabulary', $actual_fields['taxonomy_term']);
     $this->assertArrayHasKey('user', $actual_fields['user']);
     $this->assertArrayHasKey('test_content_type', $actual_fields['node']);
-    $this->assertCount(7, $actual_fields['node']);
-    $this->assertCount(7, $actual_fields['comment']);
+    $this->assertCount(8, $actual_fields['node']);
+    $this->assertCount(8, $actual_fields['comment']);
     $this->assertCount(22, $actual_fields['node']['test_content_type']);
     foreach ($actual_fields as $entity_type_id => $bundles) {
       foreach ($bundles as $bundle => $fields) {
