@@ -87,7 +87,10 @@ class NodeRevisionPermissionsTest extends NodeTestBase {
     }
 
     // Create an admin account (returns TRUE for all revision permissions).
-    $admin_account = $this->drupalCreateUser(['access content', 'administer nodes']);
+    $admin_account = $this->drupalCreateUser([
+      'access content',
+      'administer nodes',
+    ]);
     $admin_account->is_admin = TRUE;
     $this->accounts['admin'] = $admin_account;
     $accounts['admin'] = $admin_account;
@@ -107,10 +110,14 @@ class NodeRevisionPermissionsTest extends NodeTestBase {
     $permutations = $this->generatePermutations($parameters);
 
     $node_revision_access = \Drupal::service('access_check.node.revision');
-    $connection = \Drupal::database();
+    $vids = \Drupal::entityQuery('node')
+      ->allRevisions()
+      ->accessCheck(FALSE)
+      ->condition('nid', $revision->id())
+      ->execute();
     foreach ($permutations as $case) {
       // Skip this test if there are no revisions for the node.
-      if (!($revision->isDefaultRevision() && ($connection->query('SELECT COUNT(vid) FROM {node_field_revision} WHERE nid = :nid', [':nid' => $revision->id()])->fetchField() == 1 || $case['op'] == 'update' || $case['op'] == 'delete'))) {
+      if (!($revision->isDefaultRevision() && (count($vids) == 1 || $case['op'] == 'update' || $case['op'] == 'delete'))) {
         if (!empty($case['account']->is_admin) || $case['account']->hasPermission($this->map[$case['op']])) {
           $this->assertTrue($node_revision_access->checkAccess($revision, $case['account'], $case['op']), "{$this->map[$case['op']]} granted.");
         }
@@ -156,10 +163,14 @@ class NodeRevisionPermissionsTest extends NodeTestBase {
 
     $permutations = $this->generatePermutations($parameters);
     $node_revision_access = \Drupal::service('access_check.node.revision');
-    $connection = \Drupal::database();
+    $vids = \Drupal::entityQuery('node')
+      ->allRevisions()
+      ->accessCheck(FALSE)
+      ->condition('nid', $revision->id())
+      ->execute();
     foreach ($permutations as $case) {
       // Skip this test if there are no revisions for the node.
-      if (!($revision->isDefaultRevision() && ($connection->query('SELECT COUNT(vid) FROM {node_field_revision} WHERE nid = :nid', [':nid' => $revision->id()])->fetchField() == 1 || $case['op'] == 'update' || $case['op'] == 'delete'))) {
+      if (!($revision->isDefaultRevision() && (count($vids) == 1 || $case['op'] == 'update' || $case['op'] == 'delete'))) {
         if (!empty($case['account']->is_admin) || $case['account']->hasPermission($this->typeMap[$case['op']])) {
           $this->assertTrue($node_revision_access->checkAccess($revision, $case['account'], $case['op']), "{$this->typeMap[$case['op']]} granted.");
         }
