@@ -254,14 +254,14 @@ class BulkFormTest extends NodeTestBase {
     $this->submitForm($edit, 'Apply to selected items');
 
     $label = $this->loadNode(1)->label();
-    $this->assertText("$label (Original translation) - The following content item translations will be deleted:");
+    $this->assertSession()->pageTextContains("$label (Original translation) - The following content item translations will be deleted:");
     $label = $this->loadNode(2)->label();
-    $this->assertText("$label (Original translation) - The following content item translations will be deleted:");
+    $this->assertSession()->pageTextContains("$label (Original translation) - The following content item translations will be deleted:");
     $label = $this->loadNode(3)->getTranslation('en')->label();
-    $this->assertText($label);
+    $this->assertSession()->pageTextContains($label);
     $this->assertNoText("$label (Original translation) - The following content item translations will be deleted:");
     $label = $this->loadNode(4)->label();
-    $this->assertText($label);
+    $this->assertSession()->pageTextContains($label);
     $this->assertNoText("$label (Original translation) - The following content item translations will be deleted:");
 
     $this->submitForm([], 'Delete');
@@ -278,7 +278,7 @@ class BulkFormTest extends NodeTestBase {
     $node = $this->loadNode(5);
     $this->assertNotEmpty($node, '5: Node has not been deleted');
 
-    $this->assertText('Deleted 8 content items.');
+    $this->assertSession()->pageTextContains('Deleted 8 content items.');
   }
 
   /**
