@@ -49,19 +49,19 @@ class NodeConditionTest extends EntityKernelTestBase {
       ->setContextValue('node', $page);
     $this->assertFalse($condition->execute(), 'Page type nodes fail node type checks for articles.');
     // Check for the proper summary.
-    $this->assertEqual('The node bundle is article', $condition->summary());
+    $this->assertEquals('The node bundle is article', $condition->summary());
 
     // Set the node type check to page.
     $condition->setConfig('bundles', ['page' => 'page']);
     $this->assertTrue($condition->execute(), 'Page type nodes pass node type checks for pages');
     // Check for the proper summary.
-    $this->assertEqual('The node bundle is page', $condition->summary());
+    $this->assertEquals('The node bundle is page', $condition->summary());
 
     // Set the node type check to page or article.
     $condition->setConfig('bundles', ['page' => 'page', 'article' => 'article']);
     $this->assertTrue($condition->execute(), 'Page type nodes pass node type checks for pages or articles');
     // Check for the proper summary.
-    $this->assertEqual('The node bundle is page or article', $condition->summary());
+    $this->assertEquals('The node bundle is page or article', $condition->summary());
 
     // Set the context to the article node.
     $condition->setContextValue('node', $article);
@@ -73,7 +73,7 @@ class NodeConditionTest extends EntityKernelTestBase {
 
     // Check a greater than 2 bundles summary scenario.
     $condition->setConfig('bundles', ['page' => 'page', 'article' => 'article', 'test' => 'test']);
-    $this->assertEqual('The node bundle is page, article or test', $condition->summary());
+    $this->assertEquals('The node bundle is page, article or test', $condition->summary());
   }
 
   /**
