@@ -6,6 +6,7 @@ use Drupal\KernelTests\Core\Entity\EntityKernelTestBase;
 use Drupal\language\Entity\ConfigurableLanguage;
 use Drupal\node\Entity\Node;
 use Drupal\node\Entity\NodeType;
+use Drupal\user\Entity\User;
 
 /**
  * Tests node owner functionality.
@@ -19,9 +20,9 @@ class NodeOwnerTest extends EntityKernelTestBase {
    *
    * @var array
    */
-  public static $modules = ['node', 'language'];
+  protected static $modules = ['node', 'language'];
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     // Create the node bundles required for testing.
@@ -55,7 +56,7 @@ class NodeOwnerTest extends EntityKernelTestBase {
     ]);
     $english->save();
 
-    $this->assertEqual($user->id(), $english->getOwnerId());
+    $this->assertEquals($user->id(), $english->getOwnerId());
 
     $german = $english->addTranslation('de');
     $german->title = $this->randomString();
@@ -70,9 +71,31 @@ class NodeOwnerTest extends EntityKernelTestBase {
     // Entity::save() saves all translations!
     $italian->save();
 
-    $this->assertEqual(0, $english->getOwnerId());
-    $this->assertEqual(0, $german->getOwnerId());
-    $this->assertEqual(0, $italian->getOwnerId());
+    $this->assertEquals(0, $english->getOwnerId());
+    $this->assertEquals(0, $german->getOwnerId());
+    $this->assertEquals(0, $italian->getOwnerId());
+  }
+
+  /**
+   * Test an unsaved node owner.
+   */
+  public function testUnsavedNodeOwner() {
+    $user = User::create([
+      'name' => 'foo',
+    ]);
+    $node = Node::create([
+      'type' => 'page',
+      'title' => $this->randomMachineName(),
+    ]);
+    // Set the node owner while the user is unsaved and then immediately save
+    // the user and node.
+    $node->setOwner($user);
+    $user->save();
+    $node->save();
+
+    // The ID assigned to the newly saved user will now be the owner ID of the
+    // node.
+    $this->assertEquals($user->id(), $node->getOwnerId());
   }
 
 }
