@@ -22,7 +22,7 @@ class OptionsDynamicValuesApiTest extends OptionsDynamicValuesTestBase {
   public function testOptionsAllowedValues() {
     // Test allowed values without passed $items.
     $values = options_allowed_values($this->fieldStorage);
-    $this->assertEqual([], $values);
+    $this->assertEquals([], $values);
 
     $values = options_allowed_values($this->fieldStorage, $this->entity);
 
@@ -33,7 +33,7 @@ class OptionsDynamicValuesApiTest extends OptionsDynamicValuesTestBase {
       $this->entity->bundle(),
     ];
     $expected_values = array_combine($expected_values, $expected_values);
-    $this->assertEqual($expected_values, $values);
+    $this->assertEquals($expected_values, $values);
   }
 
 }
