@@ -41,11 +41,13 @@ class PathLanguageUiTest extends PathTestBase {
     $edit = [];
     $edit['predefined_langcode'] = 'fr';
 
-    $this->drupalPostForm('admin/config/regional/language/add', $edit, 'Add language');
+    $this->drupalGet('admin/config/regional/language/add');
+    $this->submitForm($edit, 'Add language');
 
     // Enable URL language detection and selection.
     $edit = ['language_interface[enabled][language-url]' => 1];
-    $this->drupalPostForm('admin/config/regional/language/detection', $edit, 'Save settings');
+    $this->drupalGet('admin/config/regional/language/detection');
+    $this->submitForm($edit, 'Save settings');
   }
 
   /**
@@ -56,10 +58,11 @@ class PathLanguageUiTest extends PathTestBase {
     $edit = [];
     $edit['path[0][value]'] = '/admin/config/search/path';
     $edit['alias[0][value]'] = '/' . $name;
-    $this->drupalPostForm('admin/config/search/path/add', $edit, 'Save');
+    $this->drupalGet('admin/config/search/path/add');
+    $this->submitForm($edit, 'Save');
 
     $this->drupalGet($name);
-    $this->assertText('Filter aliases');
+    $this->assertSession()->pageTextContains('Filter aliases');
   }
 
   /**
@@ -71,10 +74,11 @@ class PathLanguageUiTest extends PathTestBase {
     $edit['path[0][value]'] = '/admin/config/search/path';
     $edit['alias[0][value]'] = '/' . $name;
     $edit['langcode[0][value]'] = 'en';
-    $this->drupalPostForm('admin/config/search/path/add', $edit, 'Save');
+    $this->drupalGet('admin/config/search/path/add');
+    $this->submitForm($edit, 'Save');
 
     $this->drupalGet($name);
-    $this->assertText('Filter aliases');
+    $this->assertSession()->pageTextContains('Filter aliases');
   }
 
   /**
@@ -86,10 +90,11 @@ class PathLanguageUiTest extends PathTestBase {
     $edit['path[0][value]'] = '/admin/config/search/path';
     $edit['alias[0][value]'] = '/' . $name;
     $edit['langcode[0][value]'] = 'fr';
-    $this->drupalPostForm('admin/config/search/path/add', $edit, 'Save');
+    $this->drupalGet('admin/config/search/path/add');
+    $this->submitForm($edit, 'Save');
 
     $this->drupalGet('fr/' . $name);
-    $this->assertText('Filter aliases');
+    $this->assertSession()->pageTextContains('Filter aliases');
   }
 
   /**
@@ -106,7 +111,8 @@ class PathLanguageUiTest extends PathTestBase {
       'alias[0][value]' => '/' . $this->getRandomGenerator()->word(8),
       'langcode[0][value]' => LanguageInterface::LANGCODE_NOT_SPECIFIED,
     ];
-    $this->drupalPostForm('admin/config/search/path/add', $edit, 'Save');
+    $this->drupalGet('admin/config/search/path/add');
+    $this->submitForm($edit, 'Save');
 
     $this->drupalGet($node->toUrl('edit-form'));
     $this->assertSession()->fieldValueEquals('path[0][alias]', $edit['alias[0][value]']);
