@@ -47,7 +47,7 @@ class QuickEditLoadingTest extends WebDriverTestBase {
   protected $defaultTheme = 'classy';
 
   /**
-   * An user with permissions to create and edit articles.
+   * A user with permissions to create and edit articles.
    *
    * @var \Drupal\user\UserInterface
    */
@@ -61,7 +61,7 @@ class QuickEditLoadingTest extends WebDriverTestBase {
   protected $testNode;
 
   /**
-   * A author user with permissions to access in-place editor.
+   * An author user with permissions to access in-place editor.
    *
    * @var \Drupal\user\UserInterface
    */
@@ -128,14 +128,14 @@ class QuickEditLoadingTest extends WebDriverTestBase {
     $this->drupalGet('node/1');
 
     // Library and in-place editors.
-    $this->assertNoRaw('core/modules/quickedit/js/quickedit.js', 'Quick Edit library not loaded.');
-    $this->assertNoRaw('core/modules/quickedit/js/editors/formEditor.js', "'form' in-place editor not loaded.");
+    $this->assertNoRaw('core/modules/quickedit/js/quickedit.js');
+    $this->assertNoRaw('core/modules/quickedit/js/editors/formEditor.js');
 
-    // HTML annotation and title class does not exist for users without
+    // HTML annotation and title class do not exist for users without
     // permission to in-place edit.
     $this->assertNoRaw('data-quickedit-entity-id="node/1"');
     $this->assertNoRaw('data-quickedit-field-id="node/1/body/en/full"');
-    $this->assertNoFieldByXPath('//h1[contains(@class, "js-quickedit-page-title")]');
+    $this->assertSession()->elementNotExists('xpath', '//h1[contains(@class, "js-quickedit-page-title")]');
     $assert->linkNotExists('Quick edit');
 
     // Tests the loading of Quick Edit when a user does have access to it.
@@ -157,7 +157,6 @@ class QuickEditLoadingTest extends WebDriverTestBase {
     $this->clickContextualLink('[data-quickedit-entity-id="node/' . $nid . '"]', 'Quick edit');
     // Switch to body field.
     $page->find('css', '[data-quickedit-field-id="node/' . $nid . '/body/en/full"]')->click();
-    $assert->assertWaitOnAjaxRequest();
 
     // Wait and update body field.
     $body_field_locator = '[name="body[0][value]"]';
@@ -166,12 +165,7 @@ class QuickEditLoadingTest extends WebDriverTestBase {
 
     // Wait and click by "Save" button after body field was changed.
     $assert->waitForElementVisible('css', '.quickedit-toolgroup.ops [type="submit"][aria-hidden="false"]')->click();
-    $assert->assertWaitOnAjaxRequest();
-
-    $node = Node::load($nid);
-    $vids = \Drupal::entityTypeManager()->getStorage('node')->revisionIds($node);
-    $this->assertCount(1, $vids, 'The node has only one revision.');
-    $this->assertSame($original_log, $node->revision_log->value, 'The revision log message is unchanged.');
+    $assert->waitForElementRemoved('css', '.quickedit-toolgroup.ops [type="submit"][aria-hidden="false"]');
 
     // Ensure that the changes take effect.
     $assert->responseMatches("|\s*$body_text\s*|");
@@ -179,6 +173,12 @@ class QuickEditLoadingTest extends WebDriverTestBase {
     // Reload the page and check for updated body.
     $this->drupalGet('node/' . $nid);
     $assert->pageTextContains($body_text);
+
+    // Ensure that a new revision has not been created.
+    $node = Node::load($nid);
+    $vids = \Drupal::entityTypeManager()->getStorage('node')->revisionIds($node);
+    $this->assertCount(1, $vids, 'The node has only one revision.');
+    $this->assertSame($original_log, $node->revision_log->value, 'The revision log message is unchanged.');
   }
 
   /**
@@ -188,7 +188,8 @@ class QuickEditLoadingTest extends WebDriverTestBase {
     $this->drupalLogin($this->editorUser);
 
     // Verify that the preview is loaded correctly.
-    $this->drupalPostForm('node/add/article', ['title[0][value]' => 'foo'], 'Preview');
+    $this->drupalGet('node/add/article');
+    $this->submitForm(['title[0][value]' => 'foo'], 'Preview');
     // Verify that quickedit is not active on preview.
     $this->assertNoRaw('data-quickedit-entity-id="node/' . $this->testNode->id() . '"');
     $this->assertNoRaw('data-quickedit-field-id="node/' . $this->testNode->id() . '/title/' . $this->testNode->language()->getId() . '/full"');
@@ -228,7 +229,6 @@ class QuickEditLoadingTest extends WebDriverTestBase {
     $this->clickContextualLink('[data-quickedit-entity-id="node/' . $nid . '"]', 'Quick edit');
     // Switch to title field.
     $page->find('css', '[data-quickedit-field-id="node/' . $nid . '/title/en/full"]')->click();
-    $assert->assertWaitOnAjaxRequest();
 
     // Wait and update title field.
     $field_locator = '.field--name-title';
@@ -237,7 +237,7 @@ class QuickEditLoadingTest extends WebDriverTestBase {
 
     // Wait and click by "Save" button after title field was changed.
     $this->assertSession()->waitForElementVisible('css', '.quickedit-toolgroup.ops [type="submit"][aria-hidden="false"]')->click();
-    $assert->assertWaitOnAjaxRequest();
+    $assert->waitForElementRemoved('css', '.quickedit-toolgroup.ops [type="submit"][aria-hidden="false"]');
 
     // Ensure that the changes take effect.
     $assert->responseMatches("|\s*$text_new\s*|");
@@ -294,7 +294,6 @@ class QuickEditLoadingTest extends WebDriverTestBase {
     $this->clickContextualLink('[data-quickedit-entity-id="node/' . $nid . '"]', 'Quick edit');
     // Switch to body field.
     $page->find('css', '[data-quickedit-field-id="node/' . $nid . '/body/en/full"]')->click();
-    $assert->assertWaitOnAjaxRequest();
 
     // Wait and update body field.
     $body_field_locator = '[name="body[0][value]"]';
@@ -303,7 +302,7 @@ class QuickEditLoadingTest extends WebDriverTestBase {
 
     // Wait and click by "Save" button after body field was changed.
     $assert->waitForElementVisible('css', '.quickedit-toolgroup.ops [type="submit"][aria-hidden="false"]')->click();
-    $assert->assertWaitOnAjaxRequest();
+    $assert->waitForElementRemoved('css', $body_field_locator);
 
     // Ensure that the changes take effect.
     $assert->responseMatches("|\s*$body_text\s*|");
@@ -313,7 +312,7 @@ class QuickEditLoadingTest extends WebDriverTestBase {
     $this->loggedInUser = $logged_in_user;
     // Ensure different save timestamps for field editing.
     sleep(2);
-    $this->drupalPostForm(NULL, ['body[0][value]' => '<p>Concurrent edit!</p>'], 'Save');
+    $this->submitForm(['body[0][value]' => '<p>Concurrent edit!</p>'], 'Save');
 
     $this->getSession()->getPage()->hasContent('The content has either been modified by another user, or you have already submitted modifications. As a result, your changes cannot be saved.');
   }
@@ -377,9 +376,7 @@ class QuickEditLoadingTest extends WebDriverTestBase {
     $page->attachFileToField('files[field_image_0]', $image_path);
     $alt_field = $assert->waitForField('field_image[0][alt]');
     $this->assertNotEmpty($alt_field);
-    $this->drupalPostForm(NULL, [
-      'field_image[0][alt]' => 'Vivamus aliquet elit',
-    ], t('Save'));
+    $this->submitForm(['field_image[0][alt]' => 'Vivamus aliquet elit'], 'Save');
 
     // The image field form should load normally.
     // Wait "Quick edit" button for node.
@@ -388,7 +385,6 @@ class QuickEditLoadingTest extends WebDriverTestBase {
     $this->clickContextualLink('[data-quickedit-entity-id="node/1"]', 'Quick edit');
     // Switch to body field.
     $assert->waitForElement('css', '[data-quickedit-field-id="node/1/field_image/en/full"]')->click();
-    $assert->assertWaitOnAjaxRequest();
 
     $field_locator = '.field--name-field-image';
     $assert->waitForElementVisible('css', $field_locator);
