@@ -41,7 +41,7 @@ class SearchPageAddForm extends SearchPageFormBase {
 
     parent::save($form, $form_state);
 
-    drupal_set_message($this->t('The %label search page has been added.', ['%label' => $this->entity->label()]));
+    $this->messenger()->addStatus($this->t('The %label search page has been added.', ['%label' => $this->entity->label()]));
   }
 
 }
