@@ -57,7 +57,8 @@ class SearchExactTest extends BrowserTestBase {
 
     // Test that the correct number of pager links are found for keyword search.
     $edit = ['keys' => 'love pizza'];
-    $this->drupalPostForm('search/node', $edit, 'Search');
+    $this->drupalGet('search/node');
+    $this->submitForm($edit, 'Search');
     $this->assertSession()->linkByHrefExists('page=1', 0, '2nd page link is found for keyword search.');
     $this->assertSession()->linkByHrefExists('page=2', 0, '3rd page link is found for keyword search.');
     $this->assertSession()->linkByHrefExists('page=3', 0, '4th page link is found for keyword search.');
@@ -65,7 +66,8 @@ class SearchExactTest extends BrowserTestBase {
 
     // Test that the correct number of pager links are found for exact phrase search.
     $edit = ['keys' => '"love pizza"'];
-    $this->drupalPostForm('search/node', $edit, 'Search');
+    $this->drupalGet('search/node');
+    $this->submitForm($edit, 'Search');
     $this->assertSession()->linkByHrefExists('page=1', 0, '2nd page link is found for exact phrase search.');
     $this->assertSession()->linkByHrefNotExists('page=2', '3rd page link is not found for exact phrase search.');
 
@@ -75,16 +77,18 @@ class SearchExactTest extends BrowserTestBase {
     $node_type_config->save();
 
     $edit = ['keys' => 'Druplicon'];
-    $this->drupalPostForm('search/node', $edit, 'Search');
-    $this->assertText($user->getAccountName());
-    $this->assertText($this->container->get('date.formatter')->format($node->getChangedTime(), 'short'));
+    $this->drupalGet('search/node');
+    $this->submitForm($edit, 'Search');
+    $this->assertSession()->pageTextContains($user->getAccountName());
+    $this->assertSession()->pageTextContains($this->container->get('date.formatter')->format($node->getChangedTime(), 'short'));
 
     // Check that with post settings turned off the user and changed date
     // information is not displayed.
     $node_type_config->set('display_submitted', FALSE);
     $node_type_config->save();
     $edit = ['keys' => 'Druplicon'];
-    $this->drupalPostForm('search/node', $edit, 'Search');
+    $this->drupalGet('search/node');
+    $this->submitForm($edit, 'Search');
     $this->assertNoText($user->getAccountName());
     $this->assertNoText($this->container->get('date.formatter')->format($node->getChangedTime(), 'short'));
 
