@@ -79,9 +79,10 @@ class ShortcutLinksTest extends ShortcutTestBase {
         'title[0][value]' => $title,
         'link[0][uri]' => $test_path,
       ];
-      $this->drupalPostForm('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link', $form_data, 'Save');
+      $this->drupalGet('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link');
+      $this->submitForm($form_data, 'Save');
       $this->assertSession()->statusCodeEquals(200);
-      $this->assertText('Added a shortcut for ' . $title . '.');
+      $this->assertSession()->pageTextContains('Added a shortcut for ' . $title . '.');
       $saved_set = ShortcutSet::load($set->id());
       $paths = $this->getShortcutInformation($saved_set, 'link');
       $this->assertContains('internal:' . $test_path, $paths, 'Shortcut created: ' . $test_path);
@@ -100,8 +101,8 @@ class ShortcutLinksTest extends ShortcutTestBase {
       // Test the node routes with parameters.
       $entity->save();
       $loaded = Shortcut::load($entity->id());
-      $this->assertEqual($entity->link->uri, $loaded->link->uri);
-      $this->assertEqual($entity->link->options, $loaded->link->options);
+      $this->assertEquals($entity->link->uri, $loaded->link->uri);
+      $this->assertEquals($entity->link->options, $loaded->link->options);
     }
 
     // Log in as non admin user, to check that access is checked when creating
@@ -112,7 +113,8 @@ class ShortcutLinksTest extends ShortcutTestBase {
       'title[0][value]' => $title,
       'link[0][uri]' => '/admin',
     ];
-    $this->drupalPostForm('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link', $form_data, 'Save');
+    $this->drupalGet('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link');
+    $this->submitForm($form_data, 'Save');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t("The path '@link_path' is inaccessible.", ['@link_path' => '/admin']));
 
@@ -120,7 +122,8 @@ class ShortcutLinksTest extends ShortcutTestBase {
       'title[0][value]' => $title,
       'link[0][uri]' => '/node',
     ];
-    $this->drupalPostForm('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link', $form_data, 'Save');
+    $this->drupalGet('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link');
+    $this->submitForm($form_data, 'Save');
     $this->assertSession()->linkExists($title, 0, 'Shortcut link found on the page.');
 
     // Create a new shortcut set and add a link to it.
@@ -129,13 +132,15 @@ class ShortcutLinksTest extends ShortcutTestBase {
       'label' => $this->randomMachineName(),
       'id' => strtolower($this->randomMachineName()),
     ];
-    $this->drupalPostForm('admin/config/user-interface/shortcut/add-set', $edit, 'Save');
+    $this->drupalGet('admin/config/user-interface/shortcut/add-set');
+    $this->submitForm($edit, 'Save');
     $title = $this->randomMachineName();
     $form_data = [
       'title[0][value]' => $title,
       'link[0][uri]' => '/admin',
     ];
-    $this->drupalPostForm('admin/config/user-interface/shortcut/manage/' . $edit['id'] . '/add-link', $form_data, 'Save');
+    $this->drupalGet('admin/config/user-interface/shortcut/manage/' . $edit['id'] . '/add-link');
+    $this->submitForm($form_data, 'Save');
     $this->assertSession()->statusCodeEquals(200);
   }
 
@@ -153,7 +158,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
 
     // Test the "Add to shortcuts" link.
     $this->clickLink('Add to Default shortcuts');
-    $this->assertText('Added a shortcut for Cron.');
+    $this->assertSession()->pageTextContains('Added a shortcut for Cron.');
     $this->assertSession()->linkExists('Cron', 0, 'Shortcut link found on page');
 
     $this->drupalGet('admin/structure');
@@ -162,7 +167,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
     // Test the "Remove from shortcuts" link.
     $this->clickLink('Cron');
     $this->clickLink('Remove from Default shortcuts');
-    $this->assertText('The shortcut Cron has been deleted.');
+    $this->assertSession()->pageTextContains('The shortcut Cron has been deleted.');
     $this->assertSession()->linkNotExists('Cron', 'Shortcut link removed from page');
 
     $this->drupalGet('admin/structure');
@@ -172,26 +177,26 @@ class ShortcutLinksTest extends ShortcutTestBase {
 
     // Test the "Add to shortcuts" link for a page generated by views.
     $this->clickLink('Add to Default shortcuts');
-    $this->assertText('Added a shortcut for People.');
+    $this->assertSession()->pageTextContains('Added a shortcut for People.');
     $this->assertShortcutQuickLink('Remove from Default shortcuts');
 
     // Test the "Remove from  shortcuts" link for a page generated by views.
     $this->clickLink('Remove from Default shortcuts');
-    $this->assertText('The shortcut People has been deleted.');
+    $this->assertSession()->pageTextContains('The shortcut People has been deleted.');
     $this->assertShortcutQuickLink('Add to Default shortcuts');
 
     // Test two pages which use same route name but different route parameters.
     $this->drupalGet('node/add/page');
     // Add Shortcut for Basic Page.
     $this->clickLink('Add to Default shortcuts');
-    $this->assertText('Added a shortcut for Create Basic page.');
+    $this->assertSession()->pageTextContains('Added a shortcut for Create Basic page.');
     // Assure that Article does not have its shortcut indicated as set.
     $this->drupalGet('node/add/article');
     $link = $this->xpath('//a[normalize-space()=:label]', [':label' => 'Remove from Default shortcuts']);
     $this->assertTrue(empty($link), 'Link Remove to Default shortcuts not found for Create Article page.');
     // Add Shortcut for Article.
     $this->clickLink('Add to Default shortcuts');
-    $this->assertText('Added a shortcut for Create Article.');
+    $this->assertSession()->pageTextContains('Added a shortcut for Create Article.');
 
     $this->config('system.theme')->set('default', 'seven')->save();
     $this->drupalGet('node/' . $this->node->id());
@@ -199,12 +204,12 @@ class ShortcutLinksTest extends ShortcutTestBase {
 
     // Test the "Add to shortcuts" link for node view route.
     $this->clickLink('Add to Default shortcuts');
-    $this->assertText("Added a shortcut for $title.");
+    $this->assertSession()->pageTextContains("Added a shortcut for $title.");
     $this->assertShortcutQuickLink('Remove from Default shortcuts');
 
     // Test the "Remove from shortcuts" link for node view route.
     $this->clickLink('Remove from Default shortcuts');
-    $this->assertText("The shortcut $title has been deleted.");
+    $this->assertSession()->pageTextContains("The shortcut $title has been deleted.");
     $this->assertShortcutQuickLink('Add to Default shortcuts');
 
     \Drupal::service('module_installer')->install(['block_content']);
@@ -236,12 +241,13 @@ class ShortcutLinksTest extends ShortcutTestBase {
 
     $shortcuts = $set->getShortcuts();
     $shortcut = reset($shortcuts);
-    $this->drupalPostForm('admin/config/user-interface/shortcut/link/' . $shortcut->id(), ['title[0][value]' => $new_link_name], 'Save');
+    $this->drupalGet('admin/config/user-interface/shortcut/link/' . $shortcut->id());
+    $this->submitForm(['title[0][value]' => $new_link_name], 'Save');
     $saved_set = ShortcutSet::load($set->id());
     $titles = $this->getShortcutInformation($saved_set, 'title');
     $this->assertContains($new_link_name, $titles, 'Shortcut renamed: ' . $new_link_name);
     $this->assertSession()->linkExists($new_link_name, 0, 'Renamed shortcut link appears on the page.');
-    $this->assertText('The shortcut ' . $new_link_name . ' has been updated.');
+    $this->assertSession()->pageTextContains('The shortcut ' . $new_link_name . ' has been updated.');
   }
 
   /**
@@ -255,12 +261,16 @@ class ShortcutLinksTest extends ShortcutTestBase {
 
     $shortcuts = $set->getShortcuts();
     $shortcut = reset($shortcuts);
-    $this->drupalPostForm('admin/config/user-interface/shortcut/link/' . $shortcut->id(), ['title[0][value]' => $shortcut->getTitle(), 'link[0][uri]' => $new_link_path], 'Save');
+    $this->drupalGet('admin/config/user-interface/shortcut/link/' . $shortcut->id());
+    $this->submitForm([
+      'title[0][value]' => $shortcut->getTitle(),
+      'link[0][uri]' => $new_link_path,
+    ], 'Save');
     $saved_set = ShortcutSet::load($set->id());
     $paths = $this->getShortcutInformation($saved_set, 'link');
     $this->assertContains('internal:' . $new_link_path, $paths, 'Shortcut path changed: ' . $new_link_path);
     $this->assertSession()->linkByHrefExists($new_link_path, 0, 'Shortcut with new path appears on the page.');
-    $this->assertText('The shortcut ' . $shortcut->getTitle() . ' has been updated.');
+    $this->assertSession()->pageTextContains('The shortcut ' . $shortcut->getTitle() . ' has been updated.');
   }
 
   /**
@@ -287,7 +297,8 @@ class ShortcutLinksTest extends ShortcutTestBase {
 
     $shortcuts = $set->getShortcuts();
     $shortcut = reset($shortcuts);
-    $this->drupalPostForm('admin/config/user-interface/shortcut/link/' . $shortcut->id() . '/delete', [], 'Delete');
+    $this->drupalGet('admin/config/user-interface/shortcut/link/' . $shortcut->id() . '/delete');
+    $this->submitForm([], 'Delete');
     $saved_set = ShortcutSet::load($set->id());
     $ids = $this->getShortcutInformation($saved_set, 'id');
     $this->assertNotContains($shortcut->id(), $ids, 'Successfully deleted a shortcut.');
@@ -387,15 +398,15 @@ class ShortcutLinksTest extends ShortcutTestBase {
     ]));
     $this->drupalGet(Url::fromRoute('<front>'));
     $shortcuts = $this->cssSelect('#toolbar-item-shortcuts-tray .toolbar-menu a');
-    $this->assertEqual('Add content', $shortcuts[0]->getText());
-    $this->assertEqual('All content', $shortcuts[1]->getText());
+    $this->assertEquals('Add content', $shortcuts[0]->getText());
+    $this->assertEquals('All content', $shortcuts[1]->getText());
     foreach ($this->set->getShortcuts() as $shortcut) {
       $shortcut->setWeight($shortcut->getWeight() * -1)->save();
     }
     $this->drupalGet(Url::fromRoute('<front>'));
     $shortcuts = $this->cssSelect('#toolbar-item-shortcuts-tray .toolbar-menu a');
-    $this->assertEqual('All content', $shortcuts[0]->getText());
-    $this->assertEqual('Add content', $shortcuts[1]->getText());
+    $this->assertEquals('All content', $shortcuts[0]->getText());
+    $this->assertEquals('Add content', $shortcuts[1]->getText());
   }
 
   /**
