@@ -48,7 +48,7 @@ class ShortcutSetsTest extends ShortcutTestBase {
     $this->drupalGet('user/' . $this->adminUser->id() . '/shortcuts');
     // Verify that generated shortcut set was listed as a choice on the user
     // account page.
-    $this->assertText($new_set->label());
+    $this->assertSession()->pageTextContains($new_set->label());
   }
 
   /**
@@ -65,18 +65,15 @@ class ShortcutSetsTest extends ShortcutTestBase {
     $this->assertSession()->titleEquals('List links | Drupal');
 
     // Test for the table.
-    $element = $this->xpath('//div[@class="layout-content"]//table');
-    $this->assertNotEmpty($element, 'Shortcut entity list table found.');
+    $this->assertSession()->elementExists('xpath', '//div[@class="layout-content"]//table');
 
     // Test the table header.
-    $elements = $this->xpath('//div[@class="layout-content"]//table/thead/tr/th');
-    $this->assertCount(3, $elements, 'Correct number of table header cells found.');
+    $this->assertSession()->elementsCount('xpath', '//div[@class="layout-content"]//table/thead/tr/th', 3);
 
     // Test the contents of each th cell.
-    $expected_items = [t('Name'), t('Weight'), t('Operations')];
-    foreach ($elements as $key => $element) {
-      $this->assertEqual($expected_items[$key], $element->getText());
-    }
+    $this->assertSession()->elementTextEquals('xpath', '//div[@class="layout-content"]//table/thead/tr/th[1]', 'Name');
+    $this->assertSession()->elementTextEquals('xpath', '//div[@class="layout-content"]//table/thead/tr/th[2]', 'Weight');
+    $this->assertSession()->elementTextEquals('xpath', '//div[@class="layout-content"]//table/thead/tr/th[3]', 'Operations');
 
     // Look for test shortcuts in the table.
     $weight = count($shortcuts);
@@ -112,7 +109,8 @@ class ShortcutSetsTest extends ShortcutTestBase {
 
     // Attempt to switch the default shortcut set to the newly created shortcut
     // set.
-    $this->drupalPostForm('user/' . $this->adminUser->id() . '/shortcuts', ['set' => $new_set->id()], 'Change set');
+    $this->drupalGet('user/' . $this->adminUser->id() . '/shortcuts');
+    $this->submitForm(['set' => $new_set->id()], 'Change set');
     $this->assertSession()->statusCodeEquals(200);
     $current_set = shortcut_current_displayed_set($this->adminUser);
     $this->assertTrue($new_set->id() == $current_set->id(), 'Successfully switched own shortcut set.');
@@ -138,10 +136,11 @@ class ShortcutSetsTest extends ShortcutTestBase {
       'id' => strtolower($this->randomMachineName()),
       'label' => $this->randomString(),
     ];
-    $this->drupalPostForm('user/' . $this->adminUser->id() . '/shortcuts', $edit, 'Change set');
+    $this->drupalGet('user/' . $this->adminUser->id() . '/shortcuts');
+    $this->submitForm($edit, 'Change set');
     $current_set = shortcut_current_displayed_set($this->adminUser);
     $this->assertNotEquals($this->set->id(), $current_set->id(), 'A shortcut set can be switched to at the same time as it is created.');
-    $this->assertEqual($edit['label'], $current_set->label(), 'The new set is correctly assigned to the user.');
+    $this->assertEquals($edit['label'], $current_set->label(), 'The new set is correctly assigned to the user.');
   }
 
   /**
@@ -149,10 +148,11 @@ class ShortcutSetsTest extends ShortcutTestBase {
    */
   public function testShortcutSetSwitchNoSetName() {
     $edit = ['set' => 'new'];
-    $this->drupalPostForm('user/' . $this->adminUser->id() . '/shortcuts', $edit, 'Change set');
-    $this->assertText('The new set label is required.');
+    $this->drupalGet('user/' . $this->adminUser->id() . '/shortcuts');
+    $this->submitForm($edit, 'Change set');
+    $this->assertSession()->pageTextContains('The new set label is required.');
     $current_set = shortcut_current_displayed_set($this->adminUser);
-    $this->assertEqual($this->set->id(), $current_set->id(), 'Attempting to switch to a new shortcut set without providing a set name does not succeed.');
+    $this->assertEquals($this->set->id(), $current_set->id(), 'Attempting to switch to a new shortcut set without providing a set name does not succeed.');
     $field = $this->assertSession()->fieldExists('label');
     $this->assertTrue($field->hasClass('error'));
   }
@@ -191,7 +191,8 @@ class ShortcutSetsTest extends ShortcutTestBase {
   public function testShortcutSetDelete() {
     $new_set = $this->generateShortcutSet($this->randomMachineName());
 
-    $this->drupalPostForm('admin/config/user-interface/shortcut/manage/' . $new_set->id() . '/delete', [], 'Delete');
+    $this->drupalGet('admin/config/user-interface/shortcut/manage/' . $new_set->id() . '/delete');
+    $this->submitForm([], 'Delete');
     $sets = ShortcutSet::loadMultiple();
     $this->assertFalse(isset($sets[$new_set->id()]), 'Successfully deleted a shortcut set.');
   }
@@ -215,7 +216,7 @@ class ShortcutSetsTest extends ShortcutTestBase {
     $this->drupalGet('user/' . $this->adminUser->id() . '/shortcuts');
     // Verify that generated shortcut set was listed as a choice on the user
     // account page.
-    $this->assertText($new_set->label());
+    $this->assertSession()->pageTextContains($new_set->label());
   }
 
 }
