@@ -32,10 +32,8 @@ class MigrateShortcutSetTest extends MigrateDrupal7TestBase {
     parent::setUp();
     $this->installEntitySchema('shortcut');
     $this->installEntitySchema('menu_link_content');
-    \Drupal::service('router.builder')->rebuild();
     $this->executeMigration('d7_shortcut_set');
     $this->executeMigration('d7_menu');
-    $this->executeMigration('d7_menu_links');
     $this->executeMigration('d7_shortcut');
   }
 
@@ -61,12 +59,12 @@ class MigrateShortcutSetTest extends MigrateDrupal7TestBase {
     $shortcut_set = ShortcutSet::load($id);
     $this->assertInstanceOf(ShortcutSetInterface::class, $shortcut_set);
     /** @var \Drupal\shortcut\ShortcutSetInterface $shortcut_set */
-    $this->assertIdentical($id, $shortcut_set->id());
-    $this->assertIdentical($label, $shortcut_set->label());
+    $this->assertSame($id, $shortcut_set->id());
+    $this->assertSame($label, $shortcut_set->label());
 
     // Check the number of shortcuts in the set.
     $shortcuts = $shortcut_set->getShortcuts();
-    $this->assertIdentical(count($shortcuts), $expected_size);
+    $this->assertCount($expected_size, $shortcuts);
   }
 
 }
