@@ -3,7 +3,7 @@
  * Provides date format preview feature.
  */
 
-(function($, Drupal, drupalSettings) {
+(function ($, Drupal, drupalSettings) {
   const dateFormats = drupalSettings.dateFormats;
 
   /**
@@ -38,12 +38,11 @@
        */
       function dateFormatHandler(e) {
         const baseValue = $(e.target).val() || '';
-        const dateString = baseValue.replace(
-          /\\?(.?)/gi,
-          (key, value) => (dateFormats[key] ? dateFormats[key] : value),
+        const dateString = baseValue.replace(/\\?(.?)/gi, (key, value) =>
+          dateFormats[key] ? dateFormats[key] : value,
         );
 
-        $preview.html(dateString);
+        $preview.text(dateString);
         $target.toggleClass('js-hide', !dateString.length);
       }
 
