@@ -14,7 +14,7 @@ class TemporaryQueryTest extends DatabaseTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['database_test'];
+  protected static $modules = ['database_test'];
 
   /**
    * {@inheritdoc}
@@ -36,7 +36,7 @@ class TemporaryQueryTest extends DatabaseTestBase {
     $this->drupalGet('database_test/db_query_temporary');
     $data = json_decode($this->getSession()->getPage()->getContent());
     if ($data) {
-      $this->assertEqual($this->countTableRows('test'), $data->row_count, 'The temporary table contains the correct amount of rows.');
+      $this->assertEquals($this->countTableRows('test'), $data->row_count, 'The temporary table contains the correct amount of rows.');
       $this->assertFalse($connection->schema()->tableExists($data->table_name), 'The temporary table is, indeed, temporary.');
     }
     else {
@@ -47,8 +47,8 @@ class TemporaryQueryTest extends DatabaseTestBase {
     $table_name_test = $connection->queryTemporary('SELECT name FROM {test}', []);
     $table_name_task = $connection->queryTemporary('SELECT pid FROM {test_task}', []);
 
-    $this->assertEqual($this->countTableRows($table_name_test), $this->countTableRows('test'), 'A temporary table was created successfully in this request.');
-    $this->assertEqual($this->countTableRows($table_name_task), $this->countTableRows('test_task'), 'A second temporary table was created successfully in this request.');
+    $this->assertEquals($this->countTableRows('test'), $this->countTableRows($table_name_test), 'A temporary table was created successfully in this request.');
+    $this->assertEquals($this->countTableRows('test_task'), $this->countTableRows($table_name_task), 'A second temporary table was created successfully in this request.');
 
     // Check that leading whitespace and comments do not cause problems
     // in the modified query.
@@ -57,7 +57,7 @@ class TemporaryQueryTest extends DatabaseTestBase {
       SELECT name FROM {test}
     ";
     $table_name_test = $connection->queryTemporary($sql, []);
-    $this->assertEqual($this->countTableRows($table_name_test), $this->countTableRows('test'), 'Leading white space and comments do not interfere with temporary table creation.');
+    $this->assertEquals($this->countTableRows('test'), $this->countTableRows($table_name_test), 'Leading white space and comments do not interfere with temporary table creation.');
   }
 
 }
