@@ -42,7 +42,7 @@ class DrupalDateTimeTest extends BrowserTestBase {
     ];
     // Query the AJAX Timezone Callback with a long-format date.
     $response = $this->drupalGet('system/timezone/BST/3600/1', $options);
-    $this->assertEqual('"Europe\\/London"', $response, 'Timezone AJAX callback successfully identifies and responds to a long-format date.');
+    $this->assertEquals('"Europe\\/London"', $response, 'Timezone AJAX callback successfully identifies and responds to a long-format date.');
   }
 
   /**
@@ -90,7 +90,8 @@ class DrupalDateTimeTest extends BrowserTestBase {
 
     // Set up the user with a different timezone than the site.
     $edit = ['mail' => $test_user->getEmail(), 'timezone' => 'Asia/Manila'];
-    $this->drupalPostForm('user/' . $test_user->id() . '/edit', $edit, 'Save');
+    $this->drupalGet('user/' . $test_user->id() . '/edit');
+    $this->submitForm($edit, 'Save');
 
     // Reload the user and reset the timezone in AccountProxy::setAccount().
     \Drupal::entityTypeManager()->getStorage('user')->resetCache();
@@ -111,14 +112,14 @@ class DrupalDateTimeTest extends BrowserTestBase {
     $date = DrupalDateTime::createFromTimestamp(87654321, 'UTC');
 
     // Verify that the date format method displays the default time zone.
-    $this->assertEqual('1972/10/11 12:25:21 UTC', $date->format('Y/m/d H:i:s e'), 'Date has default UTC time zone and correct date/time.');
+    $this->assertEquals('1972/10/11 12:25:21 UTC', $date->format('Y/m/d H:i:s e'), 'Date has default UTC time zone and correct date/time.');
 
     // Verify that the format method can override the time zone.
-    $this->assertEqual('1972/10/11 08:25:21 America/New_York', $date->format('Y/m/d H:i:s e', ['timezone' => 'America/New_York']), 'Date displayed overridden time zone and correct date/time');
+    $this->assertEquals('1972/10/11 08:25:21 America/New_York', $date->format('Y/m/d H:i:s e', ['timezone' => 'America/New_York']), 'Date displayed overridden time zone and correct date/time');
 
     // Verify that the date format method still displays the default time zone
     // for the date object.
-    $this->assertEqual('1972/10/11 12:25:21 UTC', $date->format('Y/m/d H:i:s e'), 'Date still has default UTC time zone and correct date/time');
+    $this->assertEquals('1972/10/11 12:25:21 UTC', $date->format('Y/m/d H:i:s e'), 'Date still has default UTC time zone and correct date/time');
   }
 
 }
