@@ -85,12 +85,14 @@ class EntityFormTest extends BrowserTestBase {
       'field_test_text[0][value]' => $this->randomMachineName(16),
     ];
 
-    $this->drupalPostForm($entity_type . '/add', $edit, 'Save');
+    $this->drupalGet($entity_type . '/add');
+    $this->submitForm($edit, 'Save');
     $entity = $this->loadEntityByName($entity_type, $name1);
     $this->assertNotNull($entity, new FormattableMarkup('%entity_type: Entity found in the database.', ['%entity_type' => $entity_type]));
 
     $edit['name[0][value]'] = $name2;
-    $this->drupalPostForm($entity_type . '/manage/' . $entity->id() . '/edit', $edit, 'Save');
+    $this->drupalGet($entity_type . '/manage/' . $entity->id() . '/edit');
+    $this->submitForm($edit, 'Save');
     $entity = $this->loadEntityByName($entity_type, $name1);
     $this->assertNull($entity, new FormattableMarkup('%entity_type: The entity has been modified.', ['%entity_type' => $entity_type]));
     $entity = $this->loadEntityByName($entity_type, $name2);
@@ -120,7 +122,8 @@ class EntityFormTest extends BrowserTestBase {
       'field_test_text[0][value]' => $this->randomMachineName(16),
     ];
 
-    $this->drupalPostForm($entity_type_id . '/add', $edit, 'Save');
+    $this->drupalGet($entity_type_id . '/add');
+    $this->submitForm($edit, 'Save');
     $entity = $this->loadEntityByName($entity_type_id, $name1);
     $this->assertNotNull($entity, new FormattableMarkup('%entity_type: Entity found in the database.', ['%entity_type' => $entity_type_id]));
 
@@ -128,13 +131,14 @@ class EntityFormTest extends BrowserTestBase {
     // translation module.
     $entity->addTranslation('ro', ['name' => $name1_ro])->save();
     $translated_entity = $this->loadEntityByName($entity_type_id, $name1)->getTranslation('ro');
-    $this->assertEqual($name1_ro, $translated_entity->name->value, new FormattableMarkup('%entity_type: The translation has been added.', ['%entity_type' => $entity_type_id]));
+    $this->assertEquals($name1_ro, $translated_entity->name->value, new FormattableMarkup('%entity_type: The translation has been added.', ['%entity_type' => $entity_type_id]));
 
     $edit['name[0][value]'] = $name2_ro;
-    $this->drupalPostForm('ro/' . $entity_type_id . '/manage/' . $entity->id() . '/edit', $edit, 'Save');
+    $this->drupalGet('ro/' . $entity_type_id . '/manage/' . $entity->id() . '/edit');
+    $this->submitForm($edit, 'Save');
     $translated_entity = $this->loadEntityByName($entity_type_id, $name1)->getTranslation('ro');
     $this->assertNotNull($translated_entity, new FormattableMarkup('%entity_type: Modified translation found in the database.', ['%entity_type' => $entity_type_id]));
-    $this->assertEqual($name2_ro, $translated_entity->name->value, new FormattableMarkup('%entity_type: The name of the translation has been modified.', ['%entity_type' => $entity_type_id]));
+    $this->assertEquals($name2_ro, $translated_entity->name->value, new FormattableMarkup('%entity_type: The name of the translation has been modified.', ['%entity_type' => $entity_type_id]));
 
     $this->drupalGet('ro/' . $entity_type_id . '/manage/' . $entity->id() . '/edit');
     $this->clickLink(t('Delete'));
@@ -166,14 +170,16 @@ class EntityFormTest extends BrowserTestBase {
     // Check that from-level validation handlers can be defined and can alter
     // the form array.
     $state->set('entity_test.form.validate.test', 'form-level');
-    $this->drupalPostForm('entity_test/add', [], 'Save');
+    $this->drupalGet('entity_test/add');
+    $this->submitForm([], 'Save');
     $this->assertTrue($state->get('entity_test.form.validate.result'), 'Form-level validation handlers behave correctly.');
 
     // Check that defining a button-level validation handler causes an exception
     // to be thrown.
     $state->set('entity_test.form.validate.test', 'button-level');
-    $this->drupalPostForm('entity_test/add', [], 'Save');
-    $this->assertEqual('Drupal\\Core\\Entity\\EntityStorageException: Entity validation was skipped.', $state->get('entity_test.form.save.exception'), 'Button-level validation handlers behave correctly.');
+    $this->drupalGet('entity_test/add');
+    $this->submitForm([], 'Save');
+    $this->assertEquals('Drupal\\Core\\Entity\\EntityStorageException: Entity validation was skipped.', $state->get('entity_test.form.save.exception'), 'Button-level validation handlers behave correctly.');
   }
 
 }
