@@ -175,7 +175,8 @@ class FormTest extends BrowserTestBase {
 
     // Attempt to submit the form with no required fields set.
     $edit = [];
-    $this->drupalPostForm('form-test/validate-required', $edit, 'Submit');
+    $this->drupalGet('form-test/validate-required');
+    $this->submitForm($edit, 'Submit');
 
     // The only error messages that should appear are the relevant 'required'
     // messages for each field.
@@ -269,7 +270,7 @@ class FormTest extends BrowserTestBase {
     $element = $assert->fieldExists('textfield');
     $this->assertEmpty($element->getValue());
     $assert->responseNotContains($random_string);
-    $this->assertText('The form has become outdated.');
+    $this->assertSession()->pageTextContains('The form has become outdated.');
     // Ensure that we don't use the posted values.
     $this->assertSession()->fieldValueEquals('textfield', '');
     $this->assertSession()->checkboxNotChecked('edit-checkboxes-foo');
@@ -290,7 +291,7 @@ class FormTest extends BrowserTestBase {
     // Verify that the error message is displayed with invalid token even when
     // required fields are filled.
     $this->assertSession()->elementExists('xpath', '//div[contains(@class, "error")]');
-    $this->assertText('The form has become outdated.');
+    $this->assertSession()->pageTextContains('The form has become outdated.');
     $this->assertSession()->fieldValueEquals('textfield', '');
     $this->assertSession()->fieldValueEquals('textarea', '');
 
@@ -308,7 +309,7 @@ class FormTest extends BrowserTestBase {
     // Verify that the error message is displayed with invalid token even when
     // required fields are filled.'
     $this->assertSession()->elementExists('xpath', '//div[contains(@class, "error")]');
-    $this->assertText('The form has become outdated.');
+    $this->assertSession()->pageTextContains('The form has become outdated.');
     $this->assertSession()->fieldValueEquals('integer_step', 5);
 
     // Check a form with a Url field
@@ -323,7 +324,7 @@ class FormTest extends BrowserTestBase {
     // Verify that the error message is displayed with invalid token even when
     // required fields are filled.
     $this->assertSession()->elementExists('xpath', '//div[contains(@class, "error")]');
-    $this->assertText('The form has become outdated.');
+    $this->assertSession()->pageTextContains('The form has become outdated.');
     $this->assertSession()->fieldValueEquals('url', '');
   }
 
@@ -352,7 +353,8 @@ class FormTest extends BrowserTestBase {
   public function testRequiredTextfieldNoTitle() {
     // Attempt to submit the form with no required field set.
     $edit = [];
-    $this->drupalPostForm('form-test/validate-required-no-title', $edit, 'Submit');
+    $this->drupalGet('form-test/validate-required-no-title');
+    $this->submitForm($edit, 'Submit');
     $this->assertNoRaw("The form_test_validate_required_form_no_title form was submitted successfully.");
 
     // Check the page for the error class on the textfield.
@@ -380,7 +382,8 @@ class FormTest extends BrowserTestBase {
   public function testCheckboxProcessing() {
     // First, try to submit without the required checkbox.
     $edit = [];
-    $this->drupalPostForm('form-test/checkbox', $edit, 'Submit');
+    $this->drupalGet('form-test/checkbox');
+    $this->submitForm($edit, 'Submit');
     $this->assertRaw(t('@name field is required.', ['@name' => 'required_checkbox']));
 
     // Now try to submit the form correctly.
@@ -440,7 +443,7 @@ class FormTest extends BrowserTestBase {
         'multiple_no_default_required',
     ];
     foreach ($expected_errors as $key) {
-      $this->assertText($form[$key]['#title'] . ' field is required.');
+      $this->assertSession()->pageTextContains($form[$key]['#title'] . ' field is required.');
     }
 
     // Post values for required fields.
@@ -645,7 +648,8 @@ class FormTest extends BrowserTestBase {
     // First test the number element type, then range.
     foreach (['form-test/number', 'form-test/number/range'] as $path) {
       // Post form and show errors.
-      $this->drupalPostForm($path, [], 'Submit');
+      $this->drupalGet($path);
+      $this->submitForm([], 'Submit');
 
       foreach ($expected as $element => $error) {
         // Create placeholder array.
@@ -673,14 +677,16 @@ class FormTest extends BrowserTestBase {
    * Tests default value handling of #type 'range' elements.
    */
   public function testRange() {
-    $this->drupalPostForm('form-test/range', [], 'Submit');
+    $this->drupalGet('form-test/range');
+    $this->submitForm([], 'Submit');
     $values = json_decode($this->getSession()->getPage()->getContent());
-    $this->assertEqual(18, $values->with_default_value);
-    $this->assertEqual(10.5, $values->float);
-    $this->assertEqual(6, $values->integer);
-    $this->assertEqual(6.9, $values->offset);
+    $this->assertEquals(18, $values->with_default_value);
+    $this->assertEquals(10.5, $values->float);
+    $this->assertEquals(6, $values->integer);
+    $this->assertEquals(6.9, $values->offset);
 
-    $this->drupalPostForm('form-test/range/invalid', [], 'Submit');
+    $this->drupalGet('form-test/range/invalid');
+    $this->submitForm([], 'Submit');
     // Verify that the 'range' element has the error class.
     $this->assertSession()->elementExists('xpath', '//input[@type="range" and contains(@class, "error")]');
   }
@@ -705,9 +711,10 @@ class FormTest extends BrowserTestBase {
       $edit = [
         'color' => $input,
       ];
-      $this->drupalPostForm('form-test/color', $edit, 'Submit');
+      $this->drupalGet('form-test/color');
+      $this->submitForm($edit, 'Submit');
       $result = json_decode($this->getSession()->getPage()->getContent());
-      $this->assertEqual($expected, $result->color);
+      $this->assertEquals($expected, $result->color);
     }
 
     // Tests invalid values are rejected.
@@ -716,7 +723,8 @@ class FormTest extends BrowserTestBase {
       $edit = [
         'color' => $input,
       ];
-      $this->drupalPostForm('form-test/color', $edit, 'Submit');
+      $this->drupalGet('form-test/color');
+      $this->submitForm($edit, 'Submit');
       $this->assertRaw(t('%name must be a valid color.', ['%name' => 'Color']));
     }
   }
@@ -749,11 +757,12 @@ class FormTest extends BrowserTestBase {
 
     // Submit the form with no input, as the browser does for disabled elements,
     // and fetch the $form_state->getValues() that is passed to the submit handler.
-    $this->drupalPostForm('form-test/disabled-elements', [], 'Submit');
+    $this->drupalGet('form-test/disabled-elements');
+    $this->submitForm([], 'Submit');
     $returned_values['normal'] = Json::decode($this->getSession()->getPage()->getContent());
 
     // Do the same with input, as could happen if JavaScript un-disables an
-    // element. drupalPostForm() emulates a browser by not submitting input for
+    // element. submitForm() emulates a browser by not submitting input for
     // disabled elements, so we need to un-disable those elements first.
     $this->drupalGet('form-test/disabled-elements');
     $disabled_elements = [];
@@ -765,7 +774,7 @@ class FormTest extends BrowserTestBase {
     // the disabled container.
     $actual_count = count($disabled_elements);
     $expected_count = 42;
-    $this->assertEqual($expected_count, $actual_count, new FormattableMarkup('Found @actual elements with disabled property (expected @expected).', ['@actual' => count($disabled_elements), '@expected' => $expected_count]));
+    $this->assertEquals($expected_count, $actual_count, new FormattableMarkup('Found @actual elements with disabled property (expected @expected).', ['@actual' => count($disabled_elements), '@expected' => $expected_count]));
 
     // Mink does not "see" hidden elements, so we need to set the value of the
     // hidden element directly.
@@ -861,16 +870,8 @@ class FormTest extends BrowserTestBase {
     }
 
     // Verify special element #type text-format.
-    $element = $this->xpath('//div[contains(@class, :div-class)]/descendant::textarea[@name=:name]', [
-      ':name' => 'text_format[value]',
-      ':div-class' => 'form-disabled',
-    ]);
-    $this->assertTrue(isset($element[0]), new FormattableMarkup('Disabled form element class found for #type %type.', ['%type' => 'text_format[value]']));
-    $element = $this->xpath('//div[contains(@class, :div-class)]/descendant::select[@name=:name]', [
-      ':name' => 'text_format[format]',
-      ':div-class' => 'form-disabled',
-    ]);
-    $this->assertTrue(isset($element[0]), new FormattableMarkup('Disabled form element class found for #type %type.', ['%type' => 'text_format[format]']));
+    $this->assertSession()->elementExists('xpath', "//div[contains(@class, 'form-disabled')]/descendant::textarea[@name='text_format[value]']");
+    $this->assertSession()->elementExists('xpath', "//div[contains(@class, 'form-disabled')]/descendant::select[@name='text_format[format]']");
   }
 
   /**
@@ -884,7 +885,7 @@ class FormTest extends BrowserTestBase {
     // an input forgery.
     // @see \Drupal\form_test\Form\FormTestInputForgeryForm::postRender
     $this->submitForm(['checkboxes[one]' => TRUE, 'checkboxes[two]' => TRUE], 'Submit');
-    $this->assertText('An illegal choice has been detected.');
+    $this->assertSession()->pageTextContains('An illegal choice has been detected.');
   }
 
   /**
