@@ -69,9 +69,10 @@ class SessionTest extends BrowserTestBase {
       'name' => $user->getAccountName(),
       'pass' => $user->passRaw,
     ];
-    $this->drupalPostForm('user/login', $edit, 'Log in');
+    $this->drupalGet('user/login');
+    $this->submitForm($edit, 'Log in');
     $this->drupalGet('user');
-    $pass = $this->assertText($user->getAccountName());
+    $pass = $this->assertSession()->pageTextContains($user->getAccountName());
     $this->_logged_in = $pass;
 
     $this->drupalGet('session-test/id');
@@ -94,11 +95,11 @@ class SessionTest extends BrowserTestBase {
     $value_1 = $this->randomMachineName();
     // Verify that the session value is stored.
     $this->drupalGet('session-test/set/' . $value_1);
-    $this->assertText($value_1);
+    $this->assertSession()->pageTextContains($value_1);
     // Verify that the session correctly returned the stored data for an
     // authenticated user.
     $this->drupalGet('session-test/get');
-    $this->assertText($value_1);
+    $this->assertSession()->pageTextContains($value_1);
 
     // Attempt to write over val_1. If drupal_save_session(FALSE) is working.
     // properly, val_1 will still be set.
@@ -107,10 +108,10 @@ class SessionTest extends BrowserTestBase {
     // session-test/no-set.
     $this->drupalGet('session-test/no-set/' . $value_2);
     $session = $this->getSession();
-    $this->assertText($value_2);
+    $this->assertSession()->pageTextContains($value_2);
     // Verify that the session data is not saved for drupal_save_session(FALSE).
     $this->drupalGet('session-test/get');
-    $this->assertText($value_1);
+    $this->assertSession()->pageTextContains($value_1);
 
     // Switch browser cookie to anonymous user, then back to user 1.
     $session_cookie_name = $this->getSessionName();
@@ -122,7 +123,7 @@ class SessionTest extends BrowserTestBase {
     $session->setCookie($session_cookie_name, $session_cookie_value);
     // Verify that the session data persists through browser close.
     $this->drupalGet('session-test/get');
-    $this->assertText($value_1);
+    $this->assertSession()->pageTextContains($value_1);
     $this->mink->setDefaultSessionName('default');
 
     // Logout the user and make sure the stored value no longer persists.
@@ -136,20 +137,20 @@ class SessionTest extends BrowserTestBase {
     $value_3 = $this->randomMachineName();
     // Verify that session data is stored for anonymous user.
     $this->drupalGet('session-test/set/' . $value_3);
-    $this->assertText($value_3);
+    $this->assertSession()->pageTextContains($value_3);
     // Verify that session correctly returns the stored data for an anonymous
     // user.
     $this->drupalGet('session-test/get');
-    $this->assertText($value_3);
+    $this->assertSession()->pageTextContains($value_3);
 
     // Try to store data when drupal_save_session(FALSE).
     $value_4 = $this->randomMachineName();
     // Verify that the session value is correctly passed to session-test/no-set.
     $this->drupalGet('session-test/no-set/' . $value_4);
-    $this->assertText($value_4);
+    $this->assertSession()->pageTextContains($value_4);
     // Verify that the session data is not saved for drupal_save_session(FALSE).
     $this->drupalGet('session-test/get');
-    $this->assertText($value_3);
+    $this->assertSession()->pageTextContains($value_3);
 
     // Login, the data should persist.
     $this->drupalLogin($user);
@@ -174,7 +175,7 @@ class SessionTest extends BrowserTestBase {
     $this->drupalLogin($user);
     // Test property added to session object form hook_user_login().
     $this->drupalGet('session-test/get-from-session-object');
-    $this->assertText('foobar');
+    $this->assertSession()->pageTextContains('foobar');
   }
 
   /**
@@ -216,7 +217,7 @@ class SessionTest extends BrowserTestBase {
     $this->assertSessionEmpty(FALSE);
     // Verify that caching was bypassed.
     $this->assertSession()->responseHeaderDoesNotExist('X-Drupal-Cache');
-    $this->assertText('This is a dummy message.');
+    $this->assertSession()->pageTextContains('This is a dummy message.');
     // Verify that session cookie was deleted.
     $this->assertSession()->responseHeaderMatches('Set-Cookie', '/SESS\w+=deleted/');
 
@@ -264,22 +265,22 @@ class SessionTest extends BrowserTestBase {
     sleep(1);
     $this->drupalGet('session-test/set/foo');
     $times2 = $query->execute()->fetchObject();
-    $this->assertEqual($times1->access, $times2->access, 'Users table was not updated.');
+    $this->assertEquals($times1->access, $times2->access, 'Users table was not updated.');
     $this->assertNotEquals($times1->timestamp, $times2->timestamp, 'Sessions table was updated.');
 
     // Write the same value again, i.e. do not modify the session.
     sleep(1);
     $this->drupalGet('session-test/set/foo');
     $times3 = $query->execute()->fetchObject();
-    $this->assertEqual($times1->access, $times3->access, 'Users table was not updated.');
-    $this->assertEqual($times2->timestamp, $times3->timestamp, 'Sessions table was not updated.');
+    $this->assertEquals($times1->access, $times3->access, 'Users table was not updated.');
+    $this->assertEquals($times2->timestamp, $times3->timestamp, 'Sessions table was not updated.');
 
     // Do not change the session.
     sleep(1);
     $this->drupalGet('');
     $times4 = $query->execute()->fetchObject();
-    $this->assertEqual($times3->access, $times4->access, 'Users table was not updated.');
-    $this->assertEqual($times3->timestamp, $times4->timestamp, 'Sessions table was not updated.');
+    $this->assertEquals($times3->access, $times4->access, 'Users table was not updated.');
+    $this->assertEquals($times3->timestamp, $times4->timestamp, 'Sessions table was not updated.');
 
     // Force updating of users and sessions table once per second.
     $settings['settings']['session_write_interval'] = (object) [
