@@ -71,9 +71,11 @@ class DateTimeTest extends BrowserTestBase {
 
     // Confirm date format and time zone.
     $this->drupalGet('node/' . $node1->id());
-    $this->assertText('2007-01-31 21:00:00 -1000', 'Date should be identical, with GMT offset of -10 hours.');
+    // Date should be identical, with GMT offset of -10 hours.
+    $this->assertSession()->pageTextContains('2007-01-31 21:00:00 -1000');
     $this->drupalGet('node/' . $node2->id());
-    $this->assertText('2007-07-31 21:00:00 -1000', 'Date should be identical, with GMT offset of -10 hours.');
+    // Date should be identical, with GMT offset of -10 hours.
+    $this->assertSession()->pageTextContains('2007-07-31 21:00:00 -1000');
 
     // Set time zone to Los Angeles time.
     $config->set('timezone.default', 'America/Los_Angeles')->save();
@@ -81,9 +83,11 @@ class DateTimeTest extends BrowserTestBase {
 
     // Confirm date format and time zone.
     $this->drupalGet('node/' . $node1->id());
-    $this->assertText('2007-01-31 23:00:00 -0800', 'Date should be two hours ahead, with GMT offset of -8 hours.');
+    // Date should be two hours ahead, with GMT offset of -8 hours.
+    $this->assertSession()->pageTextContains('2007-01-31 23:00:00 -0800');
     $this->drupalGet('node/' . $node2->id());
-    $this->assertText('2007-08-01 00:00:00 -0700', 'Date should be three hours ahead, with GMT offset of -7 hours.');
+    // Date should be three hours ahead, with GMT offset of -7 hours.
+    $this->assertSession()->pageTextContains('2007-08-01 00:00:00 -0700');
   }
 
   /**
@@ -103,18 +107,24 @@ class DateTimeTest extends BrowserTestBase {
       'label' => $name,
       'date_format_pattern' => $date_format,
     ];
-    $this->drupalPostForm('admin/config/regional/date-time/formats/add', $edit, t('Add format'));
-    $this->assertUrl(Url::fromRoute('entity.date_format.collection', [], ['absolute' => TRUE])->toString(), [], 'Correct page redirection.');
-    $this->assertText(t('Custom date format added.'), 'Date format added confirmation message appears.');
-    $this->assertText($name, 'Custom date format appears in the date format list.');
-    $this->assertText(t('Delete'), 'Delete link for custom date format appears.');
+    $this->drupalGet('admin/config/regional/date-time/formats/add');
+    $this->submitForm($edit, 'Add format');
+    // Verify that the user is redirected to the correct page.
+    $this->assertSession()->addressEquals(Url::fromRoute('entity.date_format.collection'));
+    // Check that date format added confirmation message appears.
+    $this->assertSession()->pageTextContains('Custom date format added.');
+    // Check that custom date format appears in the date format list.
+    $this->assertSession()->pageTextContains($name);
+    // Check that the delete link for custom date format appears.
+    $this->assertSession()->pageTextContains('Delete');
 
     // Edit the custom date format and re-save without editing the format.
     $this->drupalGet('admin/config/regional/date-time');
     $this->clickLink(t('Edit'));
-    $this->drupalPostForm(NULL, NULL, t('Save format'));
-    $this->assertUrl('admin/config/regional/date-time', ['absolute' => TRUE], 'Correct page redirection.');
-    $this->assertText(t('Custom date format updated.'), 'Custom date format successfully updated.');
+    $this->submitForm([], 'Save format');
+    // Verify that the user is redirected to the correct page.
+    $this->assertSession()->addressEquals(Url::fromRoute('entity.date_format.collection'));
+    $this->assertSession()->pageTextContains('Custom date format updated.');
 
     // Edit custom date format.
     $this->drupalGet('admin/config/regional/date-time');
@@ -122,15 +132,19 @@ class DateTimeTest extends BrowserTestBase {
     $edit = [
       'date_format_pattern' => 'Y m',
     ];
-    $this->drupalPostForm($this->getUrl(), $edit, t('Save format'));
-    $this->assertUrl(Url::fromRoute('entity.date_format.collection', [], ['absolute' => TRUE])->toString(), [], 'Correct page redirection.');
-    $this->assertText(t('Custom date format updated.'), 'Custom date format successfully updated.');
+    $this->drupalGet($this->getUrl());
+    $this->submitForm($edit, 'Save format');
+    // Verify that the user is redirected to the correct page.
+    $this->assertSession()->addressEquals(Url::fromRoute('entity.date_format.collection'));
+    $this->assertSession()->pageTextContains('Custom date format updated.');
 
     // Delete custom date format.
     $this->clickLink(t('Delete'));
-    $this->drupalPostForm('admin/config/regional/date-time/formats/manage/' . $date_format_id . '/delete', [], t('Delete'));
-    $this->assertUrl(Url::fromRoute('entity.date_format.collection', [], ['absolute' => TRUE])->toString(), [], 'Correct page redirection.');
-    $this->assertRaw(t('The date format %format has been deleted.', ['%format' => $name]), 'Custom date format removed.');
+    $this->drupalGet('admin/config/regional/date-time/formats/manage/' . $date_format_id . '/delete');
+    $this->submitForm([], 'Delete');
+    // Verify that the user is redirected to the correct page.
+    $this->assertSession()->addressEquals(Url::fromRoute('entity.date_format.collection'));
+    $this->assertRaw(t('The date format %format has been deleted.', ['%format' => $name]));
 
     // Make sure the date does not exist in config.
     $date_format = DateFormat::load($date_format_id);
@@ -145,11 +159,15 @@ class DateTimeTest extends BrowserTestBase {
       'label' => $name,
       'date_format_pattern' => $date_format,
     ];
-    $this->drupalPostForm('admin/config/regional/date-time/formats/add', $edit, t('Add format'));
-    $this->assertUrl(Url::fromRoute('entity.date_format.collection', [], ['absolute' => TRUE])->toString(), [], 'Correct page redirection.');
-    $this->assertText(t('Custom date format added.'), 'Date format added confirmation message appears.');
-    $this->assertText($name, 'Custom date format appears in the date format list.');
-    $this->assertText(t('Delete'), 'Delete link for custom date format appears.');
+    $this->drupalGet('admin/config/regional/date-time/formats/add');
+    $this->submitForm($edit, 'Add format');
+    // Verify that the user is redirected to the correct page.
+    $this->assertSession()->addressEquals(Url::fromRoute('entity.date_format.collection'));
+    $this->assertSession()->pageTextContains('Custom date format added.');
+    // Check that the custom date format appears in the date format list.
+    $this->assertSession()->pageTextContains($name);
+    // Check that the delete link for custom date format appears.
+    $this->assertSession()->pageTextContains('Delete');
 
     $date_format = DateFormat::create([
       'id' => 'xss_short',
@@ -160,7 +178,7 @@ class DateTimeTest extends BrowserTestBase {
 
     $this->drupalGet(Url::fromRoute('entity.date_format.collection'));
     // Ensure that the date format is properly escaped.
-    $this->assertEscaped("<script>alert('XSS');</script>");
+    $this->assertSession()->assertEscaped("<script>alert('XSS');</script>");
 
     // Add a new date format with HTML in it.
     $date_format_id = strtolower($this->randomMachineName(8));
@@ -171,11 +189,14 @@ class DateTimeTest extends BrowserTestBase {
       'label' => $name,
       'date_format_pattern' => $date_format,
     ];
-    $this->drupalPostForm('admin/config/regional/date-time/formats/add', $edit, t('Add format'));
-    $this->assertUrl(Url::fromRoute('entity.date_format.collection', [], ['absolute' => TRUE])->toString(), [], 'Correct page redirection.');
-    $this->assertText(t('Custom date format added.'), 'Date format added confirmation message appears.');
-    $this->assertText($name, 'Custom date format appears in the date format list.');
-    $this->assertEscaped('<em>' . date("Y") . '</em>');
+    $this->drupalGet('admin/config/regional/date-time/formats/add');
+    $this->submitForm($edit, 'Add format');
+    // Verify that the user is redirected to the correct page.
+    $this->assertSession()->addressEquals(Url::fromRoute('entity.date_format.collection'));
+    $this->assertSession()->pageTextContains('Custom date format added.');
+    // Check that the custom date format appears in the date format list.
+    $this->assertSession()->pageTextContains($name);
+    $this->assertSession()->assertEscaped('<em>' . date("Y") . '</em>');
   }
 
   /**
@@ -194,8 +215,11 @@ class DateTimeTest extends BrowserTestBase {
       'label' => 'dt',
       'field_name' => 'dt',
     ];
-    $this->drupalPostForm('admin/structure/types/manage/page_with_date/fields/add-field', $edit, t('Save and continue'));
-    $this->assertText(t('These settings apply to the'), 'New datetime field created, now configuring');
+    $this->drupalGet('admin/structure/types/manage/page_with_date/fields/add-field');
+    $this->submitForm($edit, 'Save and continue');
+    // Check that the new datetime field was created, and process is now set
+    // to continue for configuration.
+    $this->assertSession()->pageTextContains('These settings apply to the');
 
     $this->drupalGet('admin/structure/types/manage/page_with_date/fields/node.page_with_date.field_dt/storage');
     $edit = [
@@ -203,17 +227,19 @@ class DateTimeTest extends BrowserTestBase {
       'cardinality' => 'number',
       'cardinality_number' => '1',
     ];
-    $this->drupalPostForm('admin/structure/types/manage/page_with_date/fields/node.page_with_date.field_dt/storage', $edit, t('Save field settings'));
+    $this->drupalGet('admin/structure/types/manage/page_with_date/fields/node.page_with_date.field_dt/storage');
+    $this->submitForm($edit, 'Save field settings');
 
     $this->drupalGet('admin/structure/types/manage/page_with_date/fields');
-    $this->assertText('field_dt', 'New field is in place');
+    $this->assertSession()->pageTextContains('field_dt');
 
     $this->drupalGet('admin/structure/types/manage/page_with_date/form-display');
     $edit = [
       'fields[field_dt][type]' => 'datetime_datelist',
       'fields[field_dt][region]' => 'content',
     ];
-    $this->drupalPostForm('admin/structure/types/manage/page_with_date/form-display', $edit, t('Save'));
+    $this->drupalGet('admin/structure/types/manage/page_with_date/form-display');
+    $this->submitForm($edit, 'Save');
     $this->drupalLogout();
 
     // Now log in as a regular editor.
@@ -230,15 +256,17 @@ class DateTimeTest extends BrowserTestBase {
       'field_dt[0][value][hour]' => '1',
       'field_dt[0][value][minute]' => '30',
     ];
-    $this->drupalPostForm('node/add/page_with_date', $edit, t('Save'));
-    $this->assertText(t('Selected combination of day and month is not valid.'), 'Inorrect date failed validation');
+    $this->drupalGet('node/add/page_with_date');
+    $this->submitForm($edit, 'Save');
+    $this->assertSession()->pageTextContains('Selected combination of day and month is not valid.');
 
     $edit['field_dt[0][value][day]'] = '29';
-    $this->drupalPostForm('node/add/page_with_date', $edit, t('Save'));
-    $this->assertNoText(t('Selected combination of day and month is not valid.'), 'Correct date passed validation.');
+    $this->drupalGet('node/add/page_with_date');
+    $this->submitForm($edit, 'Save');
+    $this->assertNoText('Selected combination of day and month is not valid.');
 
     $this->drupalGet('node/1');
-    $this->assertText(t('Mon, 02/29/2016 - 01:30'), 'Node successfully created with valid date.');
+    $this->assertSession()->pageTextContains('Mon, 02/29/2016 - 01:30');
   }
 
 }
