@@ -126,7 +126,7 @@ class ErrorHandlerTest extends BrowserTestBase {
     $this->assertSession()->statusCodeEquals(500);
     // We cannot use assertErrorMessage() since the exact error reported
     // varies from database to database. Check that the SQL string is displayed.
-    $this->assertText($error_pdo_exception['%type']);
+    $this->assertSession()->pageTextContains($error_pdo_exception['%type']);
     // Assert statement improved since static queries adds table alias in the
     // error message.
     $this->assertSession()->pageTextContains($error_pdo_exception['@message']);
@@ -166,9 +166,12 @@ class ErrorHandlerTest extends BrowserTestBase {
 
   /**
    * Asserts that no messages are printed onto the page.
+   *
+   * Ensures that no messages div exists, which proves that no messages were
+   * generated by the error handler, not even an empty one.
    */
   protected function assertNoMessages() {
-    $this->assertEmpty($this->xpath('//div[contains(@class, "messages")]'), 'Ensures that also no messages div exists, which proves that no messages were generated by the error handler, not even an empty one.');
+    $this->assertSession()->elementNotExists('xpath', '//div[contains(@class, "messages")]');
   }
 
 }
