@@ -17,14 +17,14 @@ class ThemeSuggestionsAlterTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['theme_test'];
+  protected static $modules = ['theme_test'];
 
   /**
    * {@inheritdoc}
    */
   protected $defaultTheme = 'stark';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     \Drupal::service('theme_installer')->install(['test_theme']);
   }
@@ -34,7 +34,7 @@ class ThemeSuggestionsAlterTest extends BrowserTestBase {
    */
   public function testTemplateSuggestions() {
     $this->drupalGet('theme-test/suggestion-provided');
-    $this->assertText('Template for testing suggestions provided by the module declaring the theme hook.');
+    $this->assertSession()->pageTextContains('Template for testing suggestions provided by the module declaring the theme hook.');
 
     // Install test_theme, it contains a template suggested by theme_test.module
     // in theme_test_theme_suggestions_theme_test_suggestion_provided().
@@ -43,7 +43,7 @@ class ThemeSuggestionsAlterTest extends BrowserTestBase {
       ->save();
 
     $this->drupalGet('theme-test/suggestion-provided');
-    $this->assertText('Template overridden based on suggestion provided by the module declaring the theme hook.');
+    $this->assertSession()->pageTextContains('Template overridden based on suggestion provided by the module declaring the theme hook.');
   }
 
   /**
@@ -51,21 +51,21 @@ class ThemeSuggestionsAlterTest extends BrowserTestBase {
    */
   public function testGeneralSuggestionsAlter() {
     $this->drupalGet('theme-test/general-suggestion-alter');
-    $this->assertText('Original template for testing hook_theme_suggestions_alter().');
+    $this->assertSession()->pageTextContains('Original template for testing hook_theme_suggestions_alter().');
 
     // Install test_theme and test that themes can alter template suggestions.
     $this->config('system.theme')
       ->set('default', 'test_theme')
       ->save();
     $this->drupalGet('theme-test/general-suggestion-alter');
-    $this->assertText('Template overridden based on new theme suggestion provided by the test_theme theme via hook_theme_suggestions_alter().');
+    $this->assertSession()->pageTextContains('Template overridden based on new theme suggestion provided by the test_theme theme via hook_theme_suggestions_alter().');
 
     // Enable the theme_suggestions_test module to test modules implementing
     // suggestions alter hooks.
     \Drupal::service('module_installer')->install(['theme_suggestions_test']);
     $this->resetAll();
     $this->drupalGet('theme-test/general-suggestion-alter');
-    $this->assertText('Template overridden based on new theme suggestion provided by a module via hook_theme_suggestions_alter().');
+    $this->assertSession()->pageTextContains('Template overridden based on new theme suggestion provided by a module via hook_theme_suggestions_alter().');
   }
 
   /**
@@ -73,21 +73,21 @@ class ThemeSuggestionsAlterTest extends BrowserTestBase {
    */
   public function testTemplateSuggestionsAlter() {
     $this->drupalGet('theme-test/suggestion-alter');
-    $this->assertText('Original template for testing hook_theme_suggestions_HOOK_alter().');
+    $this->assertSession()->pageTextContains('Original template for testing hook_theme_suggestions_HOOK_alter().');
 
     // Install test_theme and test that themes can alter template suggestions.
     $this->config('system.theme')
       ->set('default', 'test_theme')
       ->save();
     $this->drupalGet('theme-test/suggestion-alter');
-    $this->assertText('Template overridden based on new theme suggestion provided by the test_theme theme via hook_theme_suggestions_HOOK_alter().');
+    $this->assertSession()->pageTextContains('Template overridden based on new theme suggestion provided by the test_theme theme via hook_theme_suggestions_HOOK_alter().');
 
     // Enable the theme_suggestions_test module to test modules implementing
     // suggestions alter hooks.
     \Drupal::service('module_installer')->install(['theme_suggestions_test']);
     $this->resetAll();
     $this->drupalGet('theme-test/suggestion-alter');
-    $this->assertText('Template overridden based on new theme suggestion provided by a module via hook_theme_suggestions_HOOK_alter().');
+    $this->assertSession()->pageTextContains('Template overridden based on new theme suggestion provided by a module via hook_theme_suggestions_HOOK_alter().');
   }
 
   /**
@@ -96,7 +96,7 @@ class ThemeSuggestionsAlterTest extends BrowserTestBase {
   public function testSpecificSuggestionsAlter() {
     // Test that the default template is rendered.
     $this->drupalGet('theme-test/specific-suggestion-alter');
-    $this->assertText('Template for testing specific theme calls.');
+    $this->assertSession()->pageTextContains('Template for testing specific theme calls.');
 
     $this->config('system.theme')
       ->set('default', 'test_theme')
@@ -104,57 +104,18 @@ class ThemeSuggestionsAlterTest extends BrowserTestBase {
 
     // Test a specific theme call similar to '#theme' => 'node__article'.
     $this->drupalGet('theme-test/specific-suggestion-alter');
-    $this->assertText('Template matching the specific theme call.');
-    $this->assertText('theme_test_specific_suggestions__variant', 'Specific theme call is added to the suggestions array.');
+    $this->assertSession()->pageTextContains('Template matching the specific theme call.');
+    $this->assertSession()->pageTextContains('theme_test_specific_suggestions__variant');
 
     // Ensure that the base hook is used to determine the suggestion alter hook.
     \Drupal::service('module_installer')->install(['theme_suggestions_test']);
     $this->resetAll();
     $this->drupalGet('theme-test/specific-suggestion-alter');
-    $this->assertText('Template overridden based on suggestion alter hook determined by the base hook.');
+    $this->assertSession()->pageTextContains('Template overridden based on suggestion alter hook determined by the base hook.');
     $raw_content = $this->getSession()->getPage()->getContent();
-    $this->assertTrue(strpos($raw_content, 'theme_test_specific_suggestions__variant') < strpos($raw_content, 'theme_test_specific_suggestions__variant__foo'), 'Specific theme call is added to the suggestions array before the suggestions alter hook.');
-  }
-
-  /**
-   * Tests that theme suggestion alter hooks work for theme functions.
-   */
-  public function testThemeFunctionSuggestionsAlter() {
-    $this->drupalGet('theme-test/function-suggestion-alter');
-    $this->assertText('Original theme function.');
-
-    // Install test_theme and test that themes can alter theme suggestions.
-    $this->config('system.theme')
-      ->set('default', 'test_theme')
-      ->save();
-    $this->drupalGet('theme-test/function-suggestion-alter');
-    $this->assertText('Theme function overridden based on new theme suggestion provided by the test_theme theme.');
-
-    // Enable the theme_suggestions_test module to test modules implementing
-    // suggestions alter hooks.
-    \Drupal::service('module_installer')->install(['theme_suggestions_test']);
-    $this->resetAll();
-    $this->drupalGet('theme-test/function-suggestion-alter');
-    $this->assertText('Theme function overridden based on new theme suggestion provided by a module.');
-  }
-
-  /**
-   * Tests that theme suggestion alter hooks work with theme hook includes.
-   */
-  public function testSuggestionsAlterInclude() {
-    // Check the original theme output.
-    $this->drupalGet('theme-test/suggestion-alter-include');
-    $this->assertText('Original function before altering theme suggestions.');
-
-    // Enable theme_suggestions_test module and make two requests to make sure
-    // the include file is always loaded. The file will always be included for
-    // the first request because the theme registry is being rebuilt.
-    \Drupal::service('module_installer')->install(['theme_suggestions_test']);
-    $this->resetAll();
-    $this->drupalGet('theme-test/suggestion-alter-include');
-    $this->assertText('Function suggested via suggestion alter hook found in include file.', 'Include file loaded for initial request.');
-    $this->drupalGet('theme-test/suggestion-alter-include');
-    $this->assertText('Function suggested via suggestion alter hook found in include file.', 'Include file loaded for second request.');
+    // Verify that a specific theme call is added to the suggestions array
+    // before the suggestions alter hook.
+    $this->assertLessThan(strpos($raw_content, 'theme_test_specific_suggestions__variant__foo'), strpos($raw_content, 'theme_test_specific_suggestions__variant'));
   }
 
   /**
