@@ -21,10 +21,15 @@ class OffCanvasTest extends OffCanvasTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = [
+  protected static $modules = [
     'off_canvas_test',
   ];
 
+  /**
+   * {@inheritdoc}
+   */
+  protected $defaultTheme = 'stark';
+
   /**
    * Tests that non-contextual links will work with the off-canvas dialog.
    *
@@ -87,7 +92,6 @@ class OffCanvasTest extends OffCanvasTestBase {
     $web_assert->linkExists('Off_canvas link!');
     // Click off-canvas link inside off-canvas dialog
     $page->clickLink('Off_canvas link!');
-    /*  @var \Behat\Mink\Element\NodeElement $dialog */
     $this->waitForOffCanvasToOpen();
     $web_assert->elementTextContains('css', '.ui-dialog[aria-describedby="drupal-off-canvas"]', 'Thing 2 says hello');
 
@@ -101,7 +105,6 @@ class OffCanvasTest extends OffCanvasTestBase {
     $web_assert->linkExists('Off_canvas link!');
     // Click off-canvas link inside off-canvas dialog
     $page->clickLink('Off_canvas link!');
-    /*  @var \Behat\Mink\Element\NodeElement $dialog */
     $this->waitForOffCanvasToOpen();
     $web_assert->elementTextContains('css', '.ui-dialog[aria-describedby="drupal-off-canvas"]', 'Thing 2 says hello');
   }
