@@ -8,6 +8,11 @@ use Drupal\migrate\Row;
 /**
  * Gets i18n taxonomy terms from source database.
  *
+ * For available configuration keys, refer to the parent classes:
+ * @see \Drupal\taxonomy\Plugin\migrate\source\d7\Term
+ * @see \Drupal\migrate\Plugin\migrate\source\SqlBase
+ * @see \Drupal\migrate\Plugin\migrate\source\SourcePluginBase
+ *
  * @MigrateSource(
  *   id = "d7_taxonomy_term_translation",
  *   source_module = "i18n_taxonomy"
@@ -35,7 +40,9 @@ class TermTranslation extends Term {
    * {@inheritdoc}
    */
   public function prepareRow(Row $row) {
-    parent::prepareRow($row);
+    if (!parent::prepareRow($row)) {
+      return FALSE;
+    }
     $row->setSourceProperty('language', $row->getSourceProperty('td_language'));
   }
 
