@@ -72,7 +72,7 @@ class TaxonomyTermIndentationTest extends TaxonomyTestBase {
 
     // Check explicitly that term 2's parent is term 1.
     $parents = $taxonomy_storage->loadParents($term2->id());
-    $this->assertEqual(1, key($parents), 'Term 1 is the term 2\'s parent');
+    $this->assertEquals(1, key($parents), 'Term 1 is the term 2\'s parent');
 
     // Move the second term back out to the root level.
     $this->drupalGet('admin/structure/taxonomy/manage/' . $this->vocabulary->get('vid') . '/overview');
