@@ -23,7 +23,7 @@ class TaxonomyLocalTasksTest extends LocalTaskIntegrationTestBase {
    */
   public function testTaxonomyPageLocalTasks($route, $subtask = []) {
     $tasks = [
-      0 => ['entity.taxonomy_term.canonical', 'entity.taxonomy_term.edit_form'],
+      0 => ['entity.taxonomy_term.canonical', 'entity.taxonomy_term.edit_form', 'entity.taxonomy_term.delete_form'],
     ];
     if ($subtask) {
       $tasks[] = $subtask;
