@@ -43,7 +43,10 @@ class TelephoneFieldTest extends BrowserTestBase {
     parent::setUp();
 
     $this->drupalCreateContentType(['type' => 'article']);
-    $this->webUser = $this->drupalCreateUser(['create article content', 'edit own article content']);
+    $this->webUser = $this->drupalCreateUser([
+      'create article content',
+      'edit own article content',
+    ]);
     $this->drupalLogin($this->webUser);
 
     // Add the telephone field to the article content type.
@@ -85,7 +88,7 @@ class TelephoneFieldTest extends BrowserTestBase {
    */
   public function testTelephoneWidget() {
     $this->drupalGet('node/add/article');
-    $this->assertFieldByName("field_telephone[0][value]", '', 'Widget found.');
+    $this->assertSession()->fieldValueEquals("field_telephone[0][value]", '');
     $this->assertRaw('placeholder="123-456-7890"');
   }
 
@@ -103,7 +106,8 @@ class TelephoneFieldTest extends BrowserTestBase {
       'field_telephone[0][value]' => $input,
     ];
 
-    $this->drupalPostForm('node/add/article', $edit, t('Save'));
+    $this->drupalGet('node/add/article');
+    $this->submitForm($edit, 'Save');
     $this->assertRaw('<a href="tel:' . $expected . '">');
   }
 
