@@ -117,7 +117,8 @@ class ToolbarAdminMenuTest extends BrowserTestBase {
     // Uninstall a module.
     $edit = [];
     $edit['uninstall[taxonomy]'] = TRUE;
-    $this->drupalPostForm('admin/modules/uninstall', $edit, 'Uninstall');
+    $this->drupalGet('admin/modules/uninstall');
+    $this->submitForm($edit, 'Uninstall');
     // Confirm the uninstall form.
     $this->submitForm([], 'Uninstall');
     $this->rebuildContainer();
@@ -129,7 +130,8 @@ class ToolbarAdminMenuTest extends BrowserTestBase {
     // Enable a module.
     $edit = [];
     $edit['modules[taxonomy][enable]'] = TRUE;
-    $this->drupalPostForm('admin/modules', $edit, 'Install');
+    $this->drupalGet('admin/modules');
+    $this->submitForm($edit, 'Install');
     $this->rebuildContainer();
 
     // Assert that the subtrees hash has been altered because the subtrees
@@ -147,9 +149,10 @@ class ToolbarAdminMenuTest extends BrowserTestBase {
     // Disable the link.
     $edit = [];
     $edit['enabled'] = FALSE;
-    $this->drupalPostForm("admin/structure/menu/link/" . $admin_menu_link_id . "/edit", $edit, 'Save');
+    $this->drupalGet("admin/structure/menu/link/" . $admin_menu_link_id . "/edit");
+    $this->submitForm($edit, 'Save');
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertText('The menu link has been saved.');
+    $this->assertSession()->pageTextContains('The menu link has been saved.');
 
     // Assert that the subtrees hash has been altered because the subtrees
     // structure changed.
@@ -168,7 +171,8 @@ class ToolbarAdminMenuTest extends BrowserTestBase {
 
     $edit = [];
     $edit[$rid . '[administer taxonomy]'] = FALSE;
-    $this->drupalPostForm('admin/people/permissions', $edit, 'Save permissions');
+    $this->drupalGet('admin/people/permissions');
+    $this->submitForm($edit, 'Save permissions');
 
     // Assert that the subtrees hash has been altered because the subtrees
     // structure changed.
@@ -198,8 +202,9 @@ class ToolbarAdminMenuTest extends BrowserTestBase {
     $rid = $this->drupalCreateRole(['administer content types']);
 
     // Assign the role to the user.
-    $this->drupalPostForm('user/' . $this->adminUser->id() . '/edit', ["roles[$rid]" => $rid], 'Save');
-    $this->assertText('The changes have been saved.');
+    $this->drupalGet('user/' . $this->adminUser->id() . '/edit');
+    $this->submitForm(["roles[{$rid}]" => $rid], 'Save');
+    $this->assertSession()->pageTextContains('The changes have been saved.');
 
     // Assert that the subtrees hash has been altered because the subtrees
     // structure changed.
@@ -217,7 +222,7 @@ class ToolbarAdminMenuTest extends BrowserTestBase {
     // Assert that the old admin menu subtree hash and the new admin menu
     // subtree hash are the same.
     $this->assertNotEmpty($new_subtree_hash, 'A valid hash value for the admin menu subtrees was created.');
-    $this->assertEqual($admin_user_2_hash, $new_subtree_hash, 'The user-specific subtree menu hash has not been updated.');
+    $this->assertEquals($admin_user_2_hash, $new_subtree_hash, 'The user-specific subtree menu hash has not been updated.');
   }
 
   /**
@@ -239,8 +244,9 @@ class ToolbarAdminMenuTest extends BrowserTestBase {
     $admin_user_2_hash = $this->getSubtreesHash();
 
     // Assign the role to the user.
-    $this->drupalPostForm('user/' . $admin_user_id . '/edit', ["roles[$rid]" => $rid], 'Save');
-    $this->assertText('The changes have been saved.');
+    $this->drupalGet('user/' . $admin_user_id . '/edit');
+    $this->submitForm(["roles[{$rid}]" => $rid], 'Save');
+    $this->assertSession()->pageTextContains('The changes have been saved.');
 
     // Log in adminUser and assert that the subtrees hash has changed.
     $this->drupalLogin($this->adminUser);
@@ -253,7 +259,7 @@ class ToolbarAdminMenuTest extends BrowserTestBase {
     // Assert that the old adminUser subtree hash and the new adminUser
     // subtree hash are the same.
     $this->assertNotEmpty($new_subtree_hash, 'A valid hash value for the admin menu subtrees was created.');
-    $this->assertEqual($new_subtree_hash, $admin_user_2_hash, 'The user-specific subtree menu hash has not been updated.');
+    $this->assertEquals($new_subtree_hash, $admin_user_2_hash, 'The user-specific subtree menu hash has not been updated.');
   }
 
   /**
@@ -282,13 +288,14 @@ class ToolbarAdminMenuTest extends BrowserTestBase {
       'label' => $name,
       'direction' => LanguageInterface::DIRECTION_LTR,
     ];
-    $this->drupalPostForm('admin/config/regional/language/add', $edit, 'Add custom language');
+    $this->drupalGet('admin/config/regional/language/add');
+    $this->submitForm($edit, 'Add custom language');
     t($name, [], ['langcode' => $langcode]);
     // Reset locale cache.
     $this->container->get('string_translation')->reset();
     $this->assertRaw('"edit-languages-' . $langcode . '-weight"');
     // Verify that the test language was added.
-    $this->assertText($name);
+    $this->assertSession()->pageTextContains($name);
 
     // Have the adminUser request a page in the new language.
     $this->drupalGet($langcode . '/test-page');
@@ -310,10 +317,11 @@ class ToolbarAdminMenuTest extends BrowserTestBase {
       'langcode' => $langcode,
       'translation' => 'untranslated',
     ];
-    $this->drupalPostForm('admin/config/regional/translate', $search, 'Filter');
+    $this->drupalGet('admin/config/regional/translate');
+    $this->submitForm($search, 'Filter');
     $this->assertNoText('No strings available');
     // Verify that search found the string as untranslated.
-    $this->assertText($name);
+    $this->assertSession()->pageTextContains($name);
 
     // Assume this is the only result.
     // Translate the string to a random string.
@@ -322,8 +330,9 @@ class ToolbarAdminMenuTest extends BrowserTestBase {
     $edit = [
       $lid => $translation,
     ];
-    $this->drupalPostForm('admin/config/regional/translate', $edit, 'Save translations');
-    $this->assertText('The strings have been saved.');
+    $this->drupalGet('admin/config/regional/translate');
+    $this->submitForm($edit, 'Save translations');
+    $this->assertSession()->pageTextContains('The strings have been saved.');
     // Verify that the user is redirected to the correct page.
     $this->assertSession()->addressEquals(Url::fromRoute('locale.translate_page'));
     $this->drupalLogout();
@@ -354,8 +363,8 @@ class ToolbarAdminMenuTest extends BrowserTestBase {
 
     $this->drupalGet('toolbar/subtrees/' . $subtrees_hash, ['query' => [MainContentViewSubscriber::WRAPPER_FORMAT => 'drupal_ajax']], ['X-Requested-With: XMLHttpRequest']);
     $ajax_result = json_decode($this->getSession()->getPage()->getContent(), TRUE);
-    $this->assertEqual('setToolbarSubtrees', $ajax_result[0]['command'], 'Subtrees response uses the correct command.');
-    $this->assertEqual(['system-admin_content', 'system-admin_structure', 'system-themes_page', 'system-modules_list', 'system-admin_config', 'entity-user-collection', 'front'], array_keys($ajax_result[0]['subtrees']), 'Correct subtrees returned.');
+    $this->assertEquals('setToolbarSubtrees', $ajax_result[0]['command'], 'Subtrees response uses the correct command.');
+    $this->assertEquals(['system-admin_content', 'system-admin_structure', 'system-themes_page', 'system-modules_list', 'system-admin_config', 'entity-user-collection', 'front'], array_keys($ajax_result[0]['subtrees']), 'Correct subtrees returned.');
   }
 
   /**
@@ -402,15 +411,16 @@ class ToolbarAdminMenuTest extends BrowserTestBase {
       'menu_parent' => 'admin:system.admin',
       'description[0][value]' => 'External URL & escaped',
     ];
-    $this->drupalPostForm('admin/structure/menu/manage/admin/add', $edit, 'Save');
+    $this->drupalGet('admin/structure/menu/manage/admin/add');
+    $this->submitForm($edit, 'Save');
 
     // Assert that the new menu link is shown on the menu link listing.
     $this->drupalGet('admin/structure/menu/manage/admin');
-    $this->assertText('External URL');
+    $this->assertSession()->pageTextContains('External URL');
 
     // Assert that the new menu link is shown in the toolbar on a regular page.
     $this->drupalGet(Url::fromRoute('<front>'));
-    $this->assertText('External URL');
+    $this->assertSession()->pageTextContains('External URL');
     // Ensure the description is escaped as expected.
     $this->assertRaw('title="External URL &amp; escaped"');
   }
