@@ -2,7 +2,6 @@
 
 namespace Drupal\Tests\tracker\Functional;
 
-use Drupal\Component\Render\FormattableMarkup;
 use Drupal\comment\CommentInterface;
 use Drupal\comment\Tests\CommentTestTrait;
 use Drupal\Core\Cache\Cache;
@@ -89,9 +88,9 @@ class TrackerTest extends BrowserTestBase {
     ]);
 
     $this->drupalGet('activity');
-    $this->assertNoText($unpublished->label(), 'Unpublished node does not show up in the tracker listing.');
-    $this->assertText($published->label(), 'Published node shows up in the tracker listing.');
-    $this->assertSession()->linkExists(t('My recent content'), 0, 'User tab shows up on the global tracker page.');
+    $this->assertNoText($unpublished->label());
+    $this->assertSession()->pageTextContains($published->label());
+    $this->assertSession()->linkExists('My recent content', 0, 'User tab shows up on the global tracker page.');
 
     // Assert cache contexts, specifically the pager and node access contexts.
     $this->assertCacheContexts(['languages:language_interface', 'route', 'theme', 'url.query_args:' . MainContentViewSubscriber::WRAPPER_FORMAT, 'url.query_args.pagers:0', 'user.node_grants:view', 'user']);
@@ -122,7 +121,7 @@ class TrackerTest extends BrowserTestBase {
     // Delete a node and ensure it no longer appears on the tracker.
     $published->delete();
     $this->drupalGet('activity');
-    $this->assertNoText($published->label(), 'Deleted node does not show up in the tracker listing.');
+    $this->assertNoText($published->label());
 
     // Test proper display of time on activity page when comments are disabled.
     // Disable comments.
@@ -136,8 +135,8 @@ class TrackerTest extends BrowserTestBase {
     ]);
 
     $this->drupalGet('activity');
-    $this->assertText($node->label(), 'Published node shows up in the tracker listing.');
-    $this->assertText(\Drupal::service('date.formatter')->formatTimeDiffSince($node->getChangedTime()), 'The changed time was displayed on the tracker listing.');
+    $this->assertSession()->pageTextContains($node->label());
+    $this->assertSession()->pageTextContains(\Drupal::service('date.formatter')->formatTimeDiffSince($node->getChangedTime()));
   }
 
   /**
@@ -170,13 +169,14 @@ class TrackerTest extends BrowserTestBase {
       'subject[0][value]' => $this->randomMachineName(),
       'comment_body[0][value]' => $this->randomMachineName(20),
     ];
-    $this->drupalPostForm('comment/reply/node/' . $other_published_my_comment->id() . '/comment', $comment, t('Save'));
+    $this->drupalGet('comment/reply/node/' . $other_published_my_comment->id() . '/comment');
+    $this->submitForm($comment, 'Save');
 
     $this->drupalGet('user/' . $this->user->id() . '/activity');
-    $this->assertNoText($unpublished->label(), "Unpublished nodes do not show up in the user's tracker listing.");
-    $this->assertText($my_published->label(), "Published nodes show up in the user's tracker listing.");
-    $this->assertNoText($other_published_no_comment->label(), "Another user's nodes do not show up in the user's tracker listing.");
-    $this->assertText($other_published_my_comment->label(), "Nodes that the user has commented on appear in the user's tracker listing.");
+    $this->assertNoText($unpublished->label());
+    $this->assertSession()->pageTextContains($my_published->label());
+    $this->assertNoText($other_published_no_comment->label());
+    $this->assertSession()->pageTextContains($other_published_my_comment->label());
 
     // Assert cache contexts.
     $this->assertCacheContexts(['languages:language_interface', 'route', 'theme', 'url.query_args:' . MainContentViewSubscriber::WRAPPER_FORMAT, 'url.query_args.pagers:0', 'user', 'user.node_grants:view']);
@@ -211,8 +211,8 @@ class TrackerTest extends BrowserTestBase {
     $this->assertSession()->linkExists($my_published->label());
     $this->assertSession()->linkNotExists($unpublished->label());
     // Verify that title and tab title have been set correctly.
-    $this->assertText('Activity', 'The user activity tab has the name "Activity".');
-    $this->assertTitle($this->user->getAccountName() . ' | Drupal');
+    $this->assertSession()->pageTextContains('Activity');
+    $this->assertSession()->titleEquals($this->user->getAccountName() . ' | Drupal');
 
     // Verify that unpublished comments are removed from the tracker.
     $admin_user = $this->drupalCreateUser([
@@ -221,21 +221,22 @@ class TrackerTest extends BrowserTestBase {
       'access user profiles',
     ]);
     $this->drupalLogin($admin_user);
-    $this->drupalPostForm('comment/1/edit', ['status' => CommentInterface::NOT_PUBLISHED], t('Save'));
+    $this->drupalGet('comment/1/edit');
+    $this->submitForm(['status' => CommentInterface::NOT_PUBLISHED], 'Save');
     $this->drupalGet('user/' . $this->user->id() . '/activity');
-    $this->assertNoText($other_published_my_comment->label(), 'Unpublished comments are not counted on the tracker listing.');
+    $this->assertNoText($other_published_my_comment->label());
 
     // Test escaping of title on user's tracker tab.
     \Drupal::service('module_installer')->install(['user_hooks_test']);
     Cache::invalidateTags(['rendered']);
     \Drupal::state()->set('user_hooks_test_user_format_name_alter', TRUE);
     $this->drupalGet('user/' . $this->user->id() . '/activity');
-    $this->assertEscaped('<em>' . $this->user->id() . '</em>');
+    $this->assertSession()->assertEscaped('<em>' . $this->user->id() . '</em>');
 
     \Drupal::state()->set('user_hooks_test_user_format_name_alter_safe', TRUE);
     Cache::invalidateTags(['rendered']);
     $this->drupalGet('user/' . $this->user->id() . '/activity');
-    $this->assertNoEscaped('<em>' . $this->user->id() . '</em>');
+    $this->assertSession()->assertNoEscaped('<em>' . $this->user->id() . '</em>');
     $this->assertRaw('<em>' . $this->user->id() . '</em>');
   }
 
@@ -267,7 +268,8 @@ class TrackerTest extends BrowserTestBase {
       'comment_body[0][value]' => $this->randomMachineName(20),
     ];
     sleep(1);
-    $this->drupalPostForm('comment/reply/node/' . $node->id() . '/comment', $comment, t('Save'));
+    $this->drupalGet('comment/reply/node/' . $node->id() . '/comment');
+    $this->submitForm($comment, 'Save');
     // Reload the node so that comment.module's hook_node_load()
     // implementation can set $node->last_comment_timestamp for the freshly
     // posted comment.
@@ -312,7 +314,8 @@ class TrackerTest extends BrowserTestBase {
       'subject[0][value]' => $this->randomMachineName(),
       'comment_body[0][value]' => $this->randomMachineName(20),
     ];
-    $this->drupalPostForm('comment/reply/node/' . $node_one->id() . '/comment', $comment, t('Save'));
+    $this->drupalGet('comment/reply/node/' . $node_one->id() . '/comment');
+    $this->submitForm($comment, 'Save');
 
     // If the comment is posted in the same second as the last one then Drupal
     // can't tell the difference, so we wait one second here.
@@ -323,7 +326,8 @@ class TrackerTest extends BrowserTestBase {
       'subject[0][value]' => $this->randomMachineName(),
       'comment_body[0][value]' => $this->randomMachineName(20),
     ];
-    $this->drupalPostForm('comment/reply/node/' . $node_two->id() . '/comment', $comment, t('Save'));
+    $this->drupalGet('comment/reply/node/' . $node_two->id() . '/comment');
+    $this->submitForm($comment, 'Save');
 
     // We should at this point have in our tracker for otherUser:
     // 1. node_two
@@ -343,7 +347,8 @@ class TrackerTest extends BrowserTestBase {
       'subject[0][value]' => $this->randomMachineName(),
       'comment_body[0][value]' => $this->randomMachineName(20),
     ];
-    $this->drupalPostForm('comment/reply/node/' . $node_one->id() . '/comment', $comment, t('Save'));
+    $this->drupalGet('comment/reply/node/' . $node_one->id() . '/comment');
+    $this->submitForm($comment, 'Save');
 
     // Switch back to the otherUser and assert that the order has swapped.
     $this->drupalLogin($this->otherUser);
@@ -355,7 +360,7 @@ class TrackerTest extends BrowserTestBase {
     $this->verbose($pattern);
     // Verify that the most recent comment on node appears at the top of
     // tracker.
-    $this->assertPattern($pattern);
+    $this->assertSession()->responseMatches($pattern);
   }
 
   /**
@@ -380,7 +385,8 @@ class TrackerTest extends BrowserTestBase {
       'subject[0][value]' => $this->randomMachineName(),
       'comment_body[0][value]' => $this->randomMachineName(20),
     ];
-    $this->drupalPostForm('comment/reply/node/' . $nodes[3]->id() . '/comment', $comment, t('Save'));
+    $this->drupalGet('comment/reply/node/' . $nodes[3]->id() . '/comment');
+    $this->submitForm($comment, 'Save');
 
     // Create an unpublished node.
     $unpublished = $this->drupalCreateNode([
@@ -406,7 +412,7 @@ class TrackerTest extends BrowserTestBase {
 
     // Assert that all node titles are displayed.
     foreach ($nodes as $i => $node) {
-      $this->assertText($node->label(), new FormattableMarkup('Node @i is displayed on the tracker listing pages.', ['@i' => $i]));
+      $this->assertSession()->pageTextContains($node->label());
     }
 
     // Fetch the site-wide tracker.
@@ -414,7 +420,7 @@ class TrackerTest extends BrowserTestBase {
 
     // Assert that all node titles are displayed.
     foreach ($nodes as $i => $node) {
-      $this->assertText($node->label(), new FormattableMarkup('Node @i is displayed on the tracker listing pages.', ['@i' => $i]));
+      $this->assertSession()->pageTextContains($node->label());
     }
   }
 
@@ -423,7 +429,6 @@ class TrackerTest extends BrowserTestBase {
    */
   public function testTrackerAdminUnpublish() {
     \Drupal::service('module_installer')->install(['views']);
-    \Drupal::service('router.builder')->rebuild();
     $admin_user = $this->drupalCreateUser([
       'access content overview',
       'administer nodes',
@@ -437,17 +442,18 @@ class TrackerTest extends BrowserTestBase {
 
     // Assert that the node is displayed.
     $this->drupalGet('activity');
-    $this->assertText($node->label(), 'A node is displayed on the tracker listing pages.');
+    $this->assertSession()->pageTextContains($node->label());
 
     // Unpublish the node and ensure that it's no longer displayed.
     $edit = [
       'action' => 'node_unpublish_action',
       'node_bulk_form[0]' => $node->id(),
     ];
-    $this->drupalPostForm('admin/content', $edit, t('Apply to selected items'));
+    $this->drupalGet('admin/content');
+    $this->submitForm($edit, 'Apply to selected items');
 
     $this->drupalGet('activity');
-    $this->assertText(t('No content available.'), 'A node is displayed on the tracker listing pages.');
+    $this->assertSession()->pageTextContains('No content available.');
   }
 
   /**
@@ -472,7 +478,7 @@ class TrackerTest extends BrowserTestBase {
    */
   public function assertHistoryMetadata($node_id, $node_timestamp, $node_last_comment_timestamp, $library_is_present = TRUE) {
     $settings = $this->getDrupalSettings();
-    $this->assertIdentical($library_is_present, isset($settings['ajaxPageState']) && in_array('tracker/history', explode(',', $settings['ajaxPageState']['libraries'])), 'drupal.tracker-history library is present.');
+    $this->assertSame($library_is_present, isset($settings['ajaxPageState']) && in_array('tracker/history', explode(',', $settings['ajaxPageState']['libraries'])), 'drupal.tracker-history library is present.');
     $this->assertCount(1, $this->xpath('//table/tbody/tr/td[@data-history-node-id="' . $node_id . '" and @data-history-node-timestamp="' . $node_timestamp . '"]'), 'Tracker table cell contains the data-history-node-id and data-history-node-timestamp attributes for the node.');
     $this->assertCount(1, $this->xpath('//table/tbody/tr/td[@data-history-node-last-comment-timestamp="' . $node_last_comment_timestamp . '"]'), 'Tracker table cell contains the data-history-node-last-comment-timestamp attribute for the node.');
   }
