@@ -28,7 +28,8 @@ class UserEditTest extends BrowserTestBase {
 
     // Test that error message appears when attempting to use a non-unique user name.
     $edit['name'] = $user2->getAccountName();
-    $this->drupalPostForm("user/" . $user1->id() . "/edit", $edit, t('Save'));
+    $this->drupalGet("user/" . $user1->id() . "/edit");
+    $this->submitForm($edit, 'Save');
     $this->assertRaw(t('The username %name is already taken.', ['%name' => $edit['name']]));
 
     // Check that the default value in user name field
@@ -37,7 +38,7 @@ class UserEditTest extends BrowserTestBase {
     \Drupal::service('module_installer')->install(['user_hooks_test']);
     Cache::invalidateTags(['rendered']);
     $this->drupalGet('user/' . $user1->id() . '/edit');
-    $this->assertFieldByName('name', $user1->getAccountName());
+    $this->assertSession()->fieldValueEquals('name', $user1->getAccountName());
 
     // Ensure the formatted name is displayed when expected.
     $this->drupalGet('user/' . $user1->id());
@@ -48,39 +49,45 @@ class UserEditTest extends BrowserTestBase {
     $edit = [];
     $edit['pass[pass1]'] = '';
     $edit['pass[pass2]'] = $this->randomMachineName();
-    $this->drupalPostForm("user/" . $user1->id() . "/edit", $edit, t('Save'));
-    $this->assertText(t("The specified passwords do not match."), 'Typing mismatched passwords displays an error message.');
+    $this->drupalGet("user/" . $user1->id() . "/edit");
+    $this->submitForm($edit, 'Save');
+    $this->assertSession()->pageTextContains("The specified passwords do not match.");
 
     $edit['pass[pass1]'] = $this->randomMachineName();
     $edit['pass[pass2]'] = '';
-    $this->drupalPostForm("user/" . $user1->id() . "/edit", $edit, t('Save'));
-    $this->assertText(t("The specified passwords do not match."), 'Typing mismatched passwords displays an error message.');
+    $this->drupalGet("user/" . $user1->id() . "/edit");
+    $this->submitForm($edit, 'Save');
+    $this->assertSession()->pageTextContains("The specified passwords do not match.");
 
     // Test that the error message appears when attempting to change the mail or
     // pass without the current password.
     $edit = [];
     $edit['mail'] = $this->randomMachineName() . '@new.example.com';
-    $this->drupalPostForm("user/" . $user1->id() . "/edit", $edit, t('Save'));
+    $this->drupalGet("user/" . $user1->id() . "/edit");
+    $this->submitForm($edit, 'Save');
     $this->assertRaw(t("Your current password is missing or incorrect; it's required to change the %name.", ['%name' => t('Email')]));
 
     $edit['current_pass'] = $user1->passRaw;
-    $this->drupalPostForm("user/" . $user1->id() . "/edit", $edit, t('Save'));
+    $this->drupalGet("user/" . $user1->id() . "/edit");
+    $this->submitForm($edit, 'Save');
     $this->assertRaw(t("The changes have been saved."));
 
     // Test that the user must enter current password before changing passwords.
     $edit = [];
     $edit['pass[pass1]'] = $new_pass = $this->randomMachineName();
     $edit['pass[pass2]'] = $new_pass;
-    $this->drupalPostForm("user/" . $user1->id() . "/edit", $edit, t('Save'));
+    $this->drupalGet("user/" . $user1->id() . "/edit");
+    $this->submitForm($edit, 'Save');
     $this->assertRaw(t("Your current password is missing or incorrect; it's required to change the %name.", ['%name' => t('Password')]));
 
     // Try again with the current password.
     $edit['current_pass'] = $user1->passRaw;
-    $this->drupalPostForm("user/" . $user1->id() . "/edit", $edit, t('Save'));
+    $this->drupalGet("user/" . $user1->id() . "/edit");
+    $this->submitForm($edit, 'Save');
     $this->assertRaw(t("The changes have been saved."));
 
     // Make sure the changed timestamp is updated.
-    $this->assertEqual($user1->getChangedTime(), REQUEST_TIME, 'Changing a user sets "changed" timestamp.');
+    $this->assertEquals(REQUEST_TIME, $user1->getChangedTime(), 'Changing a user sets "changed" timestamp.');
 
     // Make sure the user can log in with their new password.
     $this->drupalLogout();
@@ -93,12 +100,14 @@ class UserEditTest extends BrowserTestBase {
     $this->drupalLogin($user1);
 
     $config->set('password_strength', TRUE)->save();
-    $this->drupalPostForm("user/" . $user1->id() . "/edit", $edit, t('Save'));
-    $this->assertRaw(t('Password strength:'), 'The password strength indicator is displayed.');
+    $this->drupalGet("user/" . $user1->id() . "/edit");
+    $this->submitForm($edit, 'Save');
+    $this->assertRaw(t('Password strength:'));
 
     $config->set('password_strength', FALSE)->save();
-    $this->drupalPostForm("user/" . $user1->id() . "/edit", $edit, t('Save'));
-    $this->assertNoRaw(t('Password strength:'), 'The password strength indicator is not displayed.');
+    $this->drupalGet("user/" . $user1->id() . "/edit");
+    $this->submitForm($edit, 'Save');
+    $this->assertNoRaw(t('Password strength:'));
 
     // Check that the user status field has the correct value and that it is
     // properly displayed.
@@ -106,20 +115,22 @@ class UserEditTest extends BrowserTestBase {
     $this->drupalLogin($admin_user);
 
     $this->drupalGet('user/' . $user1->id() . '/edit');
-    $this->assertNoFieldChecked('edit-status-0');
-    $this->assertFieldChecked('edit-status-1');
+    $this->assertSession()->checkboxNotChecked('edit-status-0');
+    $this->assertSession()->checkboxChecked('edit-status-1');
 
     $edit = ['status' => 0];
-    $this->drupalPostForm('user/' . $user1->id() . '/edit', $edit, t('Save'));
-    $this->assertText(t('The changes have been saved.'));
-    $this->assertFieldChecked('edit-status-0');
-    $this->assertNoFieldChecked('edit-status-1');
+    $this->drupalGet('user/' . $user1->id() . '/edit');
+    $this->submitForm($edit, 'Save');
+    $this->assertSession()->pageTextContains('The changes have been saved.');
+    $this->assertSession()->checkboxChecked('edit-status-0');
+    $this->assertSession()->checkboxNotChecked('edit-status-1');
 
     $edit = ['status' => 1];
-    $this->drupalPostForm('user/' . $user1->id() . '/edit', $edit, t('Save'));
-    $this->assertText(t('The changes have been saved.'));
-    $this->assertNoFieldChecked('edit-status-0');
-    $this->assertFieldChecked('edit-status-1');
+    $this->drupalGet('user/' . $user1->id() . '/edit');
+    $this->submitForm($edit, 'Save');
+    $this->assertSession()->pageTextContains('The changes have been saved.');
+    $this->assertSession()->checkboxNotChecked('edit-status-0');
+    $this->assertSession()->checkboxChecked('edit-status-1');
   }
 
   /**
@@ -136,7 +147,8 @@ class UserEditTest extends BrowserTestBase {
     $user1 = $this->drupalCreateUser([]);
 
     $edit = ['pass[pass1]' => '0', 'pass[pass2]' => '0'];
-    $this->drupalPostForm("user/" . $user1->id() . "/edit", $edit, t('Save'));
+    $this->drupalGet("user/" . $user1->id() . "/edit");
+    $this->submitForm($edit, 'Save');
     $this->assertRaw(t("The changes have been saved."));
   }
 
@@ -152,7 +164,8 @@ class UserEditTest extends BrowserTestBase {
     // This user has no email address.
     $user1->mail = '';
     $user1->save();
-    $this->drupalPostForm("user/" . $user1->id() . "/edit", ['mail' => ''], t('Save'));
+    $this->drupalGet("user/" . $user1->id() . "/edit");
+    $this->submitForm(['mail' => ''], 'Save');
     $this->assertRaw(t("The changes have been saved."));
   }
 
@@ -174,4 +187,57 @@ class UserEditTest extends BrowserTestBase {
     $this->assertSession()->statusCodeEquals(403);
   }
 
+  /**
+   * Tests that a user is able to change site language.
+   */
+  public function testUserChangeSiteLanguage() {
+    // Install these modules here as these aren't needed for other test methods.
+    \Drupal::service('module_installer')->install([
+      'content_translation',
+      'language',
+    ]);
+    // Create and login as an admin user to add a new language and enable
+    // translation for user accounts.
+    $adminUser = $this->drupalCreateUser([
+      'administer account settings',
+      'administer languages',
+      'administer content translation',
+      'administer users',
+      'translate any entity',
+    ]);
+    $this->drupalLogin($adminUser);
+
+    // Add a new language into the system.
+    $edit = [
+      'predefined_langcode' => 'fr',
+    ];
+    $this->drupalGet('admin/config/regional/language/add');
+    $this->submitForm($edit, 'Add language');
+    $this->assertSession()->pageTextContains('French');
+
+    // Enable translation for user accounts.
+    $edit = [
+      'language[content_translation]' => 1,
+    ];
+    $this->drupalGet('admin/config/people/accounts');
+    $this->submitForm($edit, 'Save configuration');
+    $this->assertSession()->pageTextContains('The configuration options have been saved.');
+
+    // Create a regular user for whom translation will be enabled.
+    $webUser = $this->drupalCreateUser();
+
+    // Create a translation for a regular user account.
+    $this->drupalGet('user/' . $webUser->id() . '/translations/add/en/fr');
+    $this->submitForm([], 'Save');
+    $this->assertSession()->pageTextContains('The changes have been saved.');
+
+    // Update the site language of the user account.
+    $edit = [
+      'preferred_langcode' => 'fr',
+    ];
+    $this->drupalGet('user/' . $webUser->id() . '/edit');
+    $this->submitForm($edit, 'Save');
+    $this->assertSession()->statusCodeEquals(200);
+  }
+
 }
