@@ -48,7 +48,8 @@ class UserLanguageTest extends BrowserTestBase {
       'label' => $name,
       'direction' => LanguageInterface::DIRECTION_LTR,
     ];
-    $this->drupalPostForm('admin/config/regional/language/add', $edit, 'Add custom language');
+    $this->drupalGet('admin/config/regional/language/add');
+    $this->submitForm($edit, 'Add custom language');
     $this->drupalLogout();
 
     // Log in as normal user and edit account settings.
@@ -56,16 +57,17 @@ class UserLanguageTest extends BrowserTestBase {
     $path = 'user/' . $web_user->id() . '/edit';
     $this->drupalGet($path);
     // Ensure language settings widget is available.
-    $this->assertText('Language');
+    $this->assertSession()->pageTextContains('Language');
     // Ensure custom language is present.
-    $this->assertText($name);
+    $this->assertSession()->pageTextContains($name);
     // Switch to our custom language.
     $edit = [
       'preferred_langcode' => $langcode,
     ];
-    $this->drupalPostForm($path, $edit, 'Save');
+    $this->drupalGet($path);
+    $this->submitForm($edit, 'Save');
     // Ensure form was submitted successfully.
-    $this->assertText('The changes have been saved.');
+    $this->assertSession()->pageTextContains('The changes have been saved.');
     // Check if language was changed.
     $this->assertTrue($this->assertSession()->optionExists('edit-preferred-langcode', $langcode)->isSelected());
 
