@@ -171,7 +171,8 @@ class UserLoginTest extends BrowserTestBase {
       'name' => $account->getAccountName(),
       'pass' => $account->passRaw,
     ];
-    $this->drupalPostForm('user/login', $edit, 'Log in');
+    $this->drupalGet('user/login');
+    $this->submitForm($edit, 'Log in');
     if (isset($flood_trigger)) {
       $this->assertSession()->statusCodeEquals(403);
       $this->assertSession()->fieldNotExists('pass');
@@ -195,7 +196,7 @@ class UserLoginTest extends BrowserTestBase {
     else {
       $this->assertSession()->statusCodeEquals(200);
       $this->assertSession()->fieldValueEquals('pass', '');
-      $this->assertText('Unrecognized username or password. Forgot your password?');
+      $this->assertSession()->pageTextContains('Unrecognized username or password. Forgot your password?');
     }
   }
 
