@@ -33,7 +33,7 @@ class HandlerFilterRolesTest extends UserKernelTestBase {
     $expected = [
       'module' => ['user'],
     ];
-    $this->assertEqual($expected, $view->getDependencies());
+    $this->assertEquals($expected, $view->getDependencies());
 
     $display = &$view->getDisplay('default');
     $display['display_options']['filters']['roles_target_id'] = [
@@ -45,7 +45,7 @@ class HandlerFilterRolesTest extends UserKernelTestBase {
     ];
     $view->save();
     $expected['config'][] = 'user.role.test_user_role';
-    $this->assertEqual($expected, $view->getDependencies());
+    $this->assertEquals($expected, $view->getDependencies());
 
     $view = View::load('test_user_name');
     $display = &$view->getDisplay('default');
@@ -61,7 +61,7 @@ class HandlerFilterRolesTest extends UserKernelTestBase {
     ];
     $view->save();
     unset($expected['config']);
-    $this->assertEqual($expected, $view->getDependencies());
+    $this->assertEquals($expected, $view->getDependencies());
 
     $view = View::load('test_user_name');
     $display = &$view->getDisplay('default');
@@ -76,12 +76,12 @@ class HandlerFilterRolesTest extends UserKernelTestBase {
       'plugin_id' => 'user_roles',
     ];
     $view->save();
-    $this->assertEqual($expected, $view->getDependencies());
+    $this->assertEquals($expected, $view->getDependencies());
 
     $view = Views::getView('test_user_name');
     $view->initDisplay();
     $view->initHandlers();
-    $this->assertEqual(array_keys($view->filter['roles_target_id']->getValueOptions()), ['test_user_role']);
+    $this->assertEquals(['test_user_role'], array_keys($view->filter['roles_target_id']->getValueOptions()));
 
     $view = View::load('test_user_name');
     $display = &$view->getDisplay('default');
@@ -93,7 +93,7 @@ class HandlerFilterRolesTest extends UserKernelTestBase {
       'plugin_id' => 'user_roles',
     ];
     $view->save();
-    $this->assertEqual($expected, $view->getDependencies());
+    $this->assertEquals($expected, $view->getDependencies());
   }
 
   /**
