@@ -3,7 +3,7 @@
  * Handles AJAX fetching of views, including filter submission and response.
  */
 
-(function($, Drupal, drupalSettings) {
+(function ($, Drupal, drupalSettings) {
   /**
    * Attaches the AJAX behavior to exposed filters forms and key View links.
    *
@@ -13,12 +13,12 @@
    *   Attaches ajaxView functionality to relevant elements.
    */
   Drupal.behaviors.ViewsAjaxView = {};
-  Drupal.behaviors.ViewsAjaxView.attach = function(context, settings) {
+  Drupal.behaviors.ViewsAjaxView.attach = function (context, settings) {
     if (settings && settings.views && settings.views.ajaxViews) {
       const {
         views: { ajaxViews },
       } = settings;
-      Object.keys(ajaxViews || {}).forEach(i => {
+      Object.keys(ajaxViews || {}).forEach((i) => {
         Drupal.views.instances[i] = new Drupal.views.ajaxView(ajaxViews[i]);
       });
     }
@@ -29,7 +29,7 @@
         const {
           views: { ajaxViews },
         } = settings;
-        Object.keys(ajaxViews || {}).forEach(i => {
+        Object.keys(ajaxViews || {}).forEach((i) => {
           const selector = `.js-view-dom-id-${ajaxViews[i].view_dom_id}`;
           if ($(selector, context).length) {
             delete Drupal.views.instances[i];
@@ -51,7 +51,7 @@
   Drupal.views.instances = {};
 
   /**
-   * Javascript object for a certain view.
+   * JavaScript object for a certain view.
    *
    * @constructor
    *
@@ -60,7 +60,7 @@
    * @param {string} settings.view_dom_id
    *   The DOM id of the view.
    */
-  Drupal.views.ajaxView = function(settings) {
+  Drupal.views.ajaxView = function (settings) {
     const selector = `.js-view-dom-id-${settings.view_dom_id}`;
     this.$view = $(selector);
 
@@ -134,14 +134,14 @@
   /**
    * @method
    */
-  Drupal.views.ajaxView.prototype.attachExposedFormAjax = function() {
+  Drupal.views.ajaxView.prototype.attachExposedFormAjax = function () {
     const that = this;
     this.exposedFormAjax = [];
     // Exclude the reset buttons so no AJAX behaviors are bound. Many things
     // break during the form reset phase if using AJAX.
     $('input[type=submit], input[type=image]', this.$exposed_form)
       .not('[data-drupal-selector=edit-reset]')
-      .each(function(index) {
+      .each(function (index) {
         const selfSettings = $.extend({}, that.element_settings, {
           base: $(this).attr('id'),
           element: this,
@@ -154,7 +154,7 @@
    * @return {bool}
    *   If there is at least one parent with a view class return false.
    */
-  Drupal.views.ajaxView.prototype.filterNestedViews = function() {
+  Drupal.views.ajaxView.prototype.filterNestedViews = function () {
     // If there is at least one parent with a view class, this view
     // is nested (e.g., an attachment). Bail.
     return !this.$view.parents('.view').length;
@@ -163,7 +163,7 @@
   /**
    * Attach the ajax behavior to each link.
    */
-  Drupal.views.ajaxView.prototype.attachPagerAjax = function() {
+  Drupal.views.ajaxView.prototype.attachPagerAjax = function () {
     this.$view
       .find(
         'ul.js-pager__items > li > a, th.views-field a, .attachment .views-summary a',
@@ -179,7 +179,7 @@
    * @param {HTMLElement} link
    *   The link element.
    */
-  Drupal.views.ajaxView.prototype.attachPagerLinkAjax = function(id, link) {
+  Drupal.views.ajaxView.prototype.attachPagerLinkAjax = function (id, link) {
     const $link = $(link);
     const viewData = {};
     const href = $link.attr('href');
@@ -211,7 +211,7 @@
    * @param {string} response.selector
    *   Selector to use.
    */
-  Drupal.AjaxCommands.prototype.viewsScrollTop = function(ajax, response) {
+  Drupal.AjaxCommands.prototype.viewsScrollTop = function (ajax, response) {
     // Scroll to the top of the view. This will allow users
     // to browse newly loaded content after e.g. clicking a pager
     // link.
