@@ -3,7 +3,7 @@
 namespace Drupal\views\Tests;
 
 use Drupal\Core\Cache\Cache;
-use Drupal\system\Tests\Cache\AssertPageCacheContextsAndTagsTrait;
+use Drupal\Tests\system\Functional\Cache\AssertPageCacheContextsAndTagsTrait;
 use Drupal\views\Plugin\views\display\DisplayPluginBase;
 use Drupal\views\ViewExecutable;
 use Symfony\Component\HttpFoundation\Request;
@@ -50,14 +50,12 @@ trait AssertViewsCacheTagsTrait {
     $request_stack->push($request);
     $renderer->renderRoot($build);
 
-    // Render array cache tags.
-    $this->pass('Checking render array cache tags.');
+    // Check render array cache tags.
     sort($expected_render_array_cache_tags);
-    $this->assertEqual($build['#cache']['tags'], $expected_render_array_cache_tags);
-    $this->debugCacheTags($build['#cache']['tags'], $expected_render_array_cache_tags);
+    $this->assertEquals($expected_render_array_cache_tags, $build['#cache']['tags']);
 
     if ($views_caching_is_enabled) {
-      $this->pass('Checking Views results cache item cache tags.');
+      // Check Views render cache item cache tags.
       /** @var \Drupal\views\Plugin\views\cache\CachePluginBase $cache_plugin */
       $cache_plugin = $view->display_handler->getPlugin('cache');
 
@@ -67,32 +65,29 @@ trait AssertViewsCacheTagsTrait {
       $view->build();
       $results_cache_item = \Drupal::cache('data')->get($cache_plugin->generateResultsKey());
       if (is_array($expected_results_cache)) {
-        $this->assertTrue($results_cache_item, 'Results cache item found.');
+        $this->assertNotEmpty($results_cache_item, 'Results cache item found.');
         if ($results_cache_item) {
           sort($expected_results_cache);
-          $this->assertEqual($results_cache_item->tags, $expected_results_cache);
-          $this->debugCacheTags($results_cache_item->tags, $expected_results_cache);
+          $this->assertEquals($expected_results_cache, $results_cache_item->tags);
         }
       }
       else {
-        $this->assertFalse($results_cache_item, 'Results cache item not found.');
+        $this->assertNull($results_cache_item, 'Results cache item not found.');
       }
 
-      $this->pass('Checking Views render cache item cache tags.');
-
+      // Check Views render cache item cache tags.
       $original['#cache'] += ['contexts' => []];
       $original['#cache']['contexts'] = Cache::mergeContexts($original['#cache']['contexts'], $this->container->getParameter('renderer.config')['required_cache_contexts']);
 
       $render_cache_item = $render_cache->get($original);
       if ($views_caching_is_enabled === TRUE) {
-        $this->assertTrue(!empty($render_cache_item), 'Render cache item found.');
+        $this->assertNotEmpty($render_cache_item, 'Render cache item found.');
         if ($render_cache_item) {
-          $this->assertEqual($render_cache_item['#cache']['tags'], $expected_render_array_cache_tags);
-          $this->debugCacheTags($render_cache_item['#cache']['tags'], $expected_render_array_cache_tags);
+          $this->assertEquals($expected_render_array_cache_tags, $render_cache_item['#cache']['tags']);
         }
       }
       else {
-        $this->assertFalse($render_cache_item, 'Render cache item not found.');
+        $this->assertNull($render_cache_item, 'Render cache item not found.');
       }
     }
 
@@ -135,13 +130,11 @@ trait AssertViewsCacheTagsTrait {
     $request_stack->push($request);
     $renderer->renderRoot($build);
 
-    // Render array cache tags.
-    $this->pass('Checking render array cache tags.');
+    // Check render array cache tags.
     sort($expected_render_array_cache_tags);
-    $this->assertEqual($build['#cache']['tags'], $expected_render_array_cache_tags);
-    $this->debugCacheTags($build['#cache']['tags'], $expected_render_array_cache_tags);
+    $this->assertEquals($expected_render_array_cache_tags, $build['#cache']['tags']);
 
-    $this->pass('Checking Views render cache item cache tags.');
+    // Check Views render cache item cache tags.
     $original['#cache'] += ['contexts' => []];
     $original['#cache']['contexts'] = Cache::mergeContexts($original['#cache']['contexts'], $this->container->getParameter('renderer.config')['required_cache_contexts']);
 
@@ -149,8 +142,7 @@ trait AssertViewsCacheTagsTrait {
     if ($views_caching_is_enabled) {
       $this->assertTrue(!empty($render_cache_item), 'Render cache item found.');
       if ($render_cache_item) {
-        $this->assertEqual($render_cache_item['#cache']['tags'], $expected_render_array_cache_tags);
-        $this->debugCacheTags($render_cache_item['#cache']['tags'], $expected_render_array_cache_tags);
+        $this->assertEquals($expected_render_array_cache_tags, $render_cache_item['#cache']['tags']);
       }
     }
     else {
