@@ -70,18 +70,18 @@ class ArgumentDefaultTest extends ViewTestBase {
     $this->assertInstanceOf(ArgumentDefaultTestPlugin::class, $plugin);
 
     // Check that the value of the default argument is as expected.
-    $this->assertEqual('John', $view->argument[$id]->getDefaultArgument(), 'The correct argument default value is returned.');
+    $this->assertEquals('John', $view->argument[$id]->getDefaultArgument(), 'The correct argument default value is returned.');
     // Don't pass in a value for the default argument and make sure the query
     // just returns John.
     $this->executeView($view);
-    $this->assertEqual('John', $view->argument[$id]->getValue(), 'The correct argument value is used.');
+    $this->assertEquals('John', $view->argument[$id]->getValue(), 'The correct argument value is used.');
     $expected_result = [['name' => 'John']];
     $this->assertIdenticalResultset($view, $expected_result, ['views_test_data_name' => 'name']);
 
     // Pass in value as argument to be sure that not the default value is used.
     $view->destroy();
     $this->executeView($view, ['George']);
-    $this->assertEqual('George', $view->argument[$id]->getValue(), 'The correct argument value is used.');
+    $this->assertEquals('George', $view->argument[$id]->getValue(), 'The correct argument value is used.');
     $expected_result = [['name' => 'George']];
     $this->assertIdenticalResultset($view, $expected_result, ['views_test_data_name' => 'name']);
   }
@@ -101,7 +101,8 @@ class ArgumentDefaultTest extends ViewTestBase {
     $edit = [
       'options[default_argument_type]' => $argument_type,
     ];
-    $this->drupalPostForm('admin/structure/views/nojs/handler/test_argument_default_current_user/default/argument/uid', $edit, 'Apply');
+    $this->drupalGet('admin/structure/views/nojs/handler/test_argument_default_current_user/default/argument/uid');
+    $this->submitForm($edit, 'Apply');
 
     // Note, the undefined index error has two spaces after it.
     $error = [
@@ -125,13 +126,13 @@ class ArgumentDefaultTest extends ViewTestBase {
     $view->display_handler->overrideOption('arguments', $options);
     $view->initHandlers();
 
-    $this->assertEqual($random, $view->argument['null']->getDefaultArgument(), 'Fixed argument should be used by default.');
+    $this->assertEquals($random, $view->argument['null']->getDefaultArgument(), 'Fixed argument should be used by default.');
 
     // Make sure that a normal argument provided is used
     $random_string = $this->randomMachineName();
     $view->executeDisplay('default', [$random_string]);
 
-    $this->assertEqual($random_string, $view->args[0], 'Provided argument should be used.');
+    $this->assertEquals($random_string, $view->args[0], 'Provided argument should be used.');
   }
 
   /**
@@ -184,13 +185,13 @@ class ArgumentDefaultTest extends ViewTestBase {
     // Check the query parameter default argument fallback value.
     $view->setRequest($request);
     $view->initHandlers();
-    $this->assertEqual('all', $view->argument['type']->getDefaultArgument());
+    $this->assertEquals('all', $view->argument['type']->getDefaultArgument());
 
     // Check the query parameter default argument with a value.
     $request->query->add(['the_node_type' => 'page']);
     $view->setRequest($request);
     $view->initHandlers();
-    $this->assertEqual('page', $view->argument['type']->getDefaultArgument());
+    $this->assertEquals('page', $view->argument['type']->getDefaultArgument());
   }
 
 }
