@@ -61,13 +61,13 @@ class DisplayPageWebTest extends ViewTestBase {
     $this->assertCacheContexts(['languages:language_interface', 'route', 'theme', 'url']);
     $result = $this->xpath('//span[@class="field-content"]');
     $this->assertCount(1, $result, 'Ensure that just the filtered entry was returned.');
-    $this->assertEqual(1, $result[0]->getText(), 'The passed ID was returned.');
+    $this->assertEquals(1, $result[0]->getText(), 'The passed ID was returned.');
 
     $this->drupalGet('test_route_with_suffix/1/suffix');
     $this->assertSession()->statusCodeEquals(200);
     $result = $this->xpath('//span[@class="field-content"]');
     $this->assertCount(1, $result, 'Ensure that just the filtered entry was returned.');
-    $this->assertEqual(1, $result[0]->getText(), 'The passed ID was returned.');
+    $this->assertEquals(1, $result[0]->getText(), 'The passed ID was returned.');
 
     $this->drupalGet('test_route_with_suffix_and_argument/1/suffix/2');
     $this->assertSession()->statusCodeEquals(200);
@@ -78,13 +78,13 @@ class DisplayPageWebTest extends ViewTestBase {
     $this->assertSession()->statusCodeEquals(200);
     $result = $this->xpath('//span[@class="field-content"]');
     $this->assertCount(1, $result, 'Ensure that just the filtered entry was returned.');
-    $this->assertEqual(1, $result[0]->getText(), 'The passed ID was returned.');
+    $this->assertEquals(1, $result[0]->getText(), 'The passed ID was returned.');
 
     $this->drupalGet('test_route_with_long_argument/1');
     $this->assertSession()->statusCodeEquals(200);
     $result = $this->xpath('//span[@class="field-content"]');
     $this->assertCount(1, $result, 'Ensure that just the filtered entry was returned.');
-    $this->assertEqual(1, $result[0]->getText(), 'The passed ID was returned.');
+    $this->assertEquals(1, $result[0]->getText(), 'The passed ID was returned.');
   }
 
   /**
@@ -98,7 +98,7 @@ class DisplayPageWebTest extends ViewTestBase {
       ':ul_class' => 'tabs primary',
       ':a_class' => 'is-active',
     ]);
-    $this->assertEqual(t('Test default tab'), $element[0]->getText());
+    $this->assertEquals(t('Test default tab'), $element[0]->getText());
     $this->assertSession()->titleEquals('Test default page | Drupal');
 
     $this->drupalGet('test_page_display_menu/default');
@@ -110,7 +110,7 @@ class DisplayPageWebTest extends ViewTestBase {
       ':ul_class' => 'tabs primary',
       ':a_class' => 'is-active',
     ]);
-    $this->assertEqual(t('Test local tab'), $element[0]->getText());
+    $this->assertEquals(t('Test local tab'), $element[0]->getText());
     $this->assertSession()->titleEquals('Test local page | Drupal');
 
     // Check an ordinary menu link.
@@ -120,16 +120,15 @@ class DisplayPageWebTest extends ViewTestBase {
     $this->drupalGet('<front>');
 
     $menu_link = $this->cssSelect('nav.block-menu ul.menu a');
-    $this->assertEqual('Test menu link', $menu_link[0]->getText());
+    $this->assertEquals('Test menu link', $menu_link[0]->getText());
 
     // Update the menu link.
-    $this->drupalPostForm("admin/structure/menu/link/views_view:views.test_page_display_menu.page_3/edit", [
-      'title' => 'New title',
-    ], 'Save');
+    $this->drupalGet("admin/structure/menu/link/views_view:views.test_page_display_menu.page_3/edit");
+    $this->submitForm(['title' => 'New title'], 'Save');
 
     $this->drupalGet('<front>');
     $menu_link = $this->cssSelect('nav.block-menu ul.menu a');
-    $this->assertEqual('New title', $menu_link[0]->getText());
+    $this->assertEquals('New title', $menu_link[0]->getText());
   }
 
   /**
