@@ -71,7 +71,7 @@ class DisplayTest extends ViewTestBase {
       'display_title' => 'Display test',
       'position' => 1,
     ];
-    $this->assertEqual($displays['display_test_1'], $options);
+    $this->assertEquals($options, $displays['display_test_1']);
 
     // Add another one to ensure that position is counted up.
     $view->storage->addDisplay('display_test');
@@ -83,7 +83,7 @@ class DisplayTest extends ViewTestBase {
       'display_title' => 'Display test 2',
       'position' => 2,
     ];
-    $this->assertEqual($displays['display_test_2'], $options);
+    $this->assertEquals($options, $displays['display_test_2']);
 
     // Move the second display before the first one in order to test custom
     // sorting.
@@ -97,7 +97,7 @@ class DisplayTest extends ViewTestBase {
     $this->assertInstanceOf(DisplayTestPlugin::class, $view->display_handler);
 
     // Check the test option.
-    $this->assertIdentical($view->display_handler->getOption('test_option'), '');
+    $this->assertSame('', $view->display_handler->getOption('test_option'));
 
     $style = $view->display_handler->getOption('style');
     $style['type'] = 'test_style';
@@ -123,16 +123,16 @@ class DisplayTest extends ViewTestBase {
 
     // Test that the display category/summary is in the UI.
     $this->drupalGet('admin/structure/views/view/test_view/edit/display_test_1');
-    $this->assertText('Display test settings');
+    $this->assertSession()->pageTextContains('Display test settings');
     // Ensure that the order is as expected.
     $result = $this->xpath('//ul[@id="views-display-menu-tabs"]/li/a/child::text()');
-    $this->assertEqual($result[0]->getText(), 'Display test 2');
-    $this->assertEqual($result[1]->getText(), 'Display test');
+    $this->assertEquals('Display test 2', $result[0]->getText());
+    $this->assertEquals('Display test', $result[1]->getText());
 
     $this->clickLink('Test option title');
 
     $test_option = $this->randomString();
-    $this->drupalPostForm(NULL, ['test_option' => $test_option], t('Apply'));
+    $this->submitForm(['test_option' => $test_option], 'Apply');
 
     // Check the new value has been saved by checking the UI summary text.
     $this->drupalGet('admin/structure/views/view/test_view/edit/display_test_1');
@@ -166,10 +166,10 @@ class DisplayTest extends ViewTestBase {
 
     // Both the feed_1 and the feed_2 display are attached to the page display.
     $view->setDisplay('page_1');
-    $this->assertEqual($view->display_handler->getAttachedDisplays(), ['feed_1', 'feed_2']);
+    $this->assertEquals(['feed_1', 'feed_2'], $view->display_handler->getAttachedDisplays());
 
     $view->setDisplay('feed_1');
-    $this->assertEqual($view->display_handler->getAttachedDisplays(), []);
+    $this->assertEquals([], $view->display_handler->getAttachedDisplays());
   }
 
   /**
@@ -187,7 +187,7 @@ class DisplayTest extends ViewTestBase {
     $view->setDisplay('default');
     $errors = $view->validate();
     $this->assertTrue(!empty($errors), 'More link validation has some errors.');
-    $this->assertEqual($errors['default'][0], 'Display "Master" uses a "more" link but there are no displays it can link to. You need to specify a custom URL.', 'More link validation has the right error.');
+    $this->assertEquals('Display "Master" uses a "more" link but there are no displays it can link to. You need to specify a custom URL.', $errors['default'][0], 'More link validation has the right error.');
 
     // Confirm that the view does not validate when the page display does not exist.
     $view = Views::getView('test_view');
@@ -195,7 +195,7 @@ class DisplayTest extends ViewTestBase {
     $view->display_handler->setOption('use_more', 1);
     $errors = $view->validate();
     $this->assertTrue(!empty($errors), 'More link validation has some errors.');
-    $this->assertEqual($errors['default'][0], 'Display "Master" uses a "more" link but there are no displays it can link to. You need to specify a custom URL.', 'More link validation has the right error.');
+    $this->assertEquals('Display "Master" uses a "more" link but there are no displays it can link to. You need to specify a custom URL.', $errors['default'][0], 'More link validation has the right error.');
   }
 
   /**
@@ -308,7 +308,7 @@ class DisplayTest extends ViewTestBase {
 
     $this->drupalGet('test_display_invalid');
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertText('The &quot;invalid&quot; plugin does not exist.');
+    $this->assertSession()->pageTextContains('The "invalid" plugin does not exist.');
 
     // Rebuild the router, and ensure that the path is not accessible anymore.
     views_invalidate_cache();
@@ -327,7 +327,7 @@ class DisplayTest extends ViewTestBase {
 
     $this->drupalGet('<front>');
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertCount(1, $this->xpath('//div[@id = :id]', [':id' => 'block-' . $block->id()]));
+    $this->assertSession()->elementsCount('xpath', "//div[@id = 'block-{$block->id()}']", 1);
 
     // Change the block plugin ID to an invalid one.
     $config = $this->config('views.view.test_display_invalid');
@@ -338,8 +338,8 @@ class DisplayTest extends ViewTestBase {
     // plugin warning message.
     $this->drupalGet('<front>');
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertText('The &quot;invalid&quot; plugin does not exist.');
-    $this->assertCount(0, $this->xpath('//div[@id = :id]', [':id' => 'block-' . $block->id()]));
+    $this->assertSession()->pageTextContains('The "invalid" plugin does not exist.');
+    $this->assertSession()->elementNotExists('xpath', "//div[@id = 'block-{$block->id()}']");
   }
 
   /**
@@ -363,8 +363,8 @@ class DisplayTest extends ViewTestBase {
     $errors = $view->validate();
     // Check that the error messages are shown.
     $this->assertCount(2, $errors['default'], 'Error messages found for required relationship');
-    $this->assertEqual($errors['default'][0], t('The %handler_type %handler uses a relationship that has been removed.', ['%handler_type' => 'field', '%handler' => 'User: Last login']));
-    $this->assertEqual($errors['default'][1], t('The %handler_type %handler uses a relationship that has been removed.', ['%handler_type' => 'field', '%handler' => 'User: Created']));
+    $this->assertEquals(t('The %handler_type %handler uses a relationship that has been removed.', ['%handler_type' => 'field', '%handler' => 'User: Last login']), $errors['default'][0]);
+    $this->assertEquals(t('The %handler_type %handler uses a relationship that has been removed.', ['%handler_type' => 'field', '%handler' => 'User: Created']), $errors['default'][1]);
   }
 
   /**
@@ -373,7 +373,7 @@ class DisplayTest extends ViewTestBase {
   public function testOutputIsEmpty() {
     $view = Views::getView('test_display_empty');
     $this->executeView($view);
-    $this->assertTrue(count($view->result) > 0, 'Ensure the result of the view is not empty.');
+    $this->assertNotEmpty($view->result);
     $this->assertFalse($view->display_handler->outputIsEmpty(), 'Ensure the view output is marked as not empty.');
     $view->destroy();
 
@@ -415,7 +415,6 @@ class DisplayTest extends ViewTestBase {
    */
   public function testTranslationSetting() {
     \Drupal::service('module_installer')->install(['file']);
-    \Drupal::service('router.builder')->rebuild();
 
     // By default there should be no language settings.
     $this->checkTranslationSetting();
@@ -447,15 +446,15 @@ class DisplayTest extends ViewTestBase {
     $this->drupalGet('admin/structure/views/nojs/display/content/page_1/rendering_language');
     if ($expected_node_translatability) {
       $this->assertNoText($not_supported_text);
-      $this->assertText($supported_text);
+      $this->assertSession()->pageTextContains($supported_text);
     }
     else {
-      $this->assertText($not_supported_text);
+      $this->assertSession()->pageTextContains($not_supported_text);
       $this->assertNoText($supported_text);
     }
 
     $this->drupalGet('admin/structure/views/nojs/display/files/page_1/rendering_language');
-    $this->assertText($not_supported_text);
+    $this->assertSession()->pageTextContains($not_supported_text);
     $this->assertNoText($supported_text);
   }
 
