@@ -117,8 +117,8 @@ class SearchIntegrationTest extends ViewTestBase {
     $xpath = '//div[@class="views-row"]//a';
     /** @var \Behat\Mink\Element\NodeElement[] $results */
     $results = $this->xpath($xpath);
-    $this->assertEqual("Drupal's search rocks <em>really</em> rocks!", $results[0]->getText());
-    $this->assertEqual("Drupal's search rocks.", $results[1]->getText());
+    $this->assertEquals("Drupal's search rocks <em>really</em> rocks!", $results[0]->getText());
+    $this->assertEquals("Drupal's search rocks.", $results[1]->getText());
     $this->assertSession()->assertEscaped("Drupal's search rocks <em>really</em> rocks!");
 
     // Test sorting with another set of titles.
@@ -134,8 +134,8 @@ class SearchIntegrationTest extends ViewTestBase {
     $xpath = '//div[@class="views-row"]//a';
     /** @var \SimpleXMLElement[] $results */
     $results = $this->xpath($xpath);
-    $this->assertEqual("Testing one one one", $results[0]->getText());
-    $this->assertEqual("Testing one two two two", $results[1]->getText());
+    $this->assertEquals("Testing one one one", $results[0]->getText());
+    $this->assertEquals("Testing one two two two", $results[1]->getText());
   }
 
   /**
