@@ -8,7 +8,7 @@ use Drupal\Tests\system\Functional\Entity\Traits\EntityDefinitionTestTrait;
 use Drupal\Tests\views\Kernel\ViewsKernelTestBase;
 
 /**
- * Tests \Drupal\views\EventSubscriber\ViewsEntitySchemaSubscriber
+ * Tests \Drupal\views\EventSubscriber\ViewsEntitySchemaSubscriber.
  *
  * @group Views
  */
@@ -26,7 +26,12 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['entity_test', 'entity_test_update', 'user', 'text'];
+  protected static $modules = [
+    'entity_test',
+    'entity_test_update',
+    'user',
+    'text',
+  ];
 
   /**
    * Views used by this test.
@@ -66,7 +71,7 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp($import_test_views = TRUE) {
+  protected function setUp($import_test_views = TRUE): void {
     parent::setUp();
 
     $this->eventDispatcher = $this->container->get('event_dispatcher');
@@ -102,7 +107,7 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
     $this->assertTrue(isset($views['test_view_entity_test_additional_base_field']));
 
     $event = new EntityTypeEvent($this->entityTypeManager->getDefinition('entity_test_update'));
-    $this->eventDispatcher->dispatch(EntityTypeEvents::DELETE, $event);
+    $this->eventDispatcher->dispatch($event, EntityTypeEvents::DELETE);
 
     // We expect that views which use 'entity_test_update' as base tables are
     // disabled.
@@ -134,10 +139,10 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
     $view = $entity_storage->load('test_view_entity_test');
 
     // Ensure the base table got renamed, so also the views fields.
-    $this->assertEqual('entity_test_update_new', $view->get('base_table'));
+    $this->assertEquals('entity_test_update_new', $view->get('base_table'));
     $display = $view->getDisplay('default');
-    $this->assertEqual('entity_test_update_new', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_new', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update_new', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_new', $display['display_options']['fields']['name']['table']);
 
     // Check that only the impacted views have been updated.
     $this->assertUpdatedViews([
@@ -155,11 +160,11 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
 
     $entity_storage = $this->entityTypeManager->getStorage('view');
     $view = $entity_storage->load('test_view_entity_test_data');
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
     $display = $view->getDisplay('default');
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
     // Ensure that the data table is used.
-    $this->assertEqual('entity_test_update_data', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update_data', $display['display_options']['fields']['name']['table']);
 
     $this->renameDataTable();
     $this->applyEntityUpdates('entity_test_update');
@@ -169,10 +174,10 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
     $view = $entity_storage->load('test_view_entity_test_data');
 
     // Ensure the data table got renamed, so also the views fields.
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
     $display = $view->getDisplay('default');
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_data_new', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_data_new', $display['display_options']['fields']['name']['table']);
 
     // Check that only the impacted views have been updated.
     $this->assertUpdatedViews([
@@ -190,10 +195,10 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
     /** @var \Drupal\views\Entity\View $view */
     $entity_storage = $this->entityTypeManager->getStorage('view');
     $view = $entity_storage->load('test_view_entity_test_revision');
-    $this->assertEqual('entity_test_update_revision', $view->get('base_table'));
+    $this->assertEquals('entity_test_update_revision', $view->get('base_table'));
     $display = $view->getDisplay('default');
-    $this->assertEqual('entity_test_update_revision', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_revision', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update_revision', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_revision', $display['display_options']['fields']['name']['table']);
 
     $this->renameRevisionBaseTable();
     $this->applyEntityUpdates('entity_test_update');
@@ -203,10 +208,10 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
     $view = $entity_storage->load('test_view_entity_test_revision');
 
     // Ensure the base table got renamed, so also the views fields.
-    $this->assertEqual('entity_test_update_revision_new', $view->get('base_table'));
+    $this->assertEquals('entity_test_update_revision_new', $view->get('base_table'));
     $display = $view->getDisplay('default');
-    $this->assertEqual('entity_test_update_revision_new', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_revision_new', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update_revision_new', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_revision_new', $display['display_options']['fields']['name']['table']);
 
     // Check that only the impacted views have been updated.
     $this->assertUpdatedViews([
@@ -223,10 +228,10 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
     /** @var \Drupal\views\Entity\View $view */
     $entity_storage = $this->entityTypeManager->getStorage('view');
     $view = $entity_storage->load('test_view_entity_test_revision');
-    $this->assertEqual('entity_test_update_revision', $view->get('base_table'));
+    $this->assertEquals('entity_test_update_revision', $view->get('base_table'));
     $display = $view->getDisplay('default');
-    $this->assertEqual('entity_test_update_revision', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_revision_data', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update_revision', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_revision_data', $display['display_options']['fields']['name']['table']);
 
     $this->renameRevisionDataTable();
     $this->applyEntityUpdates('entity_test_update');
@@ -236,10 +241,10 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
     $view = $entity_storage->load('test_view_entity_test_revision');
 
     // Ensure the base table got renamed, so also the views fields.
-    $this->assertEqual('entity_test_update_revision', $view->get('base_table'));
+    $this->assertEquals('entity_test_update_revision', $view->get('base_table'));
     $display = $view->getDisplay('default');
-    $this->assertEqual('entity_test_update_revision', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_revision_data_new', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update_revision', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_revision_data_new', $display['display_options']['fields']['name']['table']);
 
     // Check that only the impacted views have been updated.
     $this->assertUpdatedViews([
@@ -259,10 +264,10 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
     $view = $entity_storage->load('test_view_entity_test');
 
     // Ensure the data table got renamed, so also the views fields.
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
     $display = $view->getDisplay('default');
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_data', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_data', $display['display_options']['fields']['name']['table']);
 
     // Check that only the impacted views have been updated.
     $this->assertUpdatedViews([
@@ -281,10 +286,10 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
     $view = $entity_storage->load('test_view_entity_test');
 
     // Ensure that nothing happens.
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
     $display = $view->getDisplay('default');
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['name']['table']);
 
     // Check that only the impacted views have been updated.
     $this->assertUpdatedViews([]);
@@ -324,16 +329,16 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
     $this->updateEntityTypeToTranslatable(TRUE);
     list($view, $display) = $this->getUpdatedViewAndDisplay();
 
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_data', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_data', $display['display_options']['fields']['name']['table']);
 
     $this->updateEntityTypeToNotTranslatable(TRUE);
     list($view, $display) = $this->getUpdatedViewAndDisplay();
 
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['name']['table']);
 
     $this->resetEntityType();
 
@@ -341,23 +346,23 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
     $this->updateEntityTypeToTranslatable(TRUE);
     list($view, $display) = $this->getUpdatedViewAndDisplay();
 
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_data', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_data', $display['display_options']['fields']['name']['table']);
 
     $this->updateEntityTypeToRevisionable(TRUE);
     list($view, $display) = $this->getUpdatedViewAndDisplay();
 
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_data', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_data', $display['display_options']['fields']['name']['table']);
 
     $this->updateEntityTypeToNotRevisionable(TRUE);
     list($view, $display) = $this->getUpdatedViewAndDisplay();
 
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_data', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_data', $display['display_options']['fields']['name']['table']);
 
     $this->resetEntityType();
 
@@ -365,23 +370,23 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
     $this->updateEntityTypeToRevisionable();
     list($view, $display) = $this->getUpdatedViewAndDisplay();
 
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['name']['table']);
 
     $this->updateEntityTypeToTranslatable(TRUE);
     list($view, $display) = $this->getUpdatedViewAndDisplay();
 
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_data', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_data', $display['display_options']['fields']['name']['table']);
 
     $this->updateEntityTypeToNotTranslatable(TRUE);
     list($view, $display) = $this->getUpdatedViewAndDisplay();
 
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['name']['table']);
 
     $this->resetEntityType();
 
@@ -389,16 +394,16 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
     $this->updateEntityTypeToRevisionable(TRUE);
     list($view, $display) = $this->getUpdatedViewAndDisplay();
 
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['name']['table']);
 
     $this->updateEntityTypeToNotRevisionable(TRUE);
     list($view, $display) = $this->getUpdatedViewAndDisplay();
 
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['name']['table']);
 
     $this->resetEntityType();
 
@@ -407,17 +412,17 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
     $this->updateEntityTypeToTranslatable(TRUE);
     list($view, $display) = $this->getUpdatedViewAndDisplay();
 
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_data', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_data', $display['display_options']['fields']['name']['table']);
 
     $this->updateEntityTypeToNotRevisionable(TRUE);
     $this->updateEntityTypeToNotTranslatable(TRUE);
     list($view, $display) = $this->getUpdatedViewAndDisplay();
 
-    $this->assertEqual('entity_test_update', $view->get('base_table'));
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update', $view->get('base_table'));
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update', $display['display_options']['fields']['name']['table']);
 
     // Check that only the impacted views have been updated.
     $this->assertUpdatedViews([
@@ -436,23 +441,23 @@ class ViewsEntitySchemaSubscriberIntegrationTest extends ViewsKernelTestBase {
 
     list($view, $display) = $this->getUpdatedViewAndDisplay(TRUE);
 
-    $this->assertEqual('entity_test_update_revision', $view->get('base_table'));
-    $this->assertEqual('entity_test_update_revision', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_revision', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update_revision', $view->get('base_table'));
+    $this->assertEquals('entity_test_update_revision', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_revision', $display['display_options']['fields']['name']['table']);
 
     $this->updateEntityTypeToTranslatable(TRUE);
     list($view, $display) = $this->getUpdatedViewAndDisplay(TRUE);
 
-    $this->assertEqual('entity_test_update_revision', $view->get('base_table'));
-    $this->assertEqual('entity_test_update_revision', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_revision_data', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update_revision', $view->get('base_table'));
+    $this->assertEquals('entity_test_update_revision', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_revision_data', $display['display_options']['fields']['name']['table']);
 
     $this->updateEntityTypeToNotTranslatable(TRUE);
     list($view, $display) = $this->getUpdatedViewAndDisplay(TRUE);
 
-    $this->assertEqual('entity_test_update_revision', $view->get('base_table'));
-    $this->assertEqual('entity_test_update_revision', $display['display_options']['fields']['id']['table']);
-    $this->assertEqual('entity_test_update_revision', $display['display_options']['fields']['name']['table']);
+    $this->assertEquals('entity_test_update_revision', $view->get('base_table'));
+    $this->assertEquals('entity_test_update_revision', $display['display_options']['fields']['id']['table']);
+    $this->assertEquals('entity_test_update_revision', $display['display_options']['fields']['name']['table']);
 
     // Check that only the impacted views have been updated.
     $this->assertUpdatedViews([
