@@ -49,31 +49,31 @@ class FieldBooleanTest extends ViewsKernelTestBase {
     $this->executeView($view);
 
     // This is john, which has no age, there are no custom formats defined, yet.
-    $this->assertEqual(t('No'), $view->field['age']->advancedRender($view->result[0]));
-    $this->assertEqual(t('Yes'), $view->field['age']->advancedRender($view->result[1]));
+    $this->assertEquals(t('No'), $view->field['age']->advancedRender($view->result[0]));
+    $this->assertEquals(t('Yes'), $view->field['age']->advancedRender($view->result[1]));
 
     // Reverse the output.
     $view->field['age']->options['not'] = TRUE;
-    $this->assertEqual(t('Yes'), $view->field['age']->advancedRender($view->result[0]));
-    $this->assertEqual(t('No'), $view->field['age']->advancedRender($view->result[1]));
+    $this->assertEquals(t('Yes'), $view->field['age']->advancedRender($view->result[0]));
+    $this->assertEquals(t('No'), $view->field['age']->advancedRender($view->result[1]));
 
     unset($view->field['age']->options['not']);
 
     // Use another output format.
     $view->field['age']->options['type'] = 'true-false';
-    $this->assertEqual(t('False'), $view->field['age']->advancedRender($view->result[0]));
-    $this->assertEqual(t('True'), $view->field['age']->advancedRender($view->result[1]));
+    $this->assertEquals(t('False'), $view->field['age']->advancedRender($view->result[0]));
+    $this->assertEquals(t('True'), $view->field['age']->advancedRender($view->result[1]));
 
     // test awesome unicode.
     $view->field['age']->options['type'] = 'unicode-yes-no';
-    $this->assertEqual('✖', $view->field['age']->advancedRender($view->result[0]));
-    $this->assertEqual('✔', $view->field['age']->advancedRender($view->result[1]));
+    $this->assertEquals('✖', $view->field['age']->advancedRender($view->result[0]));
+    $this->assertEquals('✔', $view->field['age']->advancedRender($view->result[1]));
 
     // Set a custom output format.
     $view->field['age']->formats['test'] = [t('Test-True'), t('Test-False')];
     $view->field['age']->options['type'] = 'test';
-    $this->assertEqual(t('Test-False'), $view->field['age']->advancedRender($view->result[0]));
-    $this->assertEqual(t('Test-True'), $view->field['age']->advancedRender($view->result[1]));
+    $this->assertEquals(t('Test-False'), $view->field['age']->advancedRender($view->result[0]));
+    $this->assertEquals(t('Test-True'), $view->field['age']->advancedRender($view->result[1]));
   }
 
 }
