@@ -1129,7 +1129,7 @@ class EntityViewsDataTest extends UnitTestCase {
   }
 
   /**
-   * Tests views data for a entity reference field.
+   * Tests views data for an entity reference field.
    */
   protected function assertEntityReferenceField($data) {
     $this->assertEquals('field', $data['field']['id']);
@@ -1195,24 +1195,3 @@ class TestEntityType extends ContentEntityType {
   }
 
 }
-
-namespace Drupal\entity_test\Entity;
-
-if (!function_exists('t')) {
-
-  function t($string, array $args = []) {
-    return strtr($string, $args);
-  }
-
-}
-
-
-namespace Drupal\Core\Entity;
-
-if (!function_exists('t')) {
-
-  function t($string, array $args = []) {
-    return strtr($string, $args);
-  }
-
-}
