@@ -50,7 +50,8 @@ class DisplayCRUDTest extends UITestBase {
     $this->assertSession()->linkNotExists('Master*', 'Make sure the master display is not marked as changed.');
     $this->assertSession()->linkExists('Page*', 0, 'Make sure the added display is marked as changed.');
 
-    $this->drupalPostForm("admin/structure/views/nojs/display/{$view['id']}/page_1/path", ['path' => 'test/path'], 'Apply');
+    $this->drupalGet("admin/structure/views/nojs/display/{$view['id']}/page_1/path");
+    $this->submitForm(['path' => 'test/path'], 'Apply');
     $this->submitForm([], 'Save');
   }
 
@@ -69,7 +70,8 @@ class DisplayCRUDTest extends UITestBase {
     $this->assertSession()->buttonExists('edit-displays-settings-settings-content-tab-content-details-top-actions-delete');
 
     // Delete the page, so we can test the undo process.
-    $this->drupalPostForm($path_prefix . '/page_1', [], 'Delete Page');
+    $this->drupalGet($path_prefix . '/page_1');
+    $this->submitForm([], 'Delete Page');
     $this->assertSession()->buttonExists('edit-displays-settings-settings-content-tab-content-details-top-actions-undo-delete');
     $element = $this->xpath('//a[contains(@href, :href) and contains(@class, :class)]', [':href' => $path_prefix . '/page_1', ':class' => 'views-display-deleted-link']);
     $this->assertTrue(!empty($element), 'Make sure the display link is marked as to be deleted.');
@@ -78,12 +80,14 @@ class DisplayCRUDTest extends UITestBase {
     $this->assertTrue(!empty($element), 'Make sure the display link is marked as to be deleted.');
 
     // Undo the deleting of the display.
-    $this->drupalPostForm($path_prefix . '/page_1', [], 'Undo delete of Page');
+    $this->drupalGet($path_prefix . '/page_1');
+    $this->submitForm([], 'Undo delete of Page');
     $this->assertSession()->buttonNotExists('edit-displays-settings-settings-content-tab-content-details-top-actions-undo-delete');
     $this->assertSession()->buttonExists('edit-displays-settings-settings-content-tab-content-details-top-actions-delete');
 
     // Now delete again and save the view.
-    $this->drupalPostForm($path_prefix . '/page_1', [], 'Delete Page');
+    $this->drupalGet($path_prefix . '/page_1');
+    $this->submitForm([], 'Delete Page');
     $this->submitForm([], 'Save');
 
     $this->assertSession()->linkByHrefNotExists($path_prefix . '/page_1', 'Make sure there is no display tab for the deleted display.');
@@ -92,7 +96,8 @@ class DisplayCRUDTest extends UITestBase {
     $view = $this->randomView();
     $machine_name = 'new_machine_name';
     $path_prefix = 'admin/structure/views/view/' . $view['id'] . '/edit';
-    $this->drupalPostForm("admin/structure/views/nojs/display/{$view['id']}/page_1/display_id", ['display_id' => $machine_name], 'Apply');
+    $this->drupalGet("admin/structure/views/nojs/display/{$view['id']}/page_1/display_id");
+    $this->submitForm(['display_id' => $machine_name], 'Apply');
     $this->submitForm([], 'Delete Page');
     $this->submitForm([], 'Save');
     $this->assertSession()->statusCodeEquals(200);
@@ -125,14 +130,19 @@ class DisplayCRUDTest extends UITestBase {
     // Set the title and override the css classes.
     $random_title = $this->randomMachineName();
     $random_css = $this->randomMachineName();
-    $this->drupalPostForm("admin/structure/views/nojs/display/{$view['id']}/page_2/title", ['title' => $random_title], 'Apply');
-    $this->drupalPostForm("admin/structure/views/nojs/display/{$view['id']}/page_2/css_class", ['override[dropdown]' => 'page_2', 'css_class' => $random_css], 'Apply');
+    $this->drupalGet("admin/structure/views/nojs/display/{$view['id']}/page_2/title");
+    $this->submitForm(['title' => $random_title], 'Apply');
+    $this->drupalGet("admin/structure/views/nojs/display/{$view['id']}/page_2/css_class");
+    $this->submitForm([
+      'override[dropdown]' => 'page_2',
+      'css_class' => $random_css,
+    ], 'Apply');
 
     // Duplicate as a different display type.
     $this->submitForm([], 'Duplicate as Block');
     $this->assertSession()->linkByHrefExists($path_prefix . '/block_1', 0, 'Make sure after duplicating the new display appears in the UI');
     $this->assertSession()->addressEquals($path_prefix . '/block_1');
-    $this->assertText('Block settings');
+    $this->assertSession()->pageTextContains('Block settings');
     $this->assertNoText('Page settings');
 
     $this->submitForm([], 'Save');
@@ -141,19 +151,20 @@ class DisplayCRUDTest extends UITestBase {
 
     $page_2 = $view->displayHandlers->get('page_2');
     $this->assertNotEmpty($page_2, 'The new page display got saved.');
-    $this->assertEqual('Page', $page_2->display['display_title']);
-    $this->assertEqual($path, $page_2->display['display_options']['path']);
+    $this->assertEquals('Page', $page_2->display['display_title']);
+    $this->assertEquals($path, $page_2->display['display_options']['path']);
     $block_1 = $view->displayHandlers->get('block_1');
     $this->assertNotEmpty($block_1, 'The new block display got saved.');
-    $this->assertEqual('block', $block_1->display['display_plugin']);
-    $this->assertEqual('Block', $block_1->display['display_title'], 'The new display title got generated as expected.');
+    $this->assertEquals('block', $block_1->display['display_plugin']);
+    $this->assertEquals('Block', $block_1->display['display_title'], 'The new display title got generated as expected.');
     $this->assertFalse(isset($block_1->display['display_options']['path']));
-    $this->assertEqual($random_title, $block_1->getOption('title'), 'The overridden title option from the display got copied into the duplicate');
-    $this->assertEqual($random_css, $block_1->getOption('css_class'), 'The overridden css_class option from the display got copied into the duplicate');
+    $this->assertEquals($random_title, $block_1->getOption('title'), 'The overridden title option from the display got copied into the duplicate');
+    $this->assertEquals($random_css, $block_1->getOption('css_class'), 'The overridden css_class option from the display got copied into the duplicate');
 
     // Test duplicating a display after changing the machine name.
     $view_id = $view->id();
-    $this->drupalPostForm("admin/structure/views/nojs/display/$view_id/page_2/display_id", ['display_id' => 'page_new'], 'Apply');
+    $this->drupalGet("admin/structure/views/nojs/display/{$view_id}/page_2/display_id");
+    $this->submitForm(['display_id' => 'page_new'], 'Apply');
     $this->submitForm([], 'Duplicate as Block');
     $this->submitForm([], 'Save');
     $view = Views::getView($view_id);
