@@ -56,7 +56,7 @@ class DisplayPathTest extends UITestBase {
 
     // Add a new page display and check the appearing text.
     $this->submitForm([], 'Add Page');
-    $this->assertText('No path is set');
+    $this->assertSession()->pageTextContains('No path is set');
     $this->assertSession()->linkNotExists('View page', 'No view page link found on the page.');
 
     // Save a path and make sure the summary appears as expected.
@@ -65,8 +65,9 @@ class DisplayPathTest extends UITestBase {
     //   longer use Url::fromUri(), and this path will be able to contain ':'.
     $random_path = str_replace(':', '', $random_path);
 
-    $this->drupalPostForm('admin/structure/views/nojs/display/test_view/page_1/path', ['path' => $random_path], 'Apply');
-    $this->assertText('/' . $random_path);
+    $this->drupalGet('admin/structure/views/nojs/display/test_view/page_1/path');
+    $this->submitForm(['path' => $random_path], 'Apply');
+    $this->assertSession()->pageTextContains('/' . $random_path);
     $display_link_text = t('View @display', ['@display' => 'Page']);
     $this->assertSession()->linkExists($display_link_text, 0, 'view page link found on the page.');
     $this->clickLink($display_link_text);
@@ -79,12 +80,16 @@ class DisplayPathTest extends UITestBase {
   public function doPathXssFilterTest() {
     $this->drupalGet('admin/structure/views/view/test_view');
     $this->submitForm([], 'Add Page');
-    $this->drupalPostForm('admin/structure/views/nojs/display/test_view/page_2/path', ['path' => '<object>malformed_path</object>'], 'Apply');
+    $this->drupalGet('admin/structure/views/nojs/display/test_view/page_2/path');
+    $this->submitForm(['path' => '<object>malformed_path</object>'], 'Apply');
     $this->submitForm([], 'Add Page');
-    $this->drupalPostForm('admin/structure/views/nojs/display/test_view/page_3/path', ['path' => '<script>alert("hello");</script>'], 'Apply');
+    $this->drupalGet('admin/structure/views/nojs/display/test_view/page_3/path');
+    $this->submitForm(['path' => '<script>alert("hello");</script>'], 'Apply');
     $this->submitForm([], 'Add Page');
-    $this->drupalPostForm('admin/structure/views/nojs/display/test_view/page_4/path', ['path' => '<script>alert("hello I have placeholders %");</script>'], 'Apply');
-    $this->drupalPostForm('admin/structure/views/view/test_view', [], 'Save');
+    $this->drupalGet('admin/structure/views/nojs/display/test_view/page_4/path');
+    $this->submitForm(['path' => '<script>alert("hello I have placeholders %");</script>'], 'Apply');
+    $this->drupalGet('admin/structure/views/view/test_view');
+    $this->submitForm([], 'Save');
     $this->drupalGet('admin/structure/views');
     // The anchor text should be escaped.
     $this->assertSession()->assertEscaped('/<object>malformed_path</object>');
@@ -101,13 +106,15 @@ class DisplayPathTest extends UITestBase {
   protected function doAdvancedPathsValidationTest() {
     $url = 'admin/structure/views/nojs/display/test_view/page_1/path';
 
-    $this->drupalPostForm($url, ['path' => '%/magrathea'], 'Apply');
+    $this->drupalGet($url);
+    $this->submitForm(['path' => '%/magrathea'], 'Apply');
     $this->assertSession()->addressEquals($url);
-    $this->assertText('"%" may not be used for the first segment of a path.');
+    $this->assertSession()->pageTextContains('"%" may not be used for the first segment of a path.');
 
-    $this->drupalPostForm($url, ['path' => 'user/%1/example'], 'Apply');
+    $this->drupalGet($url);
+    $this->submitForm(['path' => 'user/%1/example'], 'Apply');
     $this->assertSession()->addressEquals($url);
-    $this->assertText("Numeric placeholders may not be used. Please use plain placeholders (%).");
+    $this->assertSession()->pageTextContains("Numeric placeholders may not be used. Please use plain placeholders (%).");
   }
 
   /**
@@ -132,25 +139,33 @@ class DisplayPathTest extends UITestBase {
     $this->submitForm([], 'Add Page');
 
     // Add an invalid path (only fragment).
-    $this->drupalPostForm('admin/structure/views/nojs/display/test_view/page_1/path', ['path' => '#foo'], 'Apply');
-    $this->assertText('Path is empty');
+    $this->drupalGet('admin/structure/views/nojs/display/test_view/page_1/path');
+    $this->submitForm(['path' => '#foo'], 'Apply');
+    $this->assertSession()->pageTextContains('Path is empty');
 
     // Add an invalid path with a query.
-    $this->drupalPostForm('admin/structure/views/nojs/display/test_view/page_1/path', ['path' => 'foo?bar'], 'Apply');
-    $this->assertText('No query allowed.');
+    $this->drupalGet('admin/structure/views/nojs/display/test_view/page_1/path');
+    $this->submitForm(['path' => 'foo?bar'], 'Apply');
+    $this->assertSession()->pageTextContains('No query allowed.');
 
     // Add an invalid path with just a query.
-    $this->drupalPostForm('admin/structure/views/nojs/display/test_view/page_1/path', ['path' => '?bar'], 'Apply');
-    $this->assertText('Path is empty');
+    $this->drupalGet('admin/structure/views/nojs/display/test_view/page_1/path');
+    $this->submitForm(['path' => '?bar'], 'Apply');
+    $this->assertSession()->pageTextContains('Path is empty');
 
     // Provide a random, valid path string.
     $random_string = $this->randomMachineName();
 
     // Save a path.
-    $this->drupalPostForm('admin/structure/views/nojs/display/test_view/page_1/path', ['path' => $random_string], 'Apply');
+    $this->drupalGet('admin/structure/views/nojs/display/test_view/page_1/path');
+    $this->submitForm(['path' => $random_string], 'Apply');
     $this->drupalGet('admin/structure/views/view/test_view');
 
-    $this->drupalPostForm('admin/structure/views/nojs/display/test_view/page_1/menu', ['menu[type]' => 'default tab', 'menu[title]' => 'Test tab title'], 'Apply');
+    $this->drupalGet('admin/structure/views/nojs/display/test_view/page_1/menu');
+    $this->submitForm([
+      'menu[type]' => 'default tab',
+      'menu[title]' => 'Test tab title',
+    ], 'Apply');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertSession()->addressEquals('admin/structure/views/nojs/display/test_view/page_1/tab_options');
 
@@ -211,7 +226,8 @@ class DisplayPathTest extends UITestBase {
       'link[0][uri]' => '/admin/foo',
       'menu_parent' => 'admin:system.admin',
     ];
-    $this->drupalPostForm('admin/structure/menu/manage/admin/add', $edit, 'Save');
+    $this->drupalGet('admin/structure/menu/manage/admin/add');
+    $this->submitForm($edit, 'Save');
 
     $menu_items = \Drupal::entityTypeManager()->getStorage('menu_link_content')->getQuery()
       ->accessCheck(FALSE)
@@ -229,13 +245,14 @@ class DisplayPathTest extends UITestBase {
     $edit['page[create]'] = TRUE;
     $edit['page[path]'] = 'admin/foo';
 
-    $this->drupalPostForm('admin/structure/views/add', $edit, 'Save and edit');
+    $this->drupalGet('admin/structure/views/add');
+    $this->submitForm($edit, 'Save and edit');
 
     $parameters = new MenuTreeParameters();
     $parameters->addCondition('id', $menu_link_content->getPluginId());
     $result = \Drupal::menuTree()->load('admin', $parameters);
     $plugin_definition = end($result)->link->getPluginDefinition();
-    $this->assertEqual('view.' . $view_id . '.page_1', $plugin_definition['route_name']);
+    $this->assertEquals('view.' . $view_id . '.page_1', $plugin_definition['route_name']);
 
     $this->clickLink(t('No menu'));
 
@@ -244,7 +261,7 @@ class DisplayPathTest extends UITestBase {
       'menu[title]' => 'Menu title',
     ], 'Apply');
 
-    $this->assertText('Default tab options');
+    $this->assertSession()->pageTextContains('Default tab options');
 
     $this->submitForm([
       'tab_options[type]' => 'normal',
