@@ -79,7 +79,8 @@ class ExposedFormUITest extends UITestBase {
     $this->assertSession()->checkboxNotChecked('edit-options-value-article');
 
     // Click the Expose filter button.
-    $this->drupalPostForm('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type', $edit, 'Expose filter');
+    $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type');
+    $this->submitForm($edit, 'Expose filter');
     // Check the label of the expose button.
     $this->helperButtonHasLabel('edit-options-expose-button-button', 'Hide filter');
 
@@ -93,12 +94,12 @@ class ExposedFormUITest extends UITestBase {
     $edit = [];
     $edit['options[expose][identifier]'] = '';
     $this->submitForm($edit, 'Apply');
-    $this->assertText('The identifier is required if the filter is exposed.');
+    $this->assertSession()->pageTextContains('The identifier is required if the filter is exposed.');
 
     $edit = [];
     $edit['options[expose][identifier]'] = 'value';
     $this->submitForm($edit, 'Apply');
-    $this->assertText('This identifier is not allowed.');
+    $this->assertSession()->pageTextContains('This identifier is not allowed.');
 
     // Now check the sort criteria.
     $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/sort/created');
@@ -117,7 +118,8 @@ class ExposedFormUITest extends UITestBase {
 
     // Click the Expose sort button.
     $edit = [];
-    $this->drupalPostForm('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/sort/created', $edit, 'Expose sort');
+    $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/sort/created');
+    $this->submitForm($edit, 'Expose sort');
     // Check the label of the expose button.
     $this->helperButtonHasLabel('edit-options-expose-button-button', 'Hide sort');
     $this->assertSession()->fieldValueEquals('edit-options-expose-label', 'Authored on');
@@ -129,7 +131,8 @@ class ExposedFormUITest extends UITestBase {
     $this->assertSession()->fieldValueEquals('options[order]', 'ASC');
     // Change the order and expose the sort.
     $this->submitForm(['options[order]' => 'DESC'], 'Apply');
-    $this->drupalPostForm("admin/structure/views/nojs/handler/$view_id/default/sort/created", [], 'Expose sort');
+    $this->drupalGet("admin/structure/views/nojs/handler/{$view_id}/default/sort/created");
+    $this->submitForm([], 'Expose sort');
     $this->assertSession()->fieldValueEquals('options[order]', 'DESC');
     $this->assertSession()->fieldValueEquals('options[expose][label]', 'Authored on');
     // Change the label and save the view.
@@ -139,8 +142,8 @@ class ExposedFormUITest extends UITestBase {
     // Check that the values were saved.
     $display = View::load($view_id)->getDisplay('default');
     $this->assertTrue($display['display_options']['sorts']['created']['exposed']);
-    $this->assertEqual(['label' => $edit['options[expose][label]']], $display['display_options']['sorts']['created']['expose']);
-    $this->assertEqual('DESC', $display['display_options']['sorts']['created']['order']);
+    $this->assertEquals(['label' => $edit['options[expose][label]']], $display['display_options']['sorts']['created']['expose']);
+    $this->assertEquals('DESC', $display['display_options']['sorts']['created']['order']);
   }
 
   /**
@@ -152,7 +155,8 @@ class ExposedFormUITest extends UITestBase {
     $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type');
 
     // Click the Expose filter button.
-    $this->drupalPostForm('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type', $edit, 'Expose filter');
+    $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type');
+    $this->submitForm($edit, 'Expose filter');
     // Check the label of the grouped filters button.
     $this->helperButtonHasLabel('edit-options-group-button-button', 'Grouped filters');
 
@@ -204,7 +208,8 @@ class ExposedFormUITest extends UITestBase {
     $this->assertNoGroupedFilterErrors();
 
     // Ensure the string "0" can be used as a value for numeric filters.
-    $this->drupalPostForm('admin/structure/views/nojs/add-handler/test_exposed_admin_ui/default/filter', ['name[node_field_data.nid]' => TRUE], 'Add and configure filter criteria');
+    $this->drupalGet('admin/structure/views/nojs/add-handler/test_exposed_admin_ui/default/filter');
+    $this->submitForm(['name[node_field_data.nid]' => TRUE], 'Add and configure filter criteria');
     $this->submitForm([], 'Expose filter');
     $this->submitForm([], 'Grouped filters');
     $edit = [];
@@ -233,16 +238,18 @@ class ExposedFormUITest extends UITestBase {
     $edit["options[group_info][group_items][1][title]"] = '';
     $edit["options[group_info][group_items][1][operator]"] = 'empty';
     $this->submitForm($edit, 'Apply');
-    $this->assertText($this->groupFormUiErrors['missing_title_empty_operator']);
+    $this->assertSession()->pageTextContains($this->groupFormUiErrors['missing_title_empty_operator']);
 
     // Specify a title without a value.
     $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type');
-    $this->drupalPostForm('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type', [], 'Expose filter');
-    $this->drupalPostForm('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type', [], 'Grouped filters');
+    $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type');
+    $this->submitForm([], 'Expose filter');
+    $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type');
+    $this->submitForm([], 'Grouped filters');
     $edit = [];
     $edit["options[group_info][group_items][1][title]"] = 'Is Article';
     $this->submitForm($edit, 'Apply');
-    $this->assertText($this->groupFormUiErrors['missing_value']);
+    $this->assertSession()->pageTextContains($this->groupFormUiErrors['missing_value']);
 
     // Specify a value without a title.
     $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type');
@@ -250,7 +257,7 @@ class ExposedFormUITest extends UITestBase {
     $edit["options[group_info][group_items][1][title]"] = '';
     $edit["options[group_info][group_items][1][value][article]"] = 'article';
     $this->submitForm($edit, 'Apply');
-    $this->assertText($this->groupFormUiErrors['missing_title']);
+    $this->assertSession()->pageTextContains($this->groupFormUiErrors['missing_title']);
   }
 
   /**
@@ -278,9 +285,11 @@ class ExposedFormUITest extends UITestBase {
   */
   public function testExposedGroupedFilter() {
     // Click the Expose filter button.
-    $this->drupalPostForm('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type', [], 'Expose filter');
+    $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type');
+    $this->submitForm([], 'Expose filter');
     // Select 'Grouped filters' radio button.
-    $this->drupalPostForm('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type', [], 'Grouped filters');
+    $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/type');
+    $this->submitForm([], 'Grouped filters');
     // Add 3 groupings.
     $edit = [
       'options[group_button][radios][radios]' => 1,
@@ -298,10 +307,13 @@ class ExposedFormUITest extends UITestBase {
     $this->assertSession()->statusCodeEquals(200);
 
     // Click the Expose filter button.
-    $this->drupalPostForm('admin/structure/views/nojs/add-handler/test_exposed_admin_ui/default/filter', ['name[node_field_data.status]' => 1], 'Add and configure filter criteria');
-    $this->drupalPostForm('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/status', [], 'Expose filter');
+    $this->drupalGet('admin/structure/views/nojs/add-handler/test_exposed_admin_ui/default/filter');
+    $this->submitForm(['name[node_field_data.status]' => 1], 'Add and configure filter criteria');
+    $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/status');
+    $this->submitForm([], 'Expose filter');
     // Select 'Grouped filters' radio button.
-    $this->drupalPostForm('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/status', [], 'Grouped filters');
+    $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/status');
+    $this->submitForm([], 'Grouped filters');
     // Add 3 groupings.
     $edit = [
       'options[group_button][radios][radios]' => 1,
