@@ -37,14 +37,16 @@ class TokenizeAreaUITest extends UITestBase {
     $this->drupalGet($view->toUrl('edit-form'));
 
     // Add a global NULL argument to the view for testing argument tokens.
-    $this->drupalPostForm("admin/structure/views/nojs/add-handler/$id/page_1/argument", ['name[views.null]' => 1], 'Add and configure contextual filters');
-    $this->drupalPostForm(NULL, [], 'Apply');
+    $this->drupalGet("admin/structure/views/nojs/add-handler/{$id}/page_1/argument");
+    $this->submitForm(['name[views.null]' => 1], 'Add and configure contextual filters');
+    $this->submitForm([], 'Apply');
 
-    $this->drupalPostForm("admin/structure/views/nojs/add-handler/$id/page_1/header", ['name[views.area]' => 'views.area'], 'Add and configure header');
+    $this->drupalGet("admin/structure/views/nojs/add-handler/{$id}/page_1/header");
+    $this->submitForm(['name[views.area]' => 'views.area'], 'Add and configure header');
     // Test that field tokens are shown.
-    $this->assertText('{{ title }} == Content: Title');
+    $this->assertSession()->pageTextContains('{{ title }} == Content: Title');
     // Test that argument tokens are shown.
-    $this->assertText('{{ arguments.null }} == Global: Null title');
+    $this->assertSession()->pageTextContains('{{ arguments.null }} == Global: Null title');
   }
 
 }
