@@ -96,14 +96,16 @@ class WorkflowUiTest extends BrowserTestBase {
 
     $this->drupalLogin($this->createUser(['administer workflows']));
 
-    $this->drupalPostForm('admin/config/workflow/workflows/manage/test_workflow/add_state', [
+    $this->drupalGet('admin/config/workflow/workflows/manage/test_workflow/add_state');
+    $this->submitForm([
       'label' => 'Test State',
       'id' => 'Invalid ID',
     ], 'Save');
     $this->assertSession()->statusCodeEquals(200);
     $this->assertSession()->pageTextContains('The machine-readable name must contain only lowercase letters, numbers, and underscores.');
 
-    $this->drupalPostForm('admin/config/workflow/workflows/manage/test_workflow/add_transition', [
+    $this->drupalGet('admin/config/workflow/workflows/manage/test_workflow/add_transition');
+    $this->submitForm([
       'label' => 'Test Transition',
       'id' => 'Invalid ID',
     ], 'Save');
