@@ -54,21 +54,21 @@ class ToolkitSetupFormTest extends BrowserTestBase {
     // Test changing the jpeg image quality.
     $edit = ['gd[image_jpeg_quality]' => '70'];
     $this->submitForm($edit, 'Save configuration');
-    $this->assertEqual('70', $this->config('system.image.gd')->get('jpeg_quality'));
+    $this->assertEquals('70', $this->config('system.image.gd')->get('jpeg_quality'));
 
     // Test changing the toolkit.
     $edit = ['image_toolkit' => 'test'];
     $this->submitForm($edit, 'Save configuration');
-    $this->assertEqual('test', $this->config('system.image')->get('toolkit'));
+    $this->assertEquals('test', $this->config('system.image')->get('toolkit'));
     $this->assertSession()->fieldValueEquals('test[test_parameter]', '10');
 
     // Test changing the test toolkit parameter.
     $edit = ['test[test_parameter]' => '0'];
     $this->submitForm($edit, 'Save configuration');
-    $this->assertText('Test parameter should be different from 0.');
+    $this->assertSession()->pageTextContains('Test parameter should be different from 0.');
     $edit = ['test[test_parameter]' => '20'];
     $this->submitForm($edit, 'Save configuration');
-    $this->assertEqual('20', $this->config('system.image.test_toolkit')->get('test_parameter'));
+    $this->assertEquals('20', $this->config('system.image.test_toolkit')->get('test_parameter'));
 
     // Test access without the permission 'administer site configuration'.
     $this->drupalLogin($this->drupalCreateUser(['access administration pages']));
