@@ -59,7 +59,7 @@ class InstallerConfigDirectorySetNoDirectoryErrorTest extends InstallerTestBase
    * Verifies that installation failed.
    */
   public function testError() {
-    $this->assertText("An automated attempt to create the directory {$this->configDirectory}/sync failed, possibly due to a permissions problem.");
+    $this->assertSession()->pageTextContains("An automated attempt to create the directory {$this->configDirectory}/sync failed, possibly due to a permissions problem.");
     $this->assertDirectoryNotExists($this->configDirectory . '/sync');
   }
 
