@@ -9,11 +9,6 @@ namespace Drupal\FunctionalTests\Installer;
  */
 class InstallerExistingConfigNoSystemSiteTest extends InstallerExistingConfigTestBase {
 
-  /**
-   * {@inheritdoc}
-   */
-  protected $defaultTheme = 'stark';
-
   /**
    * {@inheritdoc}
    */
@@ -27,7 +22,7 @@ class InstallerExistingConfigNoSystemSiteTest extends InstallerExistingConfigTes
    * {@inheritdoc}
    */
   public function setUpSite() {
-    return;
+    // There are are errors. Therefore, there is nothing to do here.
   }
 
   /**
@@ -35,13 +30,13 @@ class InstallerExistingConfigNoSystemSiteTest extends InstallerExistingConfigTes
    */
   public function testConfigSync() {
     $this->htmlOutput(NULL);
-    $this->assertTitle('Configuration validation | Drupal');
-    $this->assertText('The configuration synchronization failed validation.');
-    $this->assertText('This import does not contain system.site configuration, so has been rejected.');
+    $this->assertSession()->titleEquals('Configuration validation | Drupal');
+    $this->assertSession()->pageTextContains('The configuration synchronization failed validation.');
+    $this->assertSession()->pageTextContains('This import does not contain system.site configuration, so has been rejected.');
 
     // Ensure there is no continuation button.
     $this->assertNoText('Save and continue');
-    $this->assertNoFieldById('edit-submit');
+    $this->assertSession()->buttonNotExists('edit-submit');
   }
 
   /**
