@@ -21,10 +21,11 @@ class InstallerTest extends InstallerTestBase {
    * Ensures that the user page is available after installation.
    */
   public function testInstaller() {
+    $this->assertNotNull(\Drupal::state()->get('system.css_js_query_string'), 'The dummy query string should be set during install');
     $this->assertSession()->addressEquals('user/1');
     $this->assertSession()->statusCodeEquals(200);
     // Confirm that we are logged-in after installation.
-    $this->assertText($this->rootUser->getAccountName());
+    $this->assertSession()->pageTextContains($this->rootUser->getAccountName());
 
     // Verify that the confirmation message appears.
     require_once $this->root . '/core/includes/install.inc';
@@ -34,7 +35,7 @@ class InstallerTest extends InstallerTestBase {
 
     // Ensure that the timezone is correct for sites under test after installing
     // interactively.
-    $this->assertEqual('Australia/Sydney', $this->config('system.date')->get('timezone.default'));
+    $this->assertEquals('Australia/Sydney', $this->config('system.date')->get('timezone.default'));
 
     // Ensure the profile has a weight of 1000.
     $module_extension_list = \Drupal::service('extension.list.module');
@@ -56,7 +57,7 @@ class InstallerTest extends InstallerTestBase {
     $this->assertRaw('<meta charset="utf-8" />');
 
     // Assert that the expected title is present.
-    $this->assertEqual('Choose language', $this->cssSelect('main h2')[0]->getText());
+    $this->assertEquals('Choose language', $this->cssSelect('main h2')[0]->getText());
 
     parent::setUpLanguage();
   }
@@ -70,7 +71,7 @@ class InstallerTest extends InstallerTestBase {
     copy($settings_services_file, $this->siteDirectory . '/services.yml');
     PerformanceTestRecorder::registerService($this->siteDirectory . '/services.yml', TRUE);
     // Assert that the expected title is present.
-    $this->assertEqual('Select an installation profile', $this->cssSelect('main h2')[0]->getText());
+    $this->assertEquals('Select an installation profile', $this->cssSelect('main h2')[0]->getText());
     $result = $this->xpath('//span[contains(@class, :class) and contains(text(), :text)]', [':class' => 'visually-hidden', ':text' => 'Select an installation profile']);
     $this->assertCount(1, $result, "Title/Label not displayed when '#title_display' => 'invisible' attribute is set");
 
@@ -82,14 +83,14 @@ class InstallerTest extends InstallerTestBase {
    */
   protected function setUpSettings() {
     // Assert that the expected title is present.
-    $this->assertEqual('Database configuration', $this->cssSelect('main h2')[0]->getText());
+    $this->assertEquals('Database configuration', $this->cssSelect('main h2')[0]->getText());
 
     // Assert that we use the by core supported database drivers by default and
     // not the ones from the driver_test module.
     $elements = $this->xpath('//label[@for="edit-driver-mysql"]');
-    $this->assertEqual('MySQL, MariaDB, Percona Server, or equivalent', current($elements)->getText());
+    $this->assertEquals('MySQL, MariaDB, Percona Server, or equivalent', current($elements)->getText());
     $elements = $this->xpath('//label[@for="edit-driver-pgsql"]');
-    $this->assertEqual('PostgreSQL', current($elements)->getText());
+    $this->assertEquals('PostgreSQL', current($elements)->getText());
 
     parent::setUpSettings();
   }
@@ -99,7 +100,7 @@ class InstallerTest extends InstallerTestBase {
    */
   protected function setUpSite() {
     // Assert that the expected title is present.
-    $this->assertEqual('Configure site', $this->cssSelect('main h2')[0]->getText());
+    $this->assertEquals('Configure site', $this->cssSelect('main h2')[0]->getText());
 
     // Test that SiteConfigureForm::buildForm() has made the site directory and
     // the settings file non-writable.
