@@ -2,6 +2,8 @@
 
 namespace Drupal\KernelTests\Core\Database;
 
+use Drupal\Core\Database\IntegrityConstraintViolationException;
+
 /**
  * Tests the insert builder.
  *
@@ -22,13 +24,13 @@ class InsertTest extends DatabaseTestBase {
     ]);
 
     // Check how many records are queued for insertion.
-    $this->assertIdentical($query->count(), 1, 'One record is queued for insertion.');
+    $this->assertSame(1, $query->count(), 'One record is queued for insertion.');
     $query->execute();
 
     $num_records_after = $this->connection->query('SELECT COUNT(*) FROM {test}')->fetchField();
     $this->assertSame($num_records_before + 1, (int) $num_records_after, 'Record inserts correctly.');
     $saved_age = $this->connection->query('SELECT [age] FROM {test} WHERE [name] = :name', [':name' => 'Yoko'])->fetchField();
-    $this->assertIdentical($saved_age, '29', 'Can retrieve after inserting.');
+    $this->assertSame('29', $saved_age, 'Can retrieve after inserting.');
   }
 
   /**
@@ -50,24 +52,24 @@ class InsertTest extends DatabaseTestBase {
     ]);
 
     // Check how many records are queued for insertion.
-    $this->assertIdentical($query->count(), 2, 'Two records are queued for insertion.');
+    $this->assertSame(2, $query->count(), 'Two records are queued for insertion.');
 
     // We should be able to say "use the field order".
     // This is not the recommended mechanism for most cases, but it should work.
     $query->values(['Moe', '32']);
 
     // Check how many records are queued for insertion.
-    $this->assertIdentical($query->count(), 3, 'Three records are queued for insertion.');
+    $this->assertSame(3, $query->count(), 'Three records are queued for insertion.');
     $query->execute();
 
     $num_records_after = (int) $this->connection->query('SELECT COUNT(*) FROM {test}')->fetchField();
     $this->assertSame($num_records_before + 3, $num_records_after, 'Record inserts correctly.');
     $saved_age = $this->connection->query('SELECT [age] FROM {test} WHERE [name] = :name', [':name' => 'Larry'])->fetchField();
-    $this->assertIdentical($saved_age, '30', 'Can retrieve after inserting.');
+    $this->assertSame('30', $saved_age, 'Can retrieve after inserting.');
     $saved_age = $this->connection->query('SELECT [age] FROM {test} WHERE [name] = :name', [':name' => 'Curly'])->fetchField();
-    $this->assertIdentical($saved_age, '31', 'Can retrieve after inserting.');
+    $this->assertSame('31', $saved_age, 'Can retrieve after inserting.');
     $saved_age = $this->connection->query('SELECT [age] FROM {test} WHERE [name] = :name', [':name' => 'Moe'])->fetchField();
-    $this->assertIdentical($saved_age, '32', 'Can retrieve after inserting.');
+    $this->assertSame('32', $saved_age, 'Can retrieve after inserting.');
   }
 
   /**
@@ -83,7 +85,7 @@ class InsertTest extends DatabaseTestBase {
       'age' => '30',
     ]);
     // Check how many records are queued for insertion.
-    $this->assertIdentical($query->count(), 1, 'One record is queued for insertion.');
+    $this->assertSame(1, $query->count(), 'One record is queued for insertion.');
     // This should run the insert, but leave the fields intact.
     $query->execute();
 
@@ -93,24 +95,24 @@ class InsertTest extends DatabaseTestBase {
       'name' => 'Curly',
     ]);
     // Check how many records are queued for insertion.
-    $this->assertIdentical($query->count(), 1, 'One record is queued for insertion.');
+    $this->assertSame(1, $query->count(), 'One record is queued for insertion.');
     $query->execute();
 
     // We should be able to say "use the field order".
     $query->values(['Moe', '32']);
 
     // Check how many records are queued for insertion.
-    $this->assertIdentical($query->count(), 1, 'One record is queued for insertion.');
+    $this->assertSame(1, $query->count(), 'One record is queued for insertion.');
     $query->execute();
 
     $num_records_after = $this->connection->query('SELECT COUNT(*) FROM {test}')->fetchField();
     $this->assertSame((int) $num_records_before + 3, (int) $num_records_after, 'Record inserts correctly.');
     $saved_age = $this->connection->query('SELECT [age] FROM {test} WHERE [name] = :name', [':name' => 'Larry'])->fetchField();
-    $this->assertIdentical($saved_age, '30', 'Can retrieve after inserting.');
+    $this->assertSame('30', $saved_age, 'Can retrieve after inserting.');
     $saved_age = $this->connection->query('SELECT [age] FROM {test} WHERE [name] = :name', [':name' => 'Curly'])->fetchField();
-    $this->assertIdentical($saved_age, '31', 'Can retrieve after inserting.');
+    $this->assertSame('31', $saved_age, 'Can retrieve after inserting.');
     $saved_age = $this->connection->query('SELECT [age] FROM {test} WHERE [name] = :name', [':name' => 'Moe'])->fetchField();
-    $this->assertIdentical($saved_age, '32', 'Can retrieve after inserting.');
+    $this->assertSame('32', $saved_age, 'Can retrieve after inserting.');
   }
 
   /**
@@ -126,11 +128,11 @@ class InsertTest extends DatabaseTestBase {
       ->values(['Moe', '32'])
       ->execute();
     $saved_age = $this->connection->query('SELECT [age] FROM {test} WHERE [name] = :name', [':name' => 'Larry'])->fetchField();
-    $this->assertIdentical($saved_age, '30', 'Can retrieve after inserting.');
+    $this->assertSame('30', $saved_age, 'Can retrieve after inserting.');
     $saved_age = $this->connection->query('SELECT [age] FROM {test} WHERE [name] = :name', [':name' => 'Curly'])->fetchField();
-    $this->assertIdentical($saved_age, '31', 'Can retrieve after inserting.');
+    $this->assertSame('31', $saved_age, 'Can retrieve after inserting.');
     $saved_age = $this->connection->query('SELECT [age] FROM {test} WHERE [name] = :name', [':name' => 'Moe'])->fetchField();
-    $this->assertIdentical($saved_age, '32', 'Can retrieve after inserting.');
+    $this->assertSame('32', $saved_age, 'Can retrieve after inserting.');
   }
 
   /**
@@ -144,7 +146,7 @@ class InsertTest extends DatabaseTestBase {
       ])
       ->execute();
 
-    $this->assertIdentical($id, '5', 'Auto-increment ID returned successfully.');
+    $this->assertSame('5', $id, 'Auto-increment ID returned successfully.');
   }
 
   /**
@@ -170,7 +172,7 @@ class InsertTest extends DatabaseTestBase {
       ->execute();
 
     $saved_age = $this->connection->query('SELECT [age] FROM {test} WHERE [name] = :name', [':name' => 'Meredith'])->fetchField();
-    $this->assertIdentical($saved_age, '30', 'Can retrieve after inserting.');
+    $this->assertSame('30', $saved_age, 'Can retrieve after inserting.');
   }
 
   /**
@@ -191,7 +193,7 @@ class InsertTest extends DatabaseTestBase {
       ->execute();
 
     $saved_age = $this->connection->query('SELECT [age] FROM {test_people_copy} WHERE [name] = :name', [':name' => 'Meredith'])->fetchField();
-    $this->assertIdentical($saved_age, '30', 'Can retrieve after inserting.');
+    $this->assertSame('30', $saved_age, 'Can retrieve after inserting.');
   }
 
   /**
@@ -208,4 +210,26 @@ class InsertTest extends DatabaseTestBase {
     $this->assertEquals('Update value 2', $saved_value);
   }
 
+  /**
+   * Tests insertion integrity violation with no default value for a column.
+   */
+  public function testInsertIntegrityViolation() {
+    // Remove the default from the 'age' column, so that inserting a record
+    // without its value specified will lead to integrity failure.
+    $this->connection->schema()->changeField('test', 'age', 'age', [
+      'description' => "The person's age",
+      'type' => 'int',
+      'unsigned' => TRUE,
+      'not null' => TRUE,
+    ]);
+
+    // Try inserting a record that misses the value for the 'age' column,
+    // should raise an IntegrityConstraintViolationException.
+    $this->expectException(IntegrityConstraintViolationException::class);
+    $this->connection->insert('test')
+      ->fields(['name'])
+      ->values(['name' => 'Elvis'])
+      ->execute();
+  }
+
 }
