@@ -31,7 +31,7 @@ class LoggingTest extends DatabaseTestBase {
     $this->assertCount(3, $queries, 'Correct number of queries recorded.');
 
     foreach ($queries as $query) {
-      $this->assertEqual(__FUNCTION__, $query['caller']['function'], 'Correct function in query log.');
+      $this->assertEquals(__FUNCTION__, $query['caller']['function'], 'Correct function in query log.');
     }
   }
 
@@ -72,8 +72,8 @@ class LoggingTest extends DatabaseTestBase {
     $queries1 = Database::getLog('testing1');
 
     $this->assertCount(2, $queries1, 'Recorded queries from all targets.');
-    $this->assertEqual('default', $queries1[0]['target'], 'First query used default target.');
-    $this->assertEqual('replica', $queries1[1]['target'], 'Second query used replica target.');
+    $this->assertEquals('default', $queries1[0]['target'], 'First query used default target.');
+    $this->assertEquals('replica', $queries1[1]['target'], 'Second query used replica target.');
   }
 
   /**
@@ -98,8 +98,8 @@ class LoggingTest extends DatabaseTestBase {
     $queries1 = Database::getLog('testing1');
 
     $this->assertCount(2, $queries1, 'Recorded queries from all targets.');
-    $this->assertEqual('default', $queries1[0]['target'], 'First query used default target.');
-    $this->assertEqual('default', $queries1[1]['target'], 'Second query used default target as fallback.');
+    $this->assertEquals('default', $queries1[0]['target'], 'First query used default target.');
+    $this->assertEquals('default', $queries1[1]['target'], 'Second query used default target as fallback.');
   }
 
   /**
@@ -135,7 +135,7 @@ class LoggingTest extends DatabaseTestBase {
   public function testGetLoggingWrongKey() {
     $result = Database::getLog('wrong');
 
-    $this->assertEqual([], $result, 'The function getLog with a wrong key returns an empty array.');
+    $this->assertEquals([], $result, 'The function getLog with a wrong key returns an empty array.');
   }
 
   /**
