@@ -34,8 +34,8 @@ class SelectCloneTest extends DatabaseTestBase {
     $query_result = $query->countQuery()->execute()->fetchField();
 
     // Make sure the cloned query has not been modified
-    $this->assertEqual(3, $clone_result, 'The cloned query returns the expected number of rows');
-    $this->assertEqual(2, $query_result, 'The query returns the expected number of rows');
+    $this->assertEquals(3, $clone_result, 'The cloned query returns the expected number of rows');
+    $this->assertEquals(2, $query_result, 'The query returns the expected number of rows');
   }
 
   /**
