@@ -44,7 +44,7 @@ class SelectComplexTest extends DatabaseTestBase {
       $last_priority = $record->$priority_field;
     }
 
-    $this->assertEqual(7, $num_records, 'Returned the correct number of rows.');
+    $this->assertEquals(7, $num_records, 'Returned the correct number of rows.');
   }
 
   /**
@@ -69,7 +69,7 @@ class SelectComplexTest extends DatabaseTestBase {
       $this->assertGreaterThanOrEqual(0, strcmp($record->$name_field, $last_name));
     }
 
-    $this->assertEqual(8, $num_records, 'Returned the correct number of rows.');
+    $this->assertEquals(8, $num_records, 'Returned the correct number of rows.');
   }
 
   /**
@@ -103,10 +103,10 @@ class SelectComplexTest extends DatabaseTestBase {
     ];
 
     foreach ($correct_results as $task => $count) {
-      $this->assertEqual($count, $records[$task], new FormattableMarkup("Correct number of '@task' records found.", ['@task' => $task]));
+      $this->assertEquals($count, $records[$task], new FormattableMarkup("Correct number of '@task' records found.", ['@task' => $task]));
     }
 
-    $this->assertEqual(6, $num_records, 'Returned the correct number of total rows.');
+    $this->assertEquals(6, $num_records, 'Returned the correct number of total rows.');
   }
 
   /**
@@ -138,10 +138,10 @@ class SelectComplexTest extends DatabaseTestBase {
     ];
 
     foreach ($correct_results as $task => $count) {
-      $this->assertEqual($count, $records[$task], new FormattableMarkup("Correct number of '@task' records found.", ['@task' => $task]));
+      $this->assertEquals($count, $records[$task], new FormattableMarkup("Correct number of '@task' records found.", ['@task' => $task]));
     }
 
-    $this->assertEqual(1, $num_records, 'Returned the correct number of total rows.');
+    $this->assertEquals(1, $num_records, 'Returned the correct number of total rows.');
   }
 
   /**
@@ -156,7 +156,7 @@ class SelectComplexTest extends DatabaseTestBase {
     $query->range(0, 2);
     $query_result = $query->countQuery()->execute()->fetchField();
 
-    $this->assertEqual(2, $query_result, 'Returned the correct number of rows.');
+    $this->assertEquals(2, $query_result, 'Returned the correct number of rows.');
   }
 
   /**
@@ -170,7 +170,7 @@ class SelectComplexTest extends DatabaseTestBase {
     $query->range(NULL, NULL);
     $query_result = $query->countQuery()->execute()->fetchField();
 
-    $this->assertEqual(4, $query_result, 'Returned the correct number of rows.');
+    $this->assertEquals(4, $query_result, 'Returned the correct number of rows.');
   }
 
   /**
@@ -182,7 +182,7 @@ class SelectComplexTest extends DatabaseTestBase {
     $query->distinct();
     $query_result = $query->countQuery()->execute()->fetchField();
 
-    $this->assertEqual(6, $query_result, 'Returned the correct number of rows.');
+    $this->assertEquals(6, $query_result, 'Returned the correct number of rows.');
   }
 
   /**
@@ -196,13 +196,13 @@ class SelectComplexTest extends DatabaseTestBase {
 
     $count = $query->countQuery()->execute()->fetchField();
 
-    $this->assertEqual(4, $count, 'Counted the correct number of records.');
+    $this->assertEquals(4, $count, 'Counted the correct number of records.');
 
     // Now make sure we didn't break the original query!  We should still have
     // all of the fields we asked for.
     $record = $query->execute()->fetch();
-    $this->assertEqual('George', $record->{$name_field}, 'Correct data retrieved.');
-    $this->assertEqual(27, $record->{$age_field}, 'Correct data retrieved.');
+    $this->assertEquals('George', $record->{$name_field}, 'Correct data retrieved.');
+    $this->assertEquals(27, $record->{$age_field}, 'Correct data retrieved.');
   }
 
   /**
@@ -216,7 +216,7 @@ class SelectComplexTest extends DatabaseTestBase {
     $query->addField('test', 'age');
     $query->addExpression('age + 1');
     $count = count($query->execute()->fetchCol());
-    $this->assertEqual(4, $count, 'Counted the correct number of records.');
+    $this->assertEquals(4, $count, 'Counted the correct number of records.');
   }
 
   /**
@@ -230,7 +230,7 @@ class SelectComplexTest extends DatabaseTestBase {
 
     // Check that the 'all_fields' statement is handled properly.
     $tables = $query->getTables();
-    $this->assertEqual(1, $tables['test']['all_fields'], 'Query correctly sets \'all_fields\' statement.');
+    $this->assertEquals(1, $tables['test']['all_fields'], 'Query correctly sets \'all_fields\' statement.');
     $tables = $count->getTables();
     $this->assertFalse(isset($tables['test']['all_fields']), 'Count query correctly unsets \'all_fields\' statement.');
 
@@ -239,14 +239,14 @@ class SelectComplexTest extends DatabaseTestBase {
     // The orderby string is different for PostgreSQL.
     // @see Drupal\Core\Database\Driver\pgsql\Select::orderBy()
     $db_type = Database::getConnection()->databaseType();
-    $this->assertEqual($db_type == 'pgsql' ? 'ASC NULLS FIRST' : 'ASC', $orderby['name'], 'Query correctly sets ordering clause.');
+    $this->assertEquals($db_type == 'pgsql' ? 'ASC NULLS FIRST' : 'ASC', $orderby['name'], 'Query correctly sets ordering clause.');
     $orderby = $count->getOrderBy();
     $this->assertFalse(isset($orderby['name']), 'Count query correctly unsets ordering clause.');
 
     // Make sure that the count query works.
     $count = $count->execute()->fetchField();
 
-    $this->assertEqual(4, $count, 'Counted the correct number of records.');
+    $this->assertEquals(4, $count, 'Counted the correct number of records.');
   }
 
   /**
@@ -260,11 +260,11 @@ class SelectComplexTest extends DatabaseTestBase {
     // records in the {test} table).
     $query = $this->connection->select('test');
     $query->fields('test', ['fail']);
-    $this->assertEqual(4, $query->countQuery()->execute()->fetchField(), 'Count Query removed fields');
+    $this->assertEquals(4, $query->countQuery()->execute()->fetchField(), 'Count Query removed fields');
 
     $query = $this->connection->select('test');
     $query->addExpression('fail');
-    $this->assertEqual(4, $query->countQuery()->execute()->fetchField(), 'Count Query removed expressions');
+    $this->assertEquals(4, $query->countQuery()->execute()->fetchField(), 'Count Query removed expressions');
   }
 
   /**
@@ -277,7 +277,7 @@ class SelectComplexTest extends DatabaseTestBase {
 
     $count = $query->countQuery()->execute()->fetchField();
 
-    $this->assertEqual(6, $count, 'Counted the correct number of records.');
+    $this->assertEquals(6, $count, 'Counted the correct number of records.');
   }
 
   /**
@@ -290,7 +290,7 @@ class SelectComplexTest extends DatabaseTestBase {
 
     $count = $query->countQuery()->execute()->fetchField();
 
-    $this->assertEqual(3, $count, 'Counted the correct number of records.');
+    $this->assertEquals(3, $count, 'Counted the correct number of records.');
 
     // Use a column alias as, without one, the query can succeed for the wrong
     // reason.
@@ -302,7 +302,7 @@ class SelectComplexTest extends DatabaseTestBase {
 
     $count = $query->countQuery()->execute()->fetchField();
 
-    $this->assertEqual(3, $count, 'Counted the correct number of records.');
+    $this->assertEquals(3, $count, 'Counted the correct number of records.');
   }
 
   /**
@@ -319,7 +319,7 @@ class SelectComplexTest extends DatabaseTestBase {
     $query->condition(($this->connection->condition('OR'))->condition('age', 26)->condition('age', 27));
 
     $job = $query->execute()->fetchField();
-    $this->assertEqual('Songwriter', $job, 'Correct data retrieved.');
+    $this->assertEquals('Songwriter', $job, 'Correct data retrieved.');
   }
 
   /**
@@ -332,7 +332,7 @@ class SelectComplexTest extends DatabaseTestBase {
     $query->addField($alias, 'job', 'other_job');
     $query->where("$alias.name <> test.name");
     $crowded_job = $query->execute()->fetch();
-    $this->assertEqual($crowded_job->other_job, $crowded_job->job, 'Correctly joined same table twice.');
+    $this->assertEquals($crowded_job->other_job, $crowded_job->job, 'Correctly joined same table twice.');
     $this->assertNotEquals($crowded_job->other_name, $crowded_job->name, 'Correctly joined same table twice.');
   }
 
@@ -418,7 +418,7 @@ class SelectComplexTest extends DatabaseTestBase {
       $last_priority = $record->$priority_field;
     }
 
-    $this->assertEqual(7, $num_records, 'Returned the correct number of rows.');
+    $this->assertEquals(7, $num_records, 'Returned the correct number of rows.');
 
     // Test a condition object that creates placeholders.
     $t1_name = 'John';
@@ -432,11 +432,11 @@ class SelectComplexTest extends DatabaseTestBase {
     $query->addField('t2', 'name', 't2_name');
 
     $num_records = $query->countQuery()->execute()->fetchField();
-    $this->assertEqual(1, $num_records, 'Query expected to return 1 row. Actual: ' . $num_records);
+    $this->assertEquals(1, $num_records, 'Query expected to return 1 row. Actual: ' . $num_records);
     if ($num_records == 1) {
       $record = $query->execute()->fetchObject();
-      $this->assertEqual($t1_name, $record->t1_name, 'Query expected to retrieve name ' . $t1_name . ' from table t1. Actual: ' . $record->t1_name);
-      $this->assertEqual($t2_name, $record->t2_name, 'Query expected to retrieve name ' . $t2_name . ' from table t2. Actual: ' . $record->t2_name);
+      $this->assertEquals($t1_name, $record->t1_name, 'Query expected to retrieve name ' . $t1_name . ' from table t1. Actual: ' . $record->t1_name);
+      $this->assertEquals($t2_name, $record->t2_name, 'Query expected to retrieve name ' . $t2_name . ' from table t2. Actual: ' . $record->t2_name);
     }
   }
 
