@@ -2,8 +2,6 @@
 
 namespace Drupal\KernelTests\Core\Database;
 
-use Drupal\Core\Database\Query\Condition;
-
 /**
  * Tests the Update query builder, complex queries.
  *
@@ -17,15 +15,15 @@ class UpdateComplexTest extends DatabaseTestBase {
   public function testOrConditionUpdate() {
     $update = $this->connection->update('test')
       ->fields(['job' => 'Musician'])
-      ->condition((new Condition('OR'))
+      ->condition(($this->connection->condition('OR'))
         ->condition('name', 'John')
         ->condition('name', 'Paul')
       );
     $num_updated = $update->execute();
-    $this->assertIdentical($num_updated, 2, 'Updated 2 records.');
+    $this->assertSame(2, $num_updated, 'Updated 2 records.');
 
     $num_matches = $this->connection->query('SELECT COUNT(*) FROM {test} WHERE [job] = :job', [':job' => 'Musician'])->fetchField();
-    $this->assertIdentical($num_matches, '2', 'Updated fields successfully.');
+    $this->assertSame('2', $num_matches, 'Updated fields successfully.');
   }
 
   /**
@@ -36,10 +34,10 @@ class UpdateComplexTest extends DatabaseTestBase {
       ->fields(['job' => 'Musician'])
       ->condition('name', ['John', 'Paul'], 'IN')
       ->execute();
-    $this->assertIdentical($num_updated, 2, 'Updated 2 records.');
+    $this->assertSame(2, $num_updated, 'Updated 2 records.');
 
     $num_matches = $this->connection->query('SELECT COUNT(*) FROM {test} WHERE [job] = :job', [':job' => 'Musician'])->fetchField();
-    $this->assertIdentical($num_matches, '2', 'Updated fields successfully.');
+    $this->assertSame('2', $num_matches, 'Updated fields successfully.');
   }
 
   /**
@@ -52,10 +50,10 @@ class UpdateComplexTest extends DatabaseTestBase {
       ->fields(['job' => 'Musician'])
       ->condition('name', ['John', 'Paul', 'George'], 'NoT IN')
       ->execute();
-    $this->assertIdentical($num_updated, 1, 'Updated 1 record.');
+    $this->assertSame(1, $num_updated, 'Updated 1 record.');
 
     $num_matches = $this->connection->query('SELECT COUNT(*) FROM {test} WHERE [job] = :job', [':job' => 'Musician'])->fetchField();
-    $this->assertIdentical($num_matches, '1', 'Updated fields successfully.');
+    $this->assertSame('1', $num_matches, 'Updated fields successfully.');
   }
 
   /**
@@ -66,10 +64,10 @@ class UpdateComplexTest extends DatabaseTestBase {
       ->fields(['job' => 'Musician'])
       ->condition('age', [25, 26], 'BETWEEN')
       ->execute();
-    $this->assertIdentical($num_updated, 2, 'Updated 2 records.');
+    $this->assertSame(2, $num_updated, 'Updated 2 records.');
 
     $num_matches = $this->connection->query('SELECT COUNT(*) FROM {test} WHERE [job] = :job', [':job' => 'Musician'])->fetchField();
-    $this->assertIdentical($num_matches, '2', 'Updated fields successfully.');
+    $this->assertSame('2', $num_matches, 'Updated fields successfully.');
   }
 
   /**
@@ -80,10 +78,10 @@ class UpdateComplexTest extends DatabaseTestBase {
       ->fields(['job' => 'Musician'])
       ->condition('name', '%ge%', 'LIKE')
       ->execute();
-    $this->assertIdentical($num_updated, 1, 'Updated 1 record.');
+    $this->assertSame(1, $num_updated, 'Updated 1 record.');
 
     $num_matches = $this->connection->query('SELECT COUNT(*) FROM {test} WHERE [job] = :job', [':job' => 'Musician'])->fetchField();
-    $this->assertIdentical($num_matches, '1', 'Updated fields successfully.');
+    $this->assertSame('1', $num_matches, 'Updated fields successfully.');
   }
 
   /**
@@ -96,15 +94,15 @@ class UpdateComplexTest extends DatabaseTestBase {
       ->fields(['job' => 'Musician'])
       ->expression('age', 'age + :age', [':age' => 4])
       ->execute();
-    $this->assertIdentical($num_updated, 1, 'Updated 1 record.');
+    $this->assertSame(1, $num_updated, 'Updated 1 record.');
 
     $num_matches = $this->connection->query('SELECT COUNT(*) FROM {test} WHERE [job] = :job', [':job' => 'Musician'])->fetchField();
-    $this->assertIdentical($num_matches, '1', 'Updated fields successfully.');
+    $this->assertSame('1', $num_matches, 'Updated fields successfully.');
 
     $person = $this->connection->query('SELECT * FROM {test} WHERE [name] = :name', [':name' => 'Ringo'])->fetch();
-    $this->assertEqual($person->name, 'Ringo', 'Name set correctly.');
-    $this->assertEqual($person->age, $before_age + 4, 'Age set correctly.');
-    $this->assertEqual($person->job, 'Musician', 'Job set correctly.');
+    $this->assertEquals('Ringo', $person->name, 'Name set correctly.');
+    $this->assertEquals($before_age + 4, $person->age, 'Age set correctly.');
+    $this->assertEquals('Musician', $person->job, 'Job set correctly.');
   }
 
   /**
@@ -116,10 +114,10 @@ class UpdateComplexTest extends DatabaseTestBase {
       ->condition('name', 'Ringo')
       ->expression('age', 'age + :age', [':age' => 4])
       ->execute();
-    $this->assertIdentical($num_updated, 1, 'Updated 1 record.');
+    $this->assertSame(1, $num_updated, 'Updated 1 record.');
 
     $after_age = $this->connection->query('SELECT [age] FROM {test} WHERE [name] = :name', [':name' => 'Ringo'])->fetchField();
-    $this->assertEqual($before_age + 4, $after_age, 'Age updated correctly');
+    $this->assertEquals($before_age + 4, $after_age, 'Age updated correctly');
   }
 
   /**
@@ -138,8 +136,8 @@ class UpdateComplexTest extends DatabaseTestBase {
     $num_updated = $query->execute();
     $after_age = $this->connection->query('SELECT [age] FROM {test} WHERE [name] = :name', [':name' => 'Ringo'])->fetchField();
     $expected_age = $select->execute()->fetchField();
-    $this->assertEqual($after_age, $expected_age);
-    $this->assertEqual(1, $num_updated, t('Expected 1 row to be updated in subselect update query.'));
+    $this->assertEquals($expected_age, $after_age);
+    $this->assertEquals(1, $num_updated, t('Expected 1 row to be updated in subselect update query.'));
   }
 
 }
