@@ -90,7 +90,7 @@ class ContentEntityChangedTest extends EntityKernelTestBase {
       'Changed and created time of original language can be assumed to be identical.'
     );
 
-    $this->assertEqual($entity->getChangedTimeAcrossTranslations(), $entity->getChangedTime(), 'Changed time of original language is the same as changed time across all translations.');
+    $this->assertEquals($entity->getChangedTimeAcrossTranslations(), $entity->getChangedTime(), 'Changed time of original language is the same as changed time across all translations.');
 
     $changed_en = $entity->getChangedTime();
 
@@ -99,22 +99,22 @@ class ContentEntityChangedTest extends EntityKernelTestBase {
 
     $entity->save();
 
-    $this->assertEqual($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
+    $this->assertEquals($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
 
     $this->assertTrue(
       $german->getChangedTime() > $entity->getChangedTime(),
       'Changed time of the German translation is newer then the original language.'
     );
 
-    $this->assertEqual($entity->getChangedTimeAcrossTranslations(), $german->getChangedTime(), 'Changed time of the German translation is the newest time across all translations.');
+    $this->assertEquals($entity->getChangedTimeAcrossTranslations(), $german->getChangedTime(), 'Changed time of the German translation is the newest time across all translations.');
 
     $changed_de = $german->getChangedTime();
 
     $entity->save();
 
-    $this->assertEqual($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
+    $this->assertEquals($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
 
-    $this->assertEqual($changed_de, $german->getChangedTime(), 'Changed time of the German translation did not change.');
+    $this->assertEquals($changed_de, $german->getChangedTime(), 'Changed time of the German translation did not change.');
 
     // Update a non-translatable field to make sure that the changed timestamp
     // is updated for all translations.
@@ -144,23 +144,23 @@ class ContentEntityChangedTest extends EntityKernelTestBase {
       'Changed time of original language did change.'
     );
 
-    $this->assertEqual($changed_de, $german->getChangedTime(), 'Changed time of the German translation did not change.');
+    $this->assertEquals($changed_de, $german->getChangedTime(), 'Changed time of the German translation did not change.');
 
     $this->assertTrue(
       $entity->getChangedTime() > $german->getChangedTime(),
       'Changed time of original language is newer then the German translation.'
     );
 
-    $this->assertEqual($entity->getChangedTimeAcrossTranslations(), $entity->getChangedTime(), 'Changed time of the original language is the newest time across all translations.');
+    $this->assertEquals($entity->getChangedTimeAcrossTranslations(), $entity->getChangedTime(), 'Changed time of the original language is the newest time across all translations.');
 
     $changed_en = $entity->getChangedTime();
 
     // Save entity without any changes.
     $entity->save();
 
-    $this->assertEqual($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
+    $this->assertEquals($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
 
-    $this->assertEqual($changed_de, $german->getChangedTime(), 'Changed time of the German translation did not change.');
+    $this->assertEquals($changed_de, $german->getChangedTime(), 'Changed time of the German translation did not change.');
 
     // At this point the changed time of the original language (en) is newer
     // than the changed time of the German translation. Now test that entity
@@ -168,12 +168,12 @@ class ContentEntityChangedTest extends EntityKernelTestBase {
     $query = $this->mulChangedStorage->getQuery()->accessCheck(FALSE);
     $ids = $query->condition('changed', $changed_en)->execute();
 
-    $this->assertEqual($entity->id(), reset($ids), 'Entity query can access changed time of original language.');
+    $this->assertEquals($entity->id(), reset($ids), 'Entity query can access changed time of original language.');
 
     $query = $this->mulChangedStorage->getQuery()->accessCheck(FALSE);
     $ids = $query->condition('changed', $changed_en, '=', 'en')->execute();
 
-    $this->assertEqual($entity->id(), reset($ids), 'Entity query can access changed time of original language by setting the original language as condition.');
+    $this->assertEquals($entity->id(), reset($ids), 'Entity query can access changed time of original language by setting the original language as condition.');
 
     $query = $this->mulChangedStorage->getQuery()->accessCheck(FALSE);
     $ids = $query->condition('changed', $changed_de, '=', 'en')->execute();
@@ -186,7 +186,7 @@ class ContentEntityChangedTest extends EntityKernelTestBase {
     $query = $this->mulChangedStorage->getQuery()->accessCheck(FALSE);
     $ids = $query->condition('changed', $changed_en)->condition('default_langcode', '1')->execute();
 
-    $this->assertEqual($entity->id(), reset($ids), 'Entity query can access changed time of default language.');
+    $this->assertEquals($entity->id(), reset($ids), 'Entity query can access changed time of default language.');
 
     $query = $this->mulChangedStorage->getQuery()->accessCheck(FALSE);
     $ids = $query->condition('changed', $changed_de)->condition('default_langcode', '1')->execute();
@@ -199,12 +199,12 @@ class ContentEntityChangedTest extends EntityKernelTestBase {
     $query = $this->mulChangedStorage->getQuery()->accessCheck(FALSE);
     $ids = $query->condition('changed', $changed_de)->execute();
 
-    $this->assertEqual($entity->id(), reset($ids), 'Entity query can access changed time of the German translation.');
+    $this->assertEquals($entity->id(), reset($ids), 'Entity query can access changed time of the German translation.');
 
     $query = $this->mulChangedStorage->getQuery()->accessCheck(FALSE);
     $ids = $query->condition('changed', $changed_de, '=', 'de')->execute();
 
-    $this->assertEqual($entity->id(), reset($ids), 'Entity query can access changed time of the German translation.');
+    $this->assertEquals($entity->id(), reset($ids), 'Entity query can access changed time of the German translation.');
 
     $query = $this->mulChangedStorage->getQuery();
     $ids = $query->condition('changed', $changed_en, '=', 'de')->execute();
@@ -217,17 +217,17 @@ class ContentEntityChangedTest extends EntityKernelTestBase {
     $query = $this->mulChangedStorage->getQuery();
     $ids = $query->condition('changed', $changed_de, '>')->execute();
 
-    $this->assertEqual($entity->id(), reset($ids), 'Entity query can access changed time regardless of translation.');
+    $this->assertEquals($entity->id(), reset($ids), 'Entity query can access changed time regardless of translation.');
 
     $query = $this->mulChangedStorage->getQuery();
     $ids = $query->condition('changed', $changed_en, '<')->execute();
 
-    $this->assertEqual($entity->id(), reset($ids), 'Entity query can access changed time regardless of translation.');
+    $this->assertEquals($entity->id(), reset($ids), 'Entity query can access changed time regardless of translation.');
 
     $query = $this->mulChangedStorage->getQuery();
     $ids = $query->condition('changed', 0, '>')->execute();
 
-    $this->assertEqual($entity->id(), reset($ids), 'Entity query can access changed time regardless of translation.');
+    $this->assertEquals($entity->id(), reset($ids), 'Entity query can access changed time regardless of translation.');
 
     $query = $this->mulChangedStorage->getQuery();
     $ids = $query->condition('changed', $changed_en, '>')->execute();
@@ -267,7 +267,7 @@ class ContentEntityChangedTest extends EntityKernelTestBase {
       'Changed and created time of original language can be assumed to be identical.'
     );
 
-    $this->assertEqual($entity->getChangedTimeAcrossTranslations(), $entity->getChangedTime(), 'Changed time of original language is the same as changed time across all translations.');
+    $this->assertEquals($entity->getChangedTimeAcrossTranslations(), $entity->getChangedTime(), 'Changed time of original language is the same as changed time across all translations.');
 
     $this->assertTrue(
       $this->getRevisionTranslationAffectedFlag($entity),
@@ -280,7 +280,7 @@ class ContentEntityChangedTest extends EntityKernelTestBase {
     // Save entity without any changes but create new revision.
     $entity->save();
     // A new revision without any changes should not set a new changed time.
-    $this->assertEqual($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
+    $this->assertEquals($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
 
     $this->assertFalse(
       $this->getRevisionTranslationAffectedFlag($entity),
@@ -308,14 +308,14 @@ class ContentEntityChangedTest extends EntityKernelTestBase {
 
     $entity->save();
 
-    $this->assertEqual($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
+    $this->assertEquals($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
 
     $this->assertTrue(
       $german->getChangedTime() > $entity->getChangedTime(),
       'Changed time of the German translation is newer then the original language.'
     );
 
-    $this->assertEqual($entity->getChangedTimeAcrossTranslations(), $german->getChangedTime(), 'Changed time of the German translation is the newest time across all translations.');
+    $this->assertEquals($entity->getChangedTimeAcrossTranslations(), $german->getChangedTime(), 'Changed time of the German translation is the newest time across all translations.');
 
     $this->assertTrue(
       $this->getRevisionTranslationAffectedFlag($entity),
@@ -333,9 +333,9 @@ class ContentEntityChangedTest extends EntityKernelTestBase {
     // Save entity without any changes but create new revision.
     $entity->save();
 
-    $this->assertEqual($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
+    $this->assertEquals($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
 
-    $this->assertEqual($changed_de, $german->getChangedTime(), 'Changed time of the German translation did not change.');
+    $this->assertEquals($changed_de, $german->getChangedTime(), 'Changed time of the German translation did not change.');
 
     $this->assertFalse(
       $this->getRevisionTranslationAffectedFlag($entity),
@@ -351,14 +351,14 @@ class ContentEntityChangedTest extends EntityKernelTestBase {
     $german->setOwner($user2);
     $entity->save();
 
-    $this->assertEqual($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
+    $this->assertEquals($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
 
     $this->assertTrue(
       $german->getChangedTime() > $changed_de,
       'Changed time of the German translation did change.'
     );
 
-    $this->assertEqual($entity->getChangedTimeAcrossTranslations(), $german->getChangedTime(), 'Changed time of the German translation is the newest time across all translations.');
+    $this->assertEquals($entity->getChangedTimeAcrossTranslations(), $german->getChangedTime(), 'Changed time of the German translation is the newest time across all translations.');
 
     $this->assertFalse(
       $this->getRevisionTranslationAffectedFlag($entity),
@@ -375,7 +375,7 @@ class ContentEntityChangedTest extends EntityKernelTestBase {
     $entity->setNewRevision();
     $entity->save();
 
-    $this->assertEqual($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
+    $this->assertEquals($changed_en, $entity->getChangedTime(), 'Changed time of original language did not change.');
 
     $this->assertTrue(
       $french->getChangedTime() > $entity->getChangedTime(),
@@ -387,7 +387,7 @@ class ContentEntityChangedTest extends EntityKernelTestBase {
       'Changed time of the French translation is newer then the German translation.'
     );
 
-    $this->assertEqual($entity->getChangedTimeAcrossTranslations(), $french->getChangedTime(), 'Changed time of the French translation is the newest time across all translations.');
+    $this->assertEquals($entity->getChangedTimeAcrossTranslations(), $french->getChangedTime(), 'Changed time of the French translation is the newest time across all translations.');
 
     $this->assertFalse(
       $this->getRevisionTranslationAffectedFlag($entity),
