@@ -120,38 +120,38 @@ class EntityFieldTest extends EntityKernelTestBase {
     $this->assertInstanceOf(FieldItemListInterface::class, $entity->name);
     $this->assertInstanceOf(FieldItemInterface::class, $entity->name[0]);
 
-    $this->assertEqual($this->entityName, $entity->name->value, new FormattableMarkup('%entity_type: Name value can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($this->entityName, $entity->name[0]->value, new FormattableMarkup('%entity_type: Name value can be read through list access.', ['%entity_type' => $entity_type]));
-    $this->assertEqual([0 => ['value' => $this->entityName]], $entity->name->getValue(), new FormattableMarkup('%entity_type: Plain field value returned.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($this->entityName, $entity->name->value, new FormattableMarkup('%entity_type: Name value can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($this->entityName, $entity->name[0]->value, new FormattableMarkup('%entity_type: Name value can be read through list access.', ['%entity_type' => $entity_type]));
+    $this->assertEquals([0 => ['value' => $this->entityName]], $entity->name->getValue(), new FormattableMarkup('%entity_type: Plain field value returned.', ['%entity_type' => $entity_type]));
 
     // Change the name.
     $new_name = $this->randomMachineName();
     $entity->name->value = $new_name;
-    $this->assertEqual($new_name, $entity->name->value, new FormattableMarkup('%entity_type: Name can be updated and read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual([0 => ['value' => $new_name]], $entity->name->getValue(), new FormattableMarkup('%entity_type: Plain field value reflects the update.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($new_name, $entity->name->value, new FormattableMarkup('%entity_type: Name can be updated and read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals([0 => ['value' => $new_name]], $entity->name->getValue(), new FormattableMarkup('%entity_type: Plain field value reflects the update.', ['%entity_type' => $entity_type]));
 
     $new_name = $this->randomMachineName();
     $entity->name[0]->value = $new_name;
-    $this->assertEqual($new_name, $entity->name->value, new FormattableMarkup('%entity_type: Name can be updated and read through list access.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($new_name, $entity->name->value, new FormattableMarkup('%entity_type: Name can be updated and read through list access.', ['%entity_type' => $entity_type]));
 
     // Access the user field.
     $this->assertInstanceOf(FieldItemListInterface::class, $entity->user_id);
     $this->assertInstanceOf(FieldItemInterface::class, $entity->user_id[0]);
 
-    $this->assertEqual($this->entityUser->id(), $entity->user_id->target_id, new FormattableMarkup('%entity_type: User id can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($this->entityUser->getAccountName(), $entity->user_id->entity->name->value, new FormattableMarkup('%entity_type: User name can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($this->entityUser->id(), $entity->user_id->target_id, new FormattableMarkup('%entity_type: User id can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($this->entityUser->getAccountName(), $entity->user_id->entity->name->value, new FormattableMarkup('%entity_type: User name can be read.', ['%entity_type' => $entity_type]));
 
     // Change the assigned user by entity.
     $new_user1 = $this->createUser();
     $entity->user_id->entity = $new_user1;
-    $this->assertEqual($new_user1->id(), $entity->user_id->target_id, new FormattableMarkup('%entity_type: Updated user id can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($new_user1->getAccountName(), $entity->user_id->entity->name->value, new FormattableMarkup('%entity_type: Updated username value can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($new_user1->id(), $entity->user_id->target_id, new FormattableMarkup('%entity_type: Updated user id can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($new_user1->getAccountName(), $entity->user_id->entity->name->value, new FormattableMarkup('%entity_type: Updated username value can be read.', ['%entity_type' => $entity_type]));
 
     // Change the assigned user by id.
     $new_user2 = $this->createUser();
     $entity->user_id->target_id = $new_user2->id();
-    $this->assertEqual($new_user2->id(), $entity->user_id->target_id, new FormattableMarkup('%entity_type: Updated user id can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($new_user2->getAccountName(), $entity->user_id->entity->name->value, new FormattableMarkup('%entity_type: Updated username value can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($new_user2->id(), $entity->user_id->target_id, new FormattableMarkup('%entity_type: Updated user id can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($new_user2->getAccountName(), $entity->user_id->entity->name->value, new FormattableMarkup('%entity_type: Updated username value can be read.', ['%entity_type' => $entity_type]));
 
     // Try unsetting a field property.
     $entity->name->value = NULL;
@@ -163,13 +163,13 @@ class EntityFieldTest extends EntityKernelTestBase {
     // Test setting the values via the typed data API works as well.
     // Change the assigned user by entity.
     $entity->user_id->first()->get('entity')->setValue($new_user2);
-    $this->assertEqual($new_user2->id(), $entity->user_id->target_id, new FormattableMarkup('%entity_type: Updated user id can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($new_user2->getAccountName(), $entity->user_id->entity->name->value, new FormattableMarkup('%entity_type: Updated user name value can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($new_user2->id(), $entity->user_id->target_id, new FormattableMarkup('%entity_type: Updated user id can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($new_user2->getAccountName(), $entity->user_id->entity->name->value, new FormattableMarkup('%entity_type: Updated user name value can be read.', ['%entity_type' => $entity_type]));
 
     // Change the assigned user by id.
     $entity->user_id->first()->get('target_id')->setValue($new_user2->id());
-    $this->assertEqual($new_user2->id(), $entity->user_id->target_id, new FormattableMarkup('%entity_type: Updated user id can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($new_user2->getAccountName(), $entity->user_id->entity->name->value, new FormattableMarkup('%entity_type: Updated user name value can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($new_user2->id(), $entity->user_id->target_id, new FormattableMarkup('%entity_type: Updated user id can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($new_user2->getAccountName(), $entity->user_id->entity->name->value, new FormattableMarkup('%entity_type: Updated user name value can be read.', ['%entity_type' => $entity_type]));
 
     // Try unsetting a field.
     $entity->name->first()->get('value')->setValue(NULL);
@@ -187,8 +187,8 @@ class EntityFieldTest extends EntityKernelTestBase {
       ]);
     // Access the property object, and set a value.
     $entity2->user_id->first()->get('target_id')->setValue($new_user2->id());
-    $this->assertEqual($new_user2->id(), $entity2->user_id->target_id, new FormattableMarkup('%entity_type: Updated user id can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($new_user2->name->value, $entity2->user_id->entity->name->value, new FormattableMarkup('%entity_type: Updated user name value can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($new_user2->id(), $entity2->user_id->target_id, new FormattableMarkup('%entity_type: Updated user id can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($new_user2->name->value, $entity2->user_id->entity->name->value, new FormattableMarkup('%entity_type: Updated user name value can be read.', ['%entity_type' => $entity_type]));
 
     // Test using isset(), empty() and unset().
     $entity->name->value = 'test unset';
@@ -237,25 +237,25 @@ class EntityFieldTest extends EntityKernelTestBase {
 
     // Access the language field.
     $langcode_key = $this->entityTypeManager->getDefinition($entity_type)->getKey('langcode');
-    $this->assertEqual($langcode, $entity->{$langcode_key}->value, new FormattableMarkup('%entity_type: Language code can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual(\Drupal::languageManager()->getLanguage($langcode), $entity->{$langcode_key}->language, new FormattableMarkup('%entity_type: Language object can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($langcode, $entity->{$langcode_key}->value, new FormattableMarkup('%entity_type: Language code can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals(\Drupal::languageManager()->getLanguage($langcode), $entity->{$langcode_key}->language, new FormattableMarkup('%entity_type: Language object can be read.', ['%entity_type' => $entity_type]));
 
     // Change the language by code.
     $entity->{$langcode_key}->value = \Drupal::languageManager()->getDefaultLanguage()->getId();
-    $this->assertEqual(\Drupal::languageManager()->getDefaultLanguage()->getId(), $entity->{$langcode_key}->value, new FormattableMarkup('%entity_type: Language code can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual(\Drupal::languageManager()->getDefaultLanguage(), $entity->{$langcode_key}->language, new FormattableMarkup('%entity_type: Language object can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals(\Drupal::languageManager()->getDefaultLanguage()->getId(), $entity->{$langcode_key}->value, new FormattableMarkup('%entity_type: Language code can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals(\Drupal::languageManager()->getDefaultLanguage(), $entity->{$langcode_key}->language, new FormattableMarkup('%entity_type: Language object can be read.', ['%entity_type' => $entity_type]));
 
     // Revert language by code then try setting it by language object.
     $entity->{$langcode_key}->value = $langcode;
     $entity->{$langcode_key}->language = \Drupal::languageManager()->getDefaultLanguage();
-    $this->assertEqual(\Drupal::languageManager()->getDefaultLanguage()->getId(), $entity->{$langcode_key}->value, new FormattableMarkup('%entity_type: Language code can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual(\Drupal::languageManager()->getDefaultLanguage(), $entity->{$langcode_key}->language, new FormattableMarkup('%entity_type: Language object can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals(\Drupal::languageManager()->getDefaultLanguage()->getId(), $entity->{$langcode_key}->value, new FormattableMarkup('%entity_type: Language code can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals(\Drupal::languageManager()->getDefaultLanguage(), $entity->{$langcode_key}->language, new FormattableMarkup('%entity_type: Language object can be read.', ['%entity_type' => $entity_type]));
 
     // Access the text field and test updating.
-    $this->assertEqual($this->entityFieldText, $entity->field_test_text->value, new FormattableMarkup('%entity_type: Text field can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($this->entityFieldText, $entity->field_test_text->value, new FormattableMarkup('%entity_type: Text field can be read.', ['%entity_type' => $entity_type]));
     $new_text = $this->randomMachineName();
     $entity->field_test_text->value = $new_text;
-    $this->assertEqual($new_text, $entity->field_test_text->value, new FormattableMarkup('%entity_type: Updated text field can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($new_text, $entity->field_test_text->value, new FormattableMarkup('%entity_type: Updated text field can be read.', ['%entity_type' => $entity_type]));
 
     // Test creating the entity by passing in plain values.
     $this->entityName = $this->randomMachineName();
@@ -272,10 +272,10 @@ class EntityFieldTest extends EntityKernelTestBase {
         'user_id' => $user_item,
         'field_test_text' => $text_item,
       ]);
-    $this->assertEqual($this->entityName, $entity->name->value, new FormattableMarkup('%entity_type: Name value can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($this->entityUser->id(), $entity->user_id->target_id, new FormattableMarkup('%entity_type: User id can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($this->entityUser->getAccountName(), $entity->user_id->entity->name->value, new FormattableMarkup('%entity_type: User name can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($this->entityFieldText, $entity->field_test_text->value, new FormattableMarkup('%entity_type: Text field can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($this->entityName, $entity->name->value, new FormattableMarkup('%entity_type: Name value can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($this->entityUser->id(), $entity->user_id->target_id, new FormattableMarkup('%entity_type: User id can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($this->entityUser->getAccountName(), $entity->user_id->entity->name->value, new FormattableMarkup('%entity_type: User name can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($this->entityFieldText, $entity->field_test_text->value, new FormattableMarkup('%entity_type: Text field can be read.', ['%entity_type' => $entity_type]));
 
     // Tests copying field values by assigning the TypedData objects.
     $entity2 = $this->createTestEntity($entity_type);
@@ -283,9 +283,9 @@ class EntityFieldTest extends EntityKernelTestBase {
     $entity2->user_id = $entity->user_id;
     $entity2->field_test_text = $entity->field_test_text;
     $this->assertFalse($entity->name === $entity2->name, new FormattableMarkup('%entity_type: Copying properties results in a different field object.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($entity->name->value, $entity2->name->value, new FormattableMarkup('%entity_type: Name field copied.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($entity->user_id->target_id, $entity2->user_id->target_id, new FormattableMarkup('%entity_type: User id field copied.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($entity->field_test_text->value, $entity2->field_test_text->value, new FormattableMarkup('%entity_type: Text field copied.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($entity->name->value, $entity2->name->value, new FormattableMarkup('%entity_type: Name field copied.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($entity->user_id->target_id, $entity2->user_id->target_id, new FormattableMarkup('%entity_type: User id field copied.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($entity->field_test_text->value, $entity2->field_test_text->value, new FormattableMarkup('%entity_type: Text field copied.', ['%entity_type' => $entity_type]));
 
     // Tests that assigning TypedData objects to non-field properties keeps the
     // assigned value as is.
@@ -295,19 +295,19 @@ class EntityFieldTest extends EntityKernelTestBase {
 
     // Tests adding a value to a field item list.
     $entity->name[] = 'Another name';
-    $this->assertEqual('Another name', $entity->name[1]->value, new FormattableMarkup('%entity_type: List item added via [] and the first property.', ['%entity_type' => $entity_type]));
+    $this->assertEquals('Another name', $entity->name[1]->value, new FormattableMarkup('%entity_type: List item added via [] and the first property.', ['%entity_type' => $entity_type]));
     $entity->name[] = ['value' => 'Third name'];
-    $this->assertEqual('Third name', $entity->name[2]->value, new FormattableMarkup('%entity_type: List item added via [] and an array of properties.', ['%entity_type' => $entity_type]));
+    $this->assertEquals('Third name', $entity->name[2]->value, new FormattableMarkup('%entity_type: List item added via [] and an array of properties.', ['%entity_type' => $entity_type]));
     $entity->name[3] = ['value' => 'Fourth name'];
-    $this->assertEqual('Fourth name', $entity->name[3]->value, new FormattableMarkup('%entity_type: List item added via offset and an array of properties.', ['%entity_type' => $entity_type]));
+    $this->assertEquals('Fourth name', $entity->name[3]->value, new FormattableMarkup('%entity_type: List item added via offset and an array of properties.', ['%entity_type' => $entity_type]));
     unset($entity->name[3]);
 
     // Test removing and empty-ing list items.
     $this->assertCount(3, $entity->name, new FormattableMarkup('%entity_type: List has 3 items.', ['%entity_type' => $entity_type]));
     unset($entity->name[1]);
     $this->assertCount(2, $entity->name, new FormattableMarkup('%entity_type: Second list item has been removed.', ['%entity_type' => $entity_type]));
-    $this->assertEqual('Third name', $entity->name[1]->value, new FormattableMarkup('%entity_type: The subsequent items have been shifted up.', ['%entity_type' => $entity_type]));
-    $this->assertEqual(1, $entity->name[1]->getName(), new FormattableMarkup('%entity_type: The items names have been updated to their new delta.', ['%entity_type' => $entity_type]));
+    $this->assertEquals('Third name', $entity->name[1]->value, new FormattableMarkup('%entity_type: The subsequent items have been shifted up.', ['%entity_type' => $entity_type]));
+    $this->assertEquals(1, $entity->name[1]->getName(), new FormattableMarkup('%entity_type: The items names have been updated to their new delta.', ['%entity_type' => $entity_type]));
     $entity->name[1] = NULL;
     $this->assertCount(2, $entity->name, new FormattableMarkup('%entity_type: Assigning NULL does not reduce array count.', ['%entity_type' => $entity_type]));
     $this->assertTrue($entity->name[1]->isEmpty(), new FormattableMarkup('%entity_type: Assigning NULL empties the item.', ['%entity_type' => $entity_type]));
@@ -327,15 +327,15 @@ class EntityFieldTest extends EntityKernelTestBase {
     $this->assertCount(2, $entity->name, new FormattableMarkup('%entity_type: List has 2 items.', ['%entity_type' => $entity_type]));
     $entity->name->filterEmptyItems();
     $this->assertCount(1, $entity->name, new FormattableMarkup('%entity_type: The empty item was removed.', ['%entity_type' => $entity_type]));
-    $this->assertEqual('foo', $entity->name[0]->value, new FormattableMarkup('%entity_type: The items were renumbered.', ['%entity_type' => $entity_type]));
-    $this->assertEqual(0, $entity->name[0]->getName(), new FormattableMarkup('%entity_type: The deltas were updated in the items.', ['%entity_type' => $entity_type]));
+    $this->assertEquals('foo', $entity->name[0]->value, new FormattableMarkup('%entity_type: The items were renumbered.', ['%entity_type' => $entity_type]));
+    $this->assertEquals(0, $entity->name[0]->getName(), new FormattableMarkup('%entity_type: The deltas were updated in the items.', ['%entity_type' => $entity_type]));
 
     // Test get and set field values.
     $entity->name = 'foo';
-    $this->assertEqual(['value' => 'foo'], $entity->name[0]->toArray(), new FormattableMarkup('%entity_type: Field value has been retrieved via toArray()', ['%entity_type' => $entity_type]));
+    $this->assertEquals(['value' => 'foo'], $entity->name[0]->toArray(), new FormattableMarkup('%entity_type: Field value has been retrieved via toArray()', ['%entity_type' => $entity_type]));
 
     $values = $entity->toArray();
-    $this->assertEqual([0 => ['value' => 'foo']], $values['name'], new FormattableMarkup('%entity_type: Field value has been retrieved via toArray() from an entity.', ['%entity_type' => $entity_type]));
+    $this->assertEquals([0 => ['value' => 'foo']], $values['name'], new FormattableMarkup('%entity_type: Field value has been retrieved via toArray() from an entity.', ['%entity_type' => $entity_type]));
 
     // Make sure the user id can be set to zero.
     $user_item[0]['target_id'] = 0;
@@ -389,13 +389,13 @@ class EntityFieldTest extends EntityKernelTestBase {
     $this->assertTrue((bool) $entity->id(), new FormattableMarkup('%entity_type: Entity loaded.', ['%entity_type' => $entity_type]));
 
     // Access the name field.
-    $this->assertEqual(1, $entity->id->value, new FormattableMarkup('%entity_type: ID value can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals(1, $entity->id->value, new FormattableMarkup('%entity_type: ID value can be read.', ['%entity_type' => $entity_type]));
     $this->assertIsString($entity->uuid->value);
-    $this->assertEqual('en', $entity->{$langcode_key}->value, new FormattableMarkup('%entity_type: Language code can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual(\Drupal::languageManager()->getLanguage('en'), $entity->{$langcode_key}->language, new FormattableMarkup('%entity_type: Language object can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($this->entityUser->id(), $entity->user_id->target_id, new FormattableMarkup('%entity_type: User id can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($this->entityUser->getAccountName(), $entity->user_id->entity->name->value, new FormattableMarkup('%entity_type: User name can be read.', ['%entity_type' => $entity_type]));
-    $this->assertEqual($this->entityFieldText, $entity->field_test_text->value, new FormattableMarkup('%entity_type: Text field can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals('en', $entity->{$langcode_key}->value, new FormattableMarkup('%entity_type: Language code can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals(\Drupal::languageManager()->getLanguage('en'), $entity->{$langcode_key}->language, new FormattableMarkup('%entity_type: Language object can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($this->entityUser->id(), $entity->user_id->target_id, new FormattableMarkup('%entity_type: User id can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($this->entityUser->getAccountName(), $entity->user_id->entity->name->value, new FormattableMarkup('%entity_type: User name can be read.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($this->entityFieldText, $entity->field_test_text->value, new FormattableMarkup('%entity_type: Text field can be read.', ['%entity_type' => $entity_type]));
   }
 
   /**
@@ -418,18 +418,18 @@ class EntityFieldTest extends EntityKernelTestBase {
     // Test getting metadata upfront. The entity types used for this test have
     // a default bundle that is the same as the entity type.
     $definitions = \Drupal::service('entity_field.manager')->getFieldDefinitions($entity_type, $entity_type);
-    $this->assertEqual('string', $definitions['name']->getType(), $entity_type . ': Name field found.');
-    $this->assertEqual('entity_reference', $definitions['user_id']->getType(), $entity_type . ': User field found.');
-    $this->assertEqual('text', $definitions['field_test_text']->getType(), $entity_type . ': Test-text-field field found.');
+    $this->assertEquals('string', $definitions['name']->getType(), $entity_type . ': Name field found.');
+    $this->assertEquals('entity_reference', $definitions['user_id']->getType(), $entity_type . ': User field found.');
+    $this->assertEquals('text', $definitions['field_test_text']->getType(), $entity_type . ': Test-text-field field found.');
 
     // Test deriving further metadata.
     $this->assertInstanceOf(FieldDefinitionInterface::class, $definitions['name']);
     $field_item_definition = $definitions['name']->getItemDefinition();
     $this->assertInstanceOf(ComplexDataDefinitionInterface::class, $field_item_definition);
-    $this->assertEqual('field_item:string', $field_item_definition->getDataType());
+    $this->assertEquals('field_item:string', $field_item_definition->getDataType());
     $value_definition = $field_item_definition->getPropertyDefinition('value');
     $this->assertInstanceOf(DataDefinitionInterface::class, $value_definition);
-    $this->assertEqual('string', $value_definition->getDataType());
+    $this->assertEquals('string', $value_definition->getDataType());
 
     // Test deriving metadata from references.
     $entity_definition = EntityDataDefinition::create($entity_type);
@@ -437,19 +437,19 @@ class EntityFieldTest extends EntityKernelTestBase {
     $reference_definition = $entity_definition->getPropertyDefinition($langcode_key)
       ->getPropertyDefinition('language')
       ->getTargetDefinition();
-    $this->assertEqual('language', $reference_definition->getDataType());
+    $this->assertEquals('language', $reference_definition->getDataType());
 
     $reference_definition = $entity_definition->getPropertyDefinition('user_id')
       ->getPropertyDefinition('entity')
       ->getTargetDefinition();
 
     $this->assertInstanceOf(EntityDataDefinitionInterface::class, $reference_definition);
-    $this->assertEqual('user', $reference_definition->getEntityTypeId(), 'Referenced entity is of type "user".');
+    $this->assertEquals('user', $reference_definition->getEntityTypeId(), 'Referenced entity is of type "user".');
 
     // Test propagating down.
     $name_definition = $reference_definition->getPropertyDefinition('name');
     $this->assertInstanceOf(FieldDefinitionInterface::class, $name_definition);
-    $this->assertEqual('string', $name_definition->getPropertyDefinition('value')->getDataType());
+    $this->assertEquals('string', $name_definition->getPropertyDefinition('value')->getDataType());
 
     // Test introspecting an entity object.
     // @todo: Add bundles and test bundles as well.
@@ -458,47 +458,47 @@ class EntityFieldTest extends EntityKernelTestBase {
       ->create();
 
     $definitions = $entity->getFieldDefinitions();
-    $this->assertEqual('string', $definitions['name']->getType(), $entity_type . ': Name field found.');
-    $this->assertEqual('entity_reference', $definitions['user_id']->getType(), $entity_type . ': User field found.');
-    $this->assertEqual('text', $definitions['field_test_text']->getType(), $entity_type . ': Test-text-field field found.');
+    $this->assertEquals('string', $definitions['name']->getType(), $entity_type . ': Name field found.');
+    $this->assertEquals('entity_reference', $definitions['user_id']->getType(), $entity_type . ': User field found.');
+    $this->assertEquals('text', $definitions['field_test_text']->getType(), $entity_type . ': Test-text-field field found.');
 
     $name_properties = $entity->name->getFieldDefinition()->getPropertyDefinitions();
-    $this->assertEqual('string', $name_properties['value']->getDataType(), $entity_type . ': String value property of the name found.');
+    $this->assertEquals('string', $name_properties['value']->getDataType(), $entity_type . ': String value property of the name found.');
 
     $userref_properties = $entity->user_id->getFieldDefinition()->getPropertyDefinitions();
-    $this->assertEqual('integer', $userref_properties['target_id']->getDataType(), $entity_type . ': Entity id property of the user found.');
-    $this->assertEqual('entity_reference', $userref_properties['entity']->getDataType(), $entity_type . ': Entity reference property of the user found.');
+    $this->assertEquals('integer', $userref_properties['target_id']->getDataType(), $entity_type . ': Entity id property of the user found.');
+    $this->assertEquals('entity_reference', $userref_properties['entity']->getDataType(), $entity_type . ': Entity reference property of the user found.');
 
     $textfield_properties = $entity->field_test_text->getFieldDefinition()->getFieldStorageDefinition()->getPropertyDefinitions();
-    $this->assertEqual('string', $textfield_properties['value']->getDataType(), $entity_type . ': String value property of the test-text field found.');
-    $this->assertEqual('filter_format', $textfield_properties['format']->getDataType(), $entity_type . ': String format field of the test-text field found.');
-    $this->assertEqual('string', $textfield_properties['processed']->getDataType(), $entity_type . ': String processed property of the test-text field found.');
+    $this->assertEquals('string', $textfield_properties['value']->getDataType(), $entity_type . ': String value property of the test-text field found.');
+    $this->assertEquals('filter_format', $textfield_properties['format']->getDataType(), $entity_type . ': String format field of the test-text field found.');
+    $this->assertEquals('string', $textfield_properties['processed']->getDataType(), $entity_type . ': String processed property of the test-text field found.');
 
     // Make sure provided contextual information is right.
     $entity_adapter = $entity->getTypedData();
     $this->assertSame($entity_adapter->getRoot(), $entity_adapter, 'Entity is root object.');
-    $this->assertEqual('', $entity_adapter->getPropertyPath());
-    $this->assertEqual('', $entity_adapter->getName());
+    $this->assertEquals('', $entity_adapter->getPropertyPath());
+    $this->assertEquals('', $entity_adapter->getName());
     $this->assertNull($entity_adapter->getParent());
 
     $field = $entity->user_id;
     $this->assertSame($field->getRoot()->getValue(), $entity, 'Entity is root object.');
     $this->assertSame($field->getEntity(), $entity, 'getEntity() returns the entity.');
-    $this->assertEqual('user_id', $field->getPropertyPath());
-    $this->assertEqual('user_id', $field->getName());
+    $this->assertEquals('user_id', $field->getPropertyPath());
+    $this->assertEquals('user_id', $field->getName());
     $this->assertSame($field->getParent()->getValue(), $entity, 'Parent object matches.');
 
     $field_item = $field[0];
     $this->assertSame($field_item->getRoot()->getValue(), $entity, 'Entity is root object.');
     $this->assertSame($field_item->getEntity(), $entity, 'getEntity() returns the entity.');
-    $this->assertEqual('user_id.0', $field_item->getPropertyPath());
-    $this->assertEqual('0', $field_item->getName());
+    $this->assertEquals('user_id.0', $field_item->getPropertyPath());
+    $this->assertEquals('0', $field_item->getName());
     $this->assertSame($field_item->getParent(), $field, 'Parent object matches.');
 
     $item_value = $field_item->get('entity');
     $this->assertSame($item_value->getRoot()->getValue(), $entity, 'Entity is root object.');
-    $this->assertEqual('user_id.0.entity', $item_value->getPropertyPath());
-    $this->assertEqual('entity', $item_value->getName());
+    $this->assertEquals('user_id.0.entity', $item_value->getPropertyPath());
+    $this->assertEquals('entity', $item_value->getName());
     $this->assertSame($item_value->getParent(), $field_item, 'Parent object matches.');
   }
 
@@ -537,8 +537,8 @@ class EntityFieldTest extends EntityKernelTestBase {
     }
 
     $fields = $entity->getFields();
-    $this->assertEqual(array_keys($entity->getTypedData()->getDataDefinition()->getPropertyDefinitions()), array_keys($fields), new FormattableMarkup('%entity_type: All fields returned.', ['%entity_type' => $entity_type]));
-    $this->assertEqual(iterator_to_array($entity->getIterator()), $fields, new FormattableMarkup('%entity_type: Entity iterator iterates over all fields.', ['%entity_type' => $entity_type]));
+    $this->assertEquals(array_keys($entity->getTypedData()->getDataDefinition()->getPropertyDefinitions()), array_keys($fields), new FormattableMarkup('%entity_type: All fields returned.', ['%entity_type' => $entity_type]));
+    $this->assertEquals(iterator_to_array($entity->getIterator()), $fields, new FormattableMarkup('%entity_type: Entity iterator iterates over all fields.', ['%entity_type' => $entity_type]));
   }
 
   /**
@@ -586,7 +586,7 @@ class EntityFieldTest extends EntityKernelTestBase {
 
     asort($strings);
     asort($target_strings);
-    $this->assertEqual(array_values($target_strings), array_values($strings), new FormattableMarkup('%entity_type: All contained strings found.', ['%entity_type' => $entity_type]));
+    $this->assertEquals(array_values($target_strings), array_values($strings), new FormattableMarkup('%entity_type: All contained strings found.', ['%entity_type' => $entity_type]));
   }
 
   /**
@@ -660,12 +660,12 @@ class EntityFieldTest extends EntityKernelTestBase {
     // the test entity works.
     entity_test_create_bundle('some_test_bundle', 'Some test bundle', 'entity_test_field_override');
     $field_definitions = \Drupal::service('entity_field.manager')->getFieldDefinitions('entity_test_field_override', 'entity_test_field_override');
-    $this->assertEqual('The default description.', $field_definitions['name']->getDescription());
+    $this->assertEquals('The default description.', $field_definitions['name']->getDescription());
     $this->assertNull($field_definitions['name']->getTargetBundle());
 
     $field_definitions = \Drupal::service('entity_field.manager')->getFieldDefinitions('entity_test_field_override', 'some_test_bundle');
-    $this->assertEqual('Custom description.', $field_definitions['name']->getDescription());
-    $this->assertEqual('some_test_bundle', $field_definitions['name']->getTargetBundle());
+    $this->assertEquals('Custom description.', $field_definitions['name']->getDescription());
+    $this->assertEquals('some_test_bundle', $field_definitions['name']->getTargetBundle());
 
     // Now create a config override of the bundle field.
     $field_config = $field_definitions['name']->getConfig('some_test_bundle');
@@ -675,8 +675,8 @@ class EntityFieldTest extends EntityKernelTestBase {
     // Make sure both overrides are present.
     \Drupal::service('entity_field.manager')->clearCachedFieldDefinitions();
     $field_definitions = \Drupal::service('entity_field.manager')->getFieldDefinitions('entity_test_field_override', 'some_test_bundle');
-    $this->assertEqual('Custom description.', $field_definitions['name']->getDescription());
-    $this->assertEqual('some_test_bundle', $field_definitions['name']->getTargetBundle());
+    $this->assertEquals('Custom description.', $field_definitions['name']->getDescription());
+    $this->assertEquals('some_test_bundle', $field_definitions['name']->getTargetBundle());
     $this->assertFalse($field_definitions['name']->isTranslatable());
   }
 
@@ -695,7 +695,7 @@ class EntityFieldTest extends EntityKernelTestBase {
 
     // Test validation the typed data object.
     $violations = $reference->validate();
-    $this->assertEqual(0, $violations->count());
+    $this->assertEquals(0, $violations->count());
 
     // Test validating an entity of the wrong type.
     $user = $this->createUser();
@@ -707,7 +707,7 @@ class EntityFieldTest extends EntityKernelTestBase {
     ]);
     $reference->setValue($node);
     $violations = $reference->validate();
-    $this->assertEqual(1, $violations->count());
+    $this->assertEquals(1, $violations->count());
 
     // Test bundle validation.
     NodeType::create(['type' => 'article'])
@@ -719,7 +719,7 @@ class EntityFieldTest extends EntityKernelTestBase {
     $reference_field = \Drupal::TypedDataManager()->create($definition);
     $reference_field->appendItem(['entity' => $node]);
     $violations = $reference_field->validate();
-    $this->assertEqual(1, $violations->count());
+    $this->assertEquals(1, $violations->count());
 
     $node = Node::create([
       'type' => 'article',
@@ -729,7 +729,7 @@ class EntityFieldTest extends EntityKernelTestBase {
     $node->save();
     $reference_field->entity = $node;
     $violations = $reference_field->validate();
-    $this->assertEqual(0, $violations->count());
+    $this->assertEquals(0, $violations->count());
   }
 
   /**
@@ -912,14 +912,14 @@ class EntityFieldTest extends EntityKernelTestBase {
     $entity->field_test_text->format = filter_default_format();
 
     $target = "<p>The &lt;strong&gt;text&lt;/strong&gt; text to filter.</p>\n";
-    $this->assertEqual($target, $entity->field_test_text->processed, new FormattableMarkup('%entity_type: Text is processed with the default filter.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($target, $entity->field_test_text->processed, new FormattableMarkup('%entity_type: Text is processed with the default filter.', ['%entity_type' => $entity_type]));
 
     // Save and load entity and make sure it still works.
     $entity->save();
     $entity = $this->container->get('entity_type.manager')
       ->getStorage($entity_type)
       ->load($entity->id());
-    $this->assertEqual($target, $entity->field_test_text->processed, new FormattableMarkup('%entity_type: Text is processed with the default filter.', ['%entity_type' => $entity_type]));
+    $this->assertEquals($target, $entity->field_test_text->processed, new FormattableMarkup('%entity_type: Text is processed with the default filter.', ['%entity_type' => $entity_type]));
   }
 
   /**
