@@ -127,7 +127,7 @@ abstract class EntityLanguageTestBase extends EntityKernelTestBase {
       $field->set('translatable', $translatable);
       $field->save();
       $field = FieldConfig::loadByName($entity_type, $bundle, $field_name);
-      $this->assertEqual($translatable, $field->isTranslatable(), 'Field translatability changed.');
+      $this->assertEquals($translatable, $field->isTranslatable(), 'Field translatability changed.');
     }
     \Drupal::cache('entity')->deleteAll();
   }
