@@ -162,6 +162,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     $figures = $this->figures;
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->exists($greetings, 'tr')
       ->condition("$figures.color", 'red')
       ->sort('id')
@@ -172,11 +173,12 @@ class EntityQueryTest extends EntityKernelTestBase {
 
     $query = $this->storage
       ->getQuery('OR')
+      ->accessCheck(FALSE)
       ->exists($greetings, 'tr')
       ->condition("$figures.color", 'red')
       ->sort('id');
     $count_query = clone $query;
-    $this->assertEqual(12, $count_query->count()->execute());
+    $this->assertEquals(12, $count_query->count()->execute());
     $this->queryResults = $query->execute();
     // Now bit 0 (1, 3, 5, 7, 9, 11, 13, 15) or bit 2 (4, 5, 6, 7, 12, 13, 14,
     // 15) needs to be set.
@@ -185,6 +187,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     // Test cloning of query conditions.
     $query = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("$figures.color", 'red')
       ->sort('id');
     $cloned_query = clone $query;
@@ -197,7 +200,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     $this->queryResults = $cloned_query->execute();
     $this->assertResult();
 
-    $query = $this->storage->getQuery();
+    $query = $this->storage->getQuery()->accessCheck(FALSE);
     $group = $query->orConditionGroup()
       ->exists($greetings, 'tr')
       ->condition("$figures.color", 'red');
@@ -212,6 +215,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     // No figure has both the colors blue and red at the same time.
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("$figures.color", 'blue')
       ->condition("$figures.color", 'red')
       ->sort('id')
@@ -219,7 +223,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     $this->assertResult();
 
     // But an entity might have a red and a blue figure both.
-    $query = $this->storage->getQuery();
+    $query = $this->storage->getQuery()->accessCheck(FALSE);
     $group_blue = $query->andConditionGroup()->condition("$figures.color", 'blue');
     $group_red = $query->andConditionGroup()->condition("$figures.color", 'red');
     $this->queryResults = $query
@@ -231,7 +235,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     $this->assertResult(3, 7, 11, 15);
 
     // Do the same test but with IN operator.
-    $query = $this->storage->getQuery();
+    $query = $this->storage->getQuery()->accessCheck(FALSE);
     $group_blue = $query->andConditionGroup()->condition("$figures.color", ['blue'], 'IN');
     $group_red = $query->andConditionGroup()->condition("$figures.color", ['red'], 'IN');
     $this->queryResults = $query
@@ -245,6 +249,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     // An entity might have either red or blue figure.
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("$figures.color", ['blue', 'red'], 'IN')
       ->sort('id')
       ->execute();
@@ -253,6 +258,7 @@ class EntityQueryTest extends EntityKernelTestBase {
 
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->exists("$figures.color")
       ->notExists("$greetings.value")
       ->sort('id')
@@ -263,6 +269,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     // word but allows us to test revisions and string operations.
     $ids = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("$greetings.value", 'merhaba')
       ->sort('id')
       ->execute();
@@ -278,6 +285,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     // Test querying all revisions with a condition on the revision ID field.
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition('revision_id', $first_entity->getRevisionId())
       ->allRevisions()
       ->execute();
@@ -286,12 +294,14 @@ class EntityQueryTest extends EntityKernelTestBase {
     // We changed the entity names, so the current revision should not match.
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition('name.value', $old_name)
       ->execute();
     $this->assertResult();
     // Only if all revisions are queried, we find the old revision.
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition('name.value', $old_name)
       ->allRevisions()
       ->sort('revision_id')
@@ -300,11 +310,13 @@ class EntityQueryTest extends EntityKernelTestBase {
     // When querying current revisions, this string is no longer found.
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("$greetings.value", 'merhaba')
       ->execute();
     $this->assertResult();
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("$greetings.value", 'merhaba')
       ->allRevisions()
       ->sort('revision_id')
@@ -313,31 +325,35 @@ class EntityQueryTest extends EntityKernelTestBase {
     $this->assertRevisionResult([4, 5, 6, 7, 12, 13, 14, 15], [4, 5, 6, 7, 12, 13, 14, 15]);
     $results = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("$greetings.value", 'siema', 'CONTAINS')
       ->sort('id')
       ->execute();
     // This matches both the original and new current revisions, multiple
     // revisions are returned for some entities.
     $assert = [16 => '4', 17 => '5', 18 => '6', 19 => '7', 8 => '8', 9 => '9', 10 => '10', 11 => '11', 20 => '12', 21 => '13', 22 => '14', 23 => '15'];
-    $this->assertIdentical($results, $assert);
+    $this->assertSame($assert, $results);
     $results = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("$greetings.value", 'siema', 'STARTS_WITH')
       ->sort('revision_id')
       ->execute();
     // Now we only get the ones that originally were siema, entity id 8 and
     // above.
-    $this->assertIdentical($results, array_slice($assert, 4, 8, TRUE));
+    $this->assertSame(array_slice($assert, 4, 8, TRUE), $results);
     $results = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("$greetings.value", 'a', 'ENDS_WITH')
       ->sort('revision_id')
       ->execute();
     // It is very important that we do not get the ones which only have
     // xsiemax despite originally they were merhaba, ie. ended with a.
-    $this->assertIdentical($results, array_slice($assert, 4, 8, TRUE));
+    $this->assertSame(array_slice($assert, 4, 8, TRUE), $results);
     $results = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("$greetings.value", 'a', 'ENDS_WITH')
       ->allRevisions()
       ->sort('id')
@@ -345,12 +361,13 @@ class EntityQueryTest extends EntityKernelTestBase {
       ->execute();
     // Now we get everything.
     $assert = [4 => '4', 5 => '5', 6 => '6', 7 => '7', 8 => '8', 9 => '9', 10 => '10', 11 => '11', 12 => '12', 20 => '12', 13 => '13', 21 => '13', 14 => '14', 22 => '14', 15 => '15', 23 => '15'];
-    $this->assertIdentical($results, $assert);
+    $this->assertSame($assert, $results);
 
     // Check that a query on the latest revisions without any condition returns
     // the correct results.
     $results = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->latestRevision()
       ->sort('id')
       ->sort('revision_id')
@@ -370,16 +387,19 @@ class EntityQueryTest extends EntityKernelTestBase {
     // Order up and down on a number.
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->sort('id')
       ->execute();
     $this->assertResult(range(1, 15));
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->sort('id', 'DESC')
       ->execute();
     $this->assertResult(range(15, 1));
     $query = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->sort("$figures.color")
       ->sort("$greetings.format")
       ->sort('id');
@@ -418,7 +438,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     // 13 red  tr
     // 15 red  tr
     $count_query = clone $query;
-    $this->assertEqual(15, $count_query->count()->execute());
+    $this->assertEquals(15, $count_query->count()->execute());
     $this->queryResults = $query->execute();
     $this->assertResult(8, 12, 4, 2, 3, 10, 11, 14, 15, 6, 7, 1, 9, 13, 5);
 
@@ -431,6 +451,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     \Drupal::getContainer()->get('request_stack')->push($request);
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->sort("$figures.color")
       ->sort("$greetings.format")
       ->sort('id')
@@ -441,11 +462,12 @@ class EntityQueryTest extends EntityKernelTestBase {
     // Now test the reversed order.
     $query = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->sort("$figures.color", 'DESC')
       ->sort("$greetings.format", 'DESC')
       ->sort('id', 'DESC');
     $count_query = clone $query;
-    $this->assertEqual(15, $count_query->count()->execute());
+    $this->assertEquals(15, $count_query->count()->execute());
     $this->queryResults = $query->execute();
     $this->assertResult(15, 13, 7, 5, 11, 9, 3, 1, 14, 6, 10, 2, 12, 4, 8);
   }
@@ -471,6 +493,7 @@ class EntityQueryTest extends EntityKernelTestBase {
 
     $this->queryResults = array_values($this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->tableSort($header)
       ->execute());
     $this->assertBundleOrder('asc');
@@ -486,6 +509,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     ];
     $this->queryResults = array_values($this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->tableSort($header)
       ->execute());
     $this->assertBundleOrder('desc');
@@ -497,6 +521,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     \Drupal::getContainer()->get('request_stack')->push($request);
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->tableSort($header)
       ->execute();
     $this->assertResult(range(15, 1));
@@ -534,6 +559,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     $count = $this->container->get('entity_type.manager')
       ->getStorage('entity_test')
       ->getQuery()
+      ->accessCheck(FALSE)
       ->exists("$field_name.color")
       ->count()
       ->execute();
@@ -546,7 +572,7 @@ class EntityQueryTest extends EntityKernelTestBase {
   public function testNestedConditionGroups() {
     // Query for all entities of the first bundle that have either a red
     // triangle as a figure or the Turkish greeting as a greeting.
-    $query = $this->storage->getQuery();
+    $query = $this->storage->getQuery()->accessCheck(FALSE);
 
     $first_and = $query->andConditionGroup()
       ->condition($this->figures . '.color', 'red')
@@ -574,7 +600,7 @@ class EntityQueryTest extends EntityKernelTestBase {
   public function testConditionCount() {
     // Query for all entities of the first bundle that
     // have red as a color AND are triangle shaped.
-    $query = $this->storage->getQuery();
+    $query = $this->storage->getQuery()->accessCheck(FALSE);
 
     // Add an AND condition group with 2 conditions in it.
     $and_condition_group = $query->andConditionGroup()
@@ -582,7 +608,7 @@ class EntityQueryTest extends EntityKernelTestBase {
       ->condition($this->figures . '.shape', 'triangle');
 
     // We added 2 conditions so count should be 2.
-    $this->assertEqual($and_condition_group->count(), 2);
+    $this->assertEquals(2, $and_condition_group->count());
 
     // Add an OR condition group with 2 conditions in it.
     $or_condition_group = $query->orConditionGroup()
@@ -590,7 +616,7 @@ class EntityQueryTest extends EntityKernelTestBase {
       ->condition($this->figures . '.shape', 'triangle');
 
     // We added 2 conditions so count should be 2.
-    $this->assertEqual($or_condition_group->count(), 2);
+    $this->assertEquals(2, $or_condition_group->count());
   }
 
   /**
@@ -601,6 +627,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     // Test numeric delta value in field condition.
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("$figures.0.color", 'red')
       ->sort('id')
       ->execute();
@@ -609,6 +636,7 @@ class EntityQueryTest extends EntityKernelTestBase {
 
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("$figures.1.color", 'red')
       ->sort('id')
       ->execute();
@@ -616,7 +644,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     $this->assertResult();
 
     // Test on two different deltas.
-    $query = $this->storage->getQuery();
+    $query = $this->storage->getQuery()->accessCheck(FALSE);
     $or = $query->andConditionGroup()
       ->condition("$figures.0.color", 'red')
       ->condition("$figures.1.color", 'blue');
@@ -629,6 +657,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     // Test the delta range condition.
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("$figures.%delta.color", ['blue', 'red'], 'IN')
       ->condition("$figures.%delta", [0, 1], 'IN')
       ->sort('id')
@@ -639,6 +668,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     // Test the delta range condition without conditions on the value.
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("$figures.%delta", 1)
       ->sort('id')
       ->execute();
@@ -649,12 +679,14 @@ class EntityQueryTest extends EntityKernelTestBase {
     // the first item is being targeted.
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("id.0.value", [1, 3, 5], 'IN')
       ->sort('id')
       ->execute();
     $this->assertResult(1, 3, 5);
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("id.1.value", [1, 3, 5], 'IN')
       ->sort('id')
       ->execute();
@@ -664,12 +696,14 @@ class EntityQueryTest extends EntityKernelTestBase {
     // only if just the field value is targeted.
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("id.%delta.value", [1, 3, 5], 'IN')
       ->sort('id')
       ->execute();
     $this->assertResult(1, 3, 5);
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("id.%delta.value", [1, 3, 5], 'IN')
       ->condition("id.%delta", 0, '=')
       ->sort('id')
@@ -677,6 +711,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     $this->assertResult(1, 3, 5);
     $this->queryResults = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition("id.%delta.value", [1, 3, 5], 'IN')
       ->condition("id.%delta", 1, '=')
       ->sort('id')
@@ -694,7 +729,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     foreach ($expected as $binary) {
       $assert[$binary] = strval($binary);
     }
-    $this->assertIdentical($this->queryResults, $assert);
+    $this->assertSame($assert, $this->queryResults);
   }
 
   protected function assertRevisionResult($keys, $expected) {
@@ -702,7 +737,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     foreach ($expected as $key => $binary) {
       $assert[$keys[$key]] = strval($binary);
     }
-    $this->assertIdentical($this->queryResults, $assert);
+    $this->assertSame($assert, $this->queryResults);
     return $assert;
   }
 
@@ -733,14 +768,14 @@ class EntityQueryTest extends EntityKernelTestBase {
    * The tags and metadata should propagate to the SQL query object.
    */
   public function testMetaData() {
-    $query = $this->storage->getQuery();
+    $query = $this->storage->getQuery()->accessCheck(FALSE);
     $query
       ->addTag('efq_metadata_test')
       ->addMetaData('foo', 'bar')
       ->execute();
 
     global $efq_test_metadata;
-    $this->assertEqual($efq_test_metadata, 'bar', 'Tag and metadata propagated to the SQL query object.');
+    $this->assertEquals('bar', $efq_test_metadata, 'Tag and metadata propagated to the SQL query object.');
   }
 
   /**
@@ -809,18 +844,21 @@ class EntityQueryTest extends EntityKernelTestBase {
     // Check the case insensitive field, = operator.
     $result = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition('field_ci', $fixtures[0]['lowercase'] . $fixtures[1]['lowercase'])
       ->execute();
     $this->assertCount(1, $result, 'Case insensitive, lowercase');
 
     $result = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition('field_ci', $fixtures[0]['uppercase'] . $fixtures[1]['uppercase'])
       ->execute();
     $this->assertCount(1, $result, 'Case insensitive, uppercase');
 
     $result = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition('field_ci', $fixtures[0]['uppercase'] . $fixtures[1]['lowercase'])
       ->execute();
     $this->assertCount(1, $result, 'Case insensitive, mixed.');
@@ -828,18 +866,21 @@ class EntityQueryTest extends EntityKernelTestBase {
     // Check the case sensitive field, = operator.
     $result = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition('field_cs', $fixtures[0]['lowercase'] . $fixtures[1]['lowercase'])
       ->execute();
     $this->assertCount(0, $result, 'Case sensitive, lowercase.');
 
     $result = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition('field_cs', $fixtures[0]['uppercase'] . $fixtures[1]['uppercase'])
       ->execute();
     $this->assertCount(0, $result, 'Case sensitive, uppercase.');
 
     $result = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition('field_cs', $fixtures[0]['uppercase'] . $fixtures[1]['lowercase'])
       ->execute();
     $this->assertCount(1, $result, 'Case sensitive, exact match.');
@@ -847,17 +888,20 @@ class EntityQueryTest extends EntityKernelTestBase {
     // Check the case insensitive field, IN operator.
     $result = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition('field_ci', [$fixtures[0]['lowercase'] . $fixtures[1]['lowercase']], 'IN')
       ->execute();
     $this->assertCount(1, $result, 'Case insensitive, lowercase');
 
     $result = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition('field_ci', [$fixtures[0]['uppercase'] . $fixtures[1]['uppercase']], 'IN')->execute();
     $this->assertCount(1, $result, 'Case insensitive, uppercase');
 
     $result = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition('field_ci', [$fixtures[0]['uppercase'] . $fixtures[1]['lowercase']], 'IN')
       ->execute();
     $this->assertCount(1, $result, 'Case insensitive, mixed');
@@ -865,6 +909,7 @@ class EntityQueryTest extends EntityKernelTestBase {
     // Check the case sensitive field, IN operator.
     $result = $this->storage
       ->getQuery()
+      ->accessCheck(FALSE)
       ->condition('field_cs', [$fixtures[0]['lowercase'] . $fixtures[1]['lowercase']], 'IN')
       ->execute();
     $this->assertCount(0, $result, 'Case sensitive, lowercase');
@@ -975,7 +1020,7 @@ class EntityQueryTest extends EntityKernelTestBase {
       'name' => $this->randomMachineName(),
       'vid' => 'tags',
       'description' => [
-        'value' => $this->randomString(),
+        'value' => 'description1',
         'format' => 'format1',
       ],
     ]);
@@ -985,20 +1030,37 @@ class EntityQueryTest extends EntityKernelTestBase {
       'name' => $this->randomMachineName(),
       'vid' => 'tags',
       'description' => [
-        'value' => $this->randomString(),
+        'value' => 'description2',
         'format' => 'format2',
       ],
     ]);
     $term2->save();
 
+    // Test that the properties can be queried directly.
+    $ids = $this->container->get('entity_type.manager')
+      ->getStorage('taxonomy_term')
+      ->getQuery()
+      ->condition('description.value', 'description1')
+      ->execute();
+    $this->assertCount(1, $ids);
+    $this->assertEquals($term1->id(), reset($ids));
+
     $ids = $this->container->get('entity_type.manager')
       ->getStorage('taxonomy_term')
       ->getQuery()
       ->condition('description.format', 'format1')
       ->execute();
-
     $this->assertCount(1, $ids);
-    $this->assertEqual($term1->id(), reset($ids));
+    $this->assertEquals($term1->id(), reset($ids));
+
+    // Test that the main property is queried if no property is specified.
+    $ids = $this->container->get('entity_type.manager')
+      ->getStorage('taxonomy_term')
+      ->getQuery()
+      ->condition('description', 'description1')
+      ->execute();
+    $this->assertCount(1, $ids);
+    $this->assertEquals($term1->id(), reset($ids));
   }
 
   /**
@@ -1038,14 +1100,14 @@ class EntityQueryTest extends EntityKernelTestBase {
       ->condition('id', [14], 'IN')
       ->condition("$this->figures.color", $current_values[0]['color'])
       ->execute();
-    $this->assertEqual($result, [14 => '14']);
+    $this->assertEquals([14 => '14'], $result);
     $result = $this->storage
       ->getQuery()
       ->condition('id', [14], 'IN')
       ->condition("$this->figures.color", 'red')
       ->allRevisions()
       ->execute();
-    $this->assertEqual($result, [16 => '14']);
+    $this->assertEquals([16 => '14'], $result);
 
     // Add another pending revision on the same entity and repeat the checks.
     $entity->setNewRevision(TRUE);
