@@ -145,7 +145,7 @@ class FieldSqlStorageTest extends EntityKernelTestBase {
       $entity = $storage->loadRevision($revision_id);
       foreach ($values[$revision_id] as $delta => $value) {
         if ($delta < $this->fieldCardinality) {
-          $this->assertEqual($value, $entity->{$this->fieldName}[$delta]->value);
+          $this->assertEquals($value, $entity->{$this->fieldName}[$delta]->value);
         }
         else {
           $this->assertArrayNotHasKey($delta, $entity->{$this->fieldName});
@@ -157,7 +157,7 @@ class FieldSqlStorageTest extends EntityKernelTestBase {
     $entity = $storage->load($entity->id());
     foreach ($values[$revision_id] as $delta => $value) {
       if ($delta < $this->fieldCardinality) {
-        $this->assertEqual($value, $entity->{$this->fieldName}[$delta]->value);
+        $this->assertEquals($value, $entity->{$this->fieldName}[$delta]->value);
       }
       else {
         $this->assertArrayNotHasKey($delta, $entity->{$this->fieldName});
@@ -207,7 +207,7 @@ class FieldSqlStorageTest extends EntityKernelTestBase {
         'delta' => $delta,
         $this->fieldName . '_value' => $values[$delta]['value'],
       ];
-      $this->assertEqual($expected, $row, "Row {$delta} was stored as expected.");
+      $this->assertEquals($expected, $row, "Row {$delta} was stored as expected.");
     }
 
     // Test update. Add less values and check that the previous values did not
@@ -231,7 +231,7 @@ class FieldSqlStorageTest extends EntityKernelTestBase {
         'delta' => $delta,
         $this->fieldName . '_value' => $values[$delta]['value'],
       ];
-      $this->assertEqual($expected, $row, "Row {$delta} was stored as expected.");
+      $this->assertEquals($expected, $row, "Row {$delta} was stored as expected.");
     }
 
     // Create a new revision.
@@ -259,7 +259,7 @@ class FieldSqlStorageTest extends EntityKernelTestBase {
           'delta' => $delta,
           $this->fieldName . '_value' => $values[$delta]['value'],
         ];
-        $this->assertEqual($expected, $row, "Row {$delta} was stored as expected.");
+        $this->assertEquals($expected, $row, "Row {$delta} was stored as expected.");
       }
     }
 
@@ -307,7 +307,7 @@ class FieldSqlStorageTest extends EntityKernelTestBase {
     // Load the entity back and check the values.
     $entity = $storage->load($entity->id());
     foreach ($field_names as $field_name) {
-      $this->assertEqual($values[$field_name], $entity->get($field_name)->value);
+      $this->assertEquals($values[$field_name], $entity->get($field_name)->value);
     }
   }
 
@@ -437,7 +437,7 @@ class FieldSqlStorageTest extends EntityKernelTestBase {
 
     // Verify that the tables were not dropped in the process.
     $entity = $this->container->get('entity_type.manager')->getStorage($entity_type)->load(1);
-    $this->assertEqual('field data', $entity->{$field_name}->value, t("Index changes performed without dropping the tables"));
+    $this->assertEquals('field data', $entity->{$field_name}->value, t("Index changes performed without dropping the tables"));
   }
 
   /**
@@ -459,8 +459,8 @@ class FieldSqlStorageTest extends EntityKernelTestBase {
     $schema = $field_storage->getSchema();
 
     // Retrieve the field definition and check that the foreign key is in place.
-    $this->assertEqual($foreign_key_name, $schema['foreign keys'][$foreign_key_name]['table'], 'Foreign key table name preserved through CRUD');
-    $this->assertEqual('id', $schema['foreign keys'][$foreign_key_name]['columns'][$foreign_key_name], 'Foreign key column name preserved through CRUD');
+    $this->assertEquals($foreign_key_name, $schema['foreign keys'][$foreign_key_name]['table'], 'Foreign key table name preserved through CRUD');
+    $this->assertEquals('id', $schema['foreign keys'][$foreign_key_name]['columns'][$foreign_key_name], 'Foreign key column name preserved through CRUD');
 
     // Update the field settings, it should update the foreign key definition too.
     $foreign_key_name = 'color';
@@ -470,8 +470,8 @@ class FieldSqlStorageTest extends EntityKernelTestBase {
     $schema = $field_storage->getSchema();
 
     // Check that the foreign key is in place.
-    $this->assertEqual($foreign_key_name, $schema['foreign keys'][$foreign_key_name]['table'], 'Foreign key table name modified after update');
-    $this->assertEqual('id', $schema['foreign keys'][$foreign_key_name]['columns'][$foreign_key_name], 'Foreign key column name modified after update');
+    $this->assertEquals($foreign_key_name, $schema['foreign keys'][$foreign_key_name]['table'], 'Foreign key table name modified after update');
+    $this->assertEquals('id', $schema['foreign keys'][$foreign_key_name]['columns'][$foreign_key_name], 'Foreign key column name modified after update');
   }
 
   /**
@@ -491,9 +491,9 @@ class FieldSqlStorageTest extends EntityKernelTestBase {
       'type' => 'test_field',
     ]);
     $expected = 'short_entity_type__short_field_name';
-    $this->assertEqual($expected, $this->tableMapping->getDedicatedDataTableName($field_storage));
+    $this->assertEquals($expected, $this->tableMapping->getDedicatedDataTableName($field_storage));
     $expected = 'short_entity_type_revision__short_field_name';
-    $this->assertEqual($expected, $this->tableMapping->getDedicatedRevisionTableName($field_storage));
+    $this->assertEquals($expected, $this->tableMapping->getDedicatedRevisionTableName($field_storage));
 
     // Short entity type, long field name
     $entity_type = 'short_entity_type';
@@ -504,9 +504,9 @@ class FieldSqlStorageTest extends EntityKernelTestBase {
       'type' => 'test_field',
     ]);
     $expected = 'short_entity_type__' . substr(hash('sha256', $field_storage->uuid()), 0, 10);
-    $this->assertEqual($expected, $this->tableMapping->getDedicatedDataTableName($field_storage));
+    $this->assertEquals($expected, $this->tableMapping->getDedicatedDataTableName($field_storage));
     $expected = 'short_entity_type_r__' . substr(hash('sha256', $field_storage->uuid()), 0, 10);
-    $this->assertEqual($expected, $this->tableMapping->getDedicatedRevisionTableName($field_storage));
+    $this->assertEquals($expected, $this->tableMapping->getDedicatedRevisionTableName($field_storage));
 
     // Long entity type, short field name
     $entity_type = 'long_entity_type_abcdefghijklmnopqrstuvwxyz';
@@ -517,9 +517,9 @@ class FieldSqlStorageTest extends EntityKernelTestBase {
       'type' => 'test_field',
     ]);
     $expected = 'long_entity_type_abcdefghijklmno__' . substr(hash('sha256', $field_storage->uuid()), 0, 10);
-    $this->assertEqual($expected, $this->tableMapping->getDedicatedDataTableName($field_storage));
+    $this->assertEquals($expected, $this->tableMapping->getDedicatedDataTableName($field_storage));
     $expected = 'long_entity_type_abcdefghijklmno_r__' . substr(hash('sha256', $field_storage->uuid()), 0, 10);
-    $this->assertEqual($expected, $this->tableMapping->getDedicatedRevisionTableName($field_storage));
+    $this->assertEquals($expected, $this->tableMapping->getDedicatedRevisionTableName($field_storage));
 
     // Long entity type and field name.
     $entity_type = 'long_entity_type_abcdefghijklmnopqrstuvwxyz';
@@ -530,9 +530,9 @@ class FieldSqlStorageTest extends EntityKernelTestBase {
       'type' => 'test_field',
     ]);
     $expected = 'long_entity_type_abcdefghijklmno__' . substr(hash('sha256', $field_storage->uuid()), 0, 10);
-    $this->assertEqual($expected, $this->tableMapping->getDedicatedDataTableName($field_storage));
+    $this->assertEquals($expected, $this->tableMapping->getDedicatedDataTableName($field_storage));
     $expected = 'long_entity_type_abcdefghijklmno_r__' . substr(hash('sha256', $field_storage->uuid()), 0, 10);
-    $this->assertEqual($expected, $this->tableMapping->getDedicatedRevisionTableName($field_storage));
+    $this->assertEquals($expected, $this->tableMapping->getDedicatedRevisionTableName($field_storage));
     // Try creating a second field and check there are no clashes.
     $field_storage2 = FieldStorageConfig::create([
       'entity_type' => $entity_type,
@@ -550,9 +550,9 @@ class FieldSqlStorageTest extends EntityKernelTestBase {
       'deleted' => TRUE,
     ]);
     $expected = 'field_deleted_data_' . substr(hash('sha256', $field_storage->uuid()), 0, 10);
-    $this->assertEqual($expected, $this->tableMapping->getDedicatedDataTableName($field_storage, TRUE));
+    $this->assertEquals($expected, $this->tableMapping->getDedicatedDataTableName($field_storage, TRUE));
     $expected = 'field_deleted_revision_' . substr(hash('sha256', $field_storage->uuid()), 0, 10);
-    $this->assertEqual($expected, $this->tableMapping->getDedicatedRevisionTableName($field_storage, TRUE));
+    $this->assertEquals($expected, $this->tableMapping->getDedicatedRevisionTableName($field_storage, TRUE));
 
     // Check that the table mapping is kept up-to-date in a request where a new
     // field storage definition is added. Since the cardinality of the field is
