@@ -5,6 +5,7 @@ namespace Drupal\KernelTests\Core\File;
 use Drupal\Component\FileSecurity\FileSecurity;
 use Drupal\Component\FileSystem\FileSystem;
 use Drupal\Component\Render\FormattableMarkup;
+use Drupal\Core\Database\Database;
 use Drupal\Core\File\Exception\FileException;
 use Drupal\Core\File\FileSystemInterface;
 
@@ -15,20 +16,6 @@ use Drupal\Core\File\FileSystemInterface;
  */
 class DirectoryTest extends FileTestBase {
 
-  /**
-   * Modules to enable.
-   *
-   * @var array
-   */
-  protected static $modules = ['system'];
-
-  protected function setUp(): void {
-    parent::setUp();
-
-    // These additional tables are necessary due to the call to system_cron().
-    $this->installSchema('system', ['key_value_expire']);
-  }
-
   /**
    * Test local directory handling functions.
    */
@@ -51,7 +38,7 @@ class DirectoryTest extends FileTestBase {
     $child_path = $parent_path . DIRECTORY_SEPARATOR . $child;
     /** @var \Drupal\Core\File\FileSystemInterface $file_system */
     $file_system = \Drupal::service('file_system');
-    $this->assertTrue($file_system->mkdir($child_path, 0775, TRUE), t('No error reported when creating new local directories.'), 'File');
+    $this->assertTrue($file_system->mkdir($child_path, 0775, TRUE), 'No error reported when creating new local directories.');
 
     // Ensure new directories also exist.
     $this->assertDirectoryExists($parent_path);
@@ -122,7 +109,7 @@ class DirectoryTest extends FileTestBase {
 
     // Verify contents of .htaccess file.
     $file = file_get_contents($default_scheme . '://.htaccess');
-    $this->assertEqual($file, FileSecurity::htaccessLines(FALSE), 'The .htaccess file contains the proper content.', 'File');
+    $this->assertEquals(FileSecurity::htaccessLines(FALSE), $file, 'The .htaccess file contains the proper content.');
   }
 
   /**
@@ -138,14 +125,14 @@ class DirectoryTest extends FileTestBase {
     /** @var \Drupal\Core\File\FileSystemInterface $file_system */
     $file_system = \Drupal::service('file_system');
     $path = $file_system->createFilename($basename, $directory);
-    $this->assertEqual($path, $original, new FormattableMarkup('New filepath %new equals %original.', ['%new' => $path, '%original' => $original]), 'File');
+    $this->assertEquals($original, $path, new FormattableMarkup('New filepath %new equals %original.', ['%new' => $path, '%original' => $original]));
 
     // Then we test against a file that already exists within that directory.
     $basename = 'druplicon.png';
     $original = $directory . '/' . $basename;
     $expected = $directory . '/druplicon_0.png';
     $path = $file_system->createFilename($basename, $directory);
-    $this->assertEqual($path, $expected, new FormattableMarkup('Creating a new filepath from %original equals %new (expected %expected).', ['%new' => $path, '%original' => $original, '%expected' => $expected]), 'File');
+    $this->assertEquals($expected, $path, new FormattableMarkup('Creating a new filepath from %original equals %new (expected %expected).', ['%new' => $path, '%original' => $original, '%expected' => $expected]));
 
     // @TODO: Finally we copy a file into a directory several times, to ensure a properly iterating filename suffix.
   }
@@ -168,19 +155,19 @@ class DirectoryTest extends FileTestBase {
     /** @var \Drupal\Core\File\FileSystemInterface $file_system */
     $file_system = \Drupal::service('file_system');
     $path = $file_system->getDestinationFilename($destination, FileSystemInterface::EXISTS_REPLACE);
-    $this->assertEqual($path, $destination, 'Non-existing filepath destination is correct with FileSystemInterface::EXISTS_REPLACE.', 'File');
+    $this->assertEquals($destination, $path, 'Non-existing filepath destination is correct with FileSystemInterface::EXISTS_REPLACE.');
     $path = $file_system->getDestinationFilename($destination, FileSystemInterface::EXISTS_RENAME);
-    $this->assertEqual($path, $destination, 'Non-existing filepath destination is correct with FileSystemInterface::EXISTS_RENAME.', 'File');
+    $this->assertEquals($destination, $path, 'Non-existing filepath destination is correct with FileSystemInterface::EXISTS_RENAME.');
     $path = $file_system->getDestinationFilename($destination, FileSystemInterface::EXISTS_ERROR);
-    $this->assertEqual($path, $destination, 'Non-existing filepath destination is correct with FileSystemInterface::EXISTS_ERROR.', 'File');
+    $this->assertEquals($destination, $path, 'Non-existing filepath destination is correct with FileSystemInterface::EXISTS_ERROR.');
 
     $destination = 'core/misc/druplicon.png';
     $path = $file_system->getDestinationFilename($destination, FileSystemInterface::EXISTS_REPLACE);
-    $this->assertEqual($path, $destination, 'Existing filepath destination remains the same with FileSystemInterface::EXISTS_REPLACE.', 'File');
+    $this->assertEquals($destination, $path, 'Existing filepath destination remains the same with FileSystemInterface::EXISTS_REPLACE.');
     $path = $file_system->getDestinationFilename($destination, FileSystemInterface::EXISTS_RENAME);
-    $this->assertNotEqual($path, $destination, 'A new filepath destination is created when filepath destination already exists with FileSystemInterface::EXISTS_RENAME.', 'File');
+    $this->assertNotEquals($destination, $path, 'A new filepath destination is created when filepath destination already exists with FileSystemInterface::EXISTS_RENAME.');
     $path = $file_system->getDestinationFilename($destination, FileSystemInterface::EXISTS_ERROR);
-    $this->assertEqual($path, FALSE, 'An error is returned when filepath destination already exists with FileSystemInterface::EXISTS_ERROR.', 'File');
+    $this->assertFalse($path, 'An error is returned when filepath destination already exists with FileSystemInterface::EXISTS_ERROR.');
 
     // Invalid UTF-8 causes an exception.
     $this->expectException(FileException::class);
@@ -210,4 +197,51 @@ class DirectoryTest extends FileTestBase {
     $this->assertTrue($file_system->mkdir($dir . '/foo/baz/', 0775, TRUE));
   }
 
+  /**
+   * Tests asynchronous directory creation.
+   *
+   * Image style generation can result in many calls to create similar directory
+   * paths. This test forks the process to create the same situation.
+   */
+  public function testMultiplePrepareDirectory() {
+    if (!function_exists('pcntl_fork')) {
+      $this->markTestSkipped('Requires the pcntl_fork() function');
+    }
+    $directories = [];
+    for ($i = 1; $i <= 10; $i++) {
+      $directories[] = 'public://a/b/c/d/e/f/g/h/' . $i;
+    }
+
+    $file_system = $this->container->get('file_system');
+
+    $time_to_start = microtime(TRUE) + 0.1;
+    // This loop creates a new fork to create each directory.
+    foreach ($directories as $directory) {
+      $pid = pcntl_fork();
+      if ($pid == -1) {
+        $this->fail("Error forking");
+      }
+      elseif ($pid == 0) {
+        // Sleep so that all the forks start preparing the directory at the same
+        // time.
+        usleep(($time_to_start - microtime(TRUE)) * 1000000);
+        $file_system->prepareDirectory($directory, FileSystemInterface::CREATE_DIRECTORY);
+        exit();
+      }
+    }
+
+    // This while loop holds the parent process until all the child threads
+    // are complete - at which point the script continues to execute.
+    while (pcntl_waitpid(0, $status) != -1);
+
+    foreach ($directories as $directory) {
+      $this->assertDirectoryExists($directory);
+    }
+
+    // Remove the database connection because it will have been destroyed when
+    // the forks exited. This allows
+    // \Drupal\KernelTests\KernelTestBase::tearDown() to reopen it.
+    Database::removeConnection('default');
+  }
+
 }
