@@ -7,28 +7,51 @@ use Drupal\Component\Render\FormattableMarkup;
 /**
  * Tests filename munging and unmunging.
  *
+ * Checks performed, relying on 2 <= strlen('foo') <= 5.
+ *
+ * - testMunging()
+ *   - (name).foo.txt -> (name).foo_.txt when allows_insecure_uploads === 0
+ * - testMungeBullByte()
+ *   - (name).foo\0.txt -> (name).foo_.txt regardless of allows_insecure_uploads
+ * - testMungeIgnoreInsecure()
+ *   - (name).foo.txt unmodified when allows_insecure_uploads === 1
+ * - testMungeIgnoreAllowedExtensions()
+ *   - (name).FOO.txt -> (name).FOO when allowing 'foo'.
+ *   - (name).foo.txt -> (name).foo.txt when allowing 'FOO'.
+ * - testMungeUnsafe()
+ *   - (name).php.txt -> (name).php_.txt even when allowing 'php txt'
+ *   - (name).php.txt -> (name).php_.txt even when allowing 'php txt'
+ * - testUnMunge()
+ *   - (name).foo.txt -> (unchecked) -> (name).foo.txt after un-munging
+ *
  * @group File
  */
 class NameMungingTest extends FileTestBase {
 
   /**
+   * An extension to be used as forbidden during munge operations.
+   *
    * @var string
    */
   protected $badExtension;
 
   /**
+   * The name of a file with a bad extension, after munging.
+   *
    * @var string
    */
   protected $name;
 
   /**
+   * The name of a file with an upper-cased bad extension, after munging.
+   *
    * @var string
    */
   protected $nameWithUcExt;
 
   protected function setUp(): void {
     parent::setUp();
-    $this->badExtension = 'php';
+    $this->badExtension = 'foo';
     $this->name = $this->randomMachineName() . '.' . $this->badExtension . '.txt';
     $this->nameWithUcExt = $this->randomMachineName() . '.' . strtoupper($this->badExtension) . '.txt';
   }
@@ -42,8 +65,8 @@ class NameMungingTest extends FileTestBase {
     $munged_name = file_munge_filename($this->name, '', TRUE);
     $messages = \Drupal::messenger()->all();
     \Drupal::messenger()->deleteAll();
-    $this->assertContains(strtr('For security reasons, your upload has been renamed to <em class="placeholder">%filename</em>.', ['%filename' => $munged_name]), $messages['status'], 'Alert properly set when a file is renamed.');
-    $this->assertNotEqual($munged_name, $this->name, new FormattableMarkup('The new filename (%munged) has been modified from the original (%original)', ['%munged' => $munged_name, '%original' => $this->name]));
+    $this->assertContainsEquals(strtr('For security reasons, your upload has been renamed to <em class="placeholder">%filename</em>.', ['%filename' => $munged_name]), $messages['status'], 'Alert properly set when a file is renamed.');
+    $this->assertNotEquals($this->name, $munged_name, new FormattableMarkup('The new filename (%munged) has been modified from the original (%original)', ['%munged' => $munged_name, '%original' => $this->name]));
   }
 
   /**
@@ -52,7 +75,7 @@ class NameMungingTest extends FileTestBase {
   public function testMungeNullByte() {
     $prefix = $this->randomMachineName();
     $filename = $prefix . '.' . $this->badExtension . "\0.txt";
-    $this->assertEqual(file_munge_filename($filename, ''), $prefix . '.' . $this->badExtension . '_.txt', 'A filename with a null byte is correctly munged to remove the null byte.');
+    $this->assertEquals($prefix . '.' . $this->badExtension . '_.txt', file_munge_filename($filename, ''), 'A filename with a null byte is correctly munged to remove the null byte.');
   }
 
   /**
@@ -66,16 +89,28 @@ class NameMungingTest extends FileTestBase {
   }
 
   /**
-   * White listed extensions are ignored by file_munge_filename().
+   * Tests that allowed extensions are ignored by file_munge_filename().
    */
-  public function testMungeIgnoreWhitelisted() {
-    // Declare our extension as whitelisted. The declared extensions should
-    // be case insensitive so test using one with a different case.
+  public function testMungeIgnoreAllowedExtensions() {
+    // Declare that our extension is allowed. The declared extensions should be
+    // case insensitive, so test using one with a different case.
     $munged_name = file_munge_filename($this->nameWithUcExt, $this->badExtension);
-    $this->assertSame($munged_name, $this->nameWithUcExt, new FormattableMarkup('The new filename (%munged) matches the original (%original) once the extension has been whitelisted.', ['%munged' => $munged_name, '%original' => $this->nameWithUcExt]));
+    $this->assertSame($munged_name, $this->nameWithUcExt);
     // The allowed extensions should also be normalized.
     $munged_name = file_munge_filename($this->name, strtoupper($this->badExtension));
-    $this->assertSame($munged_name, $this->name, new FormattableMarkup('The new filename (%munged) matches the original (%original) also when the whitelisted extension is in uppercase.', ['%munged' => $munged_name, '%original' => $this->name]));
+    $this->assertSame($munged_name, $this->name);
+  }
+
+  /**
+   * Tests unsafe extensions are always munged by file_munge_filename().
+   */
+  public function testMungeUnsafe() {
+    $prefix = $this->randomMachineName();
+    $name = "$prefix.php.txt";
+    // Put the php extension in the allowed list, but since it is in the unsafe
+    // extension list, it should still be munged.
+    $munged_name = file_munge_filename($name, 'php txt');
+    $this->assertSame("$prefix.php_.txt", $munged_name);
   }
 
   /**
