@@ -69,96 +69,96 @@ class TypedDataTest extends KernelTestBase {
     $typed_data = $this->createTypedData(['type' => 'boolean'], TRUE);
     $this->assertInstanceOf(BooleanInterface::class, $typed_data);
     $this->assertTrue($typed_data->getValue() === TRUE, 'Boolean value was fetched.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue(FALSE);
     $this->assertTrue($typed_data->getValue() === FALSE, 'Boolean value was changed.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $this->assertIsString($typed_data->getString());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getValue(), 'Boolean wrapper is null-able.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue('invalid');
-    $this->assertEqual(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
+    $this->assertEquals(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
 
     // String type.
     $value = $this->randomString();
     $typed_data = $this->createTypedData(['type' => 'string'], $value);
     $this->assertInstanceOf(StringInterface::class, $typed_data);
     $this->assertTrue($typed_data->getValue() === $value, 'String value was fetched.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $new_value = $this->randomString();
     $typed_data->setValue($new_value);
     $this->assertTrue($typed_data->getValue() === $new_value, 'String value was changed.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     // Funky test.
     $this->assertIsString($typed_data->getString());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getValue(), 'String wrapper is null-able.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue(['no string']);
-    $this->assertEqual(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
+    $this->assertEquals(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
 
     // Integer type.
     $value = rand();
     $typed_data = $this->createTypedData(['type' => 'integer'], $value);
     $this->assertInstanceOf(IntegerInterface::class, $typed_data);
     $this->assertTrue($typed_data->getValue() === $value, 'Integer value was fetched.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $new_value = rand();
     $typed_data->setValue($new_value);
     $this->assertTrue($typed_data->getValue() === $new_value, 'Integer value was changed.');
     $this->assertIsString($typed_data->getString());
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getValue(), 'Integer wrapper is null-able.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue('invalid');
-    $this->assertEqual(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
+    $this->assertEquals(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
 
     // Float type.
     $value = 123.45;
     $typed_data = $this->createTypedData(['type' => 'float'], $value);
     $this->assertInstanceOf(FloatInterface::class, $typed_data);
     $this->assertTrue($typed_data->getValue() === $value, 'Float value was fetched.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $new_value = 678.90;
     $typed_data->setValue($new_value);
     $this->assertTrue($typed_data->getValue() === $new_value, 'Float value was changed.');
     $this->assertIsString($typed_data->getString());
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getValue(), 'Float wrapper is null-able.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue('invalid');
-    $this->assertEqual(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
+    $this->assertEquals(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
 
     // Date Time type; values with timezone offset.
     $value = '2014-01-01T20:00:00+00:00';
     $typed_data = $this->createTypedData(['type' => 'datetime_iso8601'], $value);
     $this->assertInstanceOf(DateTimeInterface::class, $typed_data);
     $this->assertTrue($typed_data->getValue() == $value, 'Date value was fetched.');
-    $this->assertEqual($typed_data->getDateTime()->format('c'), $typed_data->getValue(), 'Value representation of a date is ISO 8601');
+    $this->assertEquals($typed_data->getDateTime()->format('c'), $typed_data->getValue(), 'Value representation of a date is ISO 8601');
     $this->assertSame('+00:00', $typed_data->getDateTime()->getTimezone()->getName());
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $new_value = '2014-01-02T20:00:00+00:00';
     $typed_data->setValue($new_value);
     $this->assertTrue($typed_data->getDateTime()->format('c') === $new_value, 'Date value was changed and set by an ISO8601 date.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $this->assertTrue($typed_data->getDateTime()->format('Y-m-d') == '2014-01-02', 'Date value was changed and set by date string.');
     $this->assertSame('+00:00', $typed_data->getDateTime()->getTimezone()->getName());
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getDateTime(), 'Date wrapper is null-able.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue('invalid');
-    $this->assertEqual(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
+    $this->assertEquals(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
     // Check implementation of DateTimeInterface.
     $typed_data = $this->createTypedData(['type' => 'datetime_iso8601'], '2014-01-01T20:00:00+00:00');
     $this->assertInstanceOf(DrupalDateTime::class, $typed_data->getDateTime());
     $this->assertSame('+00:00', $typed_data->getDateTime()->getTimezone()->getName());
     $typed_data->setDateTime(new DrupalDateTime('2014-01-02T20:00:00+00:00'));
     $this->assertSame('+00:00', $typed_data->getDateTime()->getTimezone()->getName());
-    $this->assertEqual('2014-01-02T20:00:00+00:00', $typed_data->getValue());
+    $this->assertEquals('2014-01-02T20:00:00+00:00', $typed_data->getValue());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getDateTime());
 
@@ -168,22 +168,22 @@ class TypedDataTest extends KernelTestBase {
     $this->assertInstanceOf(DateTimeInterface::class, $typed_data);
     $this->assertTrue($typed_data->getValue() == $value, 'Date value was fetched.');
     // @todo Uncomment this assertion in https://www.drupal.org/project/drupal/issues/2716891.
-    // $this->assertEqual($typed_data->getDateTime()->format('c'), $typed_data->getValue(), 'Value representation of a date is ISO 8601');
+    // $this->assertEquals($typed_data->getDateTime()->format('c'), $typed_data->getValue(), 'Value representation of a date is ISO 8601');
     $this->assertSame('UTC', $typed_data->getDateTime()->getTimezone()->getName());
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $new_value = '2014-01-02T20:00';
     $typed_data->setValue($new_value);
     // @todo Uncomment this assertion in https://www.drupal.org/project/drupal/issues/2716891.
     // $this->assertTrue($typed_data->getDateTime()->format('c') === $new_value, 'Date value was changed and set by an ISO8601 date.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $this->assertTrue($typed_data->getDateTime()->format('Y-m-d') == '2014-01-02', 'Date value was changed and set by date string.');
     $this->assertSame('UTC', $typed_data->getDateTime()->getTimezone()->getName());
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getDateTime(), 'Date wrapper is null-able.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue('invalid');
-    $this->assertEqual(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
+    $this->assertEquals(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
     // Check implementation of DateTimeInterface.
     $typed_data = $this->createTypedData(['type' => 'datetime_iso8601'], '2014-01-01T20:00:00');
     $this->assertInstanceOf(DrupalDateTime::class, $typed_data->getDateTime());
@@ -194,7 +194,7 @@ class TypedDataTest extends KernelTestBase {
     // to an offset. The offset for Australia/Sydney is +11:00.
     $typed_data->setDateTime(new DrupalDateTime('2014-01-02T20:00:00'));
     $this->assertSame('+11:00', $typed_data->getDateTime()->getTimezone()->getName());
-    $this->assertEqual('2014-01-02T20:00:00+11:00', $typed_data->getValue());
+    $this->assertEquals('2014-01-02T20:00:00+11:00', $typed_data->getValue());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getDateTime());
 
@@ -203,21 +203,21 @@ class TypedDataTest extends KernelTestBase {
     $typed_data = $this->createTypedData(['type' => 'timestamp'], $value);
     $this->assertInstanceOf(DateTimeInterface::class, $typed_data);
     $this->assertTrue($typed_data->getValue() == $value, 'Timestamp value was fetched.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $new_value = REQUEST_TIME + 1;
     $typed_data->setValue($new_value);
     $this->assertTrue($typed_data->getValue() === $new_value, 'Timestamp value was changed and set.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getDateTime(), 'Timestamp wrapper is null-able.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue('invalid');
-    $this->assertEqual(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
+    $this->assertEquals(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
     // Check implementation of DateTimeInterface.
     $typed_data = $this->createTypedData(['type' => 'timestamp'], REQUEST_TIME);
     $this->assertInstanceOf(DrupalDateTime::class, $typed_data->getDateTime());
     $typed_data->setDateTime(DrupalDateTime::createFromTimestamp(REQUEST_TIME + 1));
-    $this->assertEqual(REQUEST_TIME + 1, $typed_data->getValue());
+    $this->assertEquals(REQUEST_TIME + 1, $typed_data->getValue());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getDateTime());
 
@@ -226,22 +226,22 @@ class TypedDataTest extends KernelTestBase {
     $typed_data = $this->createTypedData(['type' => 'duration_iso8601'], $value);
     $this->assertInstanceOf(DurationInterface::class, $typed_data);
     $this->assertSame($value, $typed_data->getValue(), 'DurationIso8601 value was fetched.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue('P40D');
-    $this->assertEqual(40, $typed_data->getDuration()->d, 'DurationIso8601 value was changed and set by duration string.');
+    $this->assertEquals(40, $typed_data->getDuration()->d, 'DurationIso8601 value was changed and set by duration string.');
     $this->assertIsString($typed_data->getString());
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getValue(), 'DurationIso8601 wrapper is null-able.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue('invalid');
-    $this->assertEqual(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
+    $this->assertEquals(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
     // Check implementation of DurationInterface.
     $typed_data = $this->createTypedData(['type' => 'duration_iso8601'], 'PT20S');
     $this->assertInstanceOf(\DateInterval::class, $typed_data->getDuration());
     $typed_data->setDuration(new \DateInterval('P40D'));
     // @todo: Should we make this "nicer"?
-    $this->assertEqual('P0Y0M40DT0H0M0S', $typed_data->getValue());
+    $this->assertEquals('P0Y0M40DT0H0M0S', $typed_data->getValue());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getDuration());
 
@@ -250,21 +250,21 @@ class TypedDataTest extends KernelTestBase {
     $typed_data = $this->createTypedData(['type' => 'timespan'], $value);
     $this->assertInstanceOf(DurationInterface::class, $typed_data);
     $this->assertSame($value, $typed_data->getValue(), 'Time span value was fetched.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue(60 * 60 * 4);
-    $this->assertEqual(14400, $typed_data->getDuration()->s, 'Time span was changed');
+    $this->assertEquals(14400, $typed_data->getDuration()->s, 'Time span was changed');
     $this->assertIsString($typed_data->getString());
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getValue(), 'Time span wrapper is null-able.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue('invalid');
-    $this->assertEqual(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
+    $this->assertEquals(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
     // Check implementation of DurationInterface.
     $typed_data = $this->createTypedData(['type' => 'timespan'], 20);
     $this->assertInstanceOf(\DateInterval::class, $typed_data->getDuration());
     $typed_data->setDuration(new \DateInterval('PT4H'));
-    $this->assertEqual(60 * 60 * 4, $typed_data->getValue());
+    $this->assertEquals(60 * 60 * 4, $typed_data->getValue());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getDuration());
 
@@ -273,18 +273,18 @@ class TypedDataTest extends KernelTestBase {
     $typed_data = $this->createTypedData(['type' => 'uri'], $uri);
     $this->assertInstanceOf(UriInterface::class, $typed_data);
     $this->assertTrue($typed_data->getValue() === $uri, 'URI value was fetched.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue($uri . 'bar.txt');
     $this->assertTrue($typed_data->getValue() === $uri . 'bar.txt', 'URI value was changed.');
     $this->assertIsString($typed_data->getString());
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getValue(), 'URI wrapper is null-able.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue('invalid');
-    $this->assertEqual(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
+    $this->assertEquals(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
     $typed_data->setValue('public://field/image/Photo on 4-28-14 at 12.01 PM.jpg');
-    $this->assertEqual(0, $typed_data->validate()->count(), 'Filename with spaces is valid.');
+    $this->assertEquals(0, $typed_data->validate()->count(), 'Filename with spaces is valid.');
 
     // Generate some files that will be used to test the binary data type.
     $files = [];
@@ -305,33 +305,33 @@ class TypedDataTest extends KernelTestBase {
     $typed_data->setValue($new_value);
     $this->assertSame($new_value, $typed_data->getValue(), 'Email value was changed.');
     $this->assertIsString($typed_data->getString());
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getValue(), 'Email wrapper is null-able.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue('invalidATexample.com');
-    $this->assertEqual(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
+    $this->assertEquals(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
 
     // Binary type.
     $typed_data = $this->createTypedData(['type' => 'binary'], $files[0]->getFileUri());
     $this->assertInstanceOf(BinaryInterface::class, $typed_data);
     $this->assertIsResource($typed_data->getValue());
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     // Try setting by URI.
     $typed_data->setValue($files[1]->getFileUri());
-    $this->assertEqual(fgets(fopen($files[1]->getFileUri(), 'r')), fgets($typed_data->getValue()), 'Binary value was changed.');
+    $this->assertEquals(fgets(fopen($files[1]->getFileUri(), 'r')), fgets($typed_data->getValue()), 'Binary value was changed.');
     $this->assertIsString($typed_data->getString());
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     // Try setting by resource.
     $typed_data->setValue(fopen($files[2]->getFileUri(), 'r'));
-    $this->assertEqual(fgets($typed_data->getValue()), fgets(fopen($files[2]->getFileUri(), 'r')), 'Binary value was changed.');
+    $this->assertEquals(fgets($typed_data->getValue()), fgets(fopen($files[2]->getFileUri(), 'r')), 'Binary value was changed.');
     $this->assertIsString($typed_data->getString());
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getValue(), 'Binary wrapper is null-able.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue('invalid');
-    $this->assertEqual(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
+    $this->assertEquals(1, $typed_data->validate()->count(), 'Validation detected invalid value.');
 
     // Any type.
     $value = ['foo'];
@@ -341,16 +341,16 @@ class TypedDataTest extends KernelTestBase {
     $typed_data->setValue($new_value);
     $this->assertSame($new_value, $typed_data->getValue(), 'Any value was changed.');
     $this->assertIsString($typed_data->getString());
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue(NULL);
     $this->assertNull($typed_data->getValue(), 'Any wrapper is null-able.');
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     // We cannot test invalid values as everything is valid for the any type,
     // but make sure an array or object value passes validation also.
     $typed_data->setValue(['entry']);
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
     $typed_data->setValue((object) ['entry']);
-    $this->assertEqual(0, $typed_data->validate()->count());
+    $this->assertEquals(0, $typed_data->validate()->count());
   }
 
   /**
@@ -360,25 +360,25 @@ class TypedDataTest extends KernelTestBase {
     // Test working with an existing list of strings.
     $value = ['one', 'two', 'three'];
     $typed_data = $this->createTypedData(ListDataDefinition::create('string'), $value);
-    $this->assertEqual($value, $typed_data->getValue(), 'List value has been set.');
+    $this->assertEquals($value, $typed_data->getValue(), 'List value has been set.');
     // Test iterating.
     $count = 0;
     foreach ($typed_data as $item) {
       $this->assertInstanceOf(TypedDataInterface::class, $item);
       $count++;
     }
-    $this->assertEqual(3, $count);
+    $this->assertEquals(3, $count);
 
     // Test getting the string representation.
-    $this->assertEqual('one, two, three', $typed_data->getString());
+    $this->assertEquals('one, two, three', $typed_data->getString());
     $typed_data[1] = '';
-    $this->assertEqual('one, three', $typed_data->getString());
+    $this->assertEquals('one, three', $typed_data->getString());
 
     // Test using array access.
-    $this->assertEqual('one', $typed_data[0]->getValue());
+    $this->assertEquals('one', $typed_data[0]->getValue());
     $typed_data[] = 'four';
-    $this->assertEqual('four', $typed_data[3]->getValue());
-    $this->assertEqual(4, $typed_data->count());
+    $this->assertEquals('four', $typed_data[3]->getValue());
+    $this->assertEquals(4, $typed_data->count());
     $this->assertTrue(isset($typed_data[0]));
     $this->assertTrue(!isset($typed_data[6]));
 
@@ -407,12 +407,12 @@ class TypedDataTest extends KernelTestBase {
     $this->assertFalse($typed_data->isEmpty());
     $this->assertCount(3, $typed_data);
 
-    $this->assertEqual([NULL, '', 'three'], $typed_data->getValue());
+    $this->assertEquals([NULL, '', 'three'], $typed_data->getValue());
     // Test unsetting.
     unset($typed_data[1]);
     $this->assertCount(2, $typed_data);
     // Check that items were shifted.
-    $this->assertEqual('three', $typed_data[1]->getValue());
+    $this->assertEquals('three', $typed_data[1]->getValue());
 
     // Getting a not set list item returns NULL, and does not create a new item.
     $this->assertNull($typed_data[2]);
@@ -420,7 +420,7 @@ class TypedDataTest extends KernelTestBase {
 
     // Test setting the list with less values.
     $typed_data->setValue(['one']);
-    $this->assertEqual(1, $typed_data->count());
+    $this->assertEquals(1, $typed_data->count());
 
     // Test setting invalid values.
     try {
@@ -442,11 +442,11 @@ class TypedDataTest extends KernelTestBase {
     $typed_data->filter(function (TypedDataInterface $item) {
       return TRUE;
     });
-    $this->assertEqual(2, $typed_data->count());
-    $this->assertEqual('zero', $typed_data[0]->getValue());
-    $this->assertEqual(0, $typed_data[0]->getName());
-    $this->assertEqual('one', $typed_data[1]->getValue());
-    $this->assertEqual(1, $typed_data[1]->getName());
+    $this->assertEquals(2, $typed_data->count());
+    $this->assertEquals('zero', $typed_data[0]->getValue());
+    $this->assertEquals(0, $typed_data[0]->getName());
+    $this->assertEquals('one', $typed_data[1]->getValue());
+    $this->assertEquals(1, $typed_data[1]->getName());
 
     // Check that a none-pass filter empties the list.
     $value = ['zero', 'one'];
@@ -454,7 +454,7 @@ class TypedDataTest extends KernelTestBase {
     $typed_data->filter(function (TypedDataInterface $item) {
       return FALSE;
     });
-    $this->assertEqual(0, $typed_data->count());
+    $this->assertEquals(0, $typed_data->count());
 
     // Check that filtering correctly renumbers elements.
     $value = ['zero', 'one', 'two'];
@@ -462,11 +462,11 @@ class TypedDataTest extends KernelTestBase {
     $typed_data->filter(function (TypedDataInterface $item) {
       return $item->getValue() !== 'one';
     });
-    $this->assertEqual(2, $typed_data->count());
-    $this->assertEqual('zero', $typed_data[0]->getValue());
-    $this->assertEqual(0, $typed_data[0]->getName());
-    $this->assertEqual('two', $typed_data[1]->getValue());
-    $this->assertEqual(1, $typed_data[1]->getName());
+    $this->assertEquals(2, $typed_data->count());
+    $this->assertEquals('zero', $typed_data[0]->getValue());
+    $this->assertEquals(0, $typed_data[0]->getName());
+    $this->assertEquals('two', $typed_data[1]->getValue());
+    $this->assertEquals(1, $typed_data[1]->getName());
   }
 
   /**
@@ -492,36 +492,36 @@ class TypedDataTest extends KernelTestBase {
       $this->assertInstanceOf(TypedDataInterface::class, $item);
       $count++;
     }
-    $this->assertEqual(3, $count);
+    $this->assertEquals(3, $count);
 
     // Test retrieving metadata.
-    $this->assertEqual(array_keys($value), array_keys($typed_data->getDataDefinition()->getPropertyDefinitions()));
+    $this->assertEquals(array_keys($value), array_keys($typed_data->getDataDefinition()->getPropertyDefinitions()));
     $definition = $typed_data->getDataDefinition()->getPropertyDefinition('one');
-    $this->assertEqual('string', $definition->getDataType());
+    $this->assertEquals('string', $definition->getDataType());
     $this->assertNull($typed_data->getDataDefinition()->getPropertyDefinition('invalid'));
 
     // Test getting and setting properties.
-    $this->assertEqual('eins', $typed_data->get('one')->getValue());
-    $this->assertEqual($value, $typed_data->toArray());
+    $this->assertEquals('eins', $typed_data->get('one')->getValue());
+    $this->assertEquals($value, $typed_data->toArray());
     $typed_data->set('one', 'uno');
-    $this->assertEqual('uno', $typed_data->get('one')->getValue());
+    $this->assertEquals('uno', $typed_data->get('one')->getValue());
     // Make sure the update is reflected in the value of the map also.
     $value = $typed_data->getValue();
-    $this->assertEqual(['one' => 'uno', 'two' => 'zwei', 'three' => 'drei'], $value);
+    $this->assertEquals(['one' => 'uno', 'two' => 'zwei', 'three' => 'drei'], $value);
 
     $properties = $typed_data->getProperties();
-    $this->assertEqual(array_keys($value), array_keys($properties));
+    $this->assertEquals(array_keys($value), array_keys($properties));
     $this->assertSame($typed_data->get('one'), $properties['one'], 'Properties are identical.');
 
     // Test setting a not defined property. It shouldn't show up in the
     // properties, but be kept in the values.
     $typed_data->setValue(['foo' => 'bar']);
-    $this->assertEqual(['one', 'two', 'three'], array_keys($typed_data->getProperties()));
-    $this->assertEqual(['foo', 'one', 'two', 'three'], array_keys($typed_data->getValue()));
+    $this->assertEquals(['one', 'two', 'three'], array_keys($typed_data->getProperties()));
+    $this->assertEquals(['foo', 'one', 'two', 'three'], array_keys($typed_data->getValue()));
 
     // Test getting the string representation.
     $typed_data->setValue(['one' => 'eins', 'two' => '', 'three' => 'drei']);
-    $this->assertEqual('eins, drei', $typed_data->getString());
+    $this->assertEquals('eins, drei', $typed_data->getString());
 
     // Test isEmpty and cloning.
     $this->assertFalse($typed_data->isEmpty());
@@ -561,9 +561,9 @@ class TypedDataTest extends KernelTestBase {
     // Test adding a new property to the map.
     $typed_data->getDataDefinition()->setPropertyDefinition('zero', DataDefinition::create('any'));
     $typed_data->set('zero', 'null');
-    $this->assertEqual('null', $typed_data->get('zero')->getValue());
+    $this->assertEquals('null', $typed_data->get('zero')->getValue());
     $definition = $typed_data->get('zero')->getDataDefinition();
-    $this->assertEqual('any', $definition->getDataType(), 'Definition for a new map entry returned.');
+    $this->assertEquals('any', $definition->getDataType(), 'Definition for a new map entry returned.');
   }
 
   /**
@@ -575,16 +575,16 @@ class TypedDataTest extends KernelTestBase {
         'Range' => ['min' => 5],
       ]);
     $violations = $this->typedDataManager->create($definition, 10)->validate();
-    $this->assertEqual(0, $violations->count());
+    $this->assertEquals(0, $violations->count());
 
     $integer = $this->typedDataManager->create($definition, 1);
     $violations = $integer->validate();
-    $this->assertEqual(1, $violations->count());
+    $this->assertEquals(1, $violations->count());
 
     // Test translating violation messages.
     $message = t('This value should be %limit or more.', ['%limit' => 5]);
-    $this->assertEqual($message, $violations[0]->getMessage(), 'Translated violation message retrieved.');
-    $this->assertEqual('', $violations[0]->getPropertyPath());
+    $this->assertEquals($message, $violations[0]->getMessage(), 'Translated violation message retrieved.');
+    $this->assertEquals('', $violations[0]->getPropertyPath());
     $this->assertSame($integer, $violations[0]->getRoot(), 'Root object returned.');
 
     // Test translating violation messages when pluralization is used.
@@ -593,9 +593,9 @@ class TypedDataTest extends KernelTestBase {
         'Length' => ['min' => 10, 'allowEmptyString' => FALSE],
       ]);
     $violations = $this->typedDataManager->create($definition, "short")->validate();
-    $this->assertEqual(1, $violations->count());
+    $this->assertEquals(1, $violations->count());
     $message = t('This value is too short. It should have %limit characters or more.', ['%limit' => 10]);
-    $this->assertEqual($message, $violations[0]->getMessage(), 'Translated violation message retrieved.');
+    $this->assertEquals($message, $violations[0]->getMessage(), 'Translated violation message retrieved.');
 
     // Test having multiple violations.
     $definition = DataDefinition::create('integer')
@@ -604,9 +604,9 @@ class TypedDataTest extends KernelTestBase {
         'Null' => [],
       ]);
     $violations = $this->typedDataManager->create($definition, 10)->validate();
-    $this->assertEqual(1, $violations->count());
+    $this->assertEquals(1, $violations->count());
     $violations = $this->typedDataManager->create($definition, 1)->validate();
-    $this->assertEqual(2, $violations->count());
+    $this->assertEquals(2, $violations->count());
 
     // Test validating property containers and make sure the NotNull and Null
     // constraints work with typed data containers.
@@ -614,27 +614,27 @@ class TypedDataTest extends KernelTestBase {
       ->setConstraints(['NotNull' => []]);
     $field_item = $this->typedDataManager->create($definition, ['value' => 10]);
     $violations = $field_item->validate();
-    $this->assertEqual(0, $violations->count());
+    $this->assertEquals(0, $violations->count());
 
     $field_item = $this->typedDataManager->create($definition, ['value' => 'no integer']);
     $violations = $field_item->validate();
-    $this->assertEqual(1, $violations->count());
-    $this->assertEqual('0.value', $violations[0]->getPropertyPath());
+    $this->assertEquals(1, $violations->count());
+    $this->assertEquals('0.value', $violations[0]->getPropertyPath());
 
     // Test that the field item may not be empty.
     $field_item = $this->typedDataManager->create($definition);
     $violations = $field_item->validate();
-    $this->assertEqual(1, $violations->count());
+    $this->assertEquals(1, $violations->count());
 
     // Test the Null constraint with typed data containers.
     $definition = BaseFieldDefinition::create('float')
       ->setConstraints(['Null' => []]);
     $field_item = $this->typedDataManager->create($definition, ['value' => 11.5]);
     $violations = $field_item->validate();
-    $this->assertEqual(1, $violations->count());
+    $this->assertEquals(1, $violations->count());
     $field_item = $this->typedDataManager->create($definition);
     $violations = $field_item->validate();
-    $this->assertEqual(0, $violations->count());
+    $this->assertEquals(0, $violations->count());
 
     // Test getting constraint definitions by type.
     $definitions = $this->typedDataManager->getValidationConstraintManager()->getDefinitionsByType('entity');
@@ -651,19 +651,19 @@ class TypedDataTest extends KernelTestBase {
     $definition = DataDefinition::create('integer')
       ->setRequired(TRUE);
     $violations = $this->typedDataManager->create($definition)->validate();
-    $this->assertEqual(1, $violations->count());
+    $this->assertEquals(1, $violations->count());
     $violations = $this->typedDataManager->create($definition, 0)->validate();
-    $this->assertEqual(0, $violations->count());
+    $this->assertEquals(0, $violations->count());
 
     // Test validating a list of a values and make sure property paths starting
     // with "0" are created.
     $definition = BaseFieldDefinition::create('integer');
     $violations = $this->typedDataManager->create($definition, [['value' => 10]])->validate();
-    $this->assertEqual(0, $violations->count());
+    $this->assertEquals(0, $violations->count());
     $violations = $this->typedDataManager->create($definition, [['value' => 'string']])->validate();
-    $this->assertEqual(1, $violations->count());
+    $this->assertEquals(1, $violations->count());
 
-    $this->assertEqual('string', $violations[0]->getInvalidValue());
+    $this->assertEquals('string', $violations[0]->getInvalidValue());
     $this->assertSame('0.value', $violations[0]->getPropertyPath());
   }
 
