@@ -42,6 +42,7 @@ class ConditionTest extends UnitTestCase {
       return preg_replace('/[^A-Za-z0-9_.]+/', '', $args[0]);
     });
     $connection->mapConditionOperator('=')->willReturn(['operator' => '=']);
+    $connection->condition('AND')->willReturn(new Condition('AND', FALSE));
     $connection = $connection->reveal();
 
     $query_placeholder = $this->prophesize(PlaceholderInterface::class);
@@ -53,7 +54,7 @@ class ConditionTest extends UnitTestCase {
     $query_placeholder->uniqueIdentifier()->willReturn(4);
     $query_placeholder = $query_placeholder->reveal();
 
-    $condition = new Condition('AND');
+    $condition = $connection->condition('AND');
     $condition->condition($field_name, ['value']);
     $condition->compile($connection, $query_placeholder);
 
@@ -83,6 +84,7 @@ class ConditionTest extends UnitTestCase {
       return preg_replace('/[^A-Za-z0-9_.]+/', '', $args[0]);
     });
     $connection->mapConditionOperator(Argument::any())->willReturn(NULL);
+    $connection->condition('AND')->willReturn(new Condition('AND', FALSE));
     $connection = $connection->reveal();
 
     $query_placeholder = $this->prophesize(PlaceholderInterface::class);
@@ -94,7 +96,7 @@ class ConditionTest extends UnitTestCase {
     $query_placeholder->uniqueIdentifier()->willReturn(4);
     $query_placeholder = $query_placeholder->reveal();
 
-    $condition = new Condition('AND');
+    $condition = $connection->condition('AND');
     $condition->condition($field, $value, $operator);
     $condition->compile($connection, $query_placeholder);
 
@@ -151,6 +153,7 @@ class ConditionTest extends UnitTestCase {
       return preg_replace('/[^A-Za-z0-9_.]+/', '', $args[0]);
     });
     $connection->mapConditionOperator(Argument::any())->willReturn(NULL);
+    $connection->condition('AND')->willReturn(new Condition('AND', FALSE));
     $connection = $connection->reveal();
 
     $query_placeholder = $this->prophesize(PlaceholderInterface::class);
@@ -162,7 +165,7 @@ class ConditionTest extends UnitTestCase {
     $query_placeholder->uniqueIdentifier()->willReturn(4);
     $query_placeholder = $query_placeholder->reveal();
 
-    $condition = new Condition('AND');
+    $condition = $connection->condition('AND');
     $condition->condition('name', 'value', $operator);
     $this->expectException(Error::class);
     $condition->compile($connection, $query_placeholder);
@@ -187,7 +190,7 @@ class ConditionTest extends UnitTestCase {
       ->setConstructorArgs([NULL])
       ->disableOriginalConstructor()
       ->getMock();
-    $contrib_namespace = 'Drupal\Driver\Database\mock';
+    $contrib_namespace = 'Drupal\mock\Driver\Database\mock';
     $mocked_namespace = $contrib_namespace . '\\Condition';
     class_alias('MockCondition', $mocked_namespace);
 
@@ -201,4 +204,15 @@ class ConditionTest extends UnitTestCase {
     $this->assertSame('MockCondition', get_class($condition));
   }
 
+  /**
+   * Tests the deprecation of the class Condition.
+   *
+   * @group legacy
+   */
+  public function testConditionClassDeprecation() {
+    $this->expectDeprecation('Creating an instance of this class is deprecated in drupal:9.1.0 and is removed in drupal:10.0.0. Use Database::getConnection()->condition() instead. See https://www.drupal.org/node/3159568');
+    $condition = new Condition('OR');
+    $this->assertSame('Drupal\Core\Database\Query\Condition', get_class($condition));
+  }
+
 }
