@@ -17,7 +17,6 @@ use Drupal\Core\Url;
 trait UiHelperTrait {
 
   use BrowserHtmlDebugTrait;
-  use AssertHelperTrait;
   use RefreshVariablesTrait;
 
   /**
@@ -108,7 +107,7 @@ trait UiHelperTrait {
       $this->metaRefreshCount = 0;
     }
 
-    // Log only for JavascriptTestBase tests because for Goutte we log with
+    // Log only for WebDriverTestBase tests because for Goutte we log with
     // ::getResponseLogHandler.
     if ($this->htmlOutputEnabled && !($this->getSession()->getDriver() instanceof GoutteDriver)) {
       $out = $this->getSession()->getPage()->getContent();
@@ -134,11 +133,12 @@ trait UiHelperTrait {
    *   @code
    *   // First step in form.
    *   $edit = array(...);
-   *   $this->drupalPostForm('some_url', $edit, 'Save');
+   *   $this->drupalGet('some_url');
+   *   $this->submitForm($edit, 'Save');
    *
    *   // Second step in form.
    *   $edit = array(...);
-   *   $this->drupalPostForm(NULL, $edit, 'Save');
+   *   $this->submitForm($edit, 'Save');
    *   @endcode
    * @param array $edit
    *   Field data in an associative array. Changes the current input fields
@@ -164,8 +164,6 @@ trait UiHelperTrait {
    *   $edit = array();
    *   $edit['name[]'] = array('value1', 'value2');
    *   @endcode
-   *   @todo change $edit to disallow NULL as a value for Drupal 9.
-   *     https://www.drupal.org/node/2802401
    * @param string $submit
    *   The id, name, label or value of the submit button which is to be clicked.
    *   For example, 'Save'. The first element matched by
@@ -189,17 +187,24 @@ trait UiHelperTrait {
    *   just use the webAssert object for your assertions.
    *
    * @see \Drupal\Tests\WebAssert::buttonExists()
+   *
+   * @deprecated in drupal:9.1.0 and is removed from drupal:10.0.0. Use
+   *   $this->submitForm() instead.
+   *
+   * @see https://www.drupal.org/node/3168858
    */
   protected function drupalPostForm($path, $edit, $submit, array $options = [], $form_html_id = NULL) {
+    @trigger_error('UiHelperTrait::drupalPostForm() is deprecated in drupal:9.1.0 and is removed from drupal:10.0.0. Use $this->submitForm() instead. See https://www.drupal.org/node/3168858', E_USER_DEPRECATED);
     if (is_object($submit)) {
       // Cast MarkupInterface objects to string.
       $submit = (string) $submit;
     }
     if ($edit === NULL) {
+      @trigger_error('Calling ' . __METHOD__ . '() with $edit set to NULL is deprecated in drupal:9.1.0 and the method is removed in drupal:10.0.0. Use $this->submitForm() instead. See https://www.drupal.org/node/3168858', E_USER_DEPRECATED);
       $edit = [];
     }
-    if (is_array($edit)) {
-      $edit = $this->castSafeStrings($edit);
+    if ($path === NULL) {
+      @trigger_error('Calling ' . __METHOD__ . '() with $path set to NULL is deprecated in drupal:9.2.0 and the method is removed in drupal:10.0.0. Use $this->submitForm() instead. See https://www.drupal.org/node/3168858', E_USER_DEPRECATED);
     }
 
     if (isset($path)) {
@@ -267,7 +272,8 @@ trait UiHelperTrait {
     // idea being if you were properly logged out you should be seeing a login
     // screen.
     $assert_session = $this->assertSession();
-    $this->drupalGet(Url::fromRoute('user.logout', [], ['query' => ['destination' => 'user']]));
+    $destination = Url::fromRoute('user.page')->toString();
+    $this->drupalGet(Url::fromRoute('user.logout', [], ['query' => ['destination' => $destination]]));
     $assert_session->fieldExists('name');
     $assert_session->fieldExists('pass');
 
@@ -336,7 +342,7 @@ trait UiHelperTrait {
       $this->metaRefreshCount = 0;
     }
 
-    // Log only for JavascriptTestBase tests because for Goutte we log with
+    // Log only for WebDriverTestBase tests because for Goutte we log with
     // ::getResponseLogHandler.
     if ($this->htmlOutputEnabled && !($this->getSession()->getDriver() instanceof GoutteDriver)) {
       $html_output = 'GET request to: ' . $url .
@@ -350,7 +356,7 @@ trait UiHelperTrait {
   }
 
   /**
-   * Builds an a absolute URL from a system path or a URL object.
+   * Builds an absolute URL from a system path or a URL object.
    *
    * @param string|\Drupal\Core\Url $path
    *   A system path or a URL.
@@ -462,7 +468,7 @@ trait UiHelperTrait {
   protected function click($css_selector) {
     $starting_url = $this->getSession()->getCurrentUrl();
     $this->getSession()->getDriver()->click($this->cssSelectToXpath($css_selector));
-    // Log only for JavascriptTestBase tests because for Goutte we log with
+    // Log only for WebDriverTestBase tests because for Goutte we log with
     // ::getResponseLogHandler.
     if ($this->htmlOutputEnabled && !($this->getSession()->getDriver() instanceof GoutteDriver)) {
       $out = $this->getSession()->getPage()->getContent();
@@ -527,7 +533,7 @@ trait UiHelperTrait {
     if (!empty($refresh) && (!isset($this->maximumMetaRefreshCount) || $this->metaRefreshCount < $this->maximumMetaRefreshCount)) {
       // Parse the content attribute of the meta tag for the format:
       // "[delay]: URL=[page_to_redirect_to]".
-      if (preg_match('/\d+;\s*URL=(?<url>.*)/i', $refresh[0]->getAttribute('content'), $match)) {
+      if (preg_match('/\d+;\s*URL=\'?(?<url>[^\']*)/i', $refresh[0]->getAttribute('content'), $match)) {
         $this->metaRefreshCount++;
         return $this->drupalGet($this->getAbsoluteUrl(Html::decodeEntities($match['url'])));
       }
